OC.L10N.register(
    "dav",
    {
    "Calendar" : "日历",
    "Tasks" : "任务",
    "Personal" : "个人",
    "{actor} created calendar {calendar}" : "{actor} 创建了日历 {calendar}",
    "You created calendar {calendar}" : "您创建的日历 {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} 删除了日历 {calendar}",
    "You deleted calendar {calendar}" : "您删除的日历 {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} 更新了日历 {calendar}",
    "You updated calendar {calendar}" : "您更新了日历 {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} 还原了日历 {calendar}",
    "You restored calendar {calendar}" : "你还原了日历 {calendar}",
    "You shared calendar {calendar} as public link" : "您已将日历 {calendar} 共享为公开链接",
    "You removed public link for calendar {calendar}" : "您移除了日历 {calendar} 的公开链接",
    "{actor} shared calendar {calendar} with you" : "{actor} 收到的日历共享 {calendar}",
    "You shared calendar {calendar} with {user}" : "您与 {user} 共享了日历 {calendar}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} 与 {user} 共享了日历 {calendar}",
    "{actor} unshared calendar {calendar} from you" : "你取消了 {actor} 共享的日历 {calendar}",
    "You unshared calendar {calendar} from {user}" : "{user} 取消了你共享的日历 {calendar}",
    "{actor} unshared calendar {calendar} from {user}" : "{user} 取消了 {actor} 共享的日历 {calendar}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} 取消了他们自己共享的日历 {calendar}",
    "You shared calendar {calendar} with group {group}" : "您通过组 {group} 共享了日历 {calendar}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} 通过组 {group} 共享了日历 {calendar}",
    "You unshared calendar {calendar} from group {group}" : "群组 {group} 取消了你共享的日历 {calendar}",
    "{actor} unshared calendar {calendar} from group {group}" : "群组 {group} 取消了 {actor} 共享的日历 {calendar}",
    "Untitled event" : "未命名事件",
    "{actor} created event {event} in calendar {calendar}" : "{actor} 在日历 {calendar} 中创建了事件 {event}",
    "You created event {event} in calendar {calendar}" : "您在日历 {calendar} 中创建了事件 {event}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} 在日历 {calendar} 中删除了事件 {event}",
    "You deleted event {event} from calendar {calendar}" : "您在日历 {calendar} 中删除了事件 {event}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} 在日历 {calendar} 中更新了事件 {event}",
    "You updated event {event} in calendar {calendar}" : "您在日历 {calendar} 中更新了事件 {event}",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} 将事件 {event} 从日历 {sourceCalendar} 移动至日历 {targetCalendar}",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "您已将事件 {event} 从日历 {sourceCalendar} 移动至日历 {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} 还原了事件 {event}，它位于日历 {calendar}",
    "You restored event {event} of calendar {calendar}" : "你还原了事件 {event}，它位于日历 {calendar}",
    "Busy" : "忙碌",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} 在清单 {calendar} 中创建了待办事项 {todo}",
    "You created to-do {todo} in list {calendar}" : "您已在清单 {calendar} 中创建了待办事项 {todo}",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} 从列表 {calendar} 中删除了待办事项 {todo}",
    "You deleted to-do {todo} from list {calendar}" : "你从列表 {calendar} 中删除了待办事项 {todo}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} 更新了列表 {calendar} 中的待办事项 {todo}",
    "You updated to-do {todo} in list {calendar}" : "你更新了列表 {calendar} 中的待办事项 {todo}",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} 解决了列表 {calendar} 中的待办事项 {todo}",
    "You solved to-do {todo} in list {calendar}" : "你解决了列表 {calendar} 中的待办事项 {todo}",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} 重新开启了列表 {calendar} 中的待办事项 {todo}",
    "You reopened to-do {todo} in list {calendar}" : "你重新开启了列表 {calendar} 中的待办事项 {todo}",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} 将待办事项 {todo} 从列表 {sourceCalendar} 移动到列表 {targetCalendar}",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "你将待办事项 {todo} 从列表 {sourceCalendar} 移动到列表 {targetCalendar}",
    "Calendar, contacts and tasks" : "日历、联系人和任务",
    "A <strong>calendar</strong> was modified" : "<strong>日历</strong>已经修改",
    "A calendar <strong>event</strong> was modified" : "日历中<strong>事件</strong>已经修改",
    "A calendar <strong>to-do</strong> was modified" : "日历中的<strong>待办事项</strong>已修改",
    "Contact birthdays" : "联系人生日",
    "Death of %s" : "%s 的忌日",
    "Untitled calendar" : "未命名的日历",
    "Calendar:" : "日历：",
    "Date:" : "日期：",
    "Where:" : "地点：",
    "Description:" : "描述：",
    "_%n year_::_%n years_" : ["%n 年"],
    "_%n month_::_%n months_" : ["%n 月"],
    "_%n day_::_%n days_" : ["%n 天"],
    "_%n hour_::_%n hours_" : ["%n 小时"],
    "_%n minute_::_%n minutes_" : ["%n 分钟"],
    "%s (in %s)" : "%s（在 %s）",
    "%s (%s ago)" : "%s（%s 前）",
    "Calendar: %s" : "日历：%s",
    "Date: %s" : "日期：%s",
    "Description: %s" : "描述：%s",
    "Where: %s" : "地点：%s",
    "%1$s via %2$s" : "%1$s 通过 %2$s",
    "In the past on %1$s for the entire day" : "过去全天 %1$s ",
    "_In a minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["在 %n 分钟后全天 %1$s"],
    "_In a hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["在 %n 小时后全天 %1$s"],
    "_In a day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["在 %n 天后全天 %1$s"],
    "_In a week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["在 %n 周后全天 %1$s"],
    "_In a month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["在 %n 个月后全天 %1$s"],
    "_In a year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["在 %n 年后全天 %1$s"],
    "In the past on %1$s between %2$s - %3$s" : "过去  %2$s - %3$s %1$s",
    "_In a minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["在 %2$s - %3$s %n 分钟后 %1$s"],
    "_In a hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["在 %2$s - %3$s %n 小时后 %1$s"],
    "_In a day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["在 %2$s - %3$s %n 天后 %1$s"],
    "_In a week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["在 %2$s - %3$s %n 周后 %1$s"],
    "_In a month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["在 %2$s - %3$s %n 个月后 %1$s"],
    "_In a year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["在 %2$s - %3$s %n 年后 %1$s"],
    "Could not generate when statement" : "无法生成 when 语句",
    "Every Day for the entire day" : "每天全天",
    "Every Day for the entire day until %1$s" : "每天全天，直到 %1$s",
    "Every Day between %1$s - %2$s" : "在 %1$s - %2$s 每天",
    "Every Day between %1$s - %2$s until %3$s" : "在 %1$s - %2$s 每天，直到 %3$s",
    "Every %1$d Days for the entire day" : "每 %1$d 天全天",
    "Every %1$d Days for the entire day until %2$s" : "每 %1$d 天全天，直到 %2$s",
    "Every %1$d Days between %2$s - %3$s" : "在 %2$s - %3$s 每 %1$d 天",
    "Every %1$d Days between %2$s - %3$s until %4$s" : "在 %2$s - %3$s 每 %1$d 天，直到 %4$s",
    "Could not generate event recurrence statement" : "无法生成事件重复语句",
    "Every Week on %1$s for the entire day" : "每周全天 %1$s",
    "Every Week on %1$s for the entire day until %2$s" : "每周全天 %1$s，直到 %2$s",
    "Every Week on %1$s between %2$s - %3$s" : "在 %2$s - %3$s 每周 %1$s",
    "Every Week on %1$s between %2$s - %3$s until %4$s" : "在 %2$s - %3$s 每周 %1$s，直到 %4$s",
    "Every %1$d Weeks on %2$s for the entire day" : "每 %1$d 周全天 %2$s",
    "Every %1$d Weeks on %2$s for the entire day until %3$s" : "每 %1$d 周全天 %2$s，直到 %3$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s" : "在 %3$s - %4$s 每 %1$d 周 %2$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s until %5$s" : "在 %3$s - %4$s 每 %1$d 周 %2$s，直到 %5$s",
    "Every Month on the %1$s for the entire day" : "每个月全天 %1$s",
    "Every Month on the %1$s for the entire day until %2$s" : "每个月全天 %1$s，直到 %2$s",
    "Every Month on the %1$s between %2$s - %3$s" : "在 %2$s - %3$s 每个月 %1$s",
    "Every Month on the %1$s between %2$s - %3$s until %4$s" : "在 %2$s - %3$s 每个月 %1$s，直到 %4$s",
    "Every %1$d Months on the %2$s for the entire day" : "每 %1$d 个月全天 %2$s",
    "Every %1$d Months on the %2$s for the entire day until %3$s" : "每 %1$d 个月全天 %2$s，直到 %3$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s" : "在 %3$s - %4$s 每 %1$d 个月 %2$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s until %5$s" : "在 %3$s - %4$s 每 %1$d 个月 %2$s，直到 %5$s",
    "Every Year in %1$s on the %2$s for the entire day" : "每年 %1$s 全天 %2$s",
    "Every Year in %1$s on the %2$s for the entire day until %3$s" : "每年 %1$s 全天 %2$s，直到 %3$s ",
    "Every Year in %1$s on the %2$s between %3$s - %4$s" : "在 %3$s - %4$s 每年 %1$s %2$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s until %5$s" : "在 %3$s - %4$s 每年 %1$s %2$s，直到 %5$s",
    "Every %1$d Years in %2$s on the %3$s for the entire day" : "每 %1$d 年 %2$s 全天 %3$s",
    "Every %1$d Years in %2$s on the %3$s for the entire day until %4$s" : "每 %1$d 年 %2$s 全天 %3$s，直到 %4$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s" : "在 %4$s - %5$s 每 %1$d 年 %2$s %3$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "在 %4$s - %5$s 每 %1$d 年 %2$s %3$s，直到 %6$s",
    "On specific dates for the entire day until %1$s" : "在特定日期全天，直到 %1$s",
    "On specific dates between %1$s - %2$s until %3$s" : "在 %1$s - %2$s 特定日期，直到 %3$s",
    "In the past on %1$s" : "在过去 %1$s",
    "_In a minute on %1$s_::_In %n minutes on %1$s_" : ["%n 分钟后 %1$s"],
    "_In a hour on %1$s_::_In %n hours on %1$s_" : ["%n 小时后 %1$s"],
    "_In a day on %1$s_::_In %n days on %1$s_" : ["%n 天后 %1$s"],
    "_In a week on %1$s_::_In %n weeks on %1$s_" : ["%n 周后 %1$s"],
    "_In a month on %1$s_::_In %n months on %1$s_" : ["%n 个月后 %1$s"],
    "_In a year on %1$s_::_In %n years on %1$s_" : ["%n 年后 %1$s"],
    "In the past on %1$s then on %2$s" : "过去 %1$s，然后 %2$s",
    "_In a minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["%n 分钟后 %1$s，然后 %2$s"],
    "_In a hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["%n 小时后 %1$s，然后 %2$s"],
    "_In a day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["%n 天后 %1$s，然后 %2$s"],
    "_In a week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["%n 周后 %1$s，然后 %2$s"],
    "_In a month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["%n 个月后 %1$s，然后 %2$s"],
    "_In a year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["%n 年后 %1$s，然后 %2$s"],
    "In the past on %1$s then on %2$s and %3$s" : "在过去 %1$s，然后 %2$s 和 %3$s",
    "_In a minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["%n 分钟后 %1$s，然后 %2$s 和 %3$s"],
    "_In a hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["%n 小时后 %1$s，然后 %2$s 和 %3$s"],
    "_In a day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["%n 天后 %1$s，然后 %2$s 和 %3$s"],
    "_In a week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["%n 周后 %1$s，然后 %2$s 和 %3$s"],
    "_In a month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["%n 个月后 %1$s，然后 %2$s 和 %3$s"],
    "_In a year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["%n 年后 %1$s，然后 %2$s 和 %3$s"],
    "Could not generate next recurrence statement" : "无法生成下一个重复语句",
    "Cancelled: %1$s" : "已取消：%1$s",
    "\"%1$s\" has been canceled" : "“%1$s”已取消",
    "Re: %1$s" : "回复：%1$s",
    "%1$s has accepted your invitation" : "%1$s 已接受您的邀请",
    "%1$s has tentatively accepted your invitation" : "%1$s 暂时接受了您的邀请",
    "%1$s has declined your invitation" : "%1$s 已拒绝了您的邀请",
    "%1$s has responded to your invitation" : "%1$s 已回应了您的邀请",
    "Invitation updated: %1$s" : "邀请已更新：%1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s 已更新事件“%2$s”",
    "Invitation: %1$s" : "邀请：%1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s 想邀请您加入“%2$s”",
    "Organizer:" : "组织者：",
    "Attendees:" : "参加者：",
    "Title:" : "标题：",
    "When:" : "时间：",
    "Location:" : "地区：",
    "Link:" : "链接：",
    "Occurring:" : "发生：",
    "Accept" : "接受",
    "Decline" : "拒绝",
    "More options …" : "更多选项",
    "More options at %s" : "在%s的更多选项",
    "Monday" : "周一",
    "Tuesday" : "周二",
    "Wednesday" : "周三",
    "Thursday" : "周四",
    "Friday" : "周五",
    "Saturday" : "周六",
    "Sunday" : "周日",
    "January" : "一月",
    "February" : "二月",
    "March" : "三月",
    "April" : "四月",
    "May" : "五月",
    "June" : "六月",
    "July" : "七月",
    "August" : "八月",
    "September" : "九月",
    "October" : "十月",
    "November" : "十一月",
    "December" : "十二月",
    "First" : "第一",
    "Second" : "第二",
    "Third" : "第三",
    "Fourth" : "第四",
    "Fifth" : "第五",
    "Last" : "最后一个",
    "Second Last" : "倒数第二",
    "Third Last" : "倒数第三",
    "Fourth Last" : "倒数第四",
    "Fifth Last" : "倒数第五",
    "Contacts" : "联系人",
    "{actor} created address book {addressbook}" : "{actor} 创建了通讯录 {addressbook}",
    "You created address book {addressbook}" : "你创建了通讯录 {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} 删除了通讯录 {addressbook}",
    "You deleted address book {addressbook}" : "你删除了通讯录 {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} 更新了通讯录 {addressbook}",
    "You updated address book {addressbook}" : "你更新通讯录  {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} 与你分享了通讯录 {addressbook}",
    "You shared address book {addressbook} with {user}" : "你与 {user} 分享了通讯录 {addressbook}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} 与 {user} 分享了通讯录 {addressbook}",
    "{actor} unshared address book {addressbook} from you" : "{actor} 取消和你分享通讯录 {addressbook}",
    "You unshared address book {addressbook} from {user}" : "你取消了与 {user} 分享通讯录 {addressbook}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} 取消了与 {user} 分享通讯录",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} 取消了和自己分享通讯录 {addressbook}",
    "You shared address book {addressbook} with group {group}" : "你和小组 {group} 分享了通讯录 {addressbook}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} 和小组 {group} 分享了通讯录 {addressbook}",
    "You unshared address book {addressbook} from group {group}" : "你取消和小组 {group} 分享通讯录 ",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} 取消和小组 {group} 分享通讯录 ",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} 在通讯录 {addressbook} 中创建了联系人 {card} ",
    "You created contact {card} in address book {addressbook}" : "你在通讯录 {addressbook} 中创建了联系人 {card} ",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} 从通讯录 {addressbook} 中删除了联系人 {card} ",
    "You deleted contact {card} from address book {addressbook}" : "你从通讯录 {addressbook} 中删除了联系人 {card} ",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} 更新了通讯录 {addressbook} 中的联系人 {card} ",
    "You updated contact {card} in address book {addressbook}" : "你更新了通讯录 {addressbook} 中的联系人 {card} ",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "一名 <strong>联系人</strong>或一个<strong>通讯录</strong>被更改了",
    "Accounts" : "账号",
    "System address book which holds all accounts" : "包含所有账号的系统通讯录",
    "File is not updatable: %1$s" : "无法更新文件：%1$s",
    "Failed to get storage for file" : "无法获取文件的存储空间",
    "Could not write to final file, canceled by hook" : "无法写入最终文件，操作被插件取消",
    "Could not write file contents" : "无法写入文件内容",
    "_%n byte_::_%n bytes_" : ["%n字节"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "将文件复制到目标位置时发生错误（已复制：%1$s，预期大小：%2$s）",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "预期文件大小为 %1$s，实际从 Nextcloud 客户端读入并写入 Nextcloud 存储空间的大小为 %2$s。可能是发送端发生了网络问题，或者是服务器写入存储设备时发生错误。",
    "Could not rename part file to final file, canceled by hook" : "无法将部分文件重命名为最终文件，操作被插件取消",
    "Could not rename part file to final file" : "无法将部分文件重命名为最终文件",
    "Failed to check file size: %1$s" : "检查文件大小失败：%1$s",
    "Could not open file: %1$s, file does seem to exist" : "无法打开文件 %1$s，文件似乎不存在",
    "Could not open file: %1$s, file doesn't seem to exist" : "无法打开文件 %1$s，文件似乎不存在",
    "Encryption not ready: %1$s" : "加密不可用：%1$s",
    "Failed to open file: %1$s" : "打开文件失败：%1$s",
    "Failed to unlink: %1$s" : "解除链接失败：%1$s",
    "Failed to write file contents: %1$s" : "写入文件内容失败：%1$s",
    "File not found: %1$s" : "找不到文件：%1$s",
    "Invalid target path" : "目标路径无效",
    "System is in maintenance mode." : "系统处于维护模式。",
    "Upgrade needed" : "需要升级",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "您的 %s 需要配置使用 HTTPS 以在 iOS/macOS 中使用 CalDAV 和 CardDAV。",
    "Configures a CalDAV account" : "配置一个 CalDAV 账号",
    "Configures a CardDAV account" : "配置一个 CardDAV 账号",
    "Events" : "事件",
    "Untitled task" : "无标题任务",
    "Completed on %s" : "已完成 %s",
    "Due on %s by %s" : "到期于 %s，在 %s 之前",
    "Due on %s" : "到期于 %s",
    "Welcome to Nextcloud Calendar!\n\nThis is a sample event - explore the flexibility of planning with Nextcloud Calendar by making any edits you want!\n\nWith Nextcloud Calendar, you can:\n- Create, edit, and manage events effortlessly.\n- Create multiple calendars and share them with teammates, friends, or family.\n- Check availability and display your busy times to others.\n- Seamlessly integrate with apps and devices via CalDAV.\n- Customize your experience: schedule recurring events, adjust notifications and other settings." : "欢迎使用 Nextcloud 日历！\n\n这是一个示例事件——探索使用 Nextcloud 日历进行规划的灵活性，进行任何您想要的编辑！\n\n使用 Nextcloud 日历，您可以：\n- 轻松创建、编辑和管理事件。\n- 创建多个日历并与队友、朋友或家人共享。\n- 查看空闲时间并向他人显示您的忙碌时间。\n- 通过 CalDAV 与应用和设备无缝集成。\n- 自定义您的体验：安排重复事件、调整通知和其他设置。",
    "Example event - open me!" : "示例事件——打开我！",
    "System Address Book" : "系统通讯录",
    "The system address book contains contact information for all users in your instance." : "系统通讯录包含实例中所有用户的联系人信息。",
    "Enable System Address Book" : "启用系统通讯录",
    "DAV system address book" : "DAV 系统通讯录",
    "No outstanding DAV system address book sync." : "书书未完成 DAV 系统通讯录的同步",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "DAV 系统通讯录同步失败，这可能是因为你的服务器实例有超过1000名用户，或是因为出现了错误。请手动运行指令 “occ dav:sync-system-addressbook” 继续该操作。",
    "WebDAV endpoint" : "WebDAV 端点",
    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "无法检查您的 Web 服务器是否已正确设置以允许通过 WebDAV 进行文件同步。 请手动检查。",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "您的网页服务器没有正确设置允许文件同步，因为 WebDAV 接口看起来无法正常工作。",
    "Your web server is properly set up to allow file synchronization over WebDAV." : "您的 Web 服务器已正确设置为允许通过 WebDAV 进行文件同步。",
    "Migrated calendar (%1$s)" : "迁移的日历（%1$s）",
    "Calendars including events, details and attendees" : "日历，包括事件、详情和参加者",
    "Contacts and groups" : "联系人和群组",
    "WebDAV" : "WebDAV",
    "Absence saved" : "缺席已保存",
    "Failed to save your absence settings" : "未能保存您的离开状态设置",
    "Absence cleared" : "缺席已清除",
    "Failed to clear your absence settings" : "未能清除您的离开状态设置",
    "First day" : "第一天",
    "Last day (inclusive)" : "最后一天（含）",
    "Out of office replacement (optional)" : "外出时工作替代人员（可选）",
    "Name of the replacement" : "替代人员名称",
    "No results." : "没有结果。",
    "Start typing." : "开始输入",
    "Short absence status" : "短暂离开状态",
    "Long absence Message" : "长期离开信息",
    "Save" : "保存",
    "Disable absence" : "禁用离开状态",
    "Failed to load availability" : "可用时间段加载失败",
    "Saved availability" : "可用时间已保存",
    "Failed to save availability" : "可用时间保存失败",
    "Time zone:" : "时区：",
    "to" : "到",
    "Delete slot" : "删除插槽",
    "No working hours set" : "尚未设置工作时间",
    "Add slot" : "添加插槽",
    "Weekdays" : "工作日",
    "Pick a start time for {dayName}" : "选择 {dayName} 的开始时间",
    "Pick a end time for {dayName}" : "选择 {dayName} 的结束时间",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "不在工作时间内时，自动将用户状态设置为“勿扰”并静音所有通知。",
    "Cancel" : "取消",
    "Import" : "导入",
    "Error while saving settings" : "保存设置时出错",
    "Contact reset successfully" : "联系人重置成功",
    "Error while resetting contact" : "重置联系人时出错",
    "Contact imported successfully" : "联系人导入成功",
    "Error while importing contact" : "导入联系人时出错",
    "Import contact" : "导入联系人",
    "Reset to default" : "重置为默认设置",
    "Import contacts" : "导入联系人",
    "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "导入新的 .vcf 文件将删除现有的默认联系人，并用新联系人替换。是否要继续？",
    "Failed to save example event creation setting" : "无法保存示例事件创建设置",
    "Failed to upload the example event" : "无法上传示例事件",
    "Custom example event was saved successfully" : "已成功保存自定义示例事件",
    "Failed to delete the custom example event" : "无法删除自定义示例事件",
    "Custom example event was deleted successfully" : "已成功删除自定义示例事件",
    "Import calendar event" : "导入日历事件",
    "Uploading a new event will overwrite the existing one." : "上传新事件将覆盖现有事件。",
    "Upload event" : "上传事件",
    "Availability" : "工作时间",
    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "如果你配置了工作时间，其他人在预订会议时会看到你何时不在办公室。",
    "Absence" : "离开",
    "Configure your next absence period." : "配置你的下一次离开时段",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "也安装{calendarappstoreopen}日历应用{linkclose}，或者{calendardocopen}连接您的桌面和移动端同步日历 ↗{linkclose}。",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "请确保正确设置{emailopen}邮件服务器{linkclose}。",
    "Calendar server" : "日历服务器",
    "Send invitations to attendees" : "向参加者发送邀请",
    "Automatically generate a birthday calendar" : "自动生成生日日历",
    "Birthday calendars will be generated by a background job." : "生日日历将由后台作业生成。",
    "Hence they will not be available immediately after enabling but will show up after some time." : "因此，它们在启用后不会立即可用，但会在一段时间后显示出来。",
    "Send notifications for events" : "发送事件通知",
    "Notifications are sent via background jobs, so these must occur often enough." : "通知将通过后台任务发送，所以任务的频率要足够高。",
    "Send reminder notifications to calendar sharees as well" : "同时向日历共享者发送提醒通知",
    "Reminders are always sent to organizers and attendees." : "始终向组织者和参加者发送提醒。",
    "Enable notifications for events via push" : "启用推送事件通知",
    "Example content" : "示例内容",
    "Example content serves to showcase the features of Nextcloud. Default content is shipped with Nextcloud, and can be replaced by custom content." : "示例内容用于展示 Nextcloud 的功能。默认内容随 Nextcloud 一起提供，可以用自定义内容替换。",
    "There was an error updating your attendance status." : "更新您的出席状态时出错。",
    "Please contact the organizer directly." : "请直接联系组织者。",
    "Are you accepting the invitation?" : "您是否接受邀请？",
    "Tentative" : "暂定",
    "Your attendance was updated successfully." : "您的出席状态更新成功。"
},
"nplurals=1; plural=0;");
