OC.L10N.register(
    "files_sharing",
    {
    "File shares" : "Κοινή χρήση αρχείων",
    "Downloaded via public link" : "Μεταφορτώθηκε μέσω δημόσιου συνδέσμου",
    "Downloaded by {email}" : "Μεταφορτώθηκε από {email}",
    "{file} downloaded via public link" : "{file} μεταφορτώθηκε από δημόσιο σύνδεσμο",
    "{email} downloaded {file}" : "{email} μεταφορτώθηκε {file}",
    "Shared with group {group}" : "Διαμοιρασμένα με την ομάδα {group}",
    "Removed share for group {group}" : "Αφαιρέθηκε ο διαμοιρασμός για την ομάδα {group}",
    "{actor} shared with group {group}" : "{actor} διαμοιράστηκε με την ομάδα {group}",
    "{actor} removed share for group {group}" : "{actor} αφαιρέθηκε ο διαμοιρασμός για την ομάδα {group}",
    "Share for group {group} expired" : "Η κοινή χρήση για την ομάδα {group} έληξε",
    "You shared {file} with group {group}" : "Διαμοιραστήκατε {file} με την ομάδα {group}",
    "You removed group {group} from {file}" : "Αφαιρέσατε την ομάδα {group} από {file}",
    "{actor} shared {file} with group {group}" : "{actor} διαμοιράστηκε {file} με την ομάδα {group}",
    "{actor} removed group {group} from {file}" : "{actor} αφαίρεσε την ομάδα {group} από {file}",
    "Share for file {file} with group {group} expired" : "Η κοινή χρήση του {file} με την ομάδα {group} έληξε",
    "Shared as public link" : "Διαμοιρασμός με δημόσιο σύνδεσμο",
    "Removed public link" : "Αφαίρεση δημόσιου συνδέσμου",
    "Public link expired" : "Ο δημόσιος σύνδεσμος έληξε",
    "{actor} shared as public link" : "{actor} διαμοιράστηκε με δημόσιο σύνδεσμο",
    "{actor} removed public link" : "{actor} αφαίρεσε δημόσιο σύνδεσμο",
    "Public link of {actor} expired" : "Δημόσιος σύνδεσμος από {actor} έληξε",
    "You shared {file} as public link" : "Διαμοιραστήκατε {file} με δημόσιο σύνδεσμο",
    "You removed public link for {file}" : "Αφαιρέσατε δημόσιο σύνδεσμο για {file}",
    "Public link expired for {file}" : "Δημόσιος σύνδεσμος έληξε για {file}",
    "{actor} shared {file} as public link" : "{actor} διαμοίρασε {file} με δημόσιο σύνδεσμο",
    "{actor} removed public link for {file}" : "{actor} αφαιρέθηκε δημόσιος σύνδεσμος από {file}",
    "Public link of {actor} for {file} expired" : "Δημόσιος σύνδεσμος από {actor} για {file} έλληξε",
    "{user} accepted the remote share" : "{user} αποδέχτηκε τον απομακρυσμένο διαμοιρασμό",
    "{user} declined the remote share" : "{user} αποδέχτηκε τον δημόσιο διαμοιρασμό",
    "You received a new remote share {file} from {user}" : "Λάβατε ένα νέο απομακρυσμένο διαμοιρασμό {file} από {user}",
    "{user} accepted the remote share of {file}" : "{user} αποδέχτηκε τον απομακρυσμένο διαμοιρασμό από {file}",
    "{user} declined the remote share of {file}" : "{user} απέρριψε τον απομακρυσμένο διαμοιρασμό από {file}",
    "{user} unshared {file} from you" : "{user} απέσυρε τον διαμοιρασμό {file} από εσάς",
    "Shared with {user}" : "Διαμοιραζόμενο με {user}",
    "Removed share for {user}" : "Αφαιρέθηκε διαμοιρασμός για {user}",
    "You removed yourself" : "Αφαιρέσατε τον εαυτό σας",
    "{actor} removed themselves" : "Ο {actor} αφαίρεσε τον εαυτό του",
    "{actor} shared with {user}" : "{actor} διαμοιράστηκε με {user}",
    "{actor} removed share for {user}" : "{actor} αφαιρέθηκε διαμοιρασμός για {user}",
    "Shared by {actor}" : "Διαμοιράστηκε από {actor}",
    "{actor} removed share" : "{actor} αφαίρεσε διαμοιρασμό",
    "Share for {user} expired" : "Η κοινή χρήση για τον {user} έληξε",
    "Share expired" : "Η κοινή χρήση έληξε",
    "You shared {file} with {user}" : "Διαμοιραστήκατε {file} με {user}",
    "You removed {user} from {file}" : "Αφαιρέσατε {user} από {file}",
    "You removed yourself from {file}" : "Αφαιρέσατε τον εαυτό σας από {file}",
    "{actor} removed themselves from {file}" : "Οι {actor} αφαίρεσαν τον εαυτό τους από {file}",
    "{actor} shared {file} with {user}" : "{actor} διαμοιράστηκε {file} με {user}",
    "{actor} removed {user} from {file}" : "{actor} αφαίρεσε {user} από {file}",
    "{actor} shared {file} with you" : "{actor} διαμοιράστηκε {file} με εσάς",
    "{actor} removed you from the share named {file}" : "Ο {actor} σας αφαίρεσε από το κοινόχρηστο με όνομα {file}",
    "Share for file {file} with {user} expired" : "Η κοινή χρήση του αρχείου {file} με τον {user} έληξε",
    "Share for file {file} expired" : "Η κοινή χρήση του αρχείου {file} έληξε",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Ένα αρχείο ή φάκελος διαμοιρασμένο με mail ή με δημόσιο σύνδεσμο <strong>κατέβηκε</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Ένα αρχείο ή φάκελος διαμοιράστηκε από <strong>έναν άλλο διακομιστή</strong>",
    "Sharing" : "Διαμοιρασμός",
    "A file or folder has been <strong>shared</strong>" : "Ένα αρχείο ή φάκελος <strong>διαμοιράστηκε</strong>",
    "Shared link" : "Διαμοιρασμένος σύνδεσμος",
    "Wrong share ID, share does not exist" : "Λάθος ID κοινής χρήσης, η κοινή χρήση δεν υπάρχει",
    "Could not delete share" : "Αδυναμία διαγραφής κοινόχρηστου φακέλου",
    "Please specify a file or folder path" : "Παρακαλούμε καθορίστε την διαδρομή για το αρχείο ή τον φάκελο",
    "Wrong path, file/folder does not exist" : "Λάθος διαδρομή, το αρχείο/φάκελος δεν υπάρχει",
    "Could not create share" : "Αδυναμία δημιουργίας κοινόχρηστου",
    "Please specify a valid account to share with" : "Παρακαλούμε καθορίστε έναν έγκυρο λογαριασμό για κοινή χρήση",
    "Group sharing is disabled by the administrator" : "Διαμοιρασμός σε ομάδες είναι απενεργοποιημένος από τον διαχειρηστή",
    "Please specify a valid group" : "Παρακαλούμε καθορίστε μια έγκυρη ομάδα",
    "Public link sharing is disabled by the administrator" : "Διαμοιρασμός δημόσιου συνδέσμου είναι απενεργοποιημένος από τον διαχειριστή",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Η κοινή χρήση %s της αποστολής του κωδικού πρόσβασης από το Nextcloud Talk απέτυχε επειδή δεν είναι ενεργοποιημένο το Nextcloud Talk",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "Διαμοιρασμός %1$s απέτυχε επειδή ο εξυπηρετητής δεν επιτρέπει διαμοιρασμούς από τύπο %2$s",
    "Sharing %s failed because the back end does not support room shares" : "Διαμοιρασμός %s απέτυχε επειδή ο εξυπηρετητής δεν επιτρέπει διαμοιρασμούς δωματίων",
    "Unknown share type" : "Άγνωστος τύπος διαμοιρασμού",
    "Not a directory" : "Δεν είναι κατάλογος",
    "Could not lock node" : "Δεν ήταν δυνατό να κλειδώσει ο κόμβος",
    "Public upload is only possible for publicly shared folders" : "Δημόσιο ανέβασμα είναι δυνατό μόνο για δημόσια διαμοιρασμένους φακέλους",
    "Share must at least have READ or CREATE permissions" : "Το κοινόχρηστο πρέπει να έχει τουλάχιστον άδεια για ΑΝΑΓΝΩΣΗ ή ΔΗΜΙΟΥΡΓΙΑ",
    "Share must have READ permission if UPDATE or DELETE permission is set" : "Το κοινόχρηστο πρέπει να έχει άδεια ΑΝΑΓΝΩΣΗ αν οριστεί άδεια ΕΝΗΜΕΡΩΣΗ ή ΔΙΑΓΡΑΦΗ",
    "Public upload disabled by the administrator" : "Δημόσιο ανέβασμα είναι απενεργοποιημένο από τον διαχειριστή",
    "Could not lock path" : "Αδυναμία κλειδώματος διαδρομής",
    "Wrong or no update parameter given" : "Λάθος ή καμία παράμετρος αναβάθμισης δεν δόθηκε",
    "Wrong password" : "Λάθος κωδικός πρόσβασης",
    "shared by %s" : "Διαμοιράστηκε από 1 %s",
    "Download" : "Λήψη",
    "Direct link" : "Άμεσος σύνδεσμος",
    "Share API is disabled" : "API διαμοιρασμού είναι απενεργοποιημένο",
    "File sharing" : "Διαμοιρασμός αρχείων",
    "Share will expire tomorrow" : "Η κοινή χρήση θα λήξει αύριο",
    "Your share of {node} will expire tomorrow" : "Η κοινή χρήση του {node} θα λήξει αύριο",
    "You received {share} as a share by {user}" : "Λάβατε το {share} ως κοινή χρήση από τον {user}",
    "You received {share} to group {group} as a share by {user}" : "Λάβατε το {share} ομάδας {group} ως κοινή χρήση από τον {user}",
    "Accept" : "Αποδοχή",
    "Decline" : "Απόρριψη",
    "People" : "Άτομα",
    "Expiration date" : "Ημερομηνία λήξης",
    "Set a password" : "Ορισμός συνθηματικού",
    "Password" : "Συνθηματικό",
    "Link copied" : "Ο σύνδεσμος αντιγράφηκε",
    "Share link" : "Διαμοιρασμός συνδέσμου",
    "Copy" : "Αντιγραφή",
    "Send link via email" : "Αποστολή συνδέσμου μέσω email",
    "Select" : "Επιλογή",
    "Close" : "Κλείσιμο",
    "Error creating the share: {errorMessage}" : "Σφάλμα κατά τη δημιουργία της κοινής χρήσης: {errorMessage}",
    "Error creating the share" : "Σφάλμα κατά την δημιουργία κοινόχρηστου",
    "Cancel" : "Ακύρωση",
    "Continue" : "Συνεχίστε",
    "Error while toggling options" : "Σφάλμα κατά την εναλλαγή επιλογών",
    "Accept shares from other accounts and groups by default" : "Αποδοχή κοινόχρηστων από άλλους λογαριασμούς και ομάδες από προεπιλογή",
    "Choose a default folder for accepted shares" : "Επιλέξτε έναν προεπιλεγμένο φάκελο για τα κοινόχρηστα στοιχεία που γίνονται αποδεκτά ",
    "Invalid path selected" : "Επιλέχθηκε μη έγκυρη διαδρομή",
    "Unknown error" : "Άγνωστο σφάλμα",
    "Set default folder for accepted shares" : "Ορισμός προεπιλεγμένου φακέλου για αποδεκτά κοινόχρηστα στοιχεία",
    "Reset" : "Επαναφορά",
    "Reset folder to system default" : "Επαναφορά του φακέλου στις προεπιλογές συστήματος",
    "group" : "ομάδα",
    "conversation" : "συνομιλία",
    "remote" : "απομακρυσμένα",
    "remote group" : "απομακρυσμένη ομάδα",
    "guest" : "Επισκέπτης",
    "Shared with the group {user} by {owner}" : "Διαμοιράστηκε με την ομάδα {user} του {owner}",
    "Shared with the conversation {user} by {owner}" : "Διαμοιράστηκε με τη συζήτηση {user} από {owner}",
    "Shared with {user} by {owner}" : "Διαμοιράστηκε με {user} από τον {owner}",
    "Added by {initiator}" : "Προστέθηκε από {initiator}",
    "Via “{folder}”" : "Μέσω “{folder}”",
    "Unshare" : "Αναίρεση διαμοιρασμού",
    "Cannot copy, please copy the link manually" : "Δεν μπορεί να αντιγραφεί, παρακαλώ αντιγράψτε χειροκίνητα",
    "Copy internal link" : "Αντιγραφή εσωτερικού συνδέσμου",
    "Internal link" : "Εσωτερικός σύνδεσμος",
    "{shareWith} by {initiator}" : "{shareWith} από {initiator}",
    "Shared via link by {initiator}" : "Διαμοιράστηκε μέσω συνδέσμου {initiator}",
    "Share link ({label})" : "Σύνδεσμος κοινής χρήσης ({label})",
    "Share link ({index})" : "Διαμοιρασμός συνδέσμου ({index})",
    "Create public link" : "Δημιουργία δημόσιου συνδέσμου",
    "Actions for \"{title}\"" : "Ενέργειες για \"{title}\"",
    "Error, please enter proper password and/or expiration date" : "Σφάλμα, παρακαλώ εισάγετε τον σωστό κωδικό πρόσβασης και/ή ημερομηνία λήξης",
    "Link share created" : "Δημιουργήθηκε ο σύνδεσμος κοινής χρήσης",
    "Error while creating the share" : "Σφάλμα κατά τη δημιουργία κοινόχρηστου",
    "Please enter the following required information before creating the share" : "Καταχωρίστε τις ακόλουθες απαιτούμενες πληροφορίες πριν δημιουργήσετε το κοινόχρηστο στοιχείο",
    "Password protection (enforced)" : "Προστασία με κωδικό (υποχρεωτικό)",
    "Password protection" : "Προστασία συνθηματικού",
    "Enter a password" : "Εισάγετε ένα συνθηματικό",
    "Create share" : "Δημιουργήστε κοινή χρήση",
    "Customize link" : "Προσαρμογή συνδέσμου",
    "Generate QR code" : "Δημιουργία QR code",
    "Add another link" : "Προσθήκη άλλου συνδέσμου",
    "Create a new share link" : "Δημιουργία νέου κοινόχρηστου συνδέσμου",
    "View only" : "Μόνο για προβολή",
    "Can edit" : "Δυνατότητα επεξεργασίας",
    "Custom permissions" : "Προσαρμοσμένα δικαιώματα",
    "Resharing is not allowed" : "Δεν επιτρέπεται ο επαναμοιρασμός",
    "Name or email …" : "Όνομα ή διεύθυνση ηλεκτρονικού ταχυδρομείου",
    "Name, email, or Federated Cloud ID …" : "Όνομα, διεύθυνση ηλεκτρονικού ταχυδρομείου ή Ομοσπονδιακό αναγνωριστικό Cloud…",
    "Searching …" : "Αναζήτηση ...",
    "No elements found." : "Δεν βρέθηκαν στοιχεία.",
    "Search everywhere" : "Αναζητήστε παντού",
    "Guest" : "Επισκέπτης",
    "Group" : "Ομάδα",
    "Email" : "Email",
    "Talk conversation" : "Συνομιλία στο Talk",
    "Deck board" : "Πίνακας του Deck",
    "on {server}" : "στον {server}",
    "Note:" : "Σημείωση:",
    "File drop" : "Απόθεση αρχείου",
    "Terms of service" : "Όροι χρήσης",
    "Share with group" : "Κοινή χρήση με ομάδα",
    "Share in conversation" : "Κοινή χρήση σε συζήτηση",
    "Share with guest" : "Κοινή χρήση με επισκέπτη",
    "Update share" : "Ενημέρωση κοινόχρηστου",
    "Save share" : "Αποθήκευση κοινόχρηστου",
    "Read" : "Ανάγνωση",
    "Create" : "Δημιουργία",
    "Edit" : "Επεξεργασία",
    "Share" : "Διαμοιρασμός",
    "Delete" : "Διαγραφή",
    "Allow upload and editing" : "Επέτρεψε την μεταφόρτωση και επεξεργασία",
    "Allow editing" : "Επιτρέπεται η επεξεργασία",
    "Advanced settings" : "Ρυθμίσεις για προχωρημένους",
    "Share label" : "Ετικέτα διαμοιρασμού",
    "Set password" : "Ορισμός κωδικού πρόσβασης",
    "Password expired" : "Ο κωδικός πρόσβασης έληξε",
    "Video verification" : "Επαλήθευση βίντεο",
    "Expiration date (enforced)" : "Ημερομηνία λήξης (υποχρεωτικά)",
    "Set expiration date" : "Ορισμός ημερομηνίας λήξης",
    "Hide download" : "Απόκρυψη λήψης",
    "Note to recipient" : "Σημείωση προς τον παραλήπτη",
    "Enter a note for the share recipient" : "Προσθέτε σημείωση για τους παραλήπτες του κοινόχρηστου",
    "Delete share" : "Διαγραφή κοινόχρηστου",
    "Others with access" : "Άλλοι με πρόσβαση",
    "Toggle list of others with access to this directory" : "Εναλλαγή λίστας άλλων με πρόσβαση σε αυτόν τον κατάλογο",
    "Toggle list of others with access to this file" : "Εναλλαγή λίστας άλλων με πρόσβαση σε αυτόν το αρχείο",
    "Unable to fetch inherited shares" : "Δεν είναι δυνατή η λήψη άλλων διαμοιρασμών",
    "Shares" : "Κοινόχρηστα",
    "Unable to load the shares list" : "Δεν είναι δυνατή η φόρτωση λίστας διαμοιρασμών",
    "Expires {relativetime}" : "Λήγει {relativetime}",
    "this share just expired." : "το κοινόχρηστο μόλις έληξε.",
    "Shared with you by {owner}" : "Διαμοιράστηκε με σας από τον {owner}",
    "Link to a file" : "Σύνδεσμος σε αρχείο",
    "_Accept share_::_Accept shares_" : ["Αποδοχή κοινόχρηστου","Αποδοχή κοινόχρηστων"],
    "Open in Files" : "Άνοιγμα στα Αρχεία",
    "_Reject share_::_Reject shares_" : ["Απόρριψη κοινόχρηστου","Απόρριψη κοινόχρηστων"],
    "_Restore share_::_Restore shares_" : ["Επαναφορά κοινόχρηστου","Επαναφορά κοινόχρηστων"],
    "Shared" : "Κοινόχρηστα",
    "Shared with others" : "Διαμοιρασμένα με άλλους",
    "No file" : "Κανένα αρχείο",
    "Public share" : "Δημόσια κοινόχρηστο",
    "Overview of shared files." : "Επισκόπηση κοινόχρηστων αρχείων.",
    "No shares" : "Κανένα κοινόχρηστο",
    "Files and folders you shared or have been shared with you will show up here" : "Αρχεία και φάκελοι που μοιραστήκατε ή έχουν μοιραστεί με εσάς θα εμφανιστούν εδώ",
    "Shared with you" : "Διαμοιρασμένα με εσάς",
    "List of files that are shared with you." : "Λίστα αρχείων σε κοινή χρήση με εσάς.",
    "Nothing shared with you yet" : "Κανένα αρχείο δεν έχει διαμοιραστεί ακόμα με εσάς.",
    "Files and folders others shared with you will show up here" : "Αρχεία και φάκελοι που άλλοι έχουν μοιραστεί μαζί σας θα εμφανιστούν εδώ",
    "List of files that you shared with others." : "Λίστα των αρχείων που μοιραστήκατε με άλλους.",
    "Nothing shared yet" : "Δεν έχει διαμοιραστεί τίποτα μέχρι στιγμής",
    "Files and folders you shared will show up here" : "Αρχεία και φάκελοι που μοιραστήκατε θα εμφανιστούν εδώ",
    "Shared by link" : "Διαμοιρασμένα μέσω συνδέσμου",
    "List of files that are shared by link." : "Λίστα αρχείων που έχουν μοιραστεί με σύνδεσμο.",
    "No shared links" : "Κανένας διαμοιρασμένος σύνδεσμος",
    "Files and folders you shared by link will show up here" : "Αρχεία και φάκελοι που μοιραστήκατε με σύνδεσμο θα εμφανιστούν εδώ",
    "Deleted shares" : "Διαγραμμένα κοινόχρηστα",
    "List of shares you left." : "Λίστα κοινόχρηστων από τα οποία αποχωρήσατε",
    "No deleted shares" : "Δεν υπάρχουν διαγραμμένα κοινόχρηστα",
    "Shares you have left will show up here" : "Κοινόχρηστα από τα οποία έχετε αποχωρήσει θα εμφανιστούν εδώ",
    "Pending shares" : "Κοινή χρήση σε εκκρεμότητα",
    "List of unapproved shares." : "Λίστα μη αποδεκτών κοινόχρηστων.",
    "No pending shares" : "Δεν εκκρεμούν κοινόχρηστα",
    "Shares you have received but not approved will show up here" : "Κοινόχρηστα που έχετε λάβει αλλά δεν έχετε εγκρίνει θα εμφανιστούν εδώ",
    "Error deleting the share" : "Σφάλμα διαγραφής του κοινόχρηστου",
    "Error updating the share: {errorMessage}" : "Σφάλμα κατά τη δημιουργία της κοινής χρήσης: {errorMessage}",
    "Error updating the share" : "Σφάλμα κατά την ενημέρωση του κοινόχρηστου",
    "Share label saved" : "Διαμοιρασμένη ετικέτα αποθηκεύτηκε ",
    "Share password saved" : "Διαμοιρασμένο συνθηματικό αποθηκεύτηκε ",
    "Shared by" : "Διαμοιράστηκε από",
    "Shared with" : "Διαμοιράστηκε με",
    "Password created successfully" : "Συνθηματικό δημιουργήθηκε με επιτυχία",
    "Error generating password from password policy" : "Σφάλμα δημιουργίας συνθηματικού από την πολιτική συνθηματικών",
    "Shared with you and the group {group} by {owner}" : "Διαμοιράστηκε με σας και με την ομάδα {group} του {owner}",
    "Shared with you and {circle} by {owner}" : "Διαμοιράστηκε με σας και τον {circle} από τον {owner}",
    "Shared with you and the conversation {conversation} by {owner}" : "Διαμοιράστηκε με σας και με τη συζήτηση {conversation} από {owner}",
    "Shared with you in a conversation by {owner}" : "Διαμοιράστηκε με σας από τον {owner}",
    "Share not found" : "Δεν βρέθηκε το κονόχρηστο",
    "Back to %s" : "Πίσω στο %s",
    "Add to your Nextcloud" : "Προσθήκη στο Nextcloud σου",
    "Waiting…" : "Αναμονή...",
    "error" : "σφάλμα ",
    "finished" : "ολοκληρώθηκε",
    "This will stop your current uploads." : "Αυτό θα σταματήσει τις τρέχουσες μεταφορτώσεις.",
    "Move or copy" : "Μετακίνηση ή αντιγραφή",
    "You can upload into this folder" : "Μπορείτε να μεταφορτώσετε σε αυτόν τον φάκελο",
    "Show list view" : "Προβολή λίστας",
    "Show grid view" : "Προβολή πλέγματος",
    "No compatible server found at {remote}" : "Δεν βρέθηκε συμβατός διακομιστής σε {remote}",
    "Invalid server URL" : "Μη έγκυρο URL διακομιστή",
    "Failed to add the public link to your Nextcloud" : "Αποτυχία στην πρόσθεση του κοινού συνδέσμου στο Nextcloud σας",
    "Download all files" : "Λήψη όλων των αρχείων",
    "Link copied to clipboard" : "Ο σύνδεσμος αντιγράφηκε στο πρόχειρο",
    "Copy to clipboard" : "Αντιγραφή στο πρόχειρο",
    "Copy internal link to clipboard" : "Αντιγραφή εσωτερικού συνδέσμου στο πρόχειρο",
    "Only works for people with access to this folder" : "Λειτουργεί μόνο για άτομα με πρόσβαση σε αυτόν τον φάκελο",
    "Only works for people with access to this file" : "Λειτουργεί μόνο για άτομα με πρόσβαση σε αυτό το αρχείο",
    "Copy public link of \"{title}\" to clipboard" : "Αντιγραφή του δημόσιου συνδέσμου \"{title}\" στο πρόχειρο",
    "Search globally" : "Γενική αναζήτηση",
    "Search for share recipients" : "Αναζήτηση για παραλήπτες διαμοιρασμού",
    "No recommendations. Start typing." : "Δεν υπάρχουν συστάσεις. Αρχίστε να πληκτρολογείτε.",
    "Enter your name" : "Προσθέστε το όνομά σας",
    "Show sharing options" : "Εμφάνιση επιλογών κοινής χρήσης",
    "Share note" : "Σημείωση κοινόχρηστου",
    "Upload files to %s" : "Αποστολή αρχείων σε %s",
    "Note" : "Σημείωση",
    "Select or drop files" : "Επιλέξτε ή αποθέστε αρχεία",
    "Uploading files" : "Μεταφόρτωση αρχείων",
    "Uploaded files:" : "Αποστολή αρχείων:",
    "By uploading files, you agree to the %1$sterms of service%2$s." : "Με την μεταφόρτωση αρχείων, συμφωνείτε με %1$sόρους χρήσεως %2$s.",
    "Name" : "Όνομα",
    "Filename must not be empty." : "Το όνομα αρχείου δεν πρέπει να είναι κενό."
},
"nplurals=2; plural=(n != 1);");
