OC.L10N.register(
    "files_versions",
    {
    "Versions" : "Versioonid",
    "This application automatically maintains older versions of files that are changed." : "See rakendus haldab automaatselt muudetud failide vanemaid versioone.",
    "This application automatically maintains older versions of files that are changed. When enabled, a hidden versions folder is provisioned in every user's directory and is used to store old file versions. A user can revert to an older version through the web interface at any time, with the replaced file becoming a version. The app automatically manages the versions folder to ensure the account does not run out of Quota because of versions.\n\t\tIn addition to the expiry of versions, the versions app makes certain never to use more than 50% of the account's currently available free space. If stored versions exceed this limit, the app will delete the oldest versions first until it meets this limit. More information is available in the Versions documentation." : "See rakendus säilitab automaatselt muudetud failide vanemaid versioone. Kui see on lubatud, luuakse iga kasutaja kataloogis peidetud versioonide kaust ja seda kasutatakse vanade failiversioonide salvestamiseks. Kasutaja saab veebiliidese kaudu igal ajal naasta vanemale versioonile, kusjuures asendatud failist saab versioon. Rakendus haldab automaatselt versioonide kausta, et kontol kvoot versioonide tõttu otsa ei saaks.\nLisaks versioonide aegumisele tagab versioonirakendus, et ei kasutataks kunagi rohkem kui 50% konto hetkel saadaolevast vabast ruumist. Kui salvestatud versioonid ületavad selle limiidi, kustutab rakendus kõigepealt vanimad versioonid, kuni see limiit jõuab. Lisateavet leiate versioonide dokumentatsioonist.",
    "Current version" : "Hetkeversioon",
    "Initial version" : "Algversioon",
    "You" : "Sina",
    "Actions for version from {versionHumanExplicitDate}" : "Tegevused versiooniga {versionHumanExplicitDate}-st",
    "Name this version" : "Nimeta see versioon",
    "Edit version name" : "Muuda versiooni nime",
    "Compare to current version" : "Võrdle hetkeversiooniga",
    "Restore version" : "Taasta versioon",
    "Download version" : "Laadi versioon alla",
    "Delete version" : "Kustuta versioon",
    "Cancel" : "Tühista",
    "Remove version name" : "Eemalda versiooni nimi",
    "Save version name" : "Salvesta versiooni nimi",
    "Version name" : "Versiooni nimi",
    "Named versions are persisted, and excluded from automatic cleanups when your storage quota is full." : "Nimelised versioonid hoitakse alles ja ei kustutata automaatselt, kui salvestusruum on täis.",
    "Initial version restored" : "Algne versioon taastatud",
    "Version restored" : "Versioon taastatud",
    "Could not restore version" : "Versiooni taastamine ebaõnnestus",
    "Could not set version label" : "Ei saanud määrata versiooni märget",
    "Could not delete version" : "Versiooni kustutamine ebaõnnestus",
    "File versions" : "Faili versioonid"
},
"nplurals=2; plural=(n != 1);");
