OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Failide ja kaustade meeldetuletused",
    "Reminder for {name}" : "Meeldetuletus: „{name}“",
    "View file" : "Vaata faili",
    "View folder" : "Vaata kausta",
    "Files reminder" : "Failide ja kaustade meeldetuletused",
    "The \"files_reminders\" app can work properly." : "See Failide meeldetuletaja võib toimida korrektselt.",
    "The \"files_reminders\" app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "Failide meeldetuletusrakendus vajab korrektseks toimimiseks teavituste rakenduse olemasolu. Palun lisa vajalik abirakendus või eemalda see rakendus kasutuselt.",
    "Set file reminders" : "Meeldetuletuste lisamine failidele ja kaustadele",
    "**📣 File reminders**\n\nSet file reminders.\n\nNote: to use the `File reminders` app, ensure that the `Notifications` app is installed and enabled. The `Notifications` app provides the necessary APIs for the `File reminders` app to work correctly." : "**📣 Failide meeldetuletused**\n\nLisa failidele ja kaustadele meeldetuletusi.\n\nMärkus: Teavituste rakendus peab olema paigaldatud ja kasutusel, et see Failide meeldetuletuste rakendus saaks korrektselt toimida. Teavituste rakendus tagab selle rakenduse toimimiseks vajalik liideste olemasolu.",
    "Set reminder for \"{fileName}\"" : "Lisa meeldetuletus: „{fileName}“",
    "Clear reminder" : "Eemalda meeldetuletus",
    "Please choose a valid date & time" : "Palun vali korrektne kuupäev ja kellaaeg",
    "Reminder set for \"{fileName}\"" : "Meeldetuletus on lisatud: „{fileName}“",
    "Failed to set reminder" : "Meeldetuletuse lisamine ei õnnestunud",
    "Reminder cleared for \"{fileName}\"" : "Meeldetuletus on eemaldatud: „{fileName}“",
    "Failed to clear reminder" : "Meeldetuletuse eemaldamine ei õnnestunud",
    "We will remind you of this file" : "Me anname sulle selle faili või kausta osas märku",
    "Cancel" : "Tühista",
    "Set reminder" : "Lisa meeldetuletus",
    "Reminder set" : "Meeldetuletus on lisatud",
    "Later today" : "Täna hiljem",
    "Set reminder for later today" : "Lisa meeldetuletus tänaseks hilisemaks ajaks",
    "Tomorrow" : "Homme",
    "Set reminder for tomorrow" : "Lisa meeldetuletus homseks",
    "This weekend" : "See nädalavahetus",
    "Set reminder for this weekend" : "Lisa meeldetuletus selleks nädalavahetuseks",
    "Next week" : "Järgmine nädal",
    "Set reminder for next week" : "Lisa meeldetuletus järgmiseks nädalaks",
    "This files_reminder can work properly." : "See Failide meeldetuletaja võib toimida korrektselt.",
    "The files_reminder app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "Failide meeldetuletusrakendus vajab korrektseks toimimiseks teavituste rakenduse olemasolu. Palun lisa vajalik abirakendus või eemalda see rakendus kasutuselt.",
    "Set reminder at custom date & time" : "Säti meeldetuletus valitud kuupäevaks ja ajaks",
    "Set custom reminder" : "Lisa enda valitud meeldetuletus"
},
"nplurals=2; plural=(n != 1);");
