OC.L10N.register(
    "circles",
    {
    "Teams" : "Команди",
    "You created the team {circle}" : "Ви створити команду {circle}",
    "{author} created the team {circle}" : "{author} створив(-ла) команду {circle}",
    "You deleted {circle}" : "Ви вилучили коло {circle}",
    "{author} deleted {circle}" : "{author} вилучив коло {circle}",
    "You made {member} join {circle}" : "Ви запросили {member} приєднатися до {circle}",
    "{author} made {member} join {circle}" : "{author} запросив(-ла) {member} приєднатися до {circle}",
    "You added team {member} as member to {circle}" : "Ви запросили {member} стати учасником(-цею) {circle}",
    "{author} added team {member} as member to {circle}" : "{author} додав(-ла) {member} учасником(-цею) {circle}",
    "You made {member} leave {circle}" : "Ви вилучили {member} із {circle}",
    "{author} made {member} leave {circle}" : "{author} вилучив(-ла) {member} із {circle}",
    "You removed {member} from {circle}" : "Ви вилучили {member} із {circle}",
    "{author} removed {member} from {circle}" : "{author} вилучив(-ла) {member} із {circle}",
    "You joined {circle}" : "Ви приєдналися до {circle}",
    "{member} joined {circle}" : "{member} приєднався до {circle}",
    "You accepted the invitation to join {circle}" : "Ви прийняли запрошення приєднатися до {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} прийняв запрошення приєднатися до {circle}",
    "You added {member} as member to {circle}" : "Ви додали {member} учасником кола {circle}",
    "You have been added as member to {circle} by {author}" : "{author} додав(-ла) вас учасником кола {circle}",
    "{member} has been added as member to {circle} by {author}" : "{author} додав(-ла) {member} учасником кола {circle}",
    "You added {external} to {circle}" : "Ви додали {external} до {circle}",
    "{external} has been added to {circle} by {author}" : "{external} додано до {circle} {author}",
    "You accepted {member}'s request to join {circle}" : "Ви прийняли запит {member} приєднатися до {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Ваш запит на приєднання до {circle} прийнято {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "Запит {member} приєднатися до {circle} було прийнято {author}",
    "You left {circle}" : "Ви залишили {circle}",
    "{member} left {circle}" : "{member} залишив {circle}",
    "You declined the invitation to join {circle}" : "Ви відхилили запрошення приєднатися до {circle}",
    "{member} declined an invitation to join {circle}" : "{member} відхилив запрошення приєднатися до {circle}",
    "You cancelled your request to join {circle}" : "Ви скасували свій запит на приєднання до {circle}",
    "{member} cancelled a request to join {circle}" : "{member} скасував(-ла) запит на приєднання до {circle}",
    "You have been removed from {circle} by {author}" : "{author} вилучив вас із {circle}",
    "{member} has been removed from {circle} by {author}" : "{member} вилучено з кола {circle} автором {author}",
    "You removed {external} from {circle}" : "Ви вилучили {external} із {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} вилучено з кола {circle} автором {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Ви скасували запрошення користувача {member} приєднатися до {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Ваше запрошення приєднатися до {circle} було скасовано {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} скасував запрошення {member} приєднатися до {circle}",
    "You dismissed {member}'s request to join {circle}" : "Ви відхилили запит {member} приєднатися до {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Ваш запит на приєднання до {circle} відхилено {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} відхилив запит {member} на приєднання до {circle}",
    "You invited {member} to join {circle}" : "Ви запросили {member} приєднатися до {circle}",
    "You have been invited to join {circle} by {author}" : "{author} запросив вас приєднатися до {circle}",
    "{member} has been invited to join {circle} by {author}" : "{member} отримав запрошення приєднатися до {circle} від {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Ви змінили рівень участи {member} у колі {circle} на %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} змінив(-ла) ваш рівень участі у колі {circle} на %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} змінив(-ла) ваш рівень участі у колі {circle} на %1$s",
    "You sent a request to join {circle}" : "Ви надіслали запит на приєднання до {circle}",
    "{member} sent a request to join {circle}" : "{member} надіслав запит на приєднання до {circle}",
    "You are the new owner of {circle}" : "Ви новий власник {circle}",
    "{member} is the new owner of {circle}" : "{member} є новим власником {circle}",
    "On events happening in a <strong>team</strong> of which you are a member" : "При настанні подій у <strong>команді </strong>, до якої ви входите",
    "Any important event in a <strong>team</strong> you are moderating" : "Будь-яка важлива подія в <strong>команді </strong>, яку ви модеруєте",
    "On global events happening in any <strong>team</strong>" : "При настанні подій в будь-якій <strong>команді</strong>",
    "Single" : "Одиночний",
    "Personal" : "Особисте",
    "System" : "Система",
    "Visible" : "Видимий",
    "Open" : "Відкрити",
    "Invite" : "Запросити",
    "Join request" : "Запит на приєднання",
    "Friends" : "Друзі",
    "Password protected" : "Захищено паролем",
    "No Owner" : "Немає власника",
    "Hidden" : "Прихований",
    "Backend" : "Backend",
    "Local" : "Локально",
    "Root" : "Початок",
    "Team invite" : "Запрошення до команди",
    "Federated" : "Federated",
    "Mount point" : "Точка монтування",
    "Nextcloud Account" : "Обліковий запис Nextcloud",
    "Nextcloud Group" : "Група Nextcloud",
    "Email address" : "Адреса ел.пошти",
    "Contact" : "Контакт",
    "Circle" : "Коло",
    "Nextcloud App" : "Застосунок Nextcloud",
    "Member" : "Учасник",
    "Moderator" : "Модератор",
    "Admin" : "Адміністратор",
    "Owner" : "Власник",
    "%s shared »%s« with you." : "%s надав(-ла) доступ до \"%s\".",
    "%s shared »%s« with \"%s\"." : "%s надано доступ до \"%s\" із \"%s\".",
    "%s on %s" : "%s на %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$sподілив(-ла-)ся з вами \"%2$s\". \nНа вашу ел.скриньку було надіслано лист із посиланням для доступу до ресурсу.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s поділив(-ла-)ся з вами \"%2$s\". На вашу ел.скриньку було надіслано лист із посиланням для доступу до ресурсу.",
    "Password to access »%1$s« shared to you by %2$s" : "Пароль для доступу до %1$s, яким з вами поділив(-ла-)ся з вами %2$s",
    "Password to access »%s«" : "Пароль доступу до \"%s\"",
    "It is protected with the following password:" : "Він захищений таким паролем:",
    "%1$s via %2$s" : "%1$s через %2$s",
    "Click the button below to open it." : "Для відкриття натисніть кнопку нижче.",
    "Open »%s«" : "Відкрити \"%s\"",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s поділив(-ла-)ся з вами кількома файлами. \nНа вашу ел.скриньку було надіслано лист із посиланням для доступу до файлів.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s поділив(-ла-)ся з вами кількома файлами. На вашу ел.скриньку було надіслано лист із посиланням для доступу до файлів.",
    "Password to access files shared to you by %1$s" : "Пароль для доступу до файлів, наданих вам %1$s",
    "Password to access files" : "Пароль для доступу до файлів",
    "%s shared multiple files with \"%s\"." : "%s поділив(-ла-)ся кількома файлами з \"%s\".",
    "%s shared multiple files with you." : "%s поділив(-ла-)ся з вами кількома файлами.",
    "Boot up" : "Завантаження",
    "Nextcloud Initialization" : "Ініціалізація Nextcloud",
    "Circles App Initialization" : "Ініціалізація застосунка \"Кола\"",
    "Fresh installation status" : "Статус свіжої інсталяції",
    "Building Local Database" : "Створення локальної бази даних",
    "Testing Basic Circle Creation" : "Тестування створення базового кола",
    "Adding local users and moderators" : "Додавання локальних користувачів і модераторів",
    "Show all teams" : "Показати всі команди",
    "Create a new team" : "Створити нову команду",
    "Files" : "Файли",
    "This feature is not available for personal circles" : "Ця функція недоступна для особистих кіл",
    "The team is not federated" : "Команду неможливо надати у доступ об'єднаних хмар",
    "You cannot join this team" : "Ви не можете приєднатися до команди",
    "This member is not a moderator" : "Цей учасник не є модератором",
    "Insufficient privileges" : "Недостатні привілеї",
    "This member does not exist" : "Цей учасник не існує",
    "This member is the owner of the team" : "Учасник(-ця) є власником цієї команди",
    "Level cannot be changed for this type of member" : "Рівень не можна змінити для цього типу учасників",
    "You are already a member of this circle" : "Ви вже є учасником цього кола",
    "You have been blocked from this circle" : "Вас заблоковано в цьому колі",
    "The account is already a member of this circle" : "Обліковий запис уже є учасником цього кола",
    "The account has already been invited into this circle" : "Обліковий запис уже запрошено до цього кола",
    "%s (Team owned by %s)" : "%s (власником команди є %s)",
    "You are now a member of the Team \"%2$s\"" : "Ви тепер учасник команди \"%2$s\"",
    "You have been invited by %1$s into the Team \"%2$s\"" : "%1$s запросив вас до команди \"%2$s\"",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s додав запит на участь в команді \"%2$s\"",
    "Accept" : "Прийняти",
    "Refuse" : "Відмовитися",
    "Leave the team" : "Полишити команду",
    "%s" : "%s ",
    "Personal team" : "Приватна команда",
    "%s owned by %s" : "%s належить %s",
    "You have no permission to create a new team" : "У вас відсутні дозволи створювати нові команди",
    "%s shared a file with \"%s\"." : "%s поділив(-ла-)ся файлом з \"%s\".",
    "%s shared a file with you." : "%s поділив(-ла-)ся з вами файлом.",
    "%1$s shared %2$s with %3$s" : "%1$s спільний %2$s з %3$s",
    "%1$s shared %2$s with \"%3$s\"" : "%1$s спільний %2$s з «%3$s»",
    "Open %s" : "Відкрити %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s поділив(-ла-)ся з вами деяким вмістом. \nНа вашу ел.скриньку було надіслано лист із посиланням для доступу до вмісту.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s поділив(-ла-)ся з вами деяким вмістом. На вашу ел.скриньку було надіслано лист із посиланням для доступу до вмісту.",
    "Password to access content shared with you by %1$s" : "Пароль для доступу до вмісту, яким з вами поділив(-ла-)ся %1$s",
    "Password to access content" : "Пароль для доступу до вмісту",
    "This item is already shared with this team" : "Цей ресурс вже у спільному доступі з цією командою",
    "Bring cloud-users closer together." : "Зближіть користувачів хмари.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Команди дозволяють користувачам створювати власні групи з друзів, колег, знайомих.\nЗ цими групами людей подалі можна буде обмінюватися даними в різних застосунках.",
    "No files in here" : "Тут немає файлів",
    "No entries found in this folder" : "У цьому каталозі нічого немає",
    "Name" : "Ім'я",
    "Size" : "Розмір",
    "Modified" : "Змінено",
    "Teams' files" : "Файли команд",
    "Select team to filter by" : "Виберіть команду для відфільтрування",
    "No teams found" : "Жодної команди не знайдено",
    "Please select teams to filter by" : "Виберіть команди для відфільтрування",
    "No files found for the selected teams" : "Жодних файлів не знайдено для вибраних команд",
    "Shared to Circles" : "Опубліковано в Колах"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
