OC.L10N.register(
    "circles",
    {
    "You deleted {circle}" : "As cantzelladu {circle}",
    "{author} deleted {circle}" : "{author} at cantzelladu {circle}",
    "You removed {member} from {circle}" : "As bogadu a {member} dae {circle}",
    "You joined {circle}" : "As fatu s'atzessu a {circle}",
    "{member} joined {circle}" : "{member} at fatu s'atzessu a {circle}",
    "You accepted the invitation to join {circle}" : "As atzetadu s'invitu a atzèdere {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} at atzetadu s'invitu a intrare a {circle}",
    "You added {member} as member to {circle}" : "As agiuntu {member} comente cumponente de {circle}",
    "You have been added as member to {circle} by {author}" : "{author} t'at agiuntu comente cumponente de {circle}",
    "{member} has been added as member to {circle} by {author}" : "{author} at agiuntu a {member} comente cumponente de {circle}",
    "You added {external} to {circle}" : "As agiuntu a {external} in {circle}",
    "{external} has been added to {circle} by {author}" : "{author} at agiuntu a {external} in {circle}",
    "You accepted {member}'s request to join {circle}" : "As atzetadu sa rechesta de {member} de intrare in {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Sa rechesta tua de intrare in {circle} est istada atzetada dae {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "Sa rechesta de {member} de intrare in {circle} est istada atzetada dae {author}",
    "You left {circle}" : "As lassadu {circle}",
    "{member} left {circle}" : "{member} at lassadu {circle}",
    "You declined the invitation to join {circle}" : "As refudadu s'invitu a intrare in {circle}",
    "{member} declined an invitation to join {circle}" : "{member} at refudadu un'invitu a intrare in {circle}",
    "You cancelled your request to join {circle}" : "As annulladu sa rechesta de intrare in {circle}",
    "You have been removed from {circle} by {author}" : "{author} ti nch'at bogadu dae {circle}",
    "{member} has been removed from {circle} by {author}" : "{author} nch'at bogadu a {member} dae {circle}",
    "You removed {external} from {circle}" : "As bogadu a {external} dae {circle}",
    "{external} has been removed from {circle} by {author}" : "{author} nch'at bogadu a {external} dae {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "As annulladu s'invitu de {member} a intrare in {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "S'invitu a intrare in {circle} dd'at annulladu {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} at annulladu s'invitu de {member} de intrare in{circle}",
    "You dismissed {member}'s request to join {circle}" : "As iscartadu sa rechesta de {member} de intrare in {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Sa rechesta tua de intrare in {circle} dd'at iscartada {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "sa rechesta de {member} de intrare in {circle} est istada iscartada dae {author}",
    "You invited {member} to join {circle}" : "As invitadu a {member} a intrare in {circle}",
    "You have been invited to join {circle} by {author}" : "{author} t'at invitadu a intrare in {circle}",
    "{member} has been invited to join {circle} by {author}" : "{author} at invitadu a {member} a intrare in {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "As cambiadu su livellu de {member} in {circle} cun %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} at cambiadu su livellu tuo in {circle} cun %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} at cambiadu su livellu de {member} in {circle} cun %1$s",
    "You sent a request to join {circle}" : "As imbiadu una rechesta pro intrare in {circle}",
    "{member} sent a request to join {circle}" : "{member} at imbiadu una rechesta pro intrare in {circle}",
    "You are the new owner of {circle}" : "Ses mere de {circle}",
    "{member} is the new owner of {circle}" : "{member} immoe est mere de {circle}",
    "Single" : "Ùnicu",
    "Personal" : "Personale",
    "System" : "Sistema",
    "Visible" : "Visìbile",
    "Open" : "Aberi",
    "Invite" : "Invita",
    "Friends" : "Amighèntzias",
    "Password protected" : "Crae bardiada",
    "No Owner" : "Peruna propiedade",
    "Hidden" : "Cuadu",
    "Backend" : "Motore",
    "Local" : "Locale",
    "Root" : "Sorgente",
    "Federated" : "Federadu",
    "Mount point" : "Puntu de montàgiu",
    "Nextcloud Group" : "Grupu de Nextcloud",
    "Email address" : "Indiritzu de posta eletrònica",
    "Contact" : "Cuntatu",
    "Circle" : "Giru",
    "Nextcloud App" : "Aplicatzione de Nextcloud",
    "Member" : "Membru",
    "Moderator" : "Chie moderat",
    "Admin" : "Amministratzione",
    "Owner" : "Mere",
    "%s shared »%s« with you." : "%s at cumpartzidu »%s« cun tegus.",
    "%s shared »%s« with \"%s\"." : "%s at cumpartzidu »%s« cun \"%s\".",
    "%s on %s" : "%s in %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s at cumpartzidu »%2$s« cun tegus.\nDias dèpere àere giai retzidu unu messàgiu de posta seberadu cun unu ligòngiu pro intrare.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s at cumpartzidu »%2$s« cun tegus. Dias dèpere àere giai retzidu unu messàgiu de posta seberadu cun unu ligòngiu pro intrare.",
    "Password to access »%1$s« shared to you by %2$s" : "Crae pro s'atzessu »%1$s« cumpartzida cun tegus dae %2$s",
    "Password to access »%s«" : "Crae pro s'atzessu »%s«",
    "It is protected with the following password:" : "Est amparadu cun sa crae in fatu:",
    "%1$s via %2$s" : "%1$s cun %2$s",
    "Click the button below to open it." : "Incarca su butone a suta pro dd'abèrrere.",
    "Open »%s«" : "Aberi »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s at cumpartzìdu archìvios mùltiplos cun tegus.\nDias dèpere àere giai retzidu unu messàgiu de posta seberadu cun unu ligòngiu pro intrare.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s at cumpartzidu archìvios mùltiplos cun tegus. Dias dèpere àere giai retzidu unu messàgiu de posta seberadu cun unu ligòngiu pro intrare.",
    "Password to access files shared to you by %1$s" : "Crae pro intrare in is archìvios cumpartzidos cun tegus dae %1$s",
    "Password to access files" : "Crae pro intrare in is archìvios",
    "%s shared multiple files with \"%s\"." : "%s at cumpartzidu archìvios mùltiplos cun \"%s\".",
    "%s shared multiple files with you." : "%s at cumpartzidu prus archìvios cun te.",
    "Boot up" : "Avia",
    "Fresh installation status" : "Istadu de s'installatzione noa",
    "Building Local Database" : "Creschende sa base de datos locale",
    "Testing Basic Circle Creation" : " Proa de creatzione de giru de base",
    "Adding local users and moderators" : "Agiunta de utentes locales e persones chi moderent",
    "Create a new team" : "Crea un'iscuadra noa",
    "Files" : "Archìvios",
    "This feature is not available for personal circles" : "Sa funtzionalidade no est a disponimentu pro giros personales",
    "This member is not a moderator" : "Custa persone no est chie mòderat",
    "Insufficient privileges" : "Permissos non sufitzientes",
    "This member does not exist" : "Custa persone no esistit",
    "Level cannot be changed for this type of member" : "Non faghet a cambiare su livellu pro custa genia de cumponente",
    "You are already a member of this circle" : "Ses giai cumponente de custu giru",
    "You have been blocked from this circle" : "T'ant blocadu dae custu giru",
    "Accept" : "Atzeta",
    "Refuse" : "Refuda",
    "%s" : "%s",
    "%s owned by %s" : "%s de propiedade de %s",
    "You have no permission to create a new team" : "Non tenes permissu pro creare un'iscuadra noa",
    "%s shared a file with \"%s\"." : "%s at cumpartzidu un'archìviu cun \"%s\".",
    "%s shared a file with you." : "%s at cumpartzidu un'archìviu cun tegus.",
    "Open %s" : "Aberi %s",
    "Bring cloud-users closer together." : "Acosta impare a is utentes de sa nue.",
    "No files in here" : "Perunu archìviu",
    "No entries found in this folder" : "Perunu elementu agatadu in custa cartella",
    "Name" : "Nùmene",
    "Size" : "Mannària",
    "Modified" : "Modificadu",
    "Shared to Circles" : "Cumpartzidu cun is giros\\"
},
"nplurals=2; plural=(n != 1);");
