OC.L10N.register(
    "contactsinteraction",
    {
    "Recently contacted" : "Contactado recentemente",
    "Contacts Interaction" : "Interacción de contactos",
    "Manages interaction between accounts and contacts" : "Xestiona a interacción entre contas e contactos",
    "Collect data about accounts and contacts interactions and provide an address book for the data" : "Recolle datos sobre as interaccións entre contas e contactos e fornece un caderno de enderezos para os datos"
},
"nplurals=2; plural=(n != 1);");
