<?php
// This file is auto-generated. Do not edit!
return array('Adlm'=>'adlam','Ahom'=>'ahom','Aghb'=>'albaneză caucaziană','Arab'=>array(''=>'arabă','variant'=>array('persano-arabă')),'Narb'=>'arabă veche din nord','Sarb'=>'arabă veche din sud','Armi'=>'aramaică imperială','Armn'=>'armeană','Avst'=>'avestică','Bali'=>'balineză','Bamu'=>'bamum','Bass'=>'bassa vah','Batk'=>'batak','Beng'=>'bengaleză','Bhks'=>'bhaiksuki','Mymr'=>'birmană','Bopo'=>'bopomofo','Brah'=>'brahmanică','Brai'=>'braille','Bugi'=>'bugineză','Buhd'=>'buhidă','Cari'=>'cariană','Cakm'=>'chakma','Cham'=>'cham','Cher'=>'cherokee','Cyrl'=>'chirilică','Cyrs'=>'chirilică slavonă bisericească veche','Cprt'=>'cipriotă','Cpmn'=>'cipro-minoană','Zyyy'=>'comună','Copt'=>'coptă','Kore'=>'coreeană','Xsux'=>'cuneiformă sumero-akkadiană','Egyd'=>'demotică egipteană','Deva'=>'devanagari','Diak'=>'dives akuru','Dogr'=>'dogra','Hebr'=>'ebraică','Elba'=>'elbasan','Elym'=>'elimaică','Zsye'=>'emoji','Ethi'=>'etiopiană','Phnx'=>'feniciană','Lisu'=>'fraser','Geor'=>'georgiană','Geok'=>'georgiană bisericească','Glag'=>'glagolitică','Goth'=>'gotică','Gran'=>'grantha','Grek'=>'greacă','Gujr'=>'gujarati','Gong'=>'gunjala gondi','Guru'=>'gurmukhi','Hani'=>'han','Hanb'=>'hanb','Hang'=>'hangul','Rohg'=>'hanifi','Hano'=>'hanunoo','Hatr'=>'hatrană','Egyh'=>'hieratică egipteană','Hluw'=>'hieroglife anatoliene','Egyp'=>'hieroglife egiptene','Maya'=>'hieroglife maya','Hira'=>'hiragana','Inds'=>'indus','Ital'=>'italică veche','Jamo'=>'jamo','Jpan'=>'japoneză','Java'=>'javaneză','Kthi'=>'kaithi','Knda'=>'kannada','Kana'=>'katakana','Kawi'=>'kawi','Kali'=>'kayah li','Khar'=>'kharosthi','Khmr'=>'khmeră','Khoj'=>'khojki','Chrs'=>'khorezmiană','Sind'=>'khudawadi','Lana'=>'lanna','Laoo'=>'laoțiană','Latn'=>'latină','Latf'=>'latină Fraktur','Latg'=>'latină gaelică','Lepc'=>'lepcha','Lyci'=>'liciană','Lydi'=>'lidiană','Limb'=>'limbu','Lina'=>'lineară A','Linb'=>'lineară B','Kits'=>'litere mici khitane','Hung'=>'maghiară veche','Mahj'=>'mahajani','Maka'=>'makasar','Mlym'=>'malayalam','Mand'=>'mandeană','Mani'=>'maniheeană','Marc'=>'marchen','Gonm'=>'masaram gondi','Medf'=>'medefaidrin','Mtei'=>'meitei mayek','Mend'=>'mende','Mero'=>'meroitică','Merc'=>'meroitică cursivă','Modi'=>'modi','Mong'=>'mongolă','Dsrt'=>'mormonă','Zinh'=>'moștenită','Mroo'=>'mro','Mult'=>'multani','Nkoo'=>'n’ko','Nbat'=>'nabateeană','Nagm'=>'nag mundari','Nand'=>'nandinagari','Aran'=>'nastaaliq','Zxxx'=>'nescrisă','Newa'=>'newa','Zmth'=>'notație matematică','Nshu'=>'nüshu','Hmnp'=>'nyiakeng puachue hmong','Ogam'=>'ogham','Olck'=>'ol chiki','Orkh'=>'orhon','Orya'=>'oriya','Osge'=>'osage','Osma'=>'osmanya','Hmng'=>'pahawh hmong','Phli'=>'pahlavi pentru inscripții','Phlp'=>'pahlavi pentru psaltire','Palm'=>'palmirenă','Prti'=>'partă pentru inscripții','Pauc'=>'pau cin hau','Perm'=>'permică veche','Xpeo'=>'persană veche','Phag'=>'phags-pa','Zanb'=>'Piața Zanabazar','Plrd'=>'pollardă fonetică','Rjng'=>'rejang','Runr'=>'runică','Samr'=>'samariteană','Saur'=>'saurashtra','Shaw'=>'savă','Zzzz'=>'scriere necunoscută','Sgnw'=>'scrierea simbolică','Shrd'=>'sharadă','Sidd'=>'siddham','Cans'=>'silabică aborigenă canadiană unificată','Hrkt'=>'silabică japoneză','Zsym'=>'simboluri','Hans'=>array(''=>'simplificată','stand-alone'=>array('han simplificată')),'Sinh'=>'singaleză','Syrc'=>'siriacă','Syrj'=>'siriacă occidentală','Syrn'=>'siriacă orientală','Sogd'=>'sogdiană','Sogo'=>'sogdiană veche','Sora'=>'sora sompeng','Soyo'=>'soyombo','Dupl'=>'stenografie duployană','Sund'=>'sundaneză','Sylo'=>'syloti nagri','Tglg'=>'tagalog','Tagb'=>'tagbanwa','Tale'=>'tai le','Talu'=>'tai le nouă','Tavt'=>'tai viet','Takr'=>'takri','Taml'=>'tamilă','Tnsa'=>'tangsa','Tang'=>'tangut','Telu'=>'telugu','Thaa'=>'thaana','Thai'=>'thailandeză','Tibt'=>'tibetană','Tfng'=>'tifinagh','Tirh'=>'tirhuta','Toto'=>'toto','Hant'=>array(''=>'tradițională','stand-alone'=>array('han tradițională')),'Ugar'=>'ugaritică','Ougr'=>'uigură veche','Vaii'=>'vai','Wara'=>'varang kshiti','Vith'=>'vithkuqi','Wcho'=>'wancho','Yezi'=>'yazidită','Yiii'=>'yi','Qaag'=>'zawgyi');
