OC.L10N.register(
    "files_sharing",
    {
    "File shares" : "Fájlmegosztások",
    "Downloaded via public link" : "Letöltve nyilvános hivatkozással",
    "Downloaded by {email}" : "Letöltötte: {email}",
    "{file} downloaded via public link" : "{file} nyilvános hivatkozással letöltve",
    "{email} downloaded {file}" : "{email} letöltötte: {file}",
    "Shared with group {group}" : "Megosztva a(z) {group} csoporttal",
    "Removed share for group {group}" : "{group} csoport megosztása eltávolítva",
    "{actor} shared with group {group}" : "{actor} megosztotta a(z) {group} csoporttal",
    "{actor} removed share for group {group}" : "{actor} eltávolította a(z) {group} csoport megosztását",
    "Share for group {group} expired" : "A(z) {group} csoport megosztása lejárt",
    "You shared {file} with group {group}" : "Megosztotta a(z) {file} fájlt a(z) {group} csoporttal",
    "You removed group {group} from {file}" : "Eltávolította a(z) {group} csoportot erről: {file}",
    "{actor} shared {file} with group {group}" : "{actor} megosztotta a(z) {file} fájlt a(z) {group} csoporttal",
    "{actor} removed group {group} from {file}" : "{actor} eltávolította a(z) {group} csoportot erről: {file}",
    "Share for file {file} with group {group} expired" : "A(z) {file} fájl megosztása a(z) {group} csoporttal lejárt",
    "Shared as public link" : "Nyilvános hivatkozásként megosztva",
    "Removed public link" : "Nyilvános hivatkozás eltávolítva",
    "Public link expired" : "Nyilvános hivatkozás lejárt",
    "{actor} shared as public link" : "{actor} megosztotta nyilvános hivatkozásként",
    "{actor} removed public link" : "{actor} eltávolított egy nyilvános hivatkozást",
    "Public link of {actor} expired" : "{actor} nyilvános hivatkozása lejárt",
    "You shared {file} as public link" : "Megosztotta nyilvános hivatkozásként: {file}",
    "You removed public link for {file}" : "Eltávolította a(z) {file} nyilvános hivatkozását",
    "Public link expired for {file}" : "A(z) {file} nyilvános hivatkozása lejárt",
    "{actor} shared {file} as public link" : "{actor} nyilvános hivatkozásként megosztotta: {file}",
    "{actor} removed public link for {file}" : "{actor} eltávolította a(z) {file} nyilvános hivatkozását",
    "Public link of {actor} for {file} expired" : "{actor} nyilvános hivatkozása lejárt ehhez: {file}",
    "{user} accepted the remote share" : "{user} elfogadta a távoli megosztást",
    "{user} declined the remote share" : "{user} visszautasította a távoli megosztást",
    "You received a new remote share {file} from {user}" : "Egy új távoli megosztást kapott ehhez: {file}, tőle: {user}",
    "{user} accepted the remote share of {file}" : "{user} elfogadta a(z) {file} távoli megosztását",
    "{user} declined the remote share of {file}" : "{user} visszautasította a(z) {file} távoli megosztását",
    "{user} unshared {file} from you" : "{user} visszavonta Öntől a(z) {file} megosztását",
    "Shared with {user}" : "Megosztva vele: {user}",
    "Removed share for {user}" : "{user} megosztása eltávolítva",
    "You removed yourself" : "Eltávolította saját magát",
    "{actor} removed themselves" : "{actor} eltávolította magát",
    "{actor} shared with {user}" : "{actor} megosztotta vele: {user}",
    "{actor} removed share for {user}" : "{actor} eltávolította {user} megosztását",
    "Shared by {actor}" : "Megosztotta: {actor}",
    "{actor} removed share" : "{actor} eltávolította a megosztást",
    "Share for {user} expired" : "A megosztás {user} számára lejárt",
    "Share expired" : "A megosztás lejárt",
    "You shared {file} with {user}" : "Megosztotta vele a(z) {file} fájlt: {user}",
    "You removed {user} from {file}" : "Eltávolította innen {user} felhasználót: {file}",
    "You removed yourself from {file}" : "Eltávolította innen saját magát: {file}",
    "{actor} removed themselves from {file}" : "{actor} eltávolította innen saját magát: {file}",
    "{actor} shared {file} with {user}" : "{actor} megosztotta a(z) {file} fájlt vele: {user}",
    "{actor} removed {user} from {file}" : "{actor} eltávolította innen {user} felhasználót: {file}",
    "{actor} shared {file} with you" : "{actor} megosztotta Önnel: {file}",
    "{actor} removed you from the share named {file}" : "{actor} eltávolította Önt a megosztásból: {file}",
    "Share for file {file} with {user} expired" : "A(z) {file} fájl megosztása a(z) {user} felhasználóval lejárt",
    "Share for file {file} expired" : "A(z) {file} fájl megosztása lejárt",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Egy e-mailben vagy nyilvános hivatkozással megosztott fájl vagy mappa <strong>letöltve</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Egy fájl vagy mappa meg lett osztva egy <strong>másik kiszolgálóról</strong>",
    "Sharing" : "Megosztás",
    "A file or folder has been <strong>shared</strong>" : "Egy fájl vagy mappa <strong>megosztva</strong>",
    "Shared link" : "Hivatkozás megosztva",
    "Wrong share ID, share does not exist" : "Hibás megosztási azonosító, a megosztás nem létezik",
    "Could not delete share" : "A megosztás nem törölhető",
    "Please specify a file or folder path" : "Adjon meg egy fájl- vagy mappaútvonalat",
    "Wrong path, file/folder does not exist" : "Hibás útvonal, a fájl/mappa nem létezik",
    "Could not create share" : "A megosztás nem hozható létre",
    "Please specify a valid account to share with" : "Adjon meg egy érvényes fiókot a megosztáshoz",
    "Group sharing is disabled by the administrator" : "A csoportos megosztást letiltotta a rendszergazda",
    "Please specify a valid group" : "Adjon meg egy érvényes csoportot",
    "Public link sharing is disabled by the administrator" : "A nyilvános hivatkozással történő megosztást letiltotta a rendszergazda",
    "Please specify a valid email address" : "Adjon meg egy érvényes e-mail-címet",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "A(z) %s megosztás jelszavának Nextcloud Beszélgetéssel történő elküldése sikertelen, mert a Nextcloud Beszélgetés nem engedélyezett",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "A(z) %1$s megosztása sikertelen, mert a háttérprogram nem engedélyezi a(z) %2$s típusú megosztást",
    "Please specify a valid federated account ID" : "Adjon meg egy érvényes föderált fiókazonosítót",
    "Please specify a valid federated group ID" : "Adjon meg egy érvényes föderált csoportazonosítót",
    "You cannot share to a Team if the app is not enabled" : "Nem tudja megosztani egy Csapat számára, ha az alkalmazás nem engedélyezett",
    "Please specify a valid team" : "Adjon meg egy érvényes csapatot",
    "Sharing %s failed because the back end does not support room shares" : "A(z) %s megosztása sikertelen, mert a háttérprogram nem támogatja a szobamegosztásokat",
    "Sharing %s failed because the back end does not support ScienceMesh shares" : "A(z) %s megosztása sikertelen, mert a háttérprogram nem támogatja a ScienceMesh megosztásokat",
    "Unknown share type" : "Ismeretlen megosztástípus",
    "Not a directory" : "Nem könyvtár",
    "Could not lock node" : "Nem sikerült zárolni a csomópontot",
    "Public upload is only possible for publicly shared folders" : "A nyilvános feltöltés csak a nyilvánosan megosztott mappákban lehetséges",
    "Share must at least have READ or CREATE permissions" : "A megosztásnak legalább OLVASÁSI és LÉTREHOZÁSI engedéllyel kell rendelkeznie",
    "Share must have READ permission if UPDATE or DELETE permission is set" : "A megosztásnak OLVASÁSI jogosultsággal kell rendelkeznie, ha a FRISSÍTÉSI vagy TÖRLÉSI jogosultság meg van adva",
    "Public upload disabled by the administrator" : "A nyilvános feltöltést letiltotta a rendszergazda",
    "Could not lock path" : "Nem sikerült zárolni az útvonalat",
    "Wrong or no update parameter given" : "Hibás vagy üres frissítési paraméter",
    "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled." : "A „Jelszó kiküldése a Nextcloud Beszélgetéssel” nem sikerült a fájlnál vagy mappánál, mert a Nextcloud Beszélgetés nem engedélyezett.",
    "Wrong password" : "Hibás jelszó",
    "shared by %s" : "megosztotta: %s",
    "Download" : "Letöltés",
    "Add to your %s" : "Hozzáadás a %shoz",
    "Direct link" : "Közvetlen hivatkozás",
    "Share API is disabled" : "Megosztás API letiltva",
    "File sharing" : "Fájlmegosztás",
    "Share will expire tomorrow" : "A megosztás holnap lejár",
    "Your share of {node} will expire tomorrow" : "A(z) {node} megosztása holnap lejár",
    "You received {share} as a share by {user}" : "A(z) {share} megosztást kapta {user} felhasználótól",
    "You received {share} to group {group} as a share by {user}" : "A(z) {share} megosztást a(z) {group} csoportba kapta {user} felhasználótól.",
    "Accept" : "Elfogadás",
    "Decline" : "Elutasítás",
    "This application enables people to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable people can then share files and folders with other accounts and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other people outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation." : "Ez az alkalmazás lehetővé teszi fájlok megosztását a Nextcloudon belül. Amennyiben engedélyezve van, a rendszergazda kiválaszthatja, hogy mely csoportok oszthassanak meg fájlokat. Az érintettek ezután megoszthatják a fájlokat és mappákat más fiókokkal és csoportokkal a Nextcloudon belül. Ezenkívül, ha a rendszergazda engedélyezi a megosztás hivatkozással funkciót, akkor egy külső hivatkozás segítségével fájlokat oszthat meg más fiókokkal a Nextcloudon kívül. A rendszergazdák kikényszeríthetik a jelszavakat, a lejárati dátumokat, és engedélyezhetik a megosztási hivatkozásokkal történő kiszolgálók közötti, valamint a mobileszközökön történő megosztást.\nA funkció kikapcsolása eltávolítja a megosztott fájlokat és mappákat a kiszolgálóról az összes megosztott címzett, valamint a szinkronizálási kliensek és mobilalkalmazások számára. További információ a Nextcloud dokumentációjában található.",
    "People" : "Emberek",
    "Filter accounts" : "Fiókok szűrése",
    "Expiration date" : "Lejárati dátum",
    "Set a password" : "Jelszó beállítása",
    "Password" : "Jelszó",
    "Enter a valid password" : "Adjon meg érvényes jelszót",
    "Generate a new password" : "Új jelszó előállítása",
    "Link copied" : "Hivatkozás másolva",
    "Invalid email address" : "Érvénytelen e-mail-cím",
    "Share link" : "Megosztási hivatkozás",
    "Copy" : "Másolás",
    "Send link via email" : "Hivatkozás küldése levélben",
    "Remove email" : "E-mail eltávolítása",
    "Select" : "Kiválasztás",
    "Add a note" : "Megjegyzés hozzáadása",
    "Close" : "Bezárás",
    "Error creating the share: {errorMessage}" : "Hiba történt a megosztás létrehozása során: {errorMessage}",
    "Error creating the share" : "Megosztás létrehozása sikertelen",
    "File request" : "Fájlkérés",
    "Cancel" : "Mégse",
    "Continue" : "Folytatás",
    "Error while toggling options" : "Hiba a beállítások módosításakor",
    "Choose a default folder for accepted shares" : "Válasszon egy mappát az elfogadott megosztásokhoz",
    "Invalid path selected" : "Érvénytelen útvonal választva",
    "Unknown error" : "Ismeretlen hiba",
    "Set default folder for accepted shares" : "Alapértelmezett mappa beállítása az elfogadott megosztásokhoz",
    "Reset" : "Visszaállítás",
    "Reset folder to system default" : "Mappa visszaállítása az alapértelmezett értékre",
    "group" : "csoport",
    "conversation" : "beszélgetés",
    "remote" : "távoli",
    "remote group" : "távoli csoport",
    "guest" : "vendég",
    "Shared with the group {user} by {owner}" : "{owner} megosztotta a(z) {user} csoporttal",
    "Shared with the conversation {user} by {owner}" : "{owner} megosztotta a(z) {user} beszélgetésben",
    "Shared with {user} by {owner}" : " {owner} megosztotta {user} felhasználóval",
    "Open Sharing Details" : "Megosztás részleteinek megnyitása",
    "Added by {initiator}" : "Általa hozzáadva: {initiator}",
    "Via “{folder}”" : "A(z) „{folder}” mappán keretül",
    "Unshare" : "Megosztás visszavonása",
    "Cannot copy, please copy the link manually" : "A másolás sikertelen, másolja kézzel a hivatkozást",
    "Copy internal link" : "Belső hivatkozás másolása",
    "Internal link" : "Belső hivatkozás",
    "{shareWith} by {initiator}" : "{shareWith}, {initiator} által",
    "Shared via link by {initiator}" : "{initiator} által hivatkozással megosztva",
    "Mail share ({label})" : "E-mail megosztás ({label})",
    "Share link ({label})" : "Megosztási hivatkozás ({label})",
    "Share link ({index})" : "Megosztási hivatkozás ({index})",
    "Create public link" : "Nyilvános hivatkozás létrehozása",
    "Actions for \"{title}\"" : "A(z) „{title}” műveletei",
    "Error, please enter proper password and/or expiration date" : "Hiba, írja be a megfelelő jelszót vagy lejárati dátumot",
    "Link share created" : "Megosztási hivatkozás létrehozása",
    "Error while creating the share" : "Hiba a megosztás létrehozása során",
    "Please enter the following required information before creating the share" : "A megosztás létrehozása előtt adja meg a következő szükséges információkat",
    "Password protection (enforced)" : "Jelszavas védelem (megkövetelve)",
    "Password protection" : "Jelszavas védelem",
    "Enter a password" : "Adja meg a jelszót",
    "Create share" : "Megosztás létrehozása",
    "Customize link" : "Hivatkozás testreszabása",
    "Generate QR code" : "QR-kód készítése",
    "Add another link" : "További hivatkozás hozzáadása",
    "Create a new share link" : "Új megosztási hivatkozás létrehozása",
    "View only" : "Csak megtekintés",
    "Can edit" : "Szerkesztheti",
    "Custom permissions" : "Egyéni jogosultságok",
    "Resharing is not allowed" : "A továbbosztás nem engedélyezett",
    "Name or email …" : "Név vagy e-mail-cím…",
    "Name, email, or Federated Cloud ID …" : "Név, e-mail-cím vagy föderált felhőazonosító…",
    "Searching …" : "Keresés…",
    "No elements found." : "Nem található elem.",
    "Search everywhere" : "Keresés mindenhol",
    "Guest" : "Vendég",
    "Group" : "Csoport",
    "Email" : "E-mail",
    "Team" : "Csapat",
    "Talk conversation" : "Beszélgetés",
    "Deck board" : "Kártyatábla",
    "ScienceMesh" : "ScienceMesh",
    "on {server}" : "{server} kiszolgálón",
    "Note:" : "Megjegyzés:",
    "File drop" : "Fájllerakat",
    "Terms of service" : "Szolgáltatási feltételek",
    "Update share" : "Megosztás frissítése",
    "Save share" : "Megosztás mentése",
    "Read" : "Olvasás",
    "Create" : "Létrehozás",
    "Edit" : "Szerkesztés",
    "Share" : "Megosztás",
    "Delete" : "Törlés",
    "Allow upload and editing" : "Feltöltés és szerkesztés engedélyezése",
    "Allow editing" : "Szerkesztés engedélyezése",
    "Upload only" : "Csak feltöltés",
    "Advanced settings" : "Speciális beállítások",
    "Share label" : "Megosztás címkéje",
    "Set password" : "Jelszó beállítása",
    "Password expires {passwordExpirationTime}" : "A jelszó lejárati ideje: {passwordExpirationTime}",
    "Password expired" : "A jelszó lejárt",
    "Video verification" : "Videós ellenőrzés",
    "Expiration date (enforced)" : "Lejárati idő (megkövetelve)",
    "Set expiration date" : "Lejárati idő beállítása",
    "Hide download" : "Letöltés elrejtése",
    "Allow download and sync" : "Letöltés és szinkronizálás engedélyezése",
    "Note to recipient" : "Jegyzet a címzettnek",
    "Enter a note for the share recipient" : "Adjon meg egy megjegyzést a megosztás címzettje számára",
    "Delete share" : "Megosztás törlése",
    "Others with access" : "Mások, akik hozzáféréssel rendelkeznek",
    "Toggle list of others with access to this directory" : "A könyvtárhoz hozzáféréssel rendelkezők listája be/ki",
    "Toggle list of others with access to this file" : "A fájlhoz hozzáféréssel rendelkezők listája be/ki",
    "Unable to fetch inherited shares" : "Nem sikerült lekérni az örökölt megosztásokat",
    "Shares" : "Megosztások",
    "Unable to load the shares list" : "A megosztások listájának betöltése sikertelen",
    "Expires {relativetime}" : "Lejárat: {relativetime}",
    "this share just expired." : "ez a megosztás épp most járt le.",
    "Shared with you by {owner}" : "{owner} megosztotta Önnel",
    "Internal shares" : "Belső megosztások",
    "External shares" : "Külső megosztások",
    "Link to a file" : "Hivatkozás egy fájlhoz",
    "_Accept share_::_Accept shares_" : ["Megosztás elfogadása","Megosztások elfogadása"],
    "Open in Files" : "Megnyitás a Fájlokban",
    "_Reject share_::_Reject shares_" : ["Megosztás elutasítása","Megosztások elutasítása"],
    "_Restore share_::_Restore shares_" : ["Megosztás helyreállítása","Megosztások helyreállítása"],
    "Shared" : "Megosztva",
    "Shared by {ownerDisplayName}" : "Megosztotta: {ownerDisplayName}",
    "Shared multiple times with different people" : "Többször megosztva különböző személyekkel",
    "Sharing options" : "Megosztási beállítások",
    "Shared with others" : "Megosztva másokkal",
    "Create file request" : "Fájlkérés létrehozása",
    "No file" : "Nincs fájl",
    "Public share" : "Nyilvános megosztás",
    "Overview of shared files." : "Megosztott fájlok áttekintése.",
    "No shares" : "Nincs megosztás",
    "Files and folders you shared or have been shared with you will show up here" : "A saját és mások által megosztott fájlok és mappák itt jelennek meg.",
    "Shared with you" : "Megosztva Önnel",
    "List of files that are shared with you." : "A mások által megosztott fájlok listája.",
    "Nothing shared with you yet" : "Még semmi sincs megosztva Önnel",
    "Files and folders others shared with you will show up here" : "A mások által megosztott fájlok és mappák itt jelennek meg",
    "List of files that you shared with others." : "A másokkal megosztott fájlok listája.",
    "Nothing shared yet" : "Még semmi sincs megosztva",
    "Files and folders you shared will show up here" : "A megosztott fájlok és mappák itt fognak megjelenni",
    "Shared by link" : "Megosztva hivatkozással",
    "List of files that are shared by link." : "Hivatkozással megosztott fájlok listája.",
    "No shared links" : "Nincs megosztott hivatkozás",
    "Files and folders you shared by link will show up here" : "A hivatkozással megosztott fájlok és mappák itt jelennek meg",
    "Deleted shares" : "Törölt megosztások",
    "List of shares you left." : "Elhagyott megosztások listája.",
    "No deleted shares" : "Nincs törölt megosztás",
    "Shares you have left will show up here" : "Az Ön által elhagyott megosztások itt jelennek meg.",
    "Pending shares" : "Függőben lévő megosztások",
    "List of unapproved shares." : "Nem jóváhagyott megosztások listája.",
    "No pending shares" : "Nincsenek függőben lévő megosztások",
    "Shares you have received but not approved will show up here" : "Az érkezett, de még nem jóváhagyott megosztások itt jelennek meg",
    "Error updating the share: {errorMessage}" : "Hiba történt a megosztás frissítése során: {errorMessage}",
    "Error updating the share" : "Hiba történt a megosztás frissítése során",
    "File \"{path}\" has been unshared" : "A(z) „{path}” fájl megosztása leállítva",
    "Folder \"{path}\" has been unshared" : "A(z) „{path}” mappa megosztása leállítva",
    "Share label saved" : "A megosztás címkéje mentve",
    "Share password saved" : "A megosztás jelszava mentve",
    "Shared by" : "Megosztotta:",
    "Shared with" : "Megosztva vele:",
    "Password created successfully" : "A jelszó sikeresen létrehozva",
    "Error generating password from password policy" : "Hiba a jelszóházirend alapján történő jelszó-előállítás során",
    "Shared with you and the group {group} by {owner}" : "{owner} megosztotta Önnel és a(z) {group} csoporttal",
    "Shared with you and {circle} by {owner}" : "{owner} megosztotta Önnel és a(z) {circle} körrel",
    "Shared with you and the conversation {conversation} by {owner}" : "{owner} megosztotta Önnel és a(z) {conversation} beszélgetéssel",
    "Shared with you in a conversation by {owner}" : "{owner} megosztotta Önnel egy beszélgetésben",
    "Share not found" : "A megosztás nem található",
    "Back to %s" : "Vissza ide: %s",
    "Add to your Nextcloud" : "Hozzáadás a Nextcloudjához",
    "Waiting…" : "Várakozás…",
    "error" : "hiba",
    "finished" : "kész",
    "This will stop your current uploads." : "Ez le fogja állítani a jelenlegi feltöltéseit.",
    "Move or copy" : "Áthelyezés vagy másolás",
    "You can upload into this folder" : "Ebbe a mappába fel tud tölteni",
    "Show list view" : "Listanézet megjelenítése",
    "Show grid view" : "Rácsnézet megjelenítése",
    "No compatible server found at {remote}" : "Nem található kompatibilis kiszolgáló itt: {remote}",
    "Invalid server URL" : "Érvénytelen kiszolgáló URL",
    "Failed to add the public link to your Nextcloud" : "Nem sikerült hozzáadni a nyilvános hivatkozást a Nexcloudjához",
    "Download all files" : "Összes fájl letöltése",
    "Link copied to clipboard" : "Hivatkozás a vágólapra másolva",
    "Copy to clipboard" : "Másolás a vágólapra",
    "Copy internal link to clipboard" : "Belső hivatkozás másolása a vágólapra",
    "Only works for people with access to this file" : "Csak azoknál működik, akiknek van hozzáférésük ehhez a fájlhoz",
    "Copy public link of \"{title}\" to clipboard" : "A(z) „{title}” nyilvános hivatkozás másolása a vágólapra",
    "Search globally" : "Globális keresés",
    "Search for share recipients" : "Megosztás résztvevőinek keresése",
    "No recommendations. Start typing." : "Nincs javaslat. Kezdjen gépelni.",
    "Enter your name" : "Adja meg a nevét",
    "Show sharing options" : "Megosztási beállítások megjelenítése",
    "Share note" : "Jegyzet megosztása",
    "Upload files to %s" : "Fájlok feltöltése ide: %s",
    "Note" : "Megjegyzés",
    "Select or drop files" : "Válasszon vagy dobjon ide fájlokat",
    "Uploading files" : "Fájlok feltöltése",
    "Uploaded files:" : "Feltöltött fájlok:",
    "By uploading files, you agree to the %1$sterms of service%2$s." : "A fájlok feltöltésével elfogadja a %1$sszolgáltatási feltételeket %2$s.",
    "Name" : "Név",
    "Filename must not be empty." : "A fájlnév nem lehet üres."
},
"nplurals=2; plural=(n != 1);");
