OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "Posljednje izvješće poslano: {on}",
    "An error occurred while sending your report." : "Došlo je do pogreške prilikom slanja vašeg izvješća.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Popis aplikacija <em>(za svaku aplikaciju: naziv, inačica, status)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Okolina baze podataka <em>(vrsta, inačica, veličina baze podataka)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Informacije o šifriranju <em>(je li omogućeno?, koji je zadani modul)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Broj dijeljenja <em>(po vrsti i postavci dopuštenja)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP okolina <em>(inačica, ograničenje memorije, maks. vrijeme izvršavanja, maks. veličina datoteke)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Pojedinosti o instanci poslužitelja <em>(inačica, korištena predmemorija, status zaključavanja/pretpregleda/avatara)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "Statistika <em>(broj datoteka, korisnika, pohrana po vrsti, komentara i oznaka)</em>",
    "Usage survey" : "Anketa o korištenju",
    "Help improve Nextcloud" : "Pomozite poboljšati Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Želite li nam pomoći poboljšati Nextcloud pružanjem nekih anonimnih podataka o svojoj instalaciji i korištenju? Slanje podataka možete ponovo onemogućiti u bilo kojem trenutku u postavkama administratora.",
    "Send usage" : "Pošalji podatke o korištenju",
    "Not now" : "Ne sada",
    "Never" : "Nikad",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Šalje anonimne podatke Nextcloudu koji nam pomažu poboljšati Nextcloud.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Možete nam pomoći da poboljšamo Nextcloud slanjem nekih podataka o svojoj trenutnoj instalaciji i korištenju.",
    "Send new report now" : "Pošalji novo izvješće",
    "Send usage survey monthly" : "Pošalji mjesečnu anketu o korištenju",
    "Data to send" : "Podaci za slanje",
    "Last report sent on: %s" : "Posljednje izvješće poslano: %s",
    "Last report" : "Posljednje izvješće"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
