OC.L10N.register(
    "related_resources",
    {
    "Calendar" : "Kalendár",
    "Calendar \"%s\"" : "Kalendár \"%s\"",
    "Deck" : "Nástenka",
    "Deck board \"%s\"" : "Tabule v Deck \"%s\"",
    "Files" : "Súbory",
    "File \"%s\"" : "Súbor \"%s\"",
    "Group Folder" : "Skupinový adresár",
    "Group Folder \"%s\"" : "Skupinový adresár \"%s\"",
    "Talk conversation" : "Konverzácia v Rozhovoroch",
    "Conversation with %s" : "Koverzácia s %s",
    "Talk" : "Rozhovor",
    "Talk conversation \"%s\"" : "Konverzácia v Rozhovore \"%s\"",
    "Related Resources" : "Príbuzné zdroje",
    "Displays resources related to current item in right panel" : "Zobrazuje zdroje súvisiace s aktuálnou položkou v pravom paneli",
    "Displays resources related to current item in right panel." : "Zobrazuje zdroje súvisiace s aktuálnou položkou v pravom paneli"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
