OC.L10N.register(
    "circles",
    {
    "Personal" : "Անձնական",
    "Federated" : "Federated",
    "Owner" : "Owner",
    "Open %s" : "Բացել {նիշքիանուն}",
    "No files in here" : "Ֆայլեր չկան այստեղ",
    "Name" : "Անուն",
    "Size" : "Չափս",
    "Modified" : "Փոփոխված"
},
"nplurals=2; plural=(n != 1);");
