OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "Fitxategien deskarga-muga",
    "File link share download limit" : "Fitxategien esteka partekatze deskarga-muga",
    "This app allows limiting the number of downloads for external link shares." : "Aplikazio honek kanpoko esteken partekatzeen deskarga kopurua mugatzeko aukera ematen du.",
    "The minimum limit is 1" : "Beheko muga 1 da",
    "Failed to set download limit" : "Ezin izan da ezarri deskarga-muga",
    "Failed to remove download limit" : "Ezin izan da kendu deskarga-muga",
    "Limit downloads" : "Mugatu deskargak",
    "Set download limit" : "Ezarri deskarga muga",
    "Setting a new limit will reset the download count" : "Muga berri bat ezarriz gero, deskarga-kopurua berrezarri egingo da",
    "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["deskarga 1 gehiago baimentzen da","{count} deskarga gehiago baimendu dira"],
    "Failed to set default download limit" : "Ezin izan da ezarri deskarga-muga lehenetsia",
    "Download limit" : "Deskarga-muga",
    "Configure the default download limit for external shares." : "Konfiguratu kanpoko partekatzeetarako deskarga-muga lehenetsia.",
    "Set default download limit" : "Ezarri deskarga muga lehenetsia",
    "You have reached the maximum amount of downloads allowed" : "Onartutako gehieneko deskarga kopurura iritsi zara",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "Partekatze honek deskarga kopuru mugatua du. Ziur deskarga berri bat abiarazi nahi duzula?"
},
"nplurals=2; plural=(n != 1);");
