OC.L10N.register(
    "logreader",
    {
    "Logging" : "Евидентирање",
    "Errors in the log" : "Грешки во записникот",
    "No errors in the logs since %s" : "Не постојат грешки во записникот од %s",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["%n грешка во записникот од %s","%n грешки во записникот од %s"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["%n предупредување во записникот од %s","%n предупредувања во записникот од %s"],
    "Log Reader" : "Читач на записи",
    "A log reader for Nextcloud" : "Читач на записи со евиденција за Nextcloud",
    "Log reader for Nextcloud" : "Читач на записи со евиденција за Nextcloud",
    "Log reader" : "Читач на записи",
    "Level" : "Ниво",
    "App" : "Апликација",
    "Time" : "Време",
    "Ctrl" : "Ctrl",
    "Download logs" : "Преземи записи",
    "Relative" : "Релативно",
    "Message" : "Порака",
    "Show details" : "Прикажи детали",
    "Debug" : "Дебаг",
    "Info" : "Инфо",
    "Warning" : "Предупредување",
    "Error" : "Грешка",
    "Fatal" : "Фатално"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
