OC.L10N.register(
    "app_api",
    {
    "Cancel" : "Odustani",
    "Delete" : "Obriši",
    "Edit" : "Izmjeni",
    "Name" : "Ime",
    "Enabled" : "Aktivirano",
    "Save" : "Spremi",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ova aplikacija se ne može instalirati zbog slijedećih neispunjenih ovisnosti:",
    "Version" : "Verzija",
    "Actions" : "Radnje",
    "Documentation" : "Dokumentacija",
    "Updates" : "Ažuriranja",
    "Disable" : "Onemogući"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
