OC.L10N.register(
    "app_api",
    {
    "Failed to enable ExApp" : "No s'ha pogut activar ExApp",
    "Failed to disable ExApp" : "No s'ha pogut desactivar ExApp",
    "Could not update ExApp" : "No s'ha pogut actualitzar ExApp",
    "AppAPI authentication failed" : "Ha fallat l'autenticació de l'AppAPI",
    "AppAPI ExApp notifier" : "Notificador AppAPI ExApp",
    "AppAPI" : "AppAPI",
    "Nextcloud AppAPI" : "Nextcloud AppAPI",
    "The AppAPI Project is an exciting initiative that aims to revolutionize the way applications are developed for Nextcloud." : "El projecte AppAPI és una iniciativa emocionant que pretén revolucionar la manera com es desenvolupen les aplicacions per a Nextcloud.",
    "External Apps management" : "Gestió d'Apps externes",
    "Admin options saved" : "Opcions d'administració desades",
    "Failed to save admin options" : "No s'han pogut desar les opcions d'administració",
    "Cancel" : "Cancelar",
    "Delete" : "Suprimir",
    "Edit" : "Edició",
    "Name" : "Nom",
    "Host" : "Servidor",
    "Nextcloud URL" : "Nextcloud URL",
    "Enabled" : "Habilitat",
    "Display name" : "Nom de visualització",
    "Network" : "Xarxa",
    "Confirm" : "Confirma",
    "Save" : "Desar",
    "Register" : "Registra",
    "External Apps" : "Apps externes",
    "Update to {version}" : "Actualització a la versió {version}",
    "Remove" : "Suprimeix",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Aquesta aplicació no té cap versió mínima de Nextcloud assignada. Això serà un error en el futur.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Aquesta aplicació no té cap versió màxima de Nextcloud assignada. Això serà un error en el futur.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Aquesta aplicació no es pot instal·lar perquè les següents dependències no es compleixen:",
    "View in store" : "Mostra-ho a la botiga",
    "Visit website" : "Visita el lloc web",
    "Report a bug" : "Informa d'un error",
    "User documentation" : "Documentació per a usuaris",
    "Admin documentation" : "Documentació per a administradors",
    "Developer documentation" : "Documentació per a desenvolupadors",
    "{license}-licensed" : "sota la llicència - {license}",
    "This app is supported via your current Nextcloud subscription." : "Aquesta aplicació és compatible amb la vostra subscripció actual a Nextcloud.",
    "Supported" : "Compatible",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Les aplicacions destacades es desenvolupen per i dins de la comunitat. Ofereixen funcionalitats centrals i estan preparades per ser emprades en producció.",
    "Featured" : "Destacada",
    "Update to {update}" : "Actualitza a {update}",
    "Icon" : "Icona",
    "Version" : "Versió",
    "Daemon" : "Dimoni",
    "Level" : "Nivell",
    "Actions" : "Accions",
    "Results from other categories" : "Resultats d'altres categories",
    "_Update_::_Update all_" : ["Actualitza","Actualitza-les totes"],
    "Type" : "Tipus",
    "Display Name" : "Nom d'usuari",
    "Your apps" : "Les vostres aplicacions",
    "Documentation" : "Documentació",
    "Details" : "Detalls",
    "Changelog" : "Registre de canvis",
    "by {author}\n{license}" : "{author}\n{license}",
    "Active apps" : "Aplicacions actives",
    "Disabled apps" : "Aplicacions inhabilitades",
    "Updates" : "Actualitzacions",
    "Featured apps" : "Aplicacions destacades",
    "Supported apps" : "Aplicacions compatibles",
    "Enable" : "Activa",
    "Disable" : "Inhabilita",
    "Allow untested app" : "Permet l'aplicació no provada",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Aquesta aplicació no està marcada com a compatible amb la vostra versió de Nextcloud. Si continueu, encara podreu instal·lar l’aplicació. Tingueu en compte que pot ser que l’aplicació no funcioni correctament.",
    "An error occurred during the request. Unable to proceed." : "S'ha produït un error durant la sol·licitud. No es pot continuar.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Error: aquesta aplicació no es pot habilitar perquè fa que el servidor sigui inestable"
},
"nplurals=2; plural=(n != 1);");
