OC.L10N.register(
    "app_api",
    {
    "Cancel" : "ரத்து செய்",
    "Delete" : "நீக்குக",
    "Edit" : "தொகுக்க",
    "Name" : "பெயர்",
    "Host" : "ஓம்புனர்",
    "Save" : "சேமிக்க ",
    "Remove" : "அகற்றுக",
    "Actions" : "செயல்கள்",
    "Type" : "வகை",
    "Documentation" : "ஆவணமாக்கல்",
    "Details" : "விவரங்கள்",
    "Enable" : "இயலுமைப்படுத்துக",
    "Disable" : "இயலுமைப்ப"
},
"nplurals=2; plural=(n != 1);");
