OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Aan favorieten toegevoegd",
    "Removed from favorites" : "Uit favorieten verwijderd",
    "You added {file} to your favorites" : "Je voegde {file} toe aan favorieten",
    "You removed {file} from your favorites" : "Je verwijderde {file} uit je favorieten",
    "Favorites" : "Favorieten",
    "File changes" : "Bestandswijzigingen",
    "Created by {user}" : "Gecreëerd door {user}",
    "Changed by {user}" : "Gewijzigd door {user}",
    "Deleted by {user}" : "Verwijderd door {user}",
    "Restored by {user}" : "Hersteld door {user}",
    "Renamed by {user}" : "Hernoemd door {user}",
    "Moved by {user}" : "Verplaatst door {user}",
    "\"remote account\"" : "\"remote account\"",
    "You created {file}" : "Je creëerde {file}",
    "You created an encrypted file in {file}" : "Je creëerde een versleuteld bestand in {file}",
    "{user} created {file}" : "{user} creëerde {file}",
    "{user} created an encrypted file in {file}" : "{user} creëerde een versleuteld bestand in {file}",
    "{file} was created in a public folder" : "{file} werd gecreëerd in een openbare map",
    "You changed {file}" : "Je wijzigde {file}",
    "You changed an encrypted file in {file}" : "Je wijzigde een versleuteld bestand in {file}",
    "{user} changed {file}" : "{user} wijzigde {file}",
    "{user} changed an encrypted file in {file}" : "{user} heeft een versleuteteld bestand veranderd in {file}",
    "You deleted {file}" : "Je verwijderde {file}",
    "You deleted an encrypted file in {file}" : "Je hebt een versleuteld bestand gewist in {file}",
    "{user} deleted {file}" : "{user} verwijderde {file}",
    "{user} deleted an encrypted file in {file}" : "{user} heeft een versleuteld bestand gewist in {file}",
    "You restored {file}" : "Je herstelde {file}",
    "{user} restored {file}" : "{user} herstelde {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Je hernoemde {oldfile} (verborgen) naar {newfile}(verborgen)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Je hernoemde {oldfile} (verborgen) naar {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Je hernoemde {oldfile} naar {newfile} (verborgen)",
    "You renamed {oldfile} to {newfile}" : "Je hernoemde {oldfile} naar {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} hernoemde {oldfile} (verborgen) naar {newfile} (verborgen)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} hernoemde {oldfile} (verborgen) naar {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} hernoemde {oldfile} naar {newfile} (verborgen)",
    "{user} renamed {oldfile} to {newfile}" : "{user} hernoemde {oldfile} naar {newfile}",
    "You moved {oldfile} to {newfile}" : "Je verplaatste {oldfile} naar {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} verplaatste {oldfile} naar {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Een bestand werd toegevoegd of verwijderd van je <strong>favorieten</strong>",
    "Files" : "Bestanden",
    "A file or folder has been <strong>changed</strong>" : "Een bestand of map is <strong>gewijzigd</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Een favoriet bestand of map is <strong>gewijzigd</strong>",
    "Failed to authorize" : "Kon niet autoriseren",
    "Invalid folder path" : "Ongeldig pad",
    "Folder not found" : "Map niet gevonden",
    "The file cannot be found" : "Het bestand kan niet worden gevonden",
    "The destination path does not exist: %1$s" : "Het bestemmingspad bestaat niet: %1$s",
    "You do not have permission to create a file at the specified location" : "Je hebt geen toestemming om een bestand aan te maken op de opgegeven locatie",
    "The file could not be converted." : "Het bestand kon niet worden geconverteerd.",
    "Could not get relative path to converted file" : "Kon geen relatief pad naar geconverteerd bestand achterhalen",
    "Favorite files" : "Favoriete bestanden",
    "No favorites" : "Geen favorieten",
    "More favorites" : "Meer favorieten",
    "Accept" : "Accepteren",
    "Reject" : "Afwijzen",
    "Incoming ownership transfer from {user}" : "Inkomend verzoek voor eigendomsoverdracht van {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Wil je {path} aanvaarden? \n\nOpmerking: het overdrachtsproces kan na acceptatie tot 1 uur duren.",
    "Ownership transfer denied" : "Eigendomsoverdracht geweigerd",
    "Your ownership transfer of {path} was denied by {user}." : "Eigendomsoverdracht van {path} is geweigerd door {user}.",
    "Ownership transfer failed" : "Eigendomsoverdracht mislukt",
    "Your ownership transfer of {path} to {user} failed." : "Eigendomsoverdracht van {path} naar {user} is mislukt.",
    "The ownership transfer of {path} from {user} failed." : "Eigendomsoverdracht van {path} van {user} is mislukt.",
    "Ownership transfer done" : "Eigendomsoverdracht geslaagd",
    "Your ownership transfer of {path} to {user} has completed." : "Eigendomsoverdracht van {path} naar {user} is gereed.",
    "The ownership transfer of {path} from {user} has completed." : "Eigendomsoverdracht van {path} van {user} is gereed.",
    "in %s" : "in %s",
    "Transferred from %1$s on %2$s" : "Overgezet van %1$s naar %2$s",
    "Files compatibility" : "Bestandscompatibiliteit",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Toestaan om bestandsnamen te beperken om te borgen dat bestanden met alle cliënts gesynchroniseerd kunnen worden. Standaard zijn alle bestandsnamen valide die zijn toegestaan op POSIX (zoals Linux en macOS.)",
    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Na inschakeling van Windows-compatibele bestandsnamen, kunnen bestaande bestanden niet meer worden gewijzigd, maar kunnen ze door de eigenaar worden hernoemd naar geldige nieuwe namen.",
    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Het is ook mogelijk om bestanden automatisch te migreren nadat deze instelling is ingeschakeld. Raadpleeg de documentatie over het occ-commando.",
    "Enforce Windows compatibility" : "Dwing Windows-compatibiliteit af",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Dit zal bestandsnamen blokkeren die niet toegestaan zijn op Windows-systemen, zoals gereserveerde namen of speciale tekens. Dit dwingt niet tot compatibiliteit voor hoofd- en kleine letters.",
    "File Management" : "Bestandsbeheer",
    "Home" : "Thuis",
    "Target folder does not exist any more" : "Doelmap bestaat niet meer",
    "Reload current directory" : "Huidige map opnieuw laden",
    "Go to the \"{dir}\" directory" : "Ga naar de \"{dir}\" map",
    "Current directory path" : "Huidig directory pad",
    "Your have used your space quota and cannot upload files anymore" : "Je hebt je ruimtequotum gebruikt en kan geen bestanden meer uploaden",
    "You do not have permission to upload or create files here." : "Je hebt geen toestemming om hier bestanden te uploaden of aan te maken.",
    "Drag and drop files here to upload" : "Drag en drop bestanden hier om te uploaden",
    "Favorite" : "Favoriet",
    "Back" : "Terug",
    "Toggle selection for file \"{displayName}\"" : "Wijzig selectie voor bestand \"{displayName}\"",
    "Toggle selection for folder \"{displayName}\"" : "Wijzig selectie voor map \"{displayName}\"",
    "File is loading" : "Bestand is aan het laden",
    "Folder is loading" : "Map is aan het laden",
    "Filename" : "Bestandsnaam",
    "Folder name" : "Mapnaam",
    "This node is unavailable" : "Deze node is niet beschikbaar",
    "Another entry with the same name already exists." : "Er bestaat al een ander item met dezelfde naam",
    "Invalid filename." : "Ongeldige bestandsnaam",
    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" hernoemd naar \"{newName}\"",
    "Rename file" : "Bestand hernoemen",
    "Folder" : "Map",
    "Unknown file type" : "Onbekend bestandstype",
    "{ext} image" : "{ext} afbeelding",
    "{ext} video" : "{ext} video",
    "{ext} audio" : "{ext} audio",
    "{ext} text" : "{ext} tekst",
    "Pending" : "In behandeling",
    "Unknown date" : "Onbekende datum",
    "Clear filter" : "Filter leegmaken",
    "Modified" : "Aangepast",
    "Search everywhere" : "Zoek in alles",
    "Type" : "Type",
    "Active filters" : "Actieve filters",
    "Remove filter" : "Verwijder filter",
    "Total rows summary" : "Aantal rijen samenvatting",
    "Toggle selection for all files and folders" : "Wijzig selectie voor alle bestanden en mappen",
    "Name" : "Naam",
    "File type" : "Bestandstype",
    "Size" : "Grootte",
    "Actions" : "Acties",
    "(selected)" : "(geselecteerd)",
    "List of files and folders." : "Lijst van bestanden en mappen.",
    "You have used your space quota and cannot upload files anymore." : "Je hebt je ruimtequotum gebruikt en kan geen bestanden meer uploaden",
    "Column headers with buttons are sortable." : "Kolomkoppen met knoppen zijn sorteerbaar",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "De lijst is niet volledig verwerkt om de prestatie niet te beperken. De bestanden worden verder verwerkt als je door de lijst navigeert.",
    "File not found" : "Bestand niet gevonden",
    "_{count} selected_::_{count} selected_" : ["{count} geselecteerd","{count} geselecteerd"],
    "Search scope options" : "Zoek bereikopties",
    "{usedQuotaByte} used" : "{usedQuotaByte} gebruikt",
    "{used} of {quota} used" : "{used} van {quota} gebruikt",
    "{relative}% used" : "{relative}% gebruikt",
    "Could not refresh storage stats" : "Kan opslagstatistieken niet vernieuwen",
    "Your storage is full, files can not be updated or synced anymore!" : "Je opslagruimte zit vol. Bestanden kunnen niet meer worden gewijzigd of gesynchroniseerd!",
    "Storage information" : "Opslaginformatie",
    "Storage quota" : "Opslagquota",
    "New folder" : "Nieuwe map",
    "Create new folder" : "Nieuwe map aanmaken",
    "This name is already in use." : "De naam is al in gebruik.",
    "Create" : "Aanmaken",
    "Files starting with a dot are hidden by default" : "Bestanden die met een punt beginnen, worden standaard verborgen",
    "Fill template fields" : "Vul de velden van het sjabloon in",
    "Submitting fields …" : "Velden verwerken ...",
    "Submit" : "Verwerken",
    "Choose a file or folder to transfer" : "Kies een bestand of map om over te dragen",
    "Transfer" : "Overdragen",
    "Transfer {path} to {userid}" : "Draag {path} over aan {userid}",
    "Invalid path selected" : "Ongeldig pad geselecteerd",
    "Unknown error" : "Onbekende fout",
    "Ownership transfer request sent" : "Aanvraag eigendomsoverdracht verstuurd",
    "Cannot transfer ownership of a file or folder you do not own" : "Kan de eigendom van een bestand of map waarvan u niet de eigenaar bent, niet overdragen",
    "Transfer ownership of a file or folder" : "Overdragen eigendom bestand of map ",
    "Choose file or folder to transfer" : "Kies over te dragen bestand of map",
    "Change" : "Pas aan",
    "New owner" : "Nieuwe eigenaar",
    "Keep {old}" : "Bewaar {old}",
    "Keep without extension" : "Bewaren zonder extensie",
    "Use {new}" : "Gebruik {new}",
    "Remove extension" : "Verwijder extensie",
    "Change file extension" : "Wijzig bestandsextensie",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Wijzigen van de bestandsextensie {old} naar {new} kan ervoor zorgen dat het bestand niet meer gelezen kan worden.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "Verwijderen van de extensie {old} kan ervoor zorgen dat het bestand niet meer gelezen kan worden.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "Toevoegen van de extensie {new} kan ervoor zorgen dat het bestand niet meer gelezen kan worden.",
    "Do not show this dialog again." : "Laat dit dialoogvenster niet meer zien.",
    "Select file or folder to link to" : "Selecteer een bestand of map om naar te linken",
    "Choose {file}" : "Kies {file}",
    "Share" : "Delen",
    "Shared by link" : "Gedeeld via link",
    "Shared" : "Gedeeld",
    "Switch to list view" : "Omschakelen naar lijstoverzicht",
    "Switch to grid view" : "Omschakelen naar roosterweergave",
    "The file could not be found" : "Het bestand kon niet worden gevonden",
    "Upload was cancelled by user" : "Upload was geannuleerd door de gebruiker",
    "Not enough free space" : "Onvoldoende vrije ruimte",
    "Operation is blocked by access control" : "De operatie werd tegengehouden door toegangscontrole",
    "Error during upload: {message}" : "Fout tijdens upload: {message}",
    "Error during upload, status code {status}" : "Fout tijdens upload, status code {status}",
    "Unknown error during upload" : "Onbekende fout tijdens upload",
    "Loading current folder" : "Laden huidige map",
    "Retry" : "Opnieuw",
    "No files in here" : "Hier geen bestanden",
    "Upload some content or sync with your devices!" : "Upload je inhoud of synchroniseer met je apparaten!",
    "Go back" : "Ga terug",
    "Views" : "Bekeken",
    "Files settings" : "Instellingen voor bestanden",
    "Your files" : "Jouw bestanden",
    "Open in files" : "Open in bestanden",
    "File cannot be accessed" : "Bestand kan niet worden benaderd",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Dit bestand is niet gevonden of je hebt geen machtigingen om het te bekijken. Vraag de verzender om het met je te delen.",
    "No search results for “{query}”" : "No search results for “{query}”",
    "Search for files" : "Zoeken naar bestanden",
    "Clipboard is not available" : "Klembord niet beschikbaar",
    "General" : "Algemeen",
    "Default view" : "Standaardweergave",
    "All files" : "Alle bestanden",
    "Personal files" : "Persoonlijke bestanden",
    "Sort favorites first" : "Sorteer eerst favorieten",
    "Sort folders before files" : "Sorteer mappen voor bestanden",
    "Folder tree" : "Mapboom",
    "Appearance" : "Uiterlijk",
    "Show hidden files" : "Toon verborgen bestanden",
    "Show file type column" : "Toon bestandstypekolom",
    "Crop image previews" : "Snij afbeeldingvoorbeelden bij",
    "Additional settings" : "Aanvullende instellingen",
    "WebDAV" : "WebDAV",
    "WebDAV URL" : "WebDAV URL",
    "Copy" : "Kopiëren",
    "Two-Factor Authentication is enabled for your account, and therefore you need to use an app password to connect an external WebDAV client." : "Tweefactorauthenticatie is ingeschakeld voor jouw account en daarom moet je een app-wachtwoord gebruiken om een externe WebDAV-client aan te sluiten.",
    "Warnings" : "Waarschuwingen",
    "Keyboard shortcuts" : "Toetsenbord sneltoetsen",
    "File actions" : "Bestandsacties",
    "Rename" : "Naam wijzigen",
    "Delete" : "Verwijderen",
    "Manage tags" : "Berichttags",
    "Selection" : "Selectie",
    "Select all files" : "Selecteer alle bestanden",
    "Deselect all" : "Deselecteer alles",
    "Navigation" : "Navigatie",
    "View" : "Bekijken",
    "Toggle grid view" : "Omschakelen roosterweergave",
    "Show those shortcuts" : "Toon die snelkoppelingen",
    "You" : "Jij",
    "Shared multiple times with different people" : "Meerdere keren gedeeld met verschillende mensen",
    "Unable to change the favorite state of the file" : "Kan de favoriete status van het bestand niet wijzigen",
    "Error while loading the file data" : "Fout bij het lezen van de bestandsgegevens",
    "Owner" : "Eigenaar",
    "Remove from favorites" : "Verwijderen uit favorieten",
    "Add to favorites" : "Aan favorieten toevoegen",
    "Tags" : "Tags",
    "Blank" : "Blanco",
    "Unable to create new file from template" : "Kan geen nieuw bestand maken vanuit het sjabloon",
    "Pick a template for {name}" : "Kies een sjabloon voor {name}",
    "Create a new file with the selected template" : "Maak een nieuw bestand met het geselecteerde sjabloon",
    "Creating file" : "Maken bestand",
    "Save as {displayName}" : "Opslaan als {displayName}",
    "Save as …" : "Opslaan als...",
    "Converting files …" : "Bestanden converteren ...",
    "Failed to convert files: {message}" : "Conversie van bestanden mislukt: {message} ",
    "All files failed to be converted" : "De conversie van alle bestanden is mislukt",
    "One file could not be converted: {message}" : "Een bestand kon niet worden geconverteerd: {message}",
    "_One file could not be converted_::_%n files could not be converted_" : ["Een bestand kon niet geconverteerd worden","%n bestanden konden niet geconverteerd worden"],
    "_One file successfully converted_::_%n files successfully converted_" : ["Een bestand succesvol geconverteerd","%n bestanden succesvol geconverteerd"],
    "Files successfully converted" : "Bestanden succesvol geconverteerd",
    "Failed to convert files" : "Conversie van bestanden mislukt",
    "Converting file …" : "Bestand converteren ...",
    "File successfully converted" : "Bestand succesvol geconverteerd",
    "Failed to convert file: {message}" : "Conversie van bestand mislukt: {message} ",
    "Failed to convert file" : "Conversie van bestand mislukt",
    "Leave this share" : "Verlaat deze share",
    "Leave these shares" : "Verlaat deze shares",
    "Disconnect storage" : "Verbinding met opslag verbreken",
    "Disconnect storages" : "Opslaglocaties ontkoppelen",
    "Delete permanently" : "Permanent verwijderen",
    "Delete and unshare" : "Verwijder en stop delen",
    "Delete file" : "Verwijder bestand",
    "Delete files" : "Verwijder bestanden",
    "Delete folder" : "Map verwijderen",
    "Delete folders" : "Verwijder mappen",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Je staat op het punt om {count} item permanent te verwijderen","Je staat op het punt om {count} items permanent te verwijderen"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Je staat op het punt om {count} item te verwijderen","Je staat op het punt om {count}items te verwijderen"],
    "Confirm deletion" : "Bevestig verwijderen",
    "Cancel" : "Annuleren",
    "Download" : "Downloaden",
    "Moving \"{source}\" to \"{destination}\" …" : "Verplaatsen \"{source}\" naar \"{destination}\" …",
    "Copying \"{source}\" to \"{destination}\" …" : "Kopiëren \"{source}\" naar \"{destination}\" …",
    "Destination is not a folder" : "Bestemming is geen map",
    "This file/folder is already in that directory" : "Dit bestand/deze map staat al in die map",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Je kan een bestand/map niet verplaatsen naar zichzelf of naar een subfolder van zichzelf.",
    "(copy)" : "(kopieer)",
    "(copy %n)" : "(kopieer %n)",
    "A file or folder with that name already exists in this folder" : "Een bestand of map met dezelfde naam is al aanwezig in deze map",
    "The files are locked" : "De bestanden zijn vergrendeld",
    "The file does not exist anymore" : "Dit bestand bestaat niet meer",
    "Choose destination" : "Kies bestemming",
    "Copy to {target}" : "Kopieer naar {target}",
    "Move to {target}" : "Verplaats naar {target}",
    "Move" : "Verplaatsen",
    "Move or copy operation failed" : "Verplaatsen of kopiëren mislukt",
    "Move or copy" : "Verplaats of kopieer",
    "Open folder {displayName}" : "Open map {displayName}",
    "Open in Files" : "Open in Bestanden",
    "Open locally" : "Lokaal openen",
    "Failed to redirect to client" : "Omleiden naar cliënt mislukt",
    "Open file locally" : "Bestand lokaal openen",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Het bestand zou nu moeten openen op je apparaat. Als dat niet het geval is, controleer dan of je de desktop app geïnstalleerd hebt.",
    "Retry and close" : "Probeer opnieuw en sluiten",
    "Open online" : "Open online",
    "Details" : "Details",
    "View in folder" : "Bekijken in map",
    "Today" : "Vandaag",
    "Last 7 days" : "Laatste 7 dagen",
    "Last 30 days" : "Laatste 30 dagen",
    "This year ({year})" : "Dit jaar ({year})",
    "Last year ({year})" : "Afgelopen jaar ({year})",
    "Documents" : "Documenten",
    "Spreadsheets" : "Spreadsheets",
    "Presentations" : "Presentaties",
    "PDFs" : "PDFs",
    "Folders" : "Mappen",
    "Audio" : "Geluid",
    "Images" : "Afbeeldingen",
    "Videos" : "Video's",
    "Created new folder \"{name}\"" : "Nieuwe map \"¨{name}\" gemaakt.",
    "Unable to initialize the templates directory" : "Kon de sjablonenmap niet instellen",
    "Create templates folder" : "Nieuwe sjablonenmap",
    "Templates" : "Sjablonen",
    "New template folder" : "Nieuwe sjablonenmap",
    "In folder" : "In map",
    "Search in all files" : "Zoeken in alle bestanden",
    "Search in folder: {folder}" : "Zoeken in map: {folder}",
    "One of the dropped files could not be processed" : "Een van de bestanden kon niet verwerkt worden.",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Je browser ondersteund de Filesystem API niet. Mappen worden niet geüpload",
    "No files to upload" : "Geen bestanden om te uploaden",
    "Unable to create the directory {directory}" : "Kan map {directory} niet maken",
    "Some files could not be uploaded" : "Sommige bestanden konden niet worden geüpload",
    "Files uploaded successfully" : "Bestand succesvol geüpload.",
    "No files to process" : "Geen bestanden te verwerken",
    "Some files could not be copied" : "Sommige bestanden konden niet gekopieerd worden",
    "Some files could not be moved" : "Een paar bestanden konden niet worden verplaatst",
    "Files copied successfully" : "Bestanden succesvol gekopieerd",
    "Files moved successfully" : "Bestanden succesvol verplaatst",
    "Conflicts resolution skipped" : "Conflictoplossing overgeslagen",
    "Upload cancelled" : "Uploaden geannuleerd",
    "Could not rename \"{oldName}\", it does not exist any more" : "Kon \"{oldName}\" niet hernoemen, het bestaat niet meer",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "De naam \"{newName}\" bestaat al in map \"{dir}\". Kies een andere naam.",
    "Could not rename \"{oldName}\"" : "Kon \"{oldName}\" niet hernoemen",
    "This operation is forbidden" : "Deze taak is verboden",
    "Storage is temporarily not available" : "Opslag is tijdelijk niet beschikbaar",
    "Unexpected error: {error}" : "Onverwachte fout: {error}",
    "_%n file_::_%n files_" : ["%n bestand","%n bestanden"],
    "_%n folder_::_%n folders_" : ["%n map","%n mappen"],
    "_%n hidden_::_%n hidden_" : ["%n onzichtbaar","%n onzichtbaar"],
    "Filename must not be empty." : "Bestandsnaam mag niet leeg zijn",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\"is niet toegestaan in een bestandsnaam",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" is een greserveerde naam en niet toegestaan voor bestandsnamen",
    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" is geen toegestaan bestandstype",
    "Filenames must not end with \"{extension}\"." : "Bestandsnamen mogen niet eindigen met \"{extension}\".",
    "List of favorite files and folders." : "Lijst van favoriete bestanden en mappen.",
    "No favorites yet" : "Nog geen favorieten",
    "Files and folders you mark as favorite will show up here" : "Bestanden en mappen die je als favoriet aanmerkt, worden hier getoond",
    "List of your files and folders." : "Lijst van je bestanden en mappen.",
    "List of your files and folders that are not shared." : "Lijst van je bestanden en mappen die niet gedeeld zijn.",
    "No personal files found" : "Geen persoonlijke bestanden gevonden",
    "Files that are not shared will show up here." : "Niet-gedeelde bestanden worden hier getoond.",
    "Recent" : "Recent",
    "List of recently modified files and folders." : "Lijst van recent gewijzigde bestanden en mappen.",
    "No recently modified files" : "Geen recent gewijzigde bestanden",
    "Files and folders you recently modified will show up here." : "Bestanden en mappen die je recent gewijzigd hebt, worden hier getoond.",
    "Search" : "Zoeken",
    "Search results within your files." : "Zoekresultaten binnen jouw bestanden.",
    "No entries found in this folder" : "Niets gevonden in deze map",
    "Select all" : "Alles selecteren",
    "Upload too large" : "Upload is te groot",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "De bestanden die je probeert te uploaden zijn groter dan de maximaal toegestane  bestandsgrootte voor deze server.",
    "File could not be found" : "Bestand kon niet worden gevonden",
    "Show list view" : "Toon lijstweergave",
    "Show grid view" : "Toon roosterweergave",
    "Close" : "Sluiten",
    "Could not create folder \"{dir}\"" : "Kon map \"{dir}\" niet aanmaken",
    "This will stop your current uploads." : "Dit beëindigt onderhanden uploads",
    "Upload cancelled." : "Uploaden geannuleerd.",
    "Processing files …" : "Verwerken bestanden ...",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan {filename} niet uploaden omdat het een map is of 0 bytes groot is",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Niet genoeg vrije ruimte. Je uploadt {size1}, maar er is slechts {size2} beschikbaar",
    "Target folder \"{dir}\" does not exist any more" : "Doelmap \"{dir}\" bestaat niet meer",
    "An unknown error has occurred" : "Er trad een onbekende fout op.",
    "File could not be uploaded" : "Bestand kon niet geüpload worden",
    "Uploading …" : "Uploaden …",
    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
    "Uploading … ({currentNumber}/{total})" : "Uploaden … ({currentNumber}/{total})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} van {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Uploaden van dat object is niet ondersteund",
    "Error when assembling chunks, status code {status}" : "Fout tijdens samenvoegen van brokken, status code {status}",
    "Choose target folder" : "Kies doelmap…",
    "Set reminder" : "Herinnering instellen",
    "Edit locally" : "Lokaal bewerken",
    "Open" : "Openen",
    "Could not load info for file \"{file}\"" : "Kon geen informatie laden voor bestand \"{file}\"",
    "Please select tag(s) to add to the selection" : "Selecteer alsjeblieft tag(s) om aan de selectie toe te voegen",
    "Apply tag(s) to selection" : "Pas tag(s) toe voor selectie",
    "Select directory \"{dirName}\"" : "Kies map \"{dirName}\"",
    "Select file \"{fileName}\"" : "Kies bestand \"{fileName}\"",
    "Unable to determine date" : "Kon datum niet vaststellen",
    "This directory is unavailable, please check the logs or contact the administrator" : "Deze map is niet beschikbaar. Verifieer de logs of neem contact op met de beheerder",
    "Could not move \"{file}\", target exists" : "Kon \"{file}\" niet verplaatsen, doel bestaat al",
    "Could not move \"{file}\"" : "Kon \"{file}\" niet verplaatsen",
    "copy" : "kopie",
    "Could not copy \"{file}\", target exists" : "Kon \"{file}\" niet kopiëren, het doel bestaat",
    "Could not copy \"{file}\"" : "Kon \"{file}\" niet kopiëren",
    "Copied {origin} inside {destination}" : "Kopieerde {origin} binnen {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Heeft {origin} en {nbfiles} andere bestanden in {destination} gekopieerd",
    "{newName} already exists" : "{newName} bestaat al",
    "Could not create file \"{file}\"" : "Kon \"{file}\" niet aanmaken",
    "Could not create file \"{file}\" because it already exists" : "Kon \"{file}\" niet aanmaken, omdat het al bestaat",
    "Could not create folder \"{dir}\" because it already exists" : "Kon map \"{dir}\" niet aanmaken, omdat die al bestaat",
    "Could not fetch file details \"{file}\"" : "Kon details van \"{file}\" niet ophalen",
    "Error deleting file \"{fileName}\"." : "Fout bij verwijderen bestand \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Geen zoekresultaten voor {tag}{filter}{endtag} in andere mappen",
    "Enter more than two characters to search in other folders" : "Voer meer dan twee tekens in om in andere mappen te zoeken",
    "{dirs} and {files}" : "{dirs} en {files}",
    "_including %n hidden_::_including %n hidden_" : ["inclusief %n verborgen","inclusief %n verborgen"],
    "You do not have permission to upload or create files here" : "Je hebt geen toestemming om hier te uploaden of bestanden aan te maken",
    "_Uploading %n file_::_Uploading %n files_" : ["%n bestand aan het uploaden","%n bestanden aan het uploaden"],
    "New" : "Nieuw",
    "New file/folder menu" : "Nieuw bestand/map menu",
    "Select file range" : "Kies een reeks bestanden",
    "{used}%" : "{used}%",
    "{used} used" : "{used} gebruikt",
    "\"{name}\" is an invalid file name." : "\"{name}\" is een ongeldige bestandsnaam.",
    "File name cannot be empty." : "Bestandsnaam kan niet leeg zijn.",
    "\"/\" is not allowed inside a file name." : "\"/\" is niet toegestaan binnen een bestandsnaam.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" bestandstype is een niet toegestaande",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Opslagruimte van {owner} zit vol, bestanden kunnen niet meer worden geüpload of gesynchroniseerd!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Groepsmap \"{mountPoint}\" is vol, bestanden kunnen niet meer gewijzigd of gesynchroniseerd worden!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Externe opslag \"{mountPoint}\" is vol, bestanden kunnen niet meer gewijzigd of gesynchroniseerd worden!",
    "Your storage is full, files cannot be updated or synced anymore!" : "Je opslagruimte zit vol. Bestanden kunnen niet meer worden gewijzigd of gesynchroniseerd!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Opslagruimte van {owner} zit bijna vol ({usedSpacePercent}%)",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Groepsmap \"{mountPoint}\" is bijna vol ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Externe opslag \"{mountPoint}\" is bijna vol ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Je opslagruimte zit bijna vol ({usedSpacePercent}%)",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["komt overeen met \"{filter}\"","komen overeen met \"{filter}\""],
    "Direct link was copied (only works for people who have access to this file/folder)" : "Directe link is gekopieerd (werkt alleen voor gebruikers met toegang tot map/bestand)",
    "Path" : "Pad",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favored" : "Favorieten",
    "Favor" : "Favoriet",
    "Copy direct link (only works for people who have access to this file/folder)" : "Kopieer Directe link (werkt alleen voor gebruikers met toegang tot map/bestand)",
    "Upload file" : "Bestand uploaden",
    "Not favored" : "Geen favoriet",
    "An error occurred while trying to update the tags" : "Er trad een fout op bij je poging om de tags bij te werken",
    "Upload (max. %s)" : "Upload (max. %s)",
    "\"{displayName}\" action executed successfully" : "\"{displayName}\" actie succesvol uitgevoerd",
    "\"{displayName}\" action failed" : "\"{displayName}\" actie mislukt",
    "\"{displayName}\" failed on some elements" : "“{displayName}” mislukt op sommige elementen",
    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" batchactie succesvol uitgevoerd",
    "Submitting fields…" : "Verzenden velden ...",
    "Filter filenames…" : "Filter bestandsnamen...",
    "WebDAV URL copied to clipboard" : "WebDAV URL naar klembord gekopieerd",
    "Enable the grid view" : "Roosterweergave inschakelen",
    "Enable folder tree" : "Mappenboom inschakelen",
    "Copy to clipboard" : "Kopiëren naar het klembord",
    "Use this address to access your Files via WebDAV" : "Gebruik dit adres om je bestanden via WebDAV te benaderen",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Als je 2FA hebt ingeschakeld moet je een app wachtwoord maken en gebruiken door hier te klikken.",
    "Deletion cancelled" : "Verwijderen geannulleerd",
    "Move cancelled" : "Verplaatsen geannuleerd",
    "Cancelled move or copy of \"{filename}\"." : "Verplaatsen of kopiëren van \"¨{filename}\" geannuleerd.",
    "Cancelled move or copy operation" : "Verplaatsen of kopiëren geannuleerd.",
    "Open details" : "Details openen",
    "Photos and images" : "Foto's en afbeeldingen",
    "New folder creation cancelled" : "Maken van nieuwe map geannuleerd",
    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} map","{folderCount} mappen"],
    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} bestand","{fileCount} bestanden"],
    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 bestand en {folderCount} map","1 bestand en {folderCount} mappen"],
    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} bestand en 1 map","{fileCount} bestanden en 1 map"],
    "{fileCount} files and {folderCount} folders" : "{fileCount} bestanden en {folderCount} mappen",
    "All folders" : "Alle mappen",
    "Personal Files" : "Persoonlijke bestanden",
    "Text file" : "Tekstbestand",
    "New text file.txt" : "Nieuw tekstbestand.txt",
    "%1$s (renamed)" : "%1$s (hernoemd)",
    "renamed file" : "bestand hernoemd",
    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Na inschakeling van Windows-compatibele bestandsnamen, kunnen bestaande bestanden niet meer worden gewijzigd, maar kunnen ze door de eigenaar worden hernoemd naar geldige nieuwe namen.",
    "Filter file names …" : "Bestandsnamen filteren ...",
    "Prevent warning dialogs from open or reenable them." : "Voorkom dat waarschuwingsvensters worden geopend of schakel ze opnieuw in.",
    "Show a warning dialog when changing a file extension." : "Een waarschuwingsvenster tonen bij het wijzigen van een bestandsextensie.",
    "Speed up your Files experience with these quick shortcuts." : "Verbeter je interactie met bestanden met deze snelkoppelingen.",
    "Open the actions menu for a file" : "Open het actiemenu voor een bestand",
    "Rename a file" : "Een bestand hernoemen",
    "Delete a file" : "Een bestand verwijderen",
    "Favorite or remove a file from favorites" : "Favoriet maken of een bestand verwijderen uit favorieten",
    "Manage tags for a file" : "Tags voor een bestand beheren",
    "Deselect all files" : "Selectie van bestanden ongedaan maken",
    "Select or deselect a file" : "Een bestand selecteren of deselecteren",
    "Select a range of files" : "Selecteer een reeks bestanden",
    "Navigate to the parent folder" : "Navigeer naar de bovenliggende map",
    "Navigate to the file above" : "Navigeer naar bovenliggend bestand",
    "Navigate to the file below" : "Navigeer naar onderliggend bestand",
    "Navigate to the file on the left (in grid mode)" : "Navigeer naar het bestand aan de linkerkant (in rastermodus)",
    "Navigate to the file on the right (in grid mode)" : "Navigeer naar het bestand aan de rechterkant (in rastermodus)",
    "Toggle the grid view" : "Rasterweergave omschakelen",
    "Open the sidebar for a file" : "Open de zijbalk voor een bestand"
},
"nplurals=2; plural=(n != 1);");
