OC.L10N.register(
    "circles",
    {
    "You deleted {circle}" : "מחקת את {circle}",
    "{author} deleted {circle}" : "{circle} נמחק על ידי {author}",
    "You removed {member} from {circle}" : "הסרת את {member} מהמעגל {circle}",
    "You joined {circle}" : "הטרפת אל {circle}",
    "You accepted the invitation to join {circle}" : "קיבלת את הבקשה להצטרף אל {circle}",
    "{member} accepted the invitation to join {circle}" : "הבקשה להצטרף אל {circle} התקבלה על ידי {member}",
    "You added {member} as member to {circle}" : "הוספת את {member} לחברות במעגל {circle}",
    "You added {external} to {circle}" : "הוספת את {external} אל {circle}",
    "You accepted {member}'s request to join {circle}" : "נענית לבקשה של {member} להצטרף אל {circle}",
    "Your request to join {circle} has been accepted by {author}" : "בקשתך להצטרף אל {circle} נענתה על ידי {author}",
    "You left {circle}" : "עזבת את {circle}",
    "You declined the invitation to join {circle}" : "דחית את ההזמנה להצטרף אל {circle}",
    "You cancelled your request to join {circle}" : "ביטלת את בקשתך להצטרף אל {circle}",
    "You have been removed from {circle} by {author}" : "הוסרת מהמעגל {circle} על ידי {author}",
    "You removed {external} from {circle}" : "הסרת את {external} מהמעגל {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "ביטלת את ההזמנה של {member} להצטרף אל {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "הזמנתך להצטרף אל {circle} בוטלה על ידי {author}",
    "You invited {member} to join {circle}" : "הזמנת את {member} להצטרף אל {circle}",
    "You have been invited to join {circle} by {author}" : "הוזמנת להצטרף אל {circle} על ידי {author}",
    "You sent a request to join {circle}" : "שלחת בקשה להצטרף אל {circle}",
    "{member} sent a request to join {circle}" : "נשלחה בקשה על ידי {member} להצטרף אל {circle}",
    "You are the new owner of {circle}" : "קיבלת בעלות על {circle}",
    "{member} is the new owner of {circle}" : "הבעלות על {circle} הועברה לידי {member}",
    "Single" : "בודד",
    "Personal" : "אישי",
    "System" : "מערכת",
    "Visible" : "גלוי",
    "Open" : "פתוח",
    "Invite" : "הזמנה",
    "Friends" : "חברים",
    "Password protected" : "מוגן בססמה",
    "No Owner" : "אין בעלים",
    "Hidden" : "מוסתר",
    "Backend" : "מנגנון",
    "Local" : "מקומי",
    "Root" : "בסיס",
    "Federated" : "Federated",
    "Mount point" : "נקודת עיגון",
    "Nextcloud Group" : "קבוצת Nextcloud",
    "Email address" : "כתובת דוא״ל",
    "Contact" : "איש/אשת קשר",
    "Circle" : "מעגל",
    "Nextcloud App" : "יישומון Nextcloud",
    "Member" : "חבר",
    "Moderator" : "פיקוח",
    "Admin" : "מנהל",
    "Owner" : "בעלות",
    "Password to access »%1$s« shared to you by %2$s" : "סיסמא לגישה ל-»%1$s« משותף לך על ידי %2$s",
    "Password to access »%s«" : "ססמת הגישה אל „%s”",
    "It is protected with the following password:" : "הוא מוגן בססמה הבאה:",
    "%1$s via %2$s" : "%1$s דרך %2$s",
    "Click the button below to open it." : "יש ללחוץ על הכפתור להלן כדי לפתוח אותו.",
    "Open »%s«" : "פתיחת „%s”",
    "Password to access files" : "ססמה לגשת לקבצים",
    "Fresh installation status" : "מצב ההתקנה החדשה",
    "Building Local Database" : "מסד הנתונים המקומי נבנה",
    "Testing Basic Circle Creation" : "נבדקת יצירת מעגל בסיסי",
    "Adding local users and moderators" : "הוספת משתמשים ומפקחים מקומיים",
    "Files" : "קבצים",
    "This feature is not available for personal circles" : "תכונה זו אינה זמינה למעגלים אישיים",
    "Insufficient privileges" : "אין מספיק הרשאות",
    "This member does not exist" : "חבר זה אינו קיים",
    "You are already a member of this circle" : "כבר יש לך חברות במעגל זה",
    "You have been blocked from this circle" : "גישתך למעגל הזה נחסמה",
    "Accept" : "אשר",
    "Refuse" : "סירוב",
    "%s" : "%s",
    "Open %s" : "פתיחה (שם קובץ)",
    "No files in here" : "אין כאן קבצים",
    "No entries found in this folder" : "לא נמצאו רשומות בתיקייה הזאת",
    "Name" : "שם",
    "Size" : "גודל",
    "Modified" : "מועד שינוי",
    "Shared to Circles" : "שותף למעגלים"
},
"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
