OC.L10N.register(
    "comments",
    {
    "Comments" : "Kommentarer",
    "You commented" : "Du kommenterade",
    "{author} commented" : "{author} kommenterade",
    "You commented on %1$s" : "Du kommenterade på %1$s",
    "You commented on {file}" : "Du kommenterade på {file}",
    "%1$s commented on %2$s" : "%1$s kommenterade på %2$s",
    "{author} commented on {file}" : "{author} kommenterade på {file}",
    "<strong>Comments</strong> for files" : "<strong>Kommentarer</strong> för filer",
    "Files" : "Filer",
    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "Du har nämnts i \"{file}\", i en kommentar av en användare som sedan har blivit borttagen",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} nämnde dig i kommentar för \"{file}\"",
    "Files app plugin to add comments to files" : "Filer-appinsticksmodul för att lägga till kommentarer till filer",
    "Edit comment" : "Redigera kommentar",
    "Delete comment" : "Ta bort kommentar",
    "Cancel edit" : "Avbryt redigering",
    "New comment" : "Ny kommentar",
    "Write a comment …" : "Skriv en kommentar ...",
    "Post comment" : "Publicera kommentar",
    "@ for mentions, : for emoji, / for smart picker" : "@ för omnämnanden, : för emoji, / för smart picker",
    "Could not reload comments" : "Kunde inte ladda om kommentarer",
    "Failed to mark comments as read" : "Kunde inte markera kommentarer som lästa",
    "Unable to load the comments list" : "Kunde inte ladda kommentarlistan",
    "No comments yet, start the conversation!" : "Inga kommentarer ännu.",
    "No more messages" : "Inga fler meddelanden",
    "Retry" : "Försök igen",
    "_1 new comment_::_{unread} new comments_" : ["1 ny kommentar","{unread} nya kommentarer"],
    "Comment" : "Kommentar",
    "An error occurred while trying to edit the comment" : "Ett fel uppstod vid redigering av kommentaren",
    "Comment deleted" : "Kommentar borttagen",
    "An error occurred while trying to delete the comment" : "Ett fel uppstod vid borttagning av kommentaren",
    "An error occurred while trying to create the comment" : "Ett fel uppstod vid skapande av kommentaren"
},
"nplurals=2; plural=(n != 1);");
