<?php
namespace Aws\SimSpaceWeaver\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS SimSpace Weaver** service.
 */
class SimSpaceWeaverException extends AwsException {}
