OC.L10N.register(
    "photos",
    {
    "Photos" : "ຮູບພາບ",
    "Videos" : "ວິດີໂອ",
    "Favorites" : "ລາຍການທີ່ມັກ",
    "Shared with you" : "ແບ່ງປັບກັບທ່ານ",
    "Tags" : "ປ້າຍກຳກັບ",
    "Back" : "ຫຼັງ",
    "Save" : "ບັນທຶກ",
    "Favorite" : "ລາຍການທີ່ມັກ",
    "Home" : "ໜ້າຫຼັກ",
    "Remove from favorites" : "ຍ້າຍຈາກລາຍການທີ່ມັກ",
    "Details" : "ລາຍລະອຽດ",
    "Add" : "ເພີ່ມ"
},
"nplurals=1; plural=0;");
