OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Einrichtungsassistent",
    "Add your profile information! For example your email is needed to receive notifications." : "Fügen Sie Ihre Profil-Informationen hinzu! Ihre E-Mail-Adresse z.B. wird zum Empfangen von Nachrichten benötigt.",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "Fügen Sie Ihre Profil-Informationen hinzu! Ihre E-Mail-Adresse z. B. wird zum Empfangen von Nachrichten und zum Zurücksetzen Ihres Passwortes benötigt.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Fügen Sie Ihre Profil-Informationen hinzu! Hinterlegen Sie ein Profilbild und Ihren vollständigen Namen für eine einfachere Wiedererkennung über alle Funktionen hinweg.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Fügen Sie Ihre Profil-Informationen hinzu! Hinterlegen Sie Ihren vollständigen Namen für eine einfachere Wiedererkennung über alle Funktionen hinweg.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Fügen Sie Ihre Profil-Informationen hinzu! Hinterlegen Sie ein Profilbild für eine einfachere Wiedererkennung über alle Funktionen hinweg.",
    "App recommendation: Calendar" : "App-Empfehlung: Kalender",
    "Schedule work & meetings, synced with all your devices." : "Planen Sie die Arbeit und Besprechungen, die mit all Ihren Geräten synchronisiert sind.",
    "App recommendation: Contacts" : "App-Empfehlung: Kontakte",
    "Keep your colleagues and friends in one place without leaking their private info." : "Halten Sie die Kontakte zu Ihren Kollegen und Freunde an einem Ort zusammen, ohne ihre privaten Daten zu verlieren.",
    "App recommendation: Mail" : "App-Empfehlung: Mail",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Einfache E-Mail App mit super integrierter Dateiverwaltung, Kontakte und Kalender.",
    "App recommendation: Tasks" : "App-Empfehlung: Tasks",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "Synchronisieren Sie Aufgaben von verschiedenen Geräten mit Ihrer Nextcloud und bearbeiten Sie diese online.",
    "App recommendation: Deck" : "App-Empfehlung: Deck",
    "Kanban style organization for personal planning and team projects." : "Kanban-ähnliche Organisation für persönliche Planung und Teamprojekte.",
    "App recommendation: Forms" : "App-Empfehlung: Formulare",
    "Simple surveys and questionnaires, self-hosted" : "Einfache Umfragen und Fragebögen, selbst gehostet",
    "App recommendation: Recognize" : "App-Empfehlung: Recognize",
    "Smart media tagging for Nextcloud" : "Intelligente Media-Verschlagwortung für Nextcloud",
    "App recommendation: Group folders" : "App-Empfehlung: Group folders",
    "Admin-configured folders shared by everyone in a group." : "Von der Administration konfigurierte Ordner, die mit jedem Gruppenmitglied geteilt sind.",
    "App recommendation: Whiteboard" : "App-Empfehlung: Whiteboard",
    "Create and share whiteboards with others and collaborate in real-time." : "Erstellen und teilen Sie Whiteboards mit anderen und arbeiten Sie in Echtzeit zusammen.",
    "Connect your calendar" : "Verbinden Sie Ihren Kalender ",
    "Connect your contacts" : "Verbinden Sie Ihre Kontakte",
    "Access files via WebDAV" : "Greifen Sie auf Dateien über WebDAV zu",
    "Download macOS/iOS configuration profile" : "Konfigurationsprofil für macOS/iOS herunterladen",
    "Desktop client" : "Desktop-Client",
    "Android app on Google Play Store" : "Android-App im Google Play Store",
    "Android app on F-Droid" : "Android-App bei F-Droid",
    "iOS app" : "iOS-App",
    "About & What's new" : "Informationen und Neuigkeiten",
    "A welcome and introduction wizard for Nextcloud" : "Ein Assistent zur Begrüßung und Einführung in Nextcloud",
    "This application enables a pop-up window when a user first logs into Nextcloud. This window welcomes new users to Nextcloud, and contains links to the standard desktop client, Android app, and the iOS app. The window also shows a link for accessing Nextcloud via WebDAV. At any time, the first run wizard can be opened again via link \"About\" on settings menu.\nThe First run wizard can be customized to meet specific design goals, or to change links and messages. Create an appropriate theme following the Theming documentation, and changes to the look and feel of this Wizard are simple. More information is available in the first run wizard documentation, as well as the theming documentation." : "Diese Anwendung aktiviert ein Pop-up-Fenster, wenn sich ein Benutzer zum ersten Mal an der Nextcloud anmeldet. Dieses Fenster begrüßt neue Benutzer und beinhaltet Links zum Standard-Desktop-Client, zur Android-App und zur iOS-App. Das Fenster zeigt auch einen Link für den WebDAV-Zugriff auf die Nextcloud. Der Assistent für die Erstanmeldung kann jederzeit erneut über den Link \"Über\" im Einstellungsmenü geöffnet werden.\nDer Assistent für die Erstanmeldung kann angepasst werden, um bestimmte Ziele zu erreichen oder Links und Nachrichten zu ändern. Erstellen Sie ein eigenes Design nach der Anleitung in der Design-Dokumentation. Änderungen am Aussehen und Verhalten dieses Assistenten sind einfach. Weitere Informationen finden Sie in der Dokumentation zum Erstausführungsassistenten sowie in der Design-Dokumentation.",
    "Download on Apple app store" : "Im Apple App Store herunterladen",
    "Download on Google play store" : "Im Google Play Store herunterladen",
    "Go to previous page" : "Zur vorigen Seite gehen",
    "Close" : "Schließen",
    "More about Nextcloud" : "Mehr über Nextcloud",
    "Explore more apps ↗" : "Weitere Apps entdecken ↗",
    "Extend the functionality of Nextcloud with hundreds of community-developed apps." : "Erweitern Sie die Funktionalität von Nextcloud mit Hunderten von der Community entwickelten Apps.",
    "Get involved! ↗" : "Mitmachen! ↗",
    "Be a part of the community that helps build, design, translate and promote Nextcloud!" : "Werden Sie Teil der Community, die beim Aufbau, Design, der Übersetzung und der Weiterentwicklung von Nextcloud hilft!",
    "Need help? ↗" : "Hilfe benötigt? ↗",
    "Find out more about your Nextcloud setup with the admin, user or developer documentation." : "Erfahren Sie mehr über die Einrichtung Ihrer Nextcloud mit der Administrations-, Benutzer- oder Entwicklerdokumentation.",
    "For large organisations ↗" : "Für große Organisationen ↗",
    "Get Nextcloud Enterprise for mission critical environments where advanced security and compliance are important." : "Holen Sie sich Nextcloud Enterprise für geschäftskritische Umgebungen, in denen erweiterte Sicherheit und Compliance wichtig sind.",
    "Seamless integration with your devices." : "Nahtlose Integration mit Ihren Geräten.",
    "Sync your files across your devices with the desktop and mobile apps, and connect your calendar and contacts." : "Synchronisieren Sie Ihre Dateien auf Ihren Geräten mit den Desktop- und Mobil-Apps und verbinden Sie Ihren Kalender und Ihre Kontakte.",
    "Desktop app ↗" : "Desktop-App ↗",
    "Download For Windows, Mac OS and Linux." : "Für Windows, Mac OS und Linux herunterladen.",
    "Calendar and contacts ↗" : "Kalender und Kontakte ↗",
    "Connect your calendar and contacts with your devices." : "Verbinden Sie Ihren Kalender und Ihre Kontakte mit Ihren Geräten.",
    "Introducing Nextcloud Hub {version}" : "Vorstellung von Nextcloud Hub {version}",
    "Welcome to {cloudName}!" : "Willkommen bei {cloudName}!",
    "This Nextcloud is on version {version}" : "Diese Nextcloud ist auf Version {version}",
    "A collaboration platform that puts you in control" : "Eine Kollaborationsplattform, mit der Sie die Kontrolle haben",
    "Privacy" : "Datenschutz",
    "Host your data and files where you decide." : "Hosten Sie Ihre Daten und Dateien dort, wo Sie möchten.",
    "Productivity" : "Produktivität",
    "Collaborate and communicate across any platform." : "Plattformübergreifende Zusammenarbeit und Kommunikation.",
    "Interoperability" : "Interoperabilität",
    "Import and export anything you want with open standards." : "Importieren und exportieren Sie alles, was Sie wollen, mit offenen Standards.",
    "Community" : "Gemeinschaft ",
    "Enjoy constant improvements from a thriving open-source community." : "Profitieren Sie von ständigen Verbesserungen durch eine florierende Open-Source-Community.",
    "Nextcloud Hub {version} release" : "Nextcloud Hub {Version} Veröffentlichung",
    "Read more about it on the Nextcloud Hub {version} blog" : "Lesen Sie mehr darüber im Blog zu Nextcloud Hub {version}",
    "Find out more on the blog" : "Erfahren Sie mehr im Blog",
    "Read the Nextcloud Hub {version} blog" : "Lesen Sie den Blog zu Nextcloud Hub {version}",
    "Share your opinion about Nextcloud Hub {version}" : "Teilen Sie Ihre Meinung zu Nextcloud Hub {version}",
    "Share via email" : "Teilen per E-Mail",
    "Share on {socialMedia}" : "Teilen auf {socialMedia}",
    "New in Nextcloud Hub {version}" : "Neu in Nextcloud Hub {version}",
    "Connect other apps to {productName}" : "Andere Apps mit {productName} verbinden",
    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to {productName}." : "Neben den mobilen Apps und dem Desktop-Client können Sie jede andere Software, die die Protokolle WebDAV/CalDAV/CardDAV unterstützt, mit {productName} verbinden.",
    "Apps to connect to {productName}" : "Apps zum Verbinden mit {productName}",
    "Set up sync clients using an {linkStart}app password{linkEnd}. That way you can make sure you are able to revoke access in case you lose that device." : "Richten Sie Synchronisierungsclients mit einem {linkStart}App-Passwort{linkEnd} ein. Auf diese Weise können Sie sicherstellen, dass Sie den Zugriff widerrufen können, falls Sie das Gerät verlieren.",
    "Get the apps to sync your files" : "Laden Sie die Apps zur Synchronisierung Ihrer Daten herunter",
    "{productName} gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "{productName} ermöglicht Ihnen den Zugriff auf Ihre Dateien, wo immer Sie sind. Unsere benutzerfreundlichen Desktop- und Mobilclients sind für alle wichtigen Plattformen kostenlos verfügbar.",
    "App for syncing" : "App zur Synchronisierung",
    "URL copied" : "URL kopiert",
    "Could not copy the URL, please copy manually" : "Die URL konnte nicht kopiert werden, bitte manuell kopieren",
    "Server address" : "Serveradresse",
    "Use this link to connect your apps and desktop client to this server:" : "Verwenden Sie diesen Link, um Ihre Apps und Ihren Desktop-Clienten mit diesem Server zu verbinden:",
    "End-to-end encryption in calls and web" : "Ende-zu-Ende-Verschlüsselung für Anrufe und im Internet",
    "Performance improvements across all our products" : "Leistungsverbesserungen für all unsere Produkte",
    "Thousands of tweaks for improved UX and stability" : "Tausende von Optimierungen für verbesserte Benutzerfreundlichkeit und Stabilität",
    "Your own new personal assistant" : "Ihr eigener neuer persönlicher Assistent",
    "Seamless file conversions" : "Nahtlose Dateikonvertierung",
    "Smarter team sharing with Team folders" : "Bessere Teamfreigabe mit Teamordnern",
    "Schedule meetings directly in Talk" : "Besprechungen direkt in Talk planen",
    "Mail you love again: translations, summaries, and mentions" : "E-Mail, die Sie wieder lieben: Übersetzungen, Zusammenfassungen und Erwähnungen",
    "Get to know the new features of Hub {version}" : "Lernen Sie die neuen Funktionen von Hub {version} kennen",
    "Nextcloud Hub 10 is here – your modular & unified digital workspace! 💫" : "Nextcloud Hub 10 ist da - Ihr modularer & vereinheitlichter digitaler Arbeitsbereich! 💫",
    "What's new?" : "Was ist neu?",
    "Nextcloud on all your devices" : "Nextcloud auf all Ihren Geräten",
    "Nextcloud Hub {version}" : "Nextcloud Hub {version}",
    "Read more" : "Weiterlesen",
    "Share on social media" : "Auf sozialen Medien teilen",
    "Get started!" : "Legen Sie los!",
    "App recommendation: Nextcloud Calendar" : "App-Empfehlung: Nextcloud-Kalender",
    "App recommendation: Nextcloud Contacts" : "App-Empfehlung: Nextcloud-Kontakte",
    "App recommendation: Nextcloud Mail" : "App-Empfehlung: Nextcloud-Mail",
    "Federated collaboration: file sharing, messaging, calls" : "Federierte Zusammenarbeit: Dateifreigabe, Messaging, Anrufe",
    "Nextcloud Whiteboard" : "Nextcloud Whiteboard",
    "Workflow Engine" : "Workflow-Engine",
    "Safer and swifter mail" : "Sicherere und schnellere E-Mail",
    "Public Collectives sharing, previews and QR-codes" : "Öffentliche Kollektive zum Teilen mit Vorschauen und QR-Codes",
    "Office and PDF templates" : "Office- und PDF-Vorlagen",
    "Chat mode for Nextcloud Assistant" : "Chat-Modus für Nextcloud Assistant",
    "Get to know the new features of Hub 9" : "Lernen Sie die neuen Funktionen von Hub 9 kennen"
},
"nplurals=2; plural=(n != 1);");
