OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "აღდგენის გასაღების პაროლი არამყოფია",
    "Please repeat the recovery key password" : "გთხოვთ გაიმეოროთ აღდგენის გასაღების პაროლი",
    "Repeated recovery key password does not match the provided recovery key password" : "გამეორებული აღდგენის გასაღების პაროლი არ ემთხვევა მოწოდებულ აღდგენის გასაღების პაროლს",
    "Recovery key successfully enabled" : "აღდგენის გასაღები წარმატებით ამოქმედდა",
    "Could not enable recovery key. Please check your recovery key password!" : "აღდგენის გასაღები ვერ ამოქმედდა. გთხოვთ დაამოწმოთ აღდგენის გასაღების პაროლი!",
    "Recovery key successfully disabled" : "აღდგენის გასაღები წარმატებით გაითიშა",
    "Could not disable recovery key. Please check your recovery key password!" : "აღდგენის გასაღები ვერ გაითიშა. გთხოვთ დაამოწმოთ აღდგენის გასაღების პაროლი!",
    "Missing parameters" : "პარამეტრები აკლია",
    "Please provide the old recovery password" : "გთხოვთ მიუთითოთ აღდგენის ძველი პაროლი",
    "Please provide a new recovery password" : "გთხოვთ მიუთითოთ აღდგენის ახალი პაროლი",
    "Please repeat the new recovery password" : "გთხოვთ გაიმეოროთ ახალი აღდგენის პაროლი",
    "Password successfully changed." : "პაროლი წარმატებით შეიცვალა.",
    "Could not change the password. Maybe the old password was not correct." : "პაროლის ცვლილება ვერ მოხერხდა. შეიძლება ძველი პაროლი არასწორია",
    "Recovery Key disabled" : "აღდგენის გასაღები გაითიშა",
    "Recovery Key enabled" : "აღდგენის გასაღები ამოქმედდა",
    "Could not enable the recovery key, please try again or contact your administrator" : "აღდგენის გასაღები ვერ ამოქმედდა, გთოვთ სცადოთ ახლიდან ან დაუკავშირდეთ თქვენს ადმინისტრატორს",
    "Could not update the private key password." : "პირადი გასაღების პაროლი ვერ განახლდა.",
    "The old password was not correct, please try again." : "ძველი პაროლი არ იყო სწორი, გთხოვთ სცადოთ ახლიდან.",
    "The current log-in password was not correct, please try again." : "ამჟამინდელი ლოგინის პაროლი არ იყო სწორი, გთხოვთ სცადოთ ახლიდან.",
    "Private key password successfully updated." : "პირადი გასაღების პაროლი წარმატებით განახლდა.",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "შიფრაციის აპლიკაციისთვის არასწორი პირადი გასაღები. დაშიფრული ფაილებისადმი წვდომის აღსადგენად, გთხოვთ განაახლოთ თქვენი პირადი გასაღების პაროლი პირად პარამეტრებში.",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "შიფრაციის აპლიკაცია მოქმედია, თუმცა თქვენი გასაღებები არაა ინიციალიზირებული. გთხოვთ გახვიდეთ და ახლიდან გაიაროთ ავტორიზაცია.",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "შიფრაციის მოდულის გამოსაყენებლად გთხოვთ ადმინისტრატორის პარამეტრებიდან აამოქმედოთ შიფრაცია სერვერულ მხარეს.",
    "Encryption app is enabled and ready" : "შიფრაციის აპლიკაცია მოქმედია და მზადყოფნაშია",
    "Bad Signature" : "ცუდი ხელმოწერა",
    "Missing Signature" : "ხელმოწერა აკლია",
    "one-time password for server-side-encryption" : "ერთჯერადი პაროლი სერვერული მხარის შიფრაციისთვის",
    "Default encryption module" : "საწყისი შიფრაციის მოდული",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "შიფრაციის აპლიკაცია მოქმედია, მაგრამ თქვენი გასაღებები არაა ინციალიზირებული, გთხოვთ გახვიდეთ და ახლიდან გაიაროთ ავტორიზაცია",
    "Encrypt the home storage" : "სახლის საცავის შიფრაცია",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "ამ არჩევნის ამოქმედება დაშიფრავს ყველა ფაილს, რომელიც განთავსებულია მთავარ საცავში, სხვა შემთხვევაში დაიშიფრება მოხოლოდ ექსტერნალურ საცავში არსებული ფაილები",
    "Enable recovery key" : "აამოქმედეთ აღდგენის გასაღები",
    "Disable recovery key" : "დაასრულეთ აღდგენის გასაღების მოქდემება",
    "Recovery key password" : "აღდგენის გასაღების პაროლი",
    "Repeat recovery key password" : "გაიმეორეთ აღდგენის გასაღების პაროლი",
    "Change recovery key password:" : "შეცვალეთ აღდგენის გასაღების პაროლი:",
    "Old recovery key password" : "ძველი აღდგენის გასაღების პაროლი",
    "New recovery key password" : "ახალი აღდგენის გასაღების პაროლი",
    "Repeat new recovery key password" : "გაიმეორეთ ახალი აღდგენის გასაღების პაროლი",
    "Change Password" : "შეცვალეთ პაროლი",
    "Basic encryption module" : "მარტივი შიფრაციის მოდული",
    "Your private key password no longer matches your log-in password." : "თქვენი პირადი გასაღების პაროლი აღარ ემთხვევა ლოგინის პაროლს.",
    "Set your old private key password to your current log-in password:" : "დააყენეთ თქვენი ძველი პირადი გასაღების პაროლი ამჟამინდელ ლოგინის პაროლზე:",
    "Old log-in password" : "ძველი ლოგინის პაროლი",
    "Current log-in password" : "ამჟამინდელი ლოგინის პაროლი",
    "Update Private Key Password" : "განაახლეთ პირადი გასაღების პაროლი",
    "Enable password recovery:" : "აამოქმედეთ პაროლის აღდგენა:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "ამ არჩევნის ამოქმედება, პაროლის დაკარგვის შემთხვევაში, საშუალებას მოგცემთ ახლიდან მოიპოვოთ წვდომა თქვენს დაშიფრულ ფაილებზე",
    "Enabled" : "მოქმედია",
    "Disabled" : "არაა მოქმედი"
},
"nplurals=2; plural=(n!=1);");
