OC.L10N.register(
    "notifications",
    {
    "User not found" : "ئىشلەتكۈچى تېپىلمىدى",
    "Hello %s" : "ياخشىمۇسىز% s",
    "Hello %s," : "ياخشىمۇسىز% s,",
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "بۇ ئېلېكترونلۇق خەتلەرنىڭ چاستوتىنى ئۆزگەرتەلەيسىز ياكى <a href = \"% s\"> تەڭشەك </a> دە چەكلىيەلەيسىز.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "بۇ ئېلېكترونلۇق خەتلەرنىڭ چاستوتىنى ئۆزگەرتەلەيسىز ياكى تەڭشەكلەردە چەكلىيەلەيسىز:% s",
    "Admin notifications" : "باشقۇرغۇچى ئۇقتۇرۇشى",
    "Notifications" : "ئۇقتۇرۇش",
    "Push notifications - Fair use policy" : "ئىتتىرىش ئۇقتۇرۇشى - ئادىل ئىشلىتىش سىياسىتى",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server and the limit was reached for this server. For enterprise users, a more scalable gateway is available." : "Nextcloud GmbH شەخسىي ئىشلەتكۈچىلەر ئۈچۈن ھەقسىز ئىتتىرىش ئۇقتۇرۇشى دەرۋازىسىنى قوللايدۇ. ياخشى مۇلازىمەتكە كاپالەتلىك قىلىش ئۈچۈن ، دەرۋازا ھەر بىر مۇلازىمېتىرغا ئىتتىرىش ئۇقتۇرۇشىنىڭ سانىنى چەكلەيدۇ ۋە بۇ مۇلازىمېتىرنىڭ چېكىگە يەتتى. كارخانا ئىشلەتكۈچىلىرىگە نىسبەتەن تېخىمۇ چوڭايتىش ئېغىزى بار.",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "بۇ ئەپ Nextcloud دا بار بولغان ئۇقتۇرۇش API نى ئارقا سەھنە بىلەن تەمىنلەيدۇ.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "بۇ ئەپ Nextcloud دا بار بولغان ئۇقتۇرۇش API نى ئارقا سەھنە بىلەن تەمىنلەيدۇ.\n\t\tAPI باشقا ئەپلەر ئارقىلىق تور UI ئابونتلىرىغا ئۇقتۇرۇش ۋە خېرىدارلارغا ھەر خىل ئىشلار توغرىسىدا ماسقەدەملەش ئۈچۈن ئىشلىتىلىدۇ. بەزى مىساللار:\n\nFile فېدېراتسىيە ھۆججەتتىن ئورتاقلىشىش: يېڭى يىراقتىن ھەمبەھىر تاپشۇرۇۋالدىڭىز\n\nMents باھا: يەنە بىر ئىشلەتكۈچى ھۆججەتتىكى باھادا سىزنى تىلغا ئالدى\n\nئۇقتۇرۇشنى يېڭىلاش: بىر ئەپ ياكى كېيىنكى بۇلۇتنىڭ ئۆزى ئۈچۈن يېڭىلاشقا بولىدۇ\n\nOunce ئېلان مەركىزى: ئېلان تەرىپىدىن ئېلان قىلىندى",
    "Failed to perform action" : "ھەرىكەت قىلالمىدى",
    "Failed to dismiss notification" : "ئۇقتۇرۇشنى رەت قىلدى",
    "Dismiss" : "خىزمەتتىن ھەيدەش",
    "Contact Nextcloud GmbH" : "Nextcloud GmbH بىلەن ئالاقىلىشىڭ",
    "in {path}" : "in {path}",
    "Push notifications might be unreliable" : "ئىتتىرىش ئۇقتۇرۇشى ئىشەنچسىز بولۇشى مۇمكىن",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server. For enterprise users, a more scalable gateway is available. Contact Nextcloud GmbH for more information." : "Nextcloud GmbH شەخسىي ئىشلەتكۈچىلەر ئۈچۈن ھەقسىز ئىتتىرىش ئۇقتۇرۇشى دەرۋازىسىنى قوللايدۇ. ياخشى مۇلازىمەتكە كاپالەتلىك قىلىش ئۈچۈن ، دەرۋازا ھەر بىر مۇلازىمېتىرغا ئىتتىرىش ئۇقتۇرۇشىنىڭ سانىنى چەكلەيدۇ. كارخانا ئىشلەتكۈچىلىرىگە نىسبەتەن تېخىمۇ چوڭايتىش ئېغىزى بار. تېخىمۇ كۆپ ئۇچۇرغا ئېرىشىش ئۈچۈن Nextcloud GmbH بىلەن ئالاقىلىشىڭ.",
    "Requesting browser permissions to show notifications" : "ئۇقتۇرۇشنى كۆرسىتىش ئۈچۈن توركۆرگۈ ئىجازىتىنى تەلەپ قىلىش",
    "No notifications" : "ئۇقتۇرۇش يوق",
    "Failed to dismiss all notifications" : "بارلىق ئۇقتۇرۇشلارنى رەت قىلدى",
    "Dismiss all notifications" : "بارلىق ئۇقتۇرۇشلارنى ئەمەلدىن قالدۇرۇڭ",
    "Never" : "ھەرگىز بولمايدۇ",
    "1 hour" : "1 سائەت",
    "3 hours" : "3 سائەت",
    "1 day" : "1 كۈن",
    "1 week" : "1 ھەپتە",
    "Your settings have been updated." : "تەڭشەكلىرىڭىز يېڭىلاندى.",
    "An error occurred while updating your settings." : "تەڭشەكلىرىڭىزنى يېڭىلىغاندا خاتالىق كۆرۈلدى.",
    "Notifications defaults" : "ئۇقتۇرۇش سۈكۈتتىكى ھالەتتە",
    "Configure the default notification settings for new users" : "يېڭى ئىشلەتكۈچىلەرنىڭ سۈكۈتتىكى ئۇقتۇرۇش تەڭشىكىنى سەپلەڭ",
    "Send email reminders about unhandled notifications after:" : "بىر تەرەپ قىلىنمىغان ئۇقتۇرۇشلار ھەققىدە ئېلېكترونلۇق ئەسكەرتىش ئەۋەتىڭ:",
    "Play sound when a new notification arrives" : "يېڭى ئۇقتۇرۇش كەلگەندە ئاۋاز ئويناڭ",
    "Play sound when a call started (requires Nextcloud Talk)" : "چاقىرىش باشلانغاندا ئاۋاز قويۇڭ (Nextcloud Talk تەلەپ قىلىدۇ)",
    "None" : "يوق",
    "You need to set up your email address before you can receive notification emails." : "ئۇقتۇرۇش ئېلېكترونلۇق خەتلىرىنى تاپشۇرۇۋېلىشتىن بۇرۇن ئېلېكترونلۇق خەت ئادرېسىڭىزنى تەڭشىشىڭىز كېرەك.",
    "Also repeat sound on a secondary speaker" : "ئىككىلەمچى ياڭراتقۇدا ئاۋازنى تەكرارلاڭ",
    "Selection of the speaker device is currently not supported by Safari" : "ياڭراتقۇ ئۈسكۈنىسىنى تاللاش ھازىر Safari نى قوللىمايدۇ",
    "Select a device" : "ئۈسكۈنىنى تاللاڭ",
    "seconds ago" : "سېكۇنت بۇرۇن"
},
"nplurals=2; plural=(n != 1);");
