OC.L10N.register(
    "app_api",
    {
    "Daemon config not found" : "Deamhan cumraíochta gan aimsiú",
    "Error starting install of ExApp" : "Earráid agus suiteáil ExApp á thosú",
    "ExApp failed to register, check the NC logs" : "Theip ar ExApp clárú, seiceáil na logaí NC",
    "ExApp not found, failed to get status" : "ExApp gan aimsiú, níor éirigh leis an stádas a fháil",
    "This app is not installed from the AppStore. No extra information available. Only enable/disable and remove actions are allowed." : "Níl an aip seo suiteáilte ón AppStore. Níl aon eolas breise ar fáil. Ní cheadaítear ach gníomhartha a chumasú/a dhíchumasú agus a bhaint.",
    "Could not perform installation of ExApp" : "Níorbh fhéidir ExApp a shuiteáil",
    "Failed to enable ExApp" : "Theip ar chumasú ExApp",
    "Failed to disable ExApp" : "Theip ar ExApp a dhíchumasú",
    "Could not update ExApp" : "Níorbh fhéidir ExApp a nuashonrú",
    "Error starting update of ExApp" : "Earráid agus nuashonrú ExApp á thosú",
    "Could not perform update of ExApp" : "Níorbh fhéidir nuashonrú ExApp a dhéanamh",
    "ExApp not found, failed to get logs" : "ExApp gan aimsiú, theip ar logaí a fháil",
    "Failed to get container logs. Note: Downloading Docker container works only for containers with the json-file or journald logging driver. Error: %s" : "Theip ar logaí coimeádán a fháil. Nóta: Ní oibríonn íoslódálacha coimeádán Docker ach do shoithí a bhfuil an tiománaí logála json-file nó journald acu. Earráid: %s",
    "AppAPI authentication failed" : "Theip ar fhíordheimhniú AppAPI",
    "AppAPI ExApp notifier" : "AppAPI fógra exApp",
    "AppAPI" : "AppAPI",
    "AI Integration Team" : "Foireann Comhtháthaithe AI",
    "ExApps Settings" : "Socruithe ExApps",
    "Nextcloud AppAPI" : "Nextcloud AppAPI",
    "### Boost your Nextcloud with AppAPI and its specially designed applications.\n\n\nThe AppAPI is a project within the Nextcloud ecosystem designed to streamline and enhance the process of\napplication development, deployment, and management.\n\nIt introduces a new methodology that allows developers to create\napplications using a variety of programming languages, not limited to PHP, which was traditionally used in Nextcloud development.\n\n\n### List of applications that require AppAPI:\n\n- [talk_bot_ai_example](https://github.com/cloud-py-api/talk_bot_ai_example)\n- [upscaler_example](https://github.com/cloud-py-api/upscaler_example)\n- [image_to_text_example](https://github.com/cloud-py-api/file_to_text_example)\n- [ai_image_generator_bot](https://github.com/cloud-py-api/ai_image_generator_bot)\n- [SummarAI](https://github.com/nextcloud/sumupbot)\n\n_If you wish to develop an application, we will gladly help and assist you._\n\n### Support\n\nWe appreciate any support for this project:\n\n- ⭐ Star our work on GitHub\n- ❗ Create an Issue or feature request\n- 💁 Resolve an Issue and create a Pull Request\n- 🧑‍💻 Develop your own application using AppAPI\n\nWe are genuinely excited about the future of the AppAPI project and its potential to transform\nthe way applications are developed and experienced within Nextcloud.\n\nAs we embark on this journey, we warmly invite you - developers, thinkers, creators, and visionaries -\nto join us in shaping a more versatile, stable, and secure app landscape.\n\n*Your insights, suggestions, and contributions are invaluable to us.*" : "### Déan do Nextcloud a threisiú le AppAPI agus a fheidhmchláir atá saindeartha.\n\n\nIs tionscadal é an AppAPI laistigh d’éiceachóras Nextcloud atá deartha chun an próiseas a shruthlíniú agus a fheabhsú\nforbairt, imscaradh agus bainistíocht feidhmchlár.\n\nTugann sé isteach modheolaíocht nua a ligeann d'fhorbróirí a chruthú\nfeidhmchláir ag baint úsáide as éagsúlacht teangacha ríomhchlárúcháin, gan a bheith teoranta do PHP, a úsáideadh go traidisiúnta i bhforbairt Nextcloud.\n\n\n### Liosta feidhmchlár a dteastaíonn AppAPI uathu:\n\n- [talk_bot_ai_example]( https://github.com/cloud-py-api/talk_bot_ai_example)\n- [upscaler_example]( https://github.com/cloud-py-api/upscaler_example)\n- [image_to_text_example]( https://github.com/cloud-py-api/file_to_text_example)\n- [ai_image_generator_bot]( https://github.com/cloud-py-api/ai_image_generator_bot)\n- [SummarAI]( https://github.com/nextcloud/sumupbot)\n\n_Más mian leat feidhmchlár a fhorbairt, cabhróimid agus cabhróimid leat._\n\n### Tacaíocht\n\nIs mór againn tacaíocht ar bith don tionscadal seo:\n\n- ⭐ Cuir réalta lenár gcuid oibre ar GitHub\n- ❗ Cruthaigh Saincheist nó iarratas gné\n- 💁 Réitigh Saincheist agus cruthaigh Iarratas Tarraingthe\n- 🧑‍💻 Forbair d’fheidhmchlár féin ag úsáid AppAPI\n\nTáimid ar bís faoi thodhchaí an tionscadail AppAPI agus an poitéinseal atá ann athrú a dhéanamh\nan bealach a fhorbraítear feidhmchláir agus an taithí atá acu laistigh de Nextcloud.\n\nAgus muid ag tabhairt faoin turas seo, tugaimid cuireadh ó chroí daoibh - forbróirí, smaointeoirí, cruthaitheoirí agus físairí -\na bheith linn i múnlú a dhéanamh ar thírdhreach aip níos ilúsáidí, níos cobhsaí agus níos sábháilte.\n\n*Tá do léargais, do mholtaí agus do chuid oibre fíor-luachmhar dúinn.*",
    "The AppAPI Project is an exciting initiative that aims to revolutionize the way applications are developed for Nextcloud." : "Is tionscnamh spreagúil é Tionscadal AppAPI a bhfuil sé mar aidhm aige an bealach a fhorbraítear feidhmchláir do Nextcloud a athrú ó bhonn.",
    "Deploy Daemons" : "Imscaradh Deamhain",
    "Deploy Daemon (DaemonConfig) is an ExApps orchestration daemon." : "Is deamhan le haghaidh ceolfhoirne de chuid ExApps é Imscaradh Deamhan (DaemonConfig).",
    "Deploy Daemons. Deploy Daemon (DaemonConfig) is an ExApps orchestration daemon." : "Imscaradh Deamhain. Is deamhan le haghaidh ceolfhoirne de chuid ExApps é Imscaradh Deamhan (DaemonConfig).",
    "Default Deploy Daemon is not accessible. Please verify its configuration" : "Níl an Deamhan Imlonnaithe Réamhshocraithe inrochtana. Fíoraigh a chumraíocht le do thoil",
    "ExApp init timeout (minutes)" : "Teorainn ama init ExApp (nóiméid)",
    "ExApp initialization process timeout after which AppAPI will mark it as failed" : "Teorainn ama phróiseas tosaithe ExApp agus marcálfaidh AppAPI é mar theip ar ina dhiaidh sin",
    "ExApp init timeout" : "Teorainn ama init ExApp",
    "ExApp container restart policy" : "Beartas atosú coimeádán ExApp",
    "Specify container restart policy, e.g. 'always' to ensure ExApp running after daemon server reboot" : "Sonraigh polasaí atosú coimeádán, e.g. 'i gcónaí' chun a chinntiú go ritheann ExApp tar éis atosaigh an fhreastalaí deamhan",
    "This settings changes are reflected only for newly created containers" : "Ní léirítear na hathruithe socruithe seo ach le haghaidh coimeádáin nuachruthaithe",
    "External Apps management" : "Bainistíocht Aipeanna Seachtracha",
    "Admin options saved" : "Sábháladh roghanna riaracháin",
    "Failed to save admin options" : "Theip ar shábháil na roghanna riaracháin",
    "Are you sure you want delete Deploy Daemon" : "An bhfuil tú cinnte gur mhaith leat Deploy Deploy a scriosadh",
    "All ExApps on this daemon will be removed" : "Bainfear gach ExApp ar an deamhan seo",
    "All ExApps installed on this daemon will be removed" : "Bainfear gach ExApp atá suiteáilte ar an deamhan seo",
    "Cancel" : "Cealaigh",
    "Delete" : "Scrios",
    "Default" : "Réamhshocrú",
    "Set as default" : "Socraigh mar réamhshocrú",
    "Test deploy" : "Imscaradh tástála",
    "Edit" : "Cuir in eagar",
    "\"manual-install\" Deploy Daemon cannot be set as default" : "\"láimhe-shuiteáil\" Ní féidir Deploy Deploy a shocrú mar réamhshocraithe",
    "Failed to save admin options. Check the logs" : "Theip ar shábháil na roghanna riaracháin. Seiceáil na logs",
    "Password confirmation failed" : "Theip ar dheimhniú an phasfhocail",
    "Deploy daemon config details" : "Imscaradh sonraí cumraíochta deamhan",
    "Deploy Daemon" : "Imscaradh Deamhan",
    "Default daemon. ExApps will be installed on it" : "Deamhan réamhshocraithe. Déanfar ExApps a shuiteáil air",
    "Manual install daemon usually used for development. It cannot be set as default daemon." : "Deamhan suiteála láimhe a úsáidtear de ghnáth le haghaidh forbartha. Ní féidir é a shocrú mar dheamhan réamhshocraithe.",
    "ExApps installed" : "ExApps suiteáilte",
    "Name" : "Ainm",
    "Protocol" : "Prótacal",
    "Host" : "Óstach",
    "Deploy config" : "Imscaradh config",
    "Docker network" : "Líonra docker",
    "Nextcloud URL" : "URL Nextcloud",
    "HaProxy password" : "Pasfhocal HaProxy",
    "GPUs support" : "Tacaíocht GPUs",
    "Compute device" : "Gléas ríomh",
    "Additional options" : "Roghanna breise",
    "Verify connection" : "Fíoraigh ceangal",
    "Daemon connection successful" : "D'éirigh le nasc deamhan",
    "Failed to connect to Daemon. Check the logs" : "Theip ar nascadh le Deamhan. Seiceáil na logs",
    "Failed to check connection to Daemon. Check the logs" : "Theip ar an nasc le Deamhan a sheiceáil. Seiceáil na logs",
    "Registered Deploy daemons list" : "Liosta deamhan Imscaradh Cláraithe",
    "No Deploy daemons configured" : "Níl aon deamhan Imscaradh cumraithe",
    "Register a custom one or setup from available templates" : "Cláraigh ceann nó socrú saincheaptha ó na teimpléid atá ar fáil",
    "Register Daemon" : "Clár Deamhan",
    "AppAPI will try to install small skeleton ExApp to verify Daemon configured correctly and deployment steps are passing." : "Déanfaidh AppAPI iarracht ExApp cnámharlach beag a shuiteáil chun a fhíorú go bhfuil Deamhan cumraithe i gceart agus céimeanna imlonnaithe ag dul thar.",
    "The following Deploy test checks must be passed to succeed:" : "Ní mór na seiceálacha tástála Imlon seo a leanas a rith le go n-éireoidh leat:",
    "More info" : "Tuilleadh eolais",
    "Download ExApp logs" : "Íosluchtaigh leabhair Exapp",
    "Remove test ExApp" : "Bain tástáil ExApp",
    "Start Deploy test" : "Tosaigh Imscaradh tástála",
    "Stop Deploy test" : "Stop an tástáil Imscaradh",
    "ExApp is unregistered and container is removed on \"Stop deploy test\"" : "Tá ExApp neamhchláraithe agus baintear an coimeádán ar \"Stop deploy test\"",
    "Register ExApp in Nextcloud" : "Cláraigh ExApp in Nextcloud",
    "Check if the ExApp is registered in Nextcloud before deployment" : "Seiceáil an bhfuil an ExApp cláraithe in Nextcloud roimh imscaradh",
    "Image pull" : "Tarraingt íomhá",
    "Check if the image is successfully pulled" : "Seiceáil an bhfuil an íomhá tarraingthe go rathúil",
    "Container started" : "Thosaigh coimeádán",
    "Check if the image successfully pulled and container is created and started" : "Seiceáil an bhfuil an íomhá tarraingthe go rathúil agus an coimeádán cruthaithe agus tosaithe",
    "Heartbeat" : "Buille croí",
    "Check for the heartbeat is finished and healthy" : "Seiceáil an bhfuil an buille croí críochnaithe agus sláintiúil",
    "Init step" : "Céim tosaigh",
    "Wait for initialization step to finish" : "Fan go gcríochnóidh an chéim tosaigh",
    "Enabled" : "Cumasaithe",
    "Check if ExApp successfully handled the enabled event and registered all stuff properly" : "Seiceáil ar éirigh le ExApp an teagmhas cumasaithe a láimhseáil agus ar chláraigh sé gach rud i gceart",
    "Only if ExApp container is preset" : "Ach amháin má tá coimeádán ExApp réamhshocraithe",
    "Deploy test passed successfully!" : "D'éirigh leis an triail a imscaradh!",
    "Deploy test failed at step \"{step}\"" : "Theip ar an tástáil a chur i bhfeidhm ag céim \"{step}\"",
    "Edit Deploy Daemon" : "Cuir Deploy Daemon in eagar",
    "Register Deploy Daemon" : "Clár Imscaradh Deamhan",
    "Daemon configuration template" : "Teimpléad cumraíochta Deamhan",
    "Select daemon configuration template" : "Roghnaigh teimpléad cumraíochta deamhan",
    "Daemon registration form" : "Foirm chláraithe daemon",
    "Unique Deploy Daemon Name" : "Ainm Deamhain Uathúil Imscaradh",
    "Display name" : "Ainm taispeána",
    "Deployment method" : "Modh imscaradh",
    "Select daemon deploy method" : "Roghnaigh modh imscaradh deamhan",
    "Daemon host" : "Deamhan óstach",
    "Set daemon as default" : "Socraigh deamhan mar réamhshocrú",
    "Set as default daemon" : "Socraigh mar dheamhan réamhshocraithe",
    "Enable https" : "Cumasaigh https",
    "Show deploy config" : "Taispeáin cumraíocht imscaradh",
    "Hide deploy config" : "Folaigh cumraíocht imlonnaithe",
    "Network" : "Líonra",
    "Docker network name" : "Ainm líonra docker",
    "AppAPI Docker Socket Proxy authentication password" : "Pasfhocal fíordheimhnithe seachfhreastalaí Soicéad Docker AppAPI",
    "Additional option" : "Rogha breise",
    "Add additional option" : "Cuir rogha breise leis",
    "Option key (unique)" : "Eochair rogha (uathúil)",
    "Option key (unique, e.g. my_key)" : "Eochair rogha (uathúil, m.sh. my_key)",
    "Option key is required" : "Tá eochair rogha ag teastáil",
    "Option value" : "Luach rogha",
    "Option value is required" : "Tá luach rogha ag teastáil",
    "Confirm" : "Deimhnigh",
    "Save" : "Sábháil",
    "Register" : "Clár",
    "Check connection" : "Seiceáil an nasc",
    "Hostname to access ExApps" : "Óstainm chun rochtain a fháil ar ExApps",
    "Hostname or path to access Docker daemon (e.g. nextcloud-appapi-dsp:2375, /var/run/docker.sock)" : "Óstainm nó cosán chun rochtain a fháil ar dheamhan Docker (m.sh. nextcloud-appapi-dsp:2375, /var/run/docker.sock)",
    "Daemon with this name already exists" : "Deamhan leis an ainm seo ann cheana",
    "Password must be at least 12 characters long" : "Caithfidh pasfhocal a bheith 12 charachtar ar a laghad ar fad",
    "With https enabled network is set to host" : "Le https cumasaithe líonra socraithe chun óstáil",
    "Changes would be applied only for newly installed ExApps. For existing ExApps, Docker containers should be recreated." : "Ní chuirfí athruithe i bhfeidhm ach amháin i gcás ExApps nua-shuiteáilte. I gcás ExApps atá ann cheana féin, ba cheart coimeádáin Docker a athchruthú.",
    "URL should start with http:// or https://" : "Ba cheart go dtosódh an URL le http:// nó https://",
    "For HTTPS daemon, Nextcloud URL should be HTTPS" : "Maidir le deamhan HTTPS, ba cheart go mbeadh URL Nextcloud mar HTTPS",
    "All available GPU devices on daemon host will be requested to be enabled in ExApp containers by Docker." : "Iarrfar ar gach feiste GPU atá ar fáil ar óstach deamhan a bheith cumasaithe i gcoimeádáin ExApp ag Docker.",
    "DaemonConfig successfully registered" : "Cláraíodh DaemonConfig go rathúil",
    "Failed to register DaemonConfig. Check the logs" : "Theip ar chlárú DaemonConfig. Seiceáil na logs",
    "DaemonConfig successfully updated" : "D'éirigh le DaemonConfig a nuashonrú",
    "Failed to update DaemonConfig. Check the logs" : "Theip ar DaemonConfig a nuashonrú. Seiceáil na logs",
    "External Apps" : "Aipeanna Seachtrach",
    "### Boost your Nextcloud with AppAPI and its specially designed applications.\n\n\nThe AppAPI is a project within the Nextcloud ecosystem designed to streamline and enhance the process of\napplication development, deployment, and management.\n\nIt introduces a new methodology that allows developers to create\napplications using a variety of programming languages, not limited to PHP, which was traditionally used in Nextcloud development.\n\n### Bundled App\n\n**Starting with Nextcloud 30.0.1, this application is included in the default Nextcloud package.**\n\n### Support\n\nWe appreciate any support for this project:\n\n- ⭐ Star our work on GitHub\n- ❗ Create an Issue or feature request\n- 💁 Resolve an Issue and create a Pull Request\n- 🧑‍💻 Develop your own application using AppAPI\n\nWe are genuinely excited about the future of the AppAPI project and its potential to transform\nthe way applications are developed and experienced within Nextcloud.\n\nAs we embark on this journey, we warmly invite you - developers, thinkers, creators, and visionaries -\nto join us in shaping a more versatile, stable, and secure app landscape.\n\n*Your insights, suggestions, and contributions are invaluable to us.*" : "### Déan do Nextcloud a threisiú le AppAPI agus a fheidhmchláir atá saindeartha.\n\n\nIs tionscadal é an AppAPI laistigh d’éiceachóras Nextcloud atá deartha chun an próiseas a shruthlíniú agus a fheabhsú\nforbairt, imscaradh agus bainistíocht feidhmchlár.\n\nTugann sé isteach modheolaíocht nua a ligeann d'fhorbróirí a chruthú\nfeidhmchláir ag baint úsáide as éagsúlacht teangacha ríomhchlárúcháin, gan a bheith teoranta do PHP, a úsáideadh go traidisiúnta i bhforbairt Nextcloud.\n\n### Aip Chuachta\n\n** Ag tosú le Nextcloud 30.0.1, tá an feidhmchlár seo san áireamh sa phacáiste réamhshocraithe Nextcloud.**\n\n### Tacaíocht\n\nIs mór againn tacaíocht ar bith don tionscadal seo:\n\n- ⭐ Cuir réalta lenár gcuid oibre ar GitHub\n- ❗ Cruthaigh Saincheist nó iarratas gné\n- 💁 Réitigh Saincheist agus cruthaigh Iarratas Tarraingthe\n- 🧑‍💻 Forbair d’fheidhmchlár féin ag úsáid AppAPI\n\nTáimid ar bís faoi thodhchaí an tionscadail AppAPI agus an poitéinseal atá ann athrú a dhéanamh\nan bealach a fhorbraítear feidhmchláir agus an taithí atá acu laistigh de Nextcloud.\n\nAgus muid ag tabhairt faoin turas seo, tugaimid cuireadh ó chroí daoibh - forbróirí, smaointeoirí, cruthaitheoirí agus físairí -\na bheith linn i múnlú a dhéanamh ar thírdhreach aip níos ilúsáidí, níos cobhsaí agus níos sábháilte.\n\n*Tá do léargais, do mholtaí agus do chuid oibre fíor-luachmhar dúinn.*",
    "Update to {version}" : "Nuashonraigh go {version}",
    "Remove" : "Bain",
    "Delete data on remove" : "Scrios sonraí ar bhaint",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Níl aon leagan íosta de Nextcloud sannta don aip seo. Earráid a bheidh anseo sa todhchaí.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Níl aon leagan Nextcloud uasta sannta don aip seo. Earráid a bheidh anseo sa todhchaí.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ní féidir an aip seo a shuiteáil toisc nach bhfuil na spleáchais seo a leanas comhlíonta:",
    "View in store" : "Amharc sa siopa",
    "Visit website" : "Tabhair cuairt ar an suíomh Gréasáin",
    "Report a bug" : "Tuairiscigh fabht",
    "User documentation" : "Doiciméadú úsáideora",
    "Admin documentation" : "Doiciméadúchán riaracháin",
    "Developer documentation" : "Doiciméadú forbróra",
    "This app is not registered in AppStore. No extra information available. Only enable/disable and remove actions are allowed." : "Níl an aip seo cláraithe in AppStore. Níl aon eolas breise ar fáil. Ní cheadaítear ach gníomhartha a chumasú/a dhíchumasú agus a bhaint.",
    "{license}-licensed" : "{license}-cheadúnaithe",
    "This app is supported via your current Nextcloud subscription." : "Tacaítear leis an aip seo trí do shíntiús reatha Nextcloud.",
    "Supported" : "Tacaithe",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Forbraíonn an pobal agus laistigh den phobal aipeanna sainghnéitheacha. Cuireann siad feidhmiúlacht lárnach ar fáil agus tá siad réidh le húsáid táirgeachta.",
    "Featured" : "Feiceálach",
    "Update to {update}" : "Nuashonraigh go {update}",
    "All ExApps are up-to-date." : "Tá gach ExApps cothrom le dáta.",
    "Default Deploy daemon is not accessible" : "Níl an deamhan Réamhshocrú Imscaradh inrochtana",
    "Icon" : "Deilbhín",
    "Version" : "Leagan",
    "Daemon" : "Deamhan",
    "Level" : "Leibhéal",
    "Actions" : "Gníomhartha",
    "Results from other categories" : "Torthaí ó chatagóirí eile",
    "No apps found" : "Níor aimsíodh aon aipeanna",
    "_%n ExApp has an update available_::_%n apps have an update available_" : ["%n Tá nuashonrú ar fáil ag ExApp","Tá nuashonrú ar fáil ag %n aip","Tá nuashonrú ar fáil ag %n aip","Tá nuashonrú ar fáil ag %n aip","Tá nuashonrú ar fáil ag %n aip"],
    "_Update_::_Update all_" : ["Nuashonrú","Nuashonraigh go léir","Nuashonraigh go léir","Nuashonraigh go léir","Nuashonraigh go léir"],
    "Type" : "Cineál",
    "Display Name" : "Ainm taispeána",
    "Your apps" : "D'aipeanna",
    "Documentation" : "Doiciméadúchán",
    "Details" : "Sonraí",
    "Changelog" : "Loga athrú",
    "by {author}\n{license}" : "le {author}\n{license}",
    "Active apps" : "Aipeanna gníomhacha",
    "Disabled apps" : "Aipeanna díchumasaithe",
    "Updates" : "Nuashonruithe",
    "Featured apps" : "Aipeanna faoi thrácht",
    "Supported apps" : "Aipeanna tacaithe",
    "manual-install apps cannot be updated" : "Ní féidir aipeanna le suiteáil láimhe a nuashonrú",
    "{progress}% Deploying" : "{dul chun cinn } % Ag imscaradh",
    "{progress}% Initializing" : "{dul chun cinn } % á thúsú",
    "Healthchecking" : "Seiceáil sláinte",
    "Deploy and Enable" : "Imscaradh agus Cumasaigh",
    "Enable" : "Cumasaigh",
    "Disable" : "Díchumasaigh",
    "Allow untested app" : "Ceadaigh aip neamhthástáilte",
    "Default Deploy daemon is not accessible. Please verify configuration" : "Níl an deamhan Réamhshocrú Imscaradh inrochtana. Fíoraigh cumraíocht le do thoil",
    "The app will be downloaded from the App Store and deployed on default Deploy Daemon" : "Déanfar an aip a íoslódáil ón Siopa Aip agus a imscaradh ar Deploy Deploy réamhshocraithe",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Níl an aip seo marcáilte mar chomhoiriúnach le do leagan Nextcloud. Má leanann tú ar aghaidh beidh tú fós in ann an aip a shuiteáil. Tabhair faoi deara go bhféadfadh sé nach n-oibreoidh an aip mar a bhíothas ag súil leis.",
    "Your ExApps" : "Do ExApps",
    "An error occurred during the request. Unable to proceed." : "Tharla earráid le linn an iarratais. Ní féidir dul ar aghaidh.",
    "The app has been enabled but needs to be updated." : "Tá an aip cumasaithe ach ní mór é a nuashonrú.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Earráid: Ní féidir an aip seo a chumasú toisc go ndéanann sé an freastalaí éagobhsaí"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
