OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "найдвартай серверийн жагсаалтанд нэмэх",
    "Server is already in the list of trusted servers." : "сервер нь аль хэдийн найдвартай серверийн жагсаалтанд  байна",
    "No server to federate with found" : "Ямар ч холбооны сервер олдсонгүй ",
    "Could not add server" : " сервер нэмж чадаагүй ",
    "Trusted servers" : "найдвартай сервер",
    "Federation" : "холбоо",
    "+ Add trusted server" : "+ найдвартай сервер нэмэх",
    "Trusted server" : "найдвартай сервер",
    "Add" : "нэмэх"
},
"nplurals=2; plural=(n != 1);");
