<?php
// This file was auto-generated from sdk-root/src/data/customer-profiles/2020-08-15/paginators-1.json
return [ 'pagination' => [ 'ListEventStreams' => [ 'input_token' => 'NextToken', 'output_token' => 'NextToken', 'limit_key' => 'MaxResults', 'result_key' => 'Items', ], ],];
