OC.L10N.register(
    "logreader",
    {
    "App" : "Toep",
    "Time" : "Tyd",
    "Relative" : "Relatief",
    "Info" : "Inligting",
    "Warning" : "Waarskuwing",
    "Error" : "Fout"
},
"nplurals=2; plural=(n != 1);");
