OC.L10N.register(
    "sharebymail",
    {
    "Shared with {email}" : "משותף עם {email}",
    "Shared with {email} by {actor}" : "שותף עם {email} על ידי {actor}",
    "Unshared from {email}" : "השיתוף עם {email} בוטל",
    "Unshared from {email} by {actor}" : "השיתוף עם {email} בוטל על ידי {actor}",
    "Password for mail share sent to {email}" : "ססמת השיתוף בדוא״ל נשלחה אל {email}",
    "Password for mail share sent to you" : "ססמת השיתוף בדוא״ל נשלחה אליך",
    "You shared {file} with {email} by mail" : "שיתפת את {file} עם {email} בדוא״ל",
    "{actor} shared {file} with {email} by mail" : "{file} שותף עם {email} בדוא״ל על ידי {actor}",
    "You unshared {file} from {email} by mail" : "ביטלת את השיתוף של {file} מפני {email} בדוא״ל",
    "{actor} unshared {file} from {email} by mail" : "{actor} ביטל שיתוף {file} מ- {email} בדואר",
    "Password to access {file} was sent to {email}" : "ססמת הגישה אל {file} נשלחה אל {email}",
    "Password to access {file} was sent to you" : "ססמת הגישה אל {file} נשלחה אליך",
    "Share by mail" : "שיתוף בדוא״ל",
    "Failed to send share by email" : "שליחת השיתוף בדוא״ל נכשלה",
    "Note:" : "הערה:",
    "%1$s via %2$s" : "%1$s דרך %2$s",
    "It is protected with the following password:" : "הוא מוגן בססמה הבאה:",
    "This is the password:" : "זו הססמה:",
    "You can choose a different password at any time in the share dialog." : "ניתן לבחור בססמה אחרת בכל עת בתיבת דו־שיח השיתוף.",
    "Could not find share" : "לא ניתן למצוא את השיתוף",
    "Share provider which allows you to share files by mail" : "ספק השיתוף שמאפשר לך לשתף קבצים בדוא״ל",
    "Send password by mail" : "שליחת ססמה בדוא״ל"
},
"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
