<?php
namespace Aws\MemoryDB\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon MemoryDB** service.
 */
class MemoryDBException extends AwsException {}
