OC.L10N.register(
    "password_policy",
    {
    "Password policy" : "Wagwoordbeleid",
    "Forbid common passwords" : "Verbied algemene wagwoorde",
    "Enforce upper and lower case characters" : "Dwing klein- en hoofletterkarakters af",
    "Enforce numeric characters" : "Dwing numeriese karakters af",
    "Enforce special characters" : "Dwing spesiale karakters af",
    "Unknown error" : "Onbekende fout",
    "Settings saved" : "Instellings gestoor"
},
"nplurals=2; plural=(n != 1);");
