OC.L10N.register(
    "provisioning_api",
    {
    "Logged in account must be an administrator or have authorization to edit this setting." : "Sisselogitud kasutajakonto peab olema peakasutajat või omama eraldi õigust selle seadustuse muutmiseks.",
    "User already exists" : "Kasutaja on juba olemas",
    "Group %1$s does not exist" : "%1$s gruppi pole olemas",
    "Insufficient privileges for group %1$s" : "%1$s grupi jaoks pole pole piisavalt õigusi",
    "No group specified (required for sub-admins)" : "Ühtegi gruppi pole määratud (vajalik peakasutajate alamgrupi puhul)",
    "Sub-admin group does not exist" : "Peakasutajate alamgruppi pole olemas",
    "Cannot create sub-admins for admin group" : "Peakasutajate grupi alamgruppi loomine ei õnnestu",
    "No permissions to promote sub-admins" : "Pole õigusi peakasutajat alamgruppi määramiseks",
    "Invalid password value" : "Vigane salasõna väärtus",
    "An email address is required, to send a password link to the user." : "Salasõnalingi saatmiseks kasutajale on vajalik e-posti aadress.",
    "Required email address was not provided" : "Vajalik e-posti aadress on lisamata",
    "User creation failed" : "Kasutaja loomine ei õnnestunud",
    "Invalid quota value: %1$s" : "Vigane kvoodi väärtus: %1$s",
    "Invalid quota value. %1$s is exceeding the maximum quota" : "Vigane kvoodi väärtus. %1$s üledab maksimumkvoodi piiri",
    "Unlimited quota is forbidden on this instance" : "Piiramatu kvoodi kasutamine on selles serveris keelatud",
    "Setting the password is not supported by the users backend" : "Salasõna lisamine pole kasutajate taustateenuse poolt toetatud",
    "Invalid language" : "Vigane keel",
    "Invalid locale" : "Vigane lokaat",
    "Invalid first day of week" : "Vigane nädala esimene päev",
    "Cannot remove yourself from the admin group" : "Sa ei saa end peakasutajate grupist eemaldada",
    "Cannot remove yourself from this group as you are a sub-admin" : "Kuna oled peakasutajate alamgrupi liige, siis sa ei saa end eemaldada",
    "Not viable to remove user from the last group you are sub-admin of" : "Pole mõistlik eemaldada kasutajat viimasest grupist, kus oled peakasutajate alamgrupi liige",
    "User does not exist" : "Kasutajat pole olemas",
    "Group does not exist" : "Gruppi pole olemas",
    "User is not a sub-admin of this group" : "Kasutaja pole selle grupi peakasutajate alamgrupi liige",
    "Email address not available" : "E-posti aadress pole saadaval",
    "Sending email failed" : "E-kirja saatmine ei õnnestunud",
    "Email confirmation" : "E-posti aadressi kinnitamine",
    "To enable the email address %s please click the button below." : "%s e-posti aadressi kinnitamiseks palun klõpsi järgnevat nuppu.",
    "Confirm" : "Kinnita",
    "Email was already removed from account and cannot be confirmed anymore." : "E-posti aadress on kasutaja andmetest eemaldatud ja seda ei saa enam kinnitada.",
    "Could not verify mail because the token is expired." : "Kuna tunnusluba on aegunud, siis e-posti aadressi kinnitamine pole võimalik.",
    "Could not verify mail because the token is invalid." : "Kuna tunnusluba on vigane, siis e-posti aadressi kinnitamine pole võimalik.",
    "An unexpected error occurred. Please contact your admin." : "Tekkis ootamatu viga. Palun võta ühendust peakasutajaga.",
    "Email confirmation successful" : "E-posti aadressi kinnitamine õnnestus.",
    "This application enables a set of APIs that external systems can use to manage accounts, groups and apps." : "See rakendus võtab kasutusele sellised API-d mis võimaldavad välistel süsteemidel hallata kasutajakontosid, gruppe ja rakendusi."
},
"nplurals=2; plural=(n != 1);");
