OC.L10N.register(
    "files_external",
    {
    "Grant access" : "Conceder acceso",
    "Error configuring OAuth2" : "Se presentó un error al configurar OAuth2",
    "Generate keys" : "Generar llaves",
    "Error generating key pair" : "Se presentó un error al generar el juego de llaves",
    "Forbidden to manage local mounts" : "Prohibido administrar montajes locales.",
    "Storage with ID \"%d\" not found" : "El almacenamiento con ID \"%d\" no fue encontrado",
    "Invalid backend or authentication mechanism class" : "Backend o clase de mecanismo de autenticación inválido ",
    "Invalid mount point" : "Punto de montaje inválido",
    "Objectstore forbidden" : "Objectstore prohibido",
    "Invalid storage backend \"%s\"" : "Almacenamiento de backend \"%s\" inválido ",
    "Not permitted to use backend \"%s\"" : "No está permitido usar el backend \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "No está permitido el uso del mecanismo de autenticación \"%s\"",
    "Unsatisfied backend parameters" : "Parametros del backend no satisfechos",
    "Unsatisfied authentication mechanism parameters" : "Parámetros no satisfechos del mecanismo de autenticación",
    "Insufficient data: %s" : "Datos insuficientes: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not editable by non-admins" : "El almacenamiento con identificador \"%d\" no puede ser editado por usuarios no administradores",
    "Access key" : "Llave de acceso",
    "Secret key" : "Llave secreta",
    "Builtin" : "Integrado",
    "None" : "Ninguno",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID del cliente",
    "Client secret" : "Secreto del cliente",
    "OpenStack v2" : "OpenStack v2",
    "Login" : "Iniciar sesión",
    "Password" : "Contraseña",
    "Tenant name" : "Nombre de inquilino",
    "Identity endpoint URL" : "URL del punto de enlace de Identidad",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Dominio",
    "Rackspace" : "Rackspace",
    "API key" : "Llave de API",
    "Global credentials" : "Credenciales globales",
    "Log-in credentials, save in database" : "Credenciales de inicio de sesión, guardar en la base de datos",
    "Login and password" : "Usuario y contraseña",
    "Log-in credentials, save in session" : "Credenciales de inicio de sesión, guardar en la sesión",
    "Global credentials, manually entered" : "Credenciales globales, ingresadas manualmente",
    "Manually entered, store in database" : "Ingresado manualmente, almacenar en la base de datos",
    "RSA public key" : "Llave pública RSA",
    "Public key" : "Llave pública",
    "RSA private key" : "Llave privada RSA",
    "Private key" : "Llave privada",
    "Kerberos default realm, defaults to \"WORKGROUP\"" : "Dominio predeterminado de Kerberos, predeterminado como \"WORKGROUP\".",
    "Kerberos ticket Apache mode" : "Ticket Kerberos modo Apache",
    "Kerberos ticket" : "Ticket de Kerberos",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Nombre del servidor",
    "Port" : "Puerto",
    "Region" : "Región",
    "Storage Class" : "Clase de almacenamiento",
    "Enable SSL" : "Habilitar SSL",
    "Enable Path Style" : "Habilitar Estilo de Ruta",
    "Legacy (v2) authentication" : "Autenticación legada (v2)",
    "Enable multipart copy" : "Habilitar la copia multi partes",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Subcarpeta remota",
    "Secure https://" : "https:// seguro",
    "FTP" : "FTP",
    "Host" : "Servidor",
    "Secure ftps://" : "ftps:// seguro",
    "Local" : "Local",
    "Location" : "Ubicación",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Raíz",
    "SFTP with secret key login" : "Inicio de sesión SFTP con llave secreta",
    "SMB/CIFS" : "SMB/CIFS",
    "Share" : "Compartir",
    "Show hidden files" : "Mostrar archivos ocultos",
    "Case sensitive file system" : "Sistema de archivos sensible a capitalización",
    "Disabling it will allow to use a case insensitive file system, but comes with a performance penalty" : "Desactivarlo permitirá utilizar un sistema de archivos insensible a mayúsculas y minúsculas, a costa de un menor rendimiento",
    "Verify ACL access when listing files" : "Verificar el acceso ACL al listar archivos",
    "Check the ACL's of each file or folder inside a directory to filter out items where the account has no read permissions, comes with a performance penalty" : "Verificar la lista de control de permisos de cada archivo o carpeta dentro de un directorio para filtrar los elementos donde el usuario no tenga permisos de lectura, a costa de un menor rendimiento",
    "Timeout" : "Tiempo de espera agotado",
    "SMB/CIFS using OC login" : "SMB / CIFS usando inicio de sesión OC",
    "Login as share" : "Iniciar sesión como recurso compartido",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Nombre del servicio",
    "Request timeout (seconds)" : "Tiemo de vida de la solicitud (segundos)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "El soporte para cURL en PHP no se encuentra habilitado o instalado. El montaje de %s no es posible. Por favor solicita a tu administador su instalación. ",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "El soporte para FTP en PHP no se encuentra habilitado o instalado. El montaje de %s no es posible. Por favor solicita a tu administador su instalación. ",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "\"%1$s\" no está instalado. No se puede montar %2$s. Por favor, pida a su administrador del sistema que lo instale.",
    "External storage" : "Almacenamiento externo",
    "External storage support" : "Soporte de almacenamiento externo",
    "Adds basic external storage support" : "Agrega soporte básico para almacenamiento externo",
    "This application enables administrators to configure connections to external storage providers, such as FTP servers, S3 or SWIFT object stores, other Nextcloud servers, WebDAV servers, and more. Administration can choose which types of storage to enable and can mount these storage locations for an account, a group, or the entire system. Users will see a new folder appear in their root Nextcloud directory, which they can access and use like any other Nextcloud folder. External storage also allows people to share files stored in these external locations. In these cases, the credentials for the owner of the file are used when the recipient requests the file from external storage, thereby ensuring that the recipient can access the shared file.\n\nExternal storage can be configured using the GUI or at the command line. This second option provides the administration with more flexibility for configuring bulk external storage mounts and setting mount priorities. More information is available in the external storage GUI documentation and the external storage Configuration File documentation." : "Esta aplicación le permite a los adminsitradores configurar las conexiónes a  proveedores de almacenamiento externo, tales como servidores FTP, S3 o almacenamiento de objetos SWIFT, otros servidores de Nextcloud, servidores WebDAV y más.  Los administradores pueden elegir qué tipos de almacenamiento habilitar y pueden montar estas ubicaciones de almacenamiento para un usuario, un grupo o para todo el sistema. Los usuarios verán aparecer una nueva carpeta en su directorio raíz de Nextcloud, la cual podrán acceder y usar como cualquier otra carpeta de Nextcloud. El almacenamiento externo también le permite a los usuarios compartir archivos almacenados en estas ubicaciones externas. En estos casos, las credenciales del dueño del archivo son usadas cuando el destinatario solicita el archivo de un almacenamiento externo, asegurando así que el destinatario pueda acceder el archivo compartido.\n\nEl almacenamiento externo se puede configurar usando el GUI o la línea de comandos. Esta segunda opción le brinda a los administradores más flexibilidad para configurar masivamente el montaje del almacenamiento externo y establecer la prioridad de montaje. Más información disponible en la documentación de almacenamiento externo GUI y la documentación del archivo de configuración del almacenamiento externo. ",
    "Confirm" : "Confirmar",
    "Storage credentials" : "Credenciales de almacenamiento",
    "To access the storage, you need to provide the authentication credentials." : "Para acceder al almacenamiento, debe proporcionar las credenciales de autenticación.",
    "Enter the storage login" : "Ingrese el inicio de sesión de almacenamiento",
    "Enter the storage password" : "Ingrese la contraseña de almacenamiento",
    "Unable to update this external storage config. {statusMessage}" : "No se pudo actualizar la configuración de este almacenamiento externo. {statusMessage}",
    "New configuration successfully saved" : "La nueva configuración se guardó exitosamente",
    "Enter missing credentials" : "Ingrese las credenciales faltantes",
    "There was an error with this external storage." : "Hay un error con este almacenamiento externo.",
    "We were unable to check the external storage {basename}" : "No pudimos revisar el almacenamiento externo {basename}",
    "Examine this faulty external storage configuration" : "Examinar la configuración fallida de este almacenamiento externo",
    "Open in Files" : "Abrir en Archivos",
    "There was an error with this external storage. Do you want to review this mount point config in the settings page?" : "Ocurrió un problema con este almacenamiento externo. ¿Desea revisar la configuración de este punto de montaje en la página de configuración?",
    "External mount error" : "Error de montaje externo",
    "List of external storage." : "Lista de almacenamientos externos.",
    "There is no external storage configured. You can configure them in your Personal settings." : "No hay ningún almacenamiento externos configurado. Puede configurarlos en su configuración personal.",
    "There is no external storage configured and you don't have the permission to configure them." : "No se ha configurado ningún almacenamiento externo y no tiene permiso para configurarlos.",
    "No external storage" : "Sin almacenamientos externos",
    "Storage type" : "Tipo de almacenamiento",
    "Unknown" : "Desconocido",
    "Scope" : "Alcance",
    "Personal" : "Personal",
    "System" : "Sistema",
    "Type to select account or group." : "Escriba para seleccionar un usuario o grupo.",
    "(Group)" : "(Grupo)",
    "Compatibility with Mac NFD encoding (slow)" : "Compatibilidad con codificación Mac NFD (lenta)",
    "Enable encryption" : "Habilitar encripción",
    "Enable previews" : "Habilitar vistas previas",
    "Enable sharing" : "Habilitar compartir",
    "Check for changes" : "Verificar si hay cambios",
    "Never" : "Nunca",
    "Once every direct access" : "Una vez cada acceso directo",
    "Read only" : "Sólo lectura",
    "Disconnect" : "Desconectar",
    "Unknown backend: {backendName}" : "Backend desconocido: {backendName}",
    "Admin defined" : "Administrador definido",
    "Automatic status checking is disabled due to the large number of configured storages, click to check status" : "La verificación automática de estado está desactivada debido al gran número de almacenamientos configurados, haga clic para verificar el estado",
    "Are you sure you want to disconnect this external storage? It will make the storage unavailable in Nextcloud and will lead to a deletion of these files and folders on any sync client that is currently connected but will not delete any files and folders on the external storage itself." : "¿Está seguro que quiere desconectar este almacenamiento externo? Esto hará que el almacenamiento no esté disponible en Nextcloud y se eliminen estos archivos y carpetas en cualquier cliente de sincronización que esté conectado actualmente, pero no se eliminarán los archivos y carpetas en el propio almacenamiento externo.",
    "Delete storage?" : "¿Borrar almacenamiento?",
    "Click to recheck the configuration" : "Haz click para volver a marcar la configuración",
    "Saved" : "Guardado",
    "Saving …" : "Guardando ...",
    "Save" : "Guardar",
    "No external storage configured or you don't have the permission to configure them" : "No se ha configurado almacenamiento externo o bien no cuentas con los permisos para configurarlos",
    "Open documentation" : "Abrir documentación",
    "External storage enables you to mount external storage services and devices as secondary Nextcloud storage devices. You may also allow people to mount their own external storage services." : "El almacenamiento externo permite montar servicios y dispositivos de almacenamiento externo como dispositivos secundarios de almacenamiento de Nextcloud. También puede permitir a los usuarios montar sus propios servicios de almacenamiento externo.",
    "Folder name" : "Nombre de la carpeta",
    "Authentication" : "Autenticación",
    "Configuration" : "Configuración",
    "Available for" : "Disponible para",
    "Add storage" : "Agregar almacenamiento",
    "All people" : "Todas las personas",
    "Advanced settings" : "Configuraciones avanzadas",
    "Allow people to mount external storage" : "Permitir a los usuarios montar almacenamientos externos",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Las credenciales globales se pueden usar para autentificarse con múltiples almacenamientos externos que tienen las mismas credenciales.",
    "Error configuring OAuth1" : "Se presentó un error al configurar OAuth1",
    "Please provide a valid app key and secret." : "Por favor proporciona una llave de aplicación y secreto válidos.",
    "OAuth1" : "OAuth1",
    "App key" : "Llave de la aplicación",
    "App secret" : "Secreto de la aplicación"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
