OC.L10N.register(
    "sharebymail",
    {
    "Shared with {email}" : "Delt med {email}",
    "Shared with {email} by {actor}" : "Delt med {email} av {actor}",
    "Unshared from {email}" : "Opphevde deling fra {email}",
    "Unshared from {email} by {actor}" : "Opphevde deling fra {email} av {actor}",
    "Password for mail share sent to {email}" : "Passord for e-postlager sendt til {email}",
    "Password for mail share sent to you" : "Passord for e-postlager sendt til deg",
    "You shared {file} with {email} by mail" : "Du delte {file} med {email} via e-post",
    "{actor} shared {file} with {email} by mail" : "{actor} delte {file} med {email} via e-post",
    "You unshared {file} from {email} by mail" : "Du opphevde delingen {file} med {email} via e-post",
    "{actor} unshared {file} from {email} by mail" : "{actor} opphevde deling av {file} fra {email} via e-post",
    "Password to access {file} was sent to {email}" : "Passord for tilgang til {file} ble sendt til {email}",
    "Password to access {file} was sent to you" : "Du ble tildelt passord for å benytte {file}",
    "Share by mail" : "Del via e-post",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Deling av %1$s feilet, fordi dette elementet er allerede delt med kontoen %2$s",
    "We cannot send you the auto-generated password. Please set a valid email address in your personal settings and try again." : "Vi kan ikke sende deg det automatisk genererte passordet. Angi en gyldig e-postadresse i dine personlige innstillinger og prøv igjen.",
    "Failed to send share by email. Got an invalid email address" : "Kunne ikke sende deling via e-post. Fikk en ugyldig e-postadresse",
    "Failed to send share by email" : "Delingen kunne ikke sendes med e-post",
    "%1$s shared %2$s with you" : "%1$s delte %2$s med deg",
    "Note:" : "Merk:",
    "This share is valid until %s at midnight" : "Denne delte ressursen er gyldig til %s ved midnatt",
    "Expiration:" : "Utløp:",
    "Open %s" : "Åpne %s",
    "%1$s via %2$s" : "%1$s via %2$s",
    "%1$s shared %2$s with you. You should have already received a separate mail with a link to access it." : "%1$s delte %2$s med deg. Du skal allerede ha mottatt en egen e-post med en lenke for å få tilgang til den.",
    "Password to access %1$s shared to you by %2$s" : "Passord for å få tilgang til %1$s delt med deg av %2$s",
    "Password to access %s" : "Passord for å få tilgang til %s",
    "It is protected with the following password:" : "Den er beskyttet med følgende passord:",
    "This password will expire at %s" : "Dette passordet vil utløpe ved %s",
    "%1$s shared %2$s with you and wants to add:" : "%1$s delte %2$s med deg og ønsker å legge til:",
    "%1$s shared %2$s with you and wants to add" : "%1$s delte %2$s med deg og ønsker å legge til",
    "%s added a note to a file shared with you" : "%s la til et notat i en fil som er delt med deg",
    "You just shared %1$s with %2$s. The share was already sent to the recipient. Due to the security policies defined by the administrator of %3$s each share needs to be protected by password and it is not allowed to send the password directly to the recipient. Therefore you need to forward the password manually to the recipient." : "Du har nettopp delt %1$s med %2$s. Delingen er allerede sendt til mottakeren. På grunn av sikkerhetsreglene som er definert av administratoren for %3$s, må hver delt passord beskyttes og det er ikke tillatt å sende passordet direkte til mottakeren. Derfor må du videresende passordet manuelt til mottakeren.",
    "Password to access %1$s shared by you with %2$s" : "Passord for å få tilgang til %1$s delt av deg med %2$s",
    "This is the password:" : "Dette er passordet:",
    "You can choose a different password at any time in the share dialog." : "Du kan velge et annet passord når som helst i delingsdialogvinduet.",
    "Could not find share" : "Delingen ble ikke funnet",
    "Share provider which allows you to share files by mail" : "Delingsleverandør som lar deg dele filer via post",
    "Unable to update share by mail config" : "Kan ikke oppdatere deling via e-postkonfigurasjon",
    "Allows people to share a personalized link to a file or folder by putting in an email address." : "Tillater personer å dele en personalisert lenke til en fil eller mappe ved å skrive inn en e-postadresse.",
    "Send password by mail" : "Send passord via e-post",
    "Reply to initiator" : "Svar til initiativtaker"
},
"nplurals=2; plural=(n != 1);");
