OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Nameščen odjemalec ni overjen za vzpostavljanje povezave. Stopite v stik s skrbnikom odjemalca.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Preusmeritveni naslov URL mora biti zapisan v polni obliki: https://domena.si/celotna-pot",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Dovoli skladno overitev OAuth2 prek drugih spletnih programov.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "Program OAuth2 omogoča skrbnikom  nastavitev vgrajenega sistema overitve za skladnost z drugimi spletnimi programi.",
    "OAuth 2.0 clients" : "Odjemalci OAuth 2.0",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "Program OAuth 2.0 omogoča zunanjim storitvam odobritev dostopa do {instanceName}.",
    "Name" : "Ime",
    "Redirection URI" : "Preusmeritveni naslov URI",
    "Client Identifier" : "ID odjemalca",
    "Secret key" : "Skrivni ključ",
    "Add client" : "Dodaj odjemalca",
    "Add" : "Dodaj",
    "Show client secret" : "Pokaži skrivno kodo odjemalca",
    "Delete" : "Izbriši"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
