<?php
/**
 * libphonenumber-for-php-lite data file
 * This file has been @generated from libphonenumber data
 * Do not modify!
 * @internal
 */

return [
    'id' => 'TK',
    'countryCode' => 690,
    'generalDesc' => [
        'pattern' => '[2-47]\\d{3,6}',
        'posLength' => [
            4,
            5,
            6,
            7,
        ],
    ],
    'fixedLine' => [
        'pattern' => '(?:2[2-4]|[34]\\d)\\d{2,5}',
        'example' => '3101',
    ],
    'mobile' => [
        'pattern' => '7[2-4]\\d{2,5}',
        'example' => '7290',
    ],
    'tollFree' => [
        'posLength' => [
            -1,
        ],
    ],
    'premiumRate' => [
        'posLength' => [
            -1,
        ],
    ],
    'sharedCost' => [
        'posLength' => [
            -1,
        ],
    ],
    'personalNumber' => [
        'posLength' => [
            -1,
        ],
    ],
    'voip' => [
        'posLength' => [
            -1,
        ],
    ],
    'pager' => [
        'posLength' => [
            -1,
        ],
    ],
    'uan' => [
        'posLength' => [
            -1,
        ],
    ],
    'voicemail' => [
        'posLength' => [
            -1,
        ],
    ],
    'noInternationalDialling' => [
        'posLength' => [
            -1,
        ],
    ],
    'internationalPrefix' => '00',
    'numberFormat' => [],
];
