<?php
namespace Aws\SSMQuickSetup\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Systems Manager QuickSetup** service.
 */
class SSMQuickSetupException extends AwsException {}
