const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=[window.OC.filePath('activity', '', 'js/ActivityTab-BCjAneVi.chunk.mjs'),window.OC.filePath('activity', '', 'js/NcCheckboxRadioSwitch-VeztTzpz-Czz9vtPv.chunk.mjs'),window.OC.filePath('activity', '', 'js/translation-CD_FiYBO-Dm5ZmTPn.chunk.mjs'),window.OC.filePath('activity', '', 'js/_commonjsHelpers-D9DevfhH.chunk.mjs'),window.OC.filePath('activity', '', 'js/logger-CawX0p3n.chunk.mjs'),window.OC.filePath('activity', '', 'js/Activity-BFfMM_ab.chunk.mjs'),window.OC.filePath('activity', '', 'js/preload-helper-DPcAka6r.chunk.mjs'),window.OC.filePath('activity', '', 'js/api-kHrAWUTr.chunk.mjs')])))=>i.map(i=>d[i]);
import{_ as o}from"./preload-helper-DPcAka6r.chunk.mjs";import{V as i,t as r,a as u}from"./translation-CD_FiYBO-Dm5ZmTPn.chunk.mjs";import"./_commonjsHelpers-D9DevfhH.chunk.mjs";const p='<svg xmlns="http://www.w3.org/2000/svg" id="mdi-lightning-bolt" viewBox="0 0 24 24"><path d="M11 15H6L13 1V9H18L11 23V15Z" /></svg>';i.prototype.t=r,i.prototype.n=u;let e=null,t=null;const c=new OCA.Files.Sidebar.Tab({id:"activity",name:r("activity","Activity"),iconSvg:p,async mount(a,n,s){if(e===null){const{default:d}=await o(async()=>{const{default:l}=await import("./ActivityTab-BCjAneVi.chunk.mjs");return{default:l}},__vite__mapDeps([0,1,2,3,4,5,6,7]),import.meta.url);e=e??i.extend(d)}t&&t.$destroy(),t=new e({parent:s}),t.update(n),t.$mount(a)},update(a){t.update(a)},destroy(){t.$destroy(),t=null}});window.addEventListener("DOMContentLoaded",async function(){if(OCA.Files&&OCA.Files.Sidebar){OCA.Files.Sidebar.registerTab(c);const{default:a}=await o(async()=>{const{default:n}=await import("./ActivityTab-BCjAneVi.chunk.mjs");return{default:n}},__vite__mapDeps([0,1,2,3,4,5,6,7]),import.meta.url);e=e??i.extend(a)}});export{p as l};
//# sourceMappingURL=activity-sidebar.mjs.map
