OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Dodano do ulubionych",
    "Removed from favorites" : "Usunięto z ulubionych",
    "You added {file} to your favorites" : "Dodałeś {file} do ulubionych",
    "You removed {file} from your favorites" : "Usunąłeś {file} z ulubionych",
    "Favorites" : "Ulubione",
    "File changes" : "Zmiany w plikach",
    "Created by {user}" : "Utworzone przez {user}",
    "Changed by {user}" : "Zmienione przez {user}",
    "Deleted by {user}" : "Usunięte przez {user}",
    "Restored by {user}" : "Przywrócone przez {user}",
    "Renamed by {user}" : "Zmienione przez {user}",
    "Moved by {user}" : "Przeniesione przez {user}",
    "\"remote account\"" : "\"zdalne konto\"",
    "You created {file}" : "Utworzyłeś {file}",
    "You created an encrypted file in {file}" : "Stworzyłeś zaszyfrowany plik w {file}",
    "{user} created {file}" : "{user} utworzył {file}",
    "{user} created an encrypted file in {file}" : "{user} utworzył zaszyfrowany plik w {file}",
    "{file} was created in a public folder" : "{file} został utworzony w katalogu publicznym",
    "You changed {file}" : "Zmieniłeś {file}",
    "You changed an encrypted file in {file}" : "Zmieniłeś zaszyfrowany plik w {file}",
    "{user} changed {file}" : "{user} zmienił {file}",
    "{user} changed an encrypted file in {file}" : "{user} zmienił zaszyfrowany plik w {file}",
    "You deleted {file}" : "Usunąłeś {file}",
    "You deleted an encrypted file in {file}" : "Usunąłeś zaszyfrowany plik w {file}",
    "{user} deleted {file}" : "{user} usunął {file}",
    "{user} deleted an encrypted file in {file}" : "{user} usunął zaszyfrowany plik w {file}",
    "You restored {file}" : "Przywróciłeś {file}",
    "{user} restored {file}" : "{user} przywrócił {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Zmieniłeś {oldfile} (hidden) na {newfile} (hidden)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Zmieniłeś {oldfile} (hidden) na {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Zmieniłeś {oldfile} na {newfile} (hidden)",
    "You renamed {oldfile} to {newfile}" : "Zmieniłeś {oldfile} na {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} zmienił {oldfile} (hidden) na {newfile} (hidden)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} zmienił {oldfile} (hidden) na {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} zmienił {oldfile} na {newfile} (hidden)",
    "{user} renamed {oldfile} to {newfile}" : "{user} zmienił {oldfile} na {newfile}",
    "You moved {oldfile} to {newfile}" : "Przeniosłeś {oldfile} do {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} przeniósł {oldfile} do {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Plik został dodany lub usunięty z <strong>ulubionych</strong>",
    "Files" : "Pliki",
    "A file or folder has been <strong>changed</strong>" : "Plik lub katalog został <strong>zmieniony</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Ulubiony plik lub katalog został <strong>zmieniony</strong>",
    "Failed to authorize" : "Błąd autoryzacji",
    "Invalid folder path" : "Nieprawidłowa ścieżka katalogu",
    "Folder not found" : "Nie znaleziono katalogu",
    "The file cannot be found" : "Nie można znaleźć pliku",
    "The destination path does not exist: %1$s" : "Ścieżka docelowa nie istnieje: %1$s",
    "You do not have permission to create a file at the specified location" : "Nie masz uprawnień do utworzenia pliku w określonej lokalizacji",
    "The file could not be converted." : "Nie udało się przekonwertować pliku.",
    "Could not get relative path to converted file" : "Nie można uzyskać ścieżki względnej do przekonwertowanego pliku",
    "Favorite files" : "Ulubione pliki",
    "No favorites" : "Brak ulubionych",
    "More favorites" : "Więcej ulubionych",
    "Accept" : "Akceptuj",
    "Reject" : "Odrzuć",
    "Incoming ownership transfer from {user}" : "Przychodzące przeniesienie własności od {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Czy chcesz zaakceptować {path}\n\nUwaga: Proces transferu po zaakceptowaniu może potrwać do 1 godziny.",
    "Ownership transfer denied" : "Odmowa przeniesienia własności",
    "Your ownership transfer of {path} was denied by {user}." : "Twoje przeniesienie własności {path} zostało odrzucone przez {user}.",
    "Ownership transfer failed" : "Przeniesienie własności nie powiodło się",
    "Your ownership transfer of {path} to {user} failed." : "Twoje przeniesienie własności {path} na {user} nie powiodło się.",
    "The ownership transfer of {path} from {user} failed." : "Przeniesienie własności {path} z {user} nie powiodło się.",
    "Ownership transfer done" : "Dokonano przeniesienia własności",
    "Your ownership transfer of {path} to {user} has completed." : "Twoje przeniesienie własności {path} na {user} zostało zakończone.",
    "The ownership transfer of {path} from {user} has completed." : "Przeniesienie własności {path} z {user} zostało zakończone.",
    "in %s" : "w %s",
    "Transferred from %1$s on %2$s" : "Przeniesiono z %1$s dnia %2$s",
    "Files compatibility" : "Zgodność plików",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Zezwalaj na ograniczenie nazw plików, aby zapewnić synchronizację plików ze wszystkimi klientami. Domyślnie dozwolone są wszystkie nazwy plików obowiązujące w systemie POSIX (np. Linux lub macOS).",
    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Po włączeniu nazw plików zgodnych z systemem Windows, istniejące pliki nie można już modyfikować, ale ich właściciel może zmienić ich nazwy na nowe, prawidłowe.",
    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Możliwe jest również automatyczne migrowanie plików po włączeniu tego ustawienia. Więcej informacji można znaleźć w dokumentacji polecenia occ.",
    "Enforce Windows compatibility" : "Wymuszaj zgodność z systemem Windows",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Spowoduje to zablokowanie nazw plików nieprawidłowych w systemach Windows, na przykład nazw zastrzeżonych lub znaków specjalnych. Nie wymusi to jednak zgodności z rozróżnianiem wielkości liter.",
    "File Management" : "Zarządzanie plikami",
    "Home" : "Strona główna",
    "Target folder does not exist any more" : "Katalog docelowy już nie istnieje",
    "Reload current directory" : "Przeładuj bieżący katalog",
    "Go to the \"{dir}\" directory" : "Przejdź do katalogu \"{dir}\"",
    "Current directory path" : "Obecna ścieżka katalogu",
    "Your have used your space quota and cannot upload files anymore" : "Wykorzystałeś limit miejsca i nie możesz już wysyłać plików.",
    "You do not have permission to upload or create files here." : "Nie masz uprawnień do wysyłania lub tworzenia plików w tym miejscu",
    "Drag and drop files here to upload" : "Przeciągnij i upuść pliki tutaj, aby je przesłać",
    "Favorite" : "Ulubiony",
    "Back" : "Poprzednia",
    "Toggle selection for file \"{displayName}\"" : "Przełącz zaznaczenie dla pliku \"{displayName}\"",
    "Toggle selection for folder \"{displayName}\"" : "Przełącz zaznaczenie dla katalogu \"{displayName}\"",
    "File is loading" : "Plik jest wczytywany",
    "Folder is loading" : "Katalog jest wczytywany",
    "Filename" : "Nazwa pliku",
    "Folder name" : "Nazwa katalogu",
    "This node is unavailable" : "Ten węzeł jest niedostępny",
    "Another entry with the same name already exists." : "Inny wpis o tej samej nazwie już istnieje.",
    "Invalid filename." : "Nieprawidłowa nazwa pliku.",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Zmieniono nazwę \"{oldName}\" na \"{newName}\"",
    "Rename file" : "Zmień nazwę pliku",
    "Folder" : "Katalog",
    "Unknown file type" : "Nieznany typ pliku",
    "{ext} image" : "{ext} zdjęcie",
    "{ext} video" : "{ext} wideo",
    "{ext} audio" : "{ext} dźwiękowy",
    "{ext} text" : "{ext} tekstowy",
    "Pending" : "Oczekujące",
    "Unknown date" : "Nieznana data",
    "Clear filter" : "Wyczyść filtr",
    "Modified" : "Zmodyfikowany",
    "Search everywhere" : "Szukaj wszędzie",
    "Type" : "Rodzaj",
    "Active filters" : "Aktywne filtry",
    "Remove filter" : "Usuń filtr",
    "Total rows summary" : "Podsumowanie wszystkich wierszy",
    "Toggle selection for all files and folders" : "Przełącz zaznaczenie dla wszystkich plików i katalogów",
    "Name" : "Nazwa",
    "File type" : "Typ pliku",
    "Size" : "Rozmiar",
    "{displayName}: failed on some elements" : "{displayName}: niepowodzenie w przypadku niektórych elementów",
    "{displayName}: done" : "{displayName}: zakończono",
    "{displayName}: failed" : "{displayName}: niepowodzenie",
    "Actions" : "Akcje",
    "(selected)" : "(wybrany)",
    "List of files and folders." : "Lista plików i katalogów.",
    "You have used your space quota and cannot upload files anymore." : "Wykorzystałeś limit miejsca i nie możesz już wysyłać plików.",
    "Column headers with buttons are sortable." : "Nagłówki kolumn z przyciskami są sortowalne.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Ta lista nie jest w pełni renderowana ze względu na wydajność. Pliki będą renderowane podczas poruszania się po liście.",
    "File not found" : "Nie odnaleziono pliku",
    "_{count} selected_::_{count} selected_" : ["wybrano {count}","wybrano {count}","wybrano {count}","wybrano {count}"],
    "Search everywhere …" : "Szukaj wszędzie…",
    "Search here …" : "Szukaj tutaj…",
    "Search scope options" : "Opcje zakresu wyszukiwania",
    "Search here" : "Szukaj tutaj",
    "{usedQuotaByte} used" : "Wykorzystano {usedQuotaByte}",
    "{used} of {quota} used" : "Wykorzystane {used} z {quota}",
    "{relative}% used" : "Wykorzystano {relative}%",
    "Could not refresh storage stats" : "Nie można odświeżyć statystyk przechowywania",
    "Your storage is full, files can not be updated or synced anymore!" : "Magazyn jest pełny. Nie można już zaktualizować ani zsynchronizować plików!",
    "Storage information" : "Informacje o przechowywaniu",
    "Storage quota" : "Limit przechowywania",
    "New folder" : "Nowy katalog",
    "Create new folder" : "Utwórz nowy katalog",
    "This name is already in use." : "Ta nazwa jest już używana.",
    "Create" : "Utwórz",
    "Files starting with a dot are hidden by default" : "Pliki zaczynające się od kropki są domyślnie ukryte",
    "Fill template fields" : "Wypełnij pola szablonu",
    "Submitting fields …" : "Wysyłanie pól…",
    "Submit" : "Wyślij",
    "Choose a file or folder to transfer" : "Wybierz plik lub katalog do przeniesienia",
    "Transfer" : "Przenieś",
    "Transfer {path} to {userid}" : "Przenieś {path} do {userid}",
    "Invalid path selected" : "Wybrano nieprawidłową ścieżkę",
    "Unknown error" : "Nieznany błąd",
    "Ownership transfer request sent" : "Wysłano żądanie przeniesienia własności",
    "Cannot transfer ownership of a file or folder you do not own" : "Nie można przenieść prawa własności do pliku lub katalogu, którego nie jesteś właścicielem",
    "Transfer ownership of a file or folder" : "Przenieś własność pliku lub katalogu",
    "Choose file or folder to transfer" : "Wybierz plik lub katalog do przeniesienia",
    "Change" : "Zmień",
    "New owner" : "Nowy właściciel",
    "Keep {old}" : "Zachowaj {old}",
    "Keep without extension" : "Przechowaj bez przedłużania",
    "Use {new}" : "Użyj {new}",
    "Remove extension" : "Usuń rozszerzenie",
    "Change file extension" : "Zmień rozszerzenie pliku",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Zmienienie rozszerzenia pliku z „{old}”  na „{new}” może spowodować, że plik będzie nieczytelny.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "Usunięcie rozszerzenia pliku „{old}” może spowodować, że plik będzie nieczytelny.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "Dodanie rozszerzenia pliku „{new}” może spowodować, że plik będzie nieczytelny.",
    "Do not show this dialog again." : "Nie pokazuj więcej tego okna dialogowego.",
    "Select file or folder to link to" : "Wybierz plik lub katalog do linku",
    "Choose {file}" : "Wybierz {file}",
    "Share" : "Udostępnij",
    "Shared by link" : "Udostępnione linkiem",
    "Shared" : "Udostępnione",
    "Switch to list view" : "Przełącz na widok listy",
    "Switch to grid view" : "Przełącz na widok siatki",
    "The file could not be found" : "Nie można znaleźć pliku",
    "Upload was cancelled by user" : "Przesyłanie zostało anulowane przez użytkownika",
    "Not enough free space" : "Za mało wolnego miejsca",
    "Operation is blocked by access control" : "Operacja jest zablokowana przez kontrolę dostępu",
    "Error during upload: {message}" : "Błąd podczas wysyłania: {message}",
    "Error during upload, status code {status}" : "Błąd podczas wysyłania, kod statusu {status}",
    "Unknown error during upload" : "Nieznany błąd podczas wysyłania",
    "Loading current folder" : "Wczytywanie bieżącego katalogu",
    "Retry" : "Powtórz",
    "No files in here" : "Brak plików",
    "Upload some content or sync with your devices!" : "Wyślij lub zsynchronizuj pliki z urządzeniami.",
    "Go back" : "Wstecz",
    "Views" : "Widoki",
    "Files settings" : "Ustawienia Plików",
    "Your files" : "Twoje pliki",
    "Open in files" : "Otwórz w Plikach",
    "File cannot be accessed" : "Nie można uzyskać dostępu do pliku",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Nie znaleziono pliku lub nie masz uprawnień, aby go wyświetlić. Poproś nadawcę o udostępnienie.",
    "No search results for “{query}”" : "Brak wyników wyszukiwania dla \"{query}\"",
    "Search for files" : "Szukaj plików",
    "Clipboard is not available" : "Schowek jest niedostępny",
    "WebDAV URL copied" : "Adres URL WebDAV skopiowany",
    "General" : "Ogólne",
    "Default view" : "Widok domyślny",
    "All files" : "Wszystkie pliki",
    "Personal files" : "Pliki osobiste",
    "Sort favorites first" : "Najpierw sortuj ulubione",
    "Sort folders before files" : "Sortuj katalogi przed plikami",
    "Folder tree" : "Drzewo folderów",
    "Appearance" : "Wygląd",
    "Show hidden files" : "Pokaż ukryte pliki",
    "Show file type column" : "Pokaż kolumnę typu pliku",
    "Show file extensions" : "Pokaż rozszerzenia plików",
    "Crop image previews" : "Przytnij podglądy obrazów",
    "Additional settings" : "Ustawienia dodatkowe",
    "WebDAV" : "WebDAV",
    "WebDAV URL" : "URL WebDAV",
    "Copy" : "Kopiuj",
    "How to access files using WebDAV" : "Jak uzyskać dostęp do plików przez WebDAV",
    "Two-Factor Authentication is enabled for your account, and therefore you need to use an app password to connect an external WebDAV client." : "Uwierzytelnianie dwuskładnikowe jest włączone dla Twojego konta, dlatego musisz użyć hasła aplikacji, aby połączyć zewnętrznego klienta WebDAV.",
    "Warnings" : "Ostrzeżenie",
    "Warn before changing a file extension" : "Ostrzegaj przed zmianą rozszerzenia pliku",
    "Warn before deleting files" : "Ostrzegaj przed usunięciem plików",
    "Keyboard shortcuts" : "Skróty klawiaturowe",
    "File actions" : "Akcje na plikach",
    "Rename" : "Zmień nazwę",
    "Delete" : "Usuń",
    "Add or remove favorite" : "Dodaj lub usuń z ulubionych",
    "Manage tags" : "Zarządzaj etykietami",
    "Selection" : "Wybór",
    "Select all files" : "Wybierz wszystkie pliki",
    "Deselect all" : "Odznacz wszystkie",
    "Select or deselect" : "Zaznacz lub odznacz",
    "Select a range" : "Wybierz zakres",
    "Navigation" : "Nawigacja",
    "Go to parent folder" : "Przejdź do folderu nadrzędnego",
    "Go to file above" : "Przejdź do pliku powyżej",
    "Go to file below" : "Przejdź do pliku poniżej",
    "Go left in grid" : "Przejdź w lewo w siatce",
    "Go right in grid" : "Przejdź w prawo w siatce",
    "View" : "Podgląd",
    "Toggle grid view" : "Przełącz widok siatki",
    "Open file sidebar" : "Otwórz panel boczny pliku",
    "Show those shortcuts" : "Pokaż te skróty",
    "You" : "Ty",
    "Shared multiple times with different people" : "Udostępniony wiele razy różnym osobom",
    "Unable to change the favorite state of the file" : "Nie można zmienić ulubionego stanu pliku",
    "Error while loading the file data" : "Błąd podczas wczytywania danych pliku",
    "Owner" : "Właściciel",
    "Remove from favorites" : "Usuń z ulubionych",
    "Add to favorites" : "Dodaj do ulubionych",
    "Tags" : "Etykiety",
    "Blank" : "Pusty",
    "Unable to create new file from template" : "Nie można utworzyć nowego pliku z szablonu",
    "Pick a template for {name}" : "Wybierz szablon dla {name}",
    "Create a new file with the selected template" : "Utwórz nowy plik z wybranym szablonem",
    "Creating file" : "Tworzenie pliku",
    "Save as {displayName}" : "Zapisz jako {displayName}",
    "Save as …" : "Zapisz jako…",
    "Converting files …" : "Konwertowanie plików…",
    "Failed to convert files: {message}" : "Nie udało się przekonwertować plików: {message}",
    "All files failed to be converted" : "Nie udało się przekonwertować żadnego pliku",
    "One file could not be converted: {message}" : "Jednego pliku nie można przekonwertować: {message}",
    "_One file could not be converted_::_%n files could not be converted_" : ["Nie można przekonwertować jednego pliku","Nie można przekonwertować %n plików","Nie można przekonwertować %n plików","Nie można przekonwertować %n plików"],
    "_One file successfully converted_::_%n files successfully converted_" : ["Pomyślnie przekonwertowany jeden plik","Pomyślnie przekonwertowane %n pliki","Pomyślnie przekonwertowanych %n plików","Pomyślnie przekonwertowanych %n plików"],
    "Files successfully converted" : "Pliki zostały pomyślnie przekonwertowane",
    "Failed to convert files" : "Nie udało się przekonwertować plików",
    "Converting file …" : "Konwertowanie plików…",
    "File successfully converted" : "Plik pomyślnie przekonwertowany",
    "Failed to convert file: {message}" : "Nie udało się przekonwertować pliku: {message}",
    "Failed to convert file" : "Nie udało się przekonwertować pliku",
    "Leave this share" : "Opuść te udostępnienie",
    "Leave these shares" : "Opuść udostępnienia",
    "Disconnect storage" : "Odłącz magazyn",
    "Disconnect storages" : "Odłącz magazyny",
    "Delete permanently" : "Usuń bezpowrotnie",
    "Delete and unshare" : "Usuń i przestań udostępniać",
    "Delete file" : "Usuń plik",
    "Delete files" : "Usuń pliki",
    "Delete folder" : "Usuń katalog",
    "Delete folders" : "Usuń katalogi",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Zamierzasz trwale usunąć {count} element","Zamierzasz trwale usunąć {count} elementy","Zamierzasz trwale usunąć {count} elementów","Zamierzasz trwale usunąć {count} elementów"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Zamierzasz usunąć {count} element","Zamierzasz usunąć {count} elementy","Zamierzasz usunąć {count} elementów","Zamierzasz usunąć {count} elementów"],
    "Confirm deletion" : "Potwierdź usunięcie",
    "Cancel" : "Anuluj",
    "Download" : "Pobierz",
    "Moving \"{source}\" to \"{destination}\" …" : "Przenoszenie „{source}” do „{destination}”…",
    "Copying \"{source}\" to \"{destination}\" …" : "Kopiowanie „{source}” do „{destination}”…",
    "Destination is not a folder" : "Miejsce docelowe nie jest katalogiem",
    "This file/folder is already in that directory" : "Ten plik/katalog znajduje się już w tym katalogu",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Nie można przenieść pliku/katalogu do tego samego katalogu lub do własnego podkatalogu",
    "(copy)" : "(kopiuj)",
    "(copy %n)" : "(kopiuj %n)",
    "A file or folder with that name already exists in this folder" : "Plik lub katalog o tej nazwie już istnieje w tym katalogu",
    "The files are locked" : "Pliki są zablokowane",
    "The file does not exist anymore" : "Plik już nie istnieje",
    "Choose destination" : "Wybierz miejsce docelowe",
    "Copy to {target}" : "Skopiuj do {target}",
    "Move to {target}" : "Przenieś do {target}",
    "Move" : "Przenieś",
    "Move or copy operation failed" : "Operacja przenoszenia lub kopiowania nie powiodła się",
    "Move or copy" : "Przenieś lub kopiuj",
    "Open folder {displayName}" : "Otwórz katalog {displayName}",
    "Open in Files" : "Otwórz w Plikach",
    "Open locally" : "Otwórz lokalnie",
    "Failed to redirect to client" : "Nie udało się przekierować do klienta",
    "Open file locally" : "Otwórz plik lokalnie",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Plik powinien teraz otworzyć się na Twoim urządzeniu. Jeśli tak się nie stanie, sprawdź, czy masz zainstalowaną aplikację komputerową.",
    "Retry and close" : "Spróbuj ponownie i zamknij",
    "Open online" : "Otwórz online",
    "Details" : "Szczegóły",
    "View in folder" : "Zobacz w katalogu",
    "Today" : "Dzisiaj",
    "Last 7 days" : "Ostatnie 7 dni",
    "Last 30 days" : "Ostatnie 30 dni",
    "This year ({year})" : "W tym roku ({year})",
    "Last year ({year})" : "Ostatni rok ({year})",
    "Documents" : "Dokumenty",
    "Spreadsheets" : "Arkusze kalkulacyjne",
    "Presentations" : "Prezentacje",
    "PDFs" : "PDFy",
    "Folders" : "Katalogi",
    "Audio" : "Dźwięk",
    "Images" : "Obrazy",
    "Videos" : "Filmy",
    "Created new folder \"{name}\"" : "Utworzono nowy katalog \"{name}\"",
    "Unable to initialize the templates directory" : "Nie można zainicjować katalogu szablonów",
    "Create templates folder" : "Utwórz katalog szablonów",
    "Templates" : "Szablony",
    "New template folder" : "Nowy katalog szablonów",
    "In folder" : "W katalogu",
    "Search in all files" : "Szukaj we wszystkich plikach",
    "Search in folder: {folder}" : "Szukaj w katalogu: {folder}",
    "One of the dropped files could not be processed" : "Jeden z upuszczonych plików nie mógł być przetworzony",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Twoja przeglądarka nie obsługuje interfejsu API systemu plików. Katalogi nie zostaną przesłane",
    "No files to upload" : "Brak plików do przesłania",
    "Unable to create the directory {directory}" : "Nie można utworzyć katalogu {directory}",
    "Some files could not be uploaded" : "Nie udało się wysłać niektórych plików",
    "Files uploaded successfully" : "Pliki przesłane pomyślnie",
    "No files to process" : "Brak plików do przetworzenia",
    "Some files could not be copied" : "Nie udało się skopiować niektórych plików",
    "Some files could not be moved" : "Niektóre pliki nie mogły zostać przeniesione",
    "Files copied successfully" : "Pliki skopiowane pomyślnie",
    "Files moved successfully" : "Pliki zostały przeniesione pomyślnie",
    "Conflicts resolution skipped" : "Pominięto rozwiązywanie konfliktów",
    "Upload cancelled" : "Anulowano przesyłanie",
    "Could not rename \"{oldName}\", it does not exist any more" : "Nie można zmienić nazwy \"{oldName}\", już nie istnieje",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nazwa \"{newName}\" jest już używana w katalogu \"{dir}\". Wybierz inną nazwę.",
    "Could not rename \"{oldName}\"" : "Nie można zmienić nazwy \"{oldName}\"",
    "This operation is forbidden" : "Ta operacja jest niedozwolona",
    "This folder is unavailable, please try again later or contact the administration" : "Ten folder jest niedostępny, spróbuj ponownie później lub skontaktuj się z administracją",
    "Storage is temporarily not available" : "Magazyn jest tymczasowo niedostępny",
    "Unexpected error: {error}" : "Nieoczekiwany błąd: {error}",
    "_%n file_::_%n files_" : ["%n plik","%n pliki","%n plików","%n plików"],
    "_%n folder_::_%n folders_" : ["%n katalog","%n katalogi","%n katalogów","%n katalogów"],
    "_%n hidden_::_%n hidden_" : ["%n ukryty","%n ukryte","%n ukrytych","%n ukrytych"],
    "Filename must not be empty." : "Nazwa pliku nie może być pusta.",
    "\"{char}\" is not allowed inside a filename." : "„{char}” nie jest dozwolone w nazwie pliku.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "„{segment}” jest nazwą zastrzeżoną i nie jest dozwolona w przypadku nazw plików.",
    "\"{extension}\" is not an allowed filetype." : "„{extension}” nie jest dozwolonym typem pliku.",
    "Filenames must not end with \"{extension}\"." : "Nazwy plików nie mogą kończyć się na „{extension}”.",
    "List of favorite files and folders." : "Lista ulubionych plików i katalogów.",
    "No favorites yet" : "Brak ulubionych",
    "Files and folders you mark as favorite will show up here" : "Pliki i katalogi, które oznaczysz jako ulubione wyświetlą się tutaj",
    "List of your files and folders." : "Lista Twoich plików i katalogów.",
    "List of your files and folders that are not shared." : "Lista twoich plików i katalogów, które nie są udostępniane",
    "No personal files found" : "Nie znaleziono plików osobistych",
    "Files that are not shared will show up here." : "Tutaj pojawią się pliki, które nie są udostępniane.",
    "Recent" : "Ostatnie",
    "List of recently modified files and folders." : "Lista ostatnio zmodyfikowanych plików i katalogów.",
    "No recently modified files" : "Brak ostatnio zmodyfikowanych plików",
    "Files and folders you recently modified will show up here." : "Tutaj pojawią się pliki i katalogi, które ostatnio zmodyfikowałeś.",
    "Search" : "Szukaj",
    "Search results within your files." : "Wyniki wyszukiwania w Twoich plikach.",
    "No entries found in this folder" : "Brak wpisów w tym katalogu",
    "Select all" : "Wybierz wszystko",
    "Upload too large" : "Wysyłany plik jest za duży",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Pliki, które próbujesz wysłać, przekraczają maksymalną dopuszczalną wielkość.",
    "File could not be found" : "Nie można znaleźć pliku",
    "Show list view" : "Pokaż widok listy",
    "Show grid view" : "Pokaż widok siatki",
    "Close" : "Zamknij",
    "Could not create folder \"{dir}\"" : "Nie można utworzyć katalogu \"{dir}\"",
    "This will stop your current uploads." : "Spowoduje to zatrzymanie wysyłania plików.",
    "Upload cancelled." : "Wysyłanie anulowane.",
    "Processing files …" : "Przetwarzanie plików…",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nie można wysłać {filename} być może jest katalogiem lub posiada 0 bajtów",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Brak wolnej przestrzeni, wysyłasz {size1} a pozostało tylko {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Katalog docelowy \"{dir}\" już nie istnieje",
    "An unknown error has occurred" : "Wystąpił nieznany błąd",
    "File could not be uploaded" : "Nie można przesłać pliku",
    "Uploading …" : "Wysyłanie…",
    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
    "Uploading … ({currentNumber}/{total})" : "Wysyłanie… ({currentNumber}/{total})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} z {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Wysyłanie tego elementu nie jest wspierane",
    "Error when assembling chunks, status code {status}" : "Błąd podczas łączenia fragmentów, kod statusu {status}",
    "Choose target folder" : "Wybierz katalog docelowy",
    "Set reminder" : "Ustaw przypomnienie",
    "Edit locally" : "Edytuj lokalnie",
    "Open" : "Otwórz",
    "Could not load info for file \"{file}\"" : "Nie można załadować informacji o pliku \"{file}\"",
    "Please select tag(s) to add to the selection" : "Wybierz etykietę(y) do dodania dla zaznaczenia",
    "Apply tag(s) to selection" : "Zastosuj etykietę(y) dla zaznaczenia",
    "Select directory \"{dirName}\"" : "Wybierz katalog \"{dirName}\"",
    "Select file \"{fileName}\"" : "Wybierz plik \"{fileName}\"",
    "Unable to determine date" : "Nie można ustalić daty",
    "This directory is unavailable, please check the logs or contact the administrator" : "Ten katalog jest niedostępny, sprawdź logi lub skontaktuj się z administratorem",
    "Could not move \"{file}\", target exists" : "Nie można przenieść \"{file}\" - plik o takiej nazwie już istnieje",
    "Could not move \"{file}\"" : "Nie można przenieść \"{file}\"",
    "copy" : "kopia",
    "Could not copy \"{file}\", target exists" : "Nie można skopiować \"{file}\", plik już istnieje",
    "Could not copy \"{file}\"" : "Nie można skopiować \"{file}\"",
    "Copied {origin} inside {destination}" : "Skopiowano {origin} wewnątrz {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Skopiowano {origin} oraz {nbfiles} innych plików wewnątrz {destination}",
    "{newName} already exists" : "{newName} już istnieje",
    "Could not create file \"{file}\"" : "Nie można utworzyć pliku \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Nie można utworzyć pliku \"{file}\", ponieważ ten plik już istnieje.",
    "Could not create folder \"{dir}\" because it already exists" : "Nie można utworzyć katalogu \"{dir}\", ponieważ już istnieje",
    "Could not fetch file details \"{file}\"" : "Nie można pobrać szczegółów pliku \"{file}\"",
    "Error deleting file \"{fileName}\"." : "Błąd podczas usuwania pliku \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Brak wyników wyszukiwania w innych katalogach dla {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Wprowadź więcej niż dwa znaki, aby przeszukać inne katalogi",
    "{dirs} and {files}" : "{dirs} i {files}",
    "_including %n hidden_::_including %n hidden_" : ["w tym %n ukryty","w tym %n ukryte","w tym %n ukrytych","w tym %n ukrytych"],
    "You do not have permission to upload or create files here" : "Nie masz uprawnień do wysyłania lub tworzenia plików w tym miejscu",
    "_Uploading %n file_::_Uploading %n files_" : ["Wysyłanie %n pliku","Wysyłanie %n plików","Wysyłanie %n plików","Wysyłanie %n plików"],
    "New" : "Nowy",
    "New file/folder menu" : "Nowe menu plików/katalogów",
    "Select file range" : "Wybierz zakres plików",
    "{used}%" : "{used}%",
    "{used} used" : "Wykorzystane {used}",
    "\"{name}\" is an invalid file name." : "\"{name}\" jest nieprawidłową nazwą pliku.",
    "File name cannot be empty." : "Nazwa pliku nie może być pusta.",
    "\"/\" is not allowed inside a file name." : "Znak \"/\" jest niedozwolony w nazwie pliku.",
    "\"{name}\" is not an allowed filetype" : "typ pliku \"{name}\" jest niedozwolony",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Magazyn dla {owner} jest pełny. Nie można już aktualizować ani synchronizować plików!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Katalog grupowy \"{mountPoint}\" jest pełny. Nie można już aktualizować ani synchronizować plików!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Magazyn zewnętrzny \"{mountPoint}\" jest pełny. Nie można już aktualizować ani synchronizować plików!",
    "Your storage is full, files cannot be updated or synced anymore!" : "Magazyn jest pełny. Nie można już zaktualizować ani zsynchronizować plików!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Magazyn dla {owner} jest pawie pełny ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Katalog grupowy \"{mountPoint}\" jest prawie pełny ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Pamięć zewnętrzna \"{mountPoint}\" jest prawie pełna ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Twój magazyn jest prawie pełny ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["pasuje do \"{filter}\"","pasują do \"{filter}\"","pasują do \"{filter}\"","pasują do \"{filter}\""],
    "Direct link was copied (only works for people who have access to this file/folder)" : "Bezpośredni link został skopiowany (działa tylko dla użytkowników, którzy mają dostęp do tego pliku/katalogu)",
    "Path" : "Ścieżka",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajty","%n bajtów","%n bajtów"],
    "Favored" : "Polubione",
    "Favor" : "Polub",
    "Copy direct link (only works for people who have access to this file/folder)" : "Skopiuj bezpośredni link (działa tylko dla użytkowników, którzy mają dostęp do tego pliku/katalogu)",
    "Upload file" : "Wyślij plik",
    "Not favored" : "Nie polubiono",
    "An error occurred while trying to update the tags" : "Wystąpił błąd podczas próby aktualizacji etykiet",
    "Upload (max. %s)" : "Wysyłanie (maks. %s)",
    "\"{displayName}\" action executed successfully" : "Akcja \"{displayName}\" została wykonana pomyślnie",
    "\"{displayName}\" action failed" : "Akcja \"{displayName}\" nie powiodła się",
    "\"{displayName}\" failed on some elements" : "\"{displayName}\" nie powiodło się w niektórych elementach",
    "\"{displayName}\" batch action executed successfully" : "Akcja wsadowa \"{displayName}\" została wykonana pomyślnie",
    "Submitting fields…" : "Przesyłanie pól…",
    "Filter filenames…" : "Filtruj nazwy plików…",
    "WebDAV URL copied to clipboard" : "Adres URL WebDAV skopiowany do schowka",
    "Enable the grid view" : "Włącz widok siatki",
    "Enable folder tree" : "Włącz drzewo katalogów",
    "Copy to clipboard" : "Kopiuj do schowka",
    "Use this address to access your Files via WebDAV" : "Użyj tego adresu, aby uzyskać dostęp do plików poprzez WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Jeśli włączyłeś 2FA, musisz utworzyć i używać nowego hasła do aplikacji, klikając tutaj.",
    "Deletion cancelled" : "Usuwanie anulowane",
    "Move cancelled" : "Przenoszenie anulowane",
    "Cancelled move or copy of \"{filename}\"." : "Anulowano przeniesienie lub kopiowanie „{filename}”.",
    "Cancelled move or copy operation" : "Anulowano operację przenoszenia lub kopiowania",
    "Open details" : "Otwórz szczegóły",
    "Photos and images" : "Zdjęcia i obrazy",
    "New folder creation cancelled" : "Tworzenie nowego katalogu zostało anulowane",
    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} katalog","{folderCount} katalogi","{folderCount} katalogów","{folderCount} katalogów"],
    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} plik","{fileCount} pliki","{fileCount} plików","{fileCount} plików"],
    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 plik i {folderCount} katalog","1 plik i {folderCount} katalogi","1 plik i {folderCount} katalogów","1 plik i {folderCount} katalogów"],
    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} plik i 1 katalog","{fileCount} pliki i 1 katalog","{fileCount} plików i 1 katalog","{fileCount} plików i 1 katalog"],
    "{fileCount} files and {folderCount} folders" : "{fileCount} plików i {folderCount} katalogów",
    "All folders" : "Wszystkie katalogi",
    "Personal Files" : "Pliki osobiste",
    "Text file" : "Plik tekstowy",
    "New text file.txt" : "Nowy plik tekstowy.txt",
    "%1$s (renamed)" : "%1$s (zmieniona nazwa)",
    "renamed file" : "zmieniona nazwa pliku",
    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Po włączeniu nazw plików zgodnych z systemem Windows, istniejących plików nie można już modyfikować, ale ich właściciel może zmienić ich nazwy na nowe, prawidłowe.",
    "Filter file names …" : "Filtruj nazwy plików…",
    "Prevent warning dialogs from open or reenable them." : "Zapobiegaj otwieraniu okien dialogowych z ostrzeżeniami lub włącz je ponownie.",
    "Show a warning dialog when changing a file extension." : "Pokaż okno dialogowe z ostrzeżeniem przy zmianie rozszerzenia pliku.",
    "Speed up your Files experience with these quick shortcuts." : "Przyspiesz korzystanie z Plików dzięki tym szybkim skrótom.",
    "Open the actions menu for a file" : "Otwórz menu akcji dla pliku",
    "Rename a file" : "Zmień nazwę",
    "Delete a file" : "Usuń plik",
    "Favorite or remove a file from favorites" : "Dodaj plik do ulubionych lub usuń go z ulubionych",
    "Manage tags for a file" : "Zarządzanie etykietami pliku",
    "Deselect all files" : "Odznacz wszystkie pliki",
    "Select or deselect a file" : "Wybierz lub odznacz plik",
    "Select a range of files" : "Wybierz zakres plików",
    "Navigate to the parent folder" : "Przejdź do katalogu nadrzędnego",
    "Navigate to the file above" : "Przejdź do pliku powyżej",
    "Navigate to the file below" : "Przejdź do pliku poniżej",
    "Navigate to the file on the left (in grid mode)" : "Przejdź do pliku po lewej stronie (w trybie siatki)",
    "Navigate to the file on the right (in grid mode)" : "Przejdź do pliku po prawej stronie (w trybie siatki)",
    "Toggle the grid view" : "Przełącz widok siatki",
    "Open the sidebar for a file" : "Otwórz pasek boczny dla pliku"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
