OC.L10N.register(
    "files_pdfviewer",
    {
    "PDF viewer" : "Przeglądarka PDF",
    "Directly view PDF documents in your Nextcloud. \nAs an added bonus, this app can also display Adobe Illustrator (.ai) files. \nPowered by [pdf.js](https://mozilla.github.io/pdf.js/)" : "Przeglądaj dokumenty PDF bezpośrednio w Nextcloud.\nJako dodatkowy bonus, ta aplikacja może także wyświetlać pliki Adobe Illustrator (.ai). \nObsługiwane przez [pdf.js](https://mozilla.github.io/pdf.js/)",
    "File upload failed." : "Przesyłanie pliku nie powiodło się."
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
