OC.L10N.register(
    "files_external",
    {
    "Grant access" : "授权",
    "Error configuring OAuth2" : "OAuth2 配置错误",
    "Generate keys" : "生成密钥",
    "Error generating key pair" : "生成密钥对错误",
    "You are not logged in" : "您尚未登录",
    "Permission denied" : "权限被拒绝",
    "Forbidden to manage local mounts" : "禁止管理本地挂载",
    "Storage with ID \"%d\" not found" : "未找到 ID 为“%d”的存储",
    "Invalid backend or authentication mechanism class" : "无效的后端或认证类型",
    "Invalid mount point" : "无效的挂载点",
    "Objectstore forbidden" : "对象存储禁止访问",
    "Invalid storage backend \"%s\"" : "无效的存储后端“%s”",
    "Not permitted to use backend \"%s\"" : "不允许使用“%s”",
    "Not permitted to use authentication mechanism \"%s\"" : "不允许使用认证方式 “%s”",
    "Unsatisfied backend parameters" : "无法满足后端条件",
    "Unsatisfied authentication mechanism parameters" : "无法满足认证类型条件",
    "Insufficient data: %s" : "数据不足：%s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not editable by non-admins" : "ID 为“%d”的存储不可由非管理员编辑",
    "Access key" : "Access key",
    "Secret key" : "Secret key",
    "Builtin" : "内置",
    "None" : "无",
    "OAuth2" : "OAuth2",
    "Client ID" : "客户端 ID",
    "Client secret" : "客户端 secret",
    "OpenStack v2" : "OpenStack v2",
    "Login" : "登录",
    "Password" : "密码",
    "Tenant name" : "租户名称",
    "Identity endpoint URL" : "身份识别 URL",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "域名",
    "Rackspace" : "Rackspace",
    "API key" : "API 密匙",
    "Global credentials" : "全局凭据",
    "Log-in credentials, save in database" : "登录凭据，保存在数据库中",
    "Login and password" : "登录和密码",
    "Log-in credentials, save in session" : "登录凭据，存储在会话中",
    "Global credentials, manually entered" : "全局凭据，手动输入",
    "Manually entered, store in database" : "手动输入，存储在数据库中",
    "RSA public key" : "RSA 公钥",
    "Public key" : "公钥",
    "RSA private key" : "RSA 私钥",
    "Private key" : "私钥",
    "Kerberos default realm, defaults to \"WORKGROUP\"" : "Kerberos 默认领域，默认为“WORKGROUP”",
    "Kerberos ticket Apache mode" : "Kerberos 凭证 Apache 模式",
    "Kerberos ticket" : "Kerberos 票据",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "主机名",
    "Port" : "端口",
    "Region" : "区域",
    "Storage Class" : "存储类型",
    "Enable SSL" : "启用 SSL",
    "Enable Path Style" : "启用 Path Style",
    "Legacy (v2) authentication" : "旧版本（v2）认证",
    "Enable multipart copy" : "启用多部分副本",
    "SSE-C encryption key" : "SSE-C 加密密钥",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "远程子文件夹",
    "Secure https://" : "安全 https://",
    "FTP" : "FTP",
    "Host" : "主机",
    "Secure ftps://" : "安全 ftps://",
    "Local" : "本地",
    "Location" : "地点",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "根路径",
    "SFTP with secret key login" : "包含 secret key 的 SFTP",
    "SMB/CIFS" : "SMB/CIFS  ",
    "Share" : "共享",
    "Show hidden files" : "显示隐藏文件",
    "Case sensitive file system" : "大小写敏感文件系统",
    "Disabling it will allow to use a case insensitive file system, but comes with a performance penalty" : "禁用此选项将允许使用大小写不敏感文件系统，但会带来性能损失",
    "Verify ACL access when listing files" : "列出文件时验证 ACL 访问",
    "Check the ACL's of each file or folder inside a directory to filter out items where the account has no read permissions, comes with a performance penalty" : "检查目录内的每个文件或文件夹的 ACL，以筛选账号没有读取权限的项目，这会带来性能损失",
    "Timeout" : "超时",
    "SMB/CIFS using OC login" : "使用 OC 登录的 SMB/CIFS",
    "Login as share" : "以共享身份登录",
    "OpenStack Object Storage" : "OpenStack 对象存储",
    "Service name" : "服务名称",
    "Request timeout (seconds)" : "请求超时时间（秒）",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "没有安装或启用 PHP 中的 cURL 支持。无法挂载 %s。请联系您的系统管理员安装。",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "没有安装或启用 PHP 中的 FTP 支持。无法挂载 %s。请联系您的系统管理员安装。",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "“%1$s” 未安装。无法挂载 %2$s。请联系管理员安装。",
    "External storage" : "外部存储",
    "External storage support" : "外部存储支持",
    "Adds basic external storage support" : "添加基本的外部存储支持",
    "This application enables administrators to configure connections to external storage providers, such as FTP servers, S3 or SWIFT object stores, other Nextcloud servers, WebDAV servers, and more. Administration can choose which types of storage to enable and can mount these storage locations for an account, a group, or the entire system. Users will see a new folder appear in their root Nextcloud directory, which they can access and use like any other Nextcloud folder. External storage also allows people to share files stored in these external locations. In these cases, the credentials for the owner of the file are used when the recipient requests the file from external storage, thereby ensuring that the recipient can access the shared file.\n\nExternal storage can be configured using the GUI or at the command line. This second option provides the administration with more flexibility for configuring bulk external storage mounts and setting mount priorities. More information is available in the external storage GUI documentation and the external storage Configuration File documentation." : "此应用程序使管理员能够配置与外部存储提供者的连接，例如 FTP 服务器、S3 或 SWIFT 对象存储、其他 Nextcloud 服务器、WebDAV 服务器等。管理员可以选择要启用的存储类型，并可以为账号、群组或整个系统装载这些存储位置。用户将在其根 Nextcloud 目录中看到一个新文件夹，它们可以像任何其他 Nextcloud 文件夹一样访问和使用。外部存储还允许人们共享存储在这些外部位置的文件。在这些情况下，当接收者从外部存储中请求文件时，会使用文件所有者的凭据，从而确保接收者可以访问共享文件。\n\n可以使用 GUI 或在命令行中配置外部存储。第二个选项为管理员配置批量外部存储装载和设置装载优先级提供了更大的灵活性。更多信息请参阅外部存储 GUI 文档和外部存储配置文件文档。",
    "Confirm" : "确认",
    "Storage credentials" : "存储凭据",
    "To access the storage, you need to provide the authentication credentials." : "要访问存储，您需要提供身份验证凭据。",
    "Enter the storage login" : "输入存储登录",
    "Enter the storage password" : "输入存储密码",
    "Unable to update this external storage config. {statusMessage}" : "无法更新此外部存储配置。{statusMessage}",
    "New configuration successfully saved" : "新配置已成功保存",
    "Enter missing credentials" : "输入缺失的认证信息",
    "Credentials successfully set" : "已成功设置凭据",
    "Error while setting credentials: {error}" : "设置凭据时出错：{error}",
    "Checking storage …" : "正在检查存储…",
    "There was an error with this external storage." : "此外部存储出现问题",
    "We were unable to check the external storage {basename}" : "我们无法检查外部存储 {basename}",
    "Examine this faulty external storage configuration" : "检查此出错的外部存储配置",
    "Open in Files" : "在文件中打开",
    "There was an error with this external storage. Do you want to review this mount point config in the settings page?" : "此外部存储存在错误。要在设置页中检查此挂载点的配置吗？",
    "External mount error" : "外部挂载错误",
    "List of external storage." : "外部存储列表",
    "There is no external storage configured. You can configure them in your Personal settings." : "未配置外部存储。您可前往您的个人设置页中进行配置。",
    "There is no external storage configured and you don't have the permission to configure them." : "未配置外部存储，且你没有配置外部存储的权限。",
    "No external storage" : "无外部存储",
    "Storage type" : "存储类型",
    "Unknown" : "未知",
    "Scope" : "适用范围",
    "Personal" : "个人",
    "System" : "系统",
    "Type to select account or group." : "输入以选择账号或群组。",
    "(Group)" : "(群组)",
    "Compatibility with Mac NFD encoding (slow)" : "兼用 Mac NFD 编码（慢）",
    "Enable encryption" : "启用加密",
    "Enable previews" : "启用预览",
    "Enable sharing" : "启用共享",
    "Check for changes" : "检查修改",
    "Never" : "从不",
    "Once every direct access" : "每次访问时",
    "Read only" : "只读",
    "Disconnect" : "断开连接",
    "Unknown backend: {backendName}" : "未知后端：{backendName}",
    "Admin defined" : "管理员定义",
    "Automatic status checking is disabled due to the large number of configured storages, click to check status" : "因为配置的存储数量过多，自动状态检查已停用，点击以检查状态。",
    "Are you sure you want to disconnect this external storage? It will make the storage unavailable in Nextcloud and will lead to a deletion of these files and folders on any sync client that is currently connected but will not delete any files and folders on the external storage itself." : "您确定要断开这个外部存储空间吗？这将会导致该存储空间在 Nextcloud 中不可用，并将会在当前连接的任何同步客户端上删除文件和文件夹，但不会删除外部存储空间本身的任何文件和文件夹。",
    "Delete storage?" : "删除存储？",
    "Click to recheck the configuration" : "点击以再次检查配置",
    "Saved" : "已保存",
    "Saving …" : "正在保存 …",
    "Save" : "保存",
    "Failed to save global credentials" : "无法保存全局凭据",
    "Failed to save global credentials: {message}" : "无法保存全局凭据：{message}",
    "No external storage configured or you don't have the permission to configure them" : "未设置外部存储或者没有权限",
    "Open documentation" : "打开文档",
    "External storage enables you to mount external storage services and devices as secondary Nextcloud storage devices. You may also allow people to mount their own external storage services." : "外部存储使你能够将外部存储服务和设备作为辅助 Nextcloud 存储设备进行挂载。你还可以允许用户挂载自己的外部存储服务。",
    "Folder name" : "目录名称",
    "Authentication" : "认证",
    "Configuration" : "配置",
    "Available for" : "可用于",
    "Add storage" : "增加存储",
    "All people" : "所有用户",
    "Advanced settings" : "高级选项",
    "Allow people to mount external storage" : "允许用户挂载外部存储",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "全局凭据可用于使用具有相同凭据的多个外部存储进行身份验证。",
    "Error configuring OAuth1" : "OAuth1 配置错误",
    "Please provide a valid app key and secret." : "请提供有效的 app key 和密钥。",
    "OAuth1" : "OAuth1",
    "App key" : "App key",
    "App secret" : "应用程序 secret"
},
"nplurals=1; plural=0;");
