OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Örgjörvaupplýsingar ekki tiltækar",
    "Copied!" : "Afritað!",
    "Not supported!" : "Ekki stutt!",
    "Press ⌘-C to copy." : "Ýttu á ⌘-C til að afrita.",
    "Press Ctrl-C to copy." : "Ýttu á Ctrl-C til að afrita.",
    "System" : "Kerfið",
    "Monitoring" : "Vöktun",
    "Monitoring app with useful server information" : "Vöktunarforrit sem nær í ýmsar notadrjúgar upplýsingar um þjón",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Gefur nytsamlegar upplýsingar um vefþjón, svo sem álag á örgjörva, diskanotkun, fjölda notenda, o.s.frv.",
    "Temperature" : "Hitastig",
    "Load" : "Hlaða inn",
    "Memory" : "Vinnsluminni",
    "Disk" : "Diskur",
    "Size:" : "Stærð:",
    "Files:" : "Skrár:",
    "Storages:" : "Gagnageymslur",
    "Free Space:" : "Laust diskapláss:",
    "Network" : "Netkerfi",
    "Active users" : "Virkir notendur",
    "Shares" : "Sameignir",
    "Users:" : "Notendur:",
    "PHP" : "PHP",
    "Version:" : "Útgáfa:",
    "Upload max size:" : "Hámarksstærð innsendingar:",
    "Database" : "Gagnagrunnur",
    "Type:" : "Tegund:",
    "External monitoring tool" : "Utanaðkomandi vöktunartól",
    "Copy" : "Afrita"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
