<?php
namespace Aws\MarketplaceEntitlementService\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Marketplace Entitlement Service** service.
 */
class MarketplaceEntitlementServiceException extends AwsException {}
