OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "Poslední přehled odeslán: {on}",
    "An error occurred while sending your report." : "Při odesílání přehledu došlo k chybě.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Seznam aplikací <em>(pro každou aplikaci: název, verze, zda vámi povolená)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Databázové prostředí <em>(typ, verze, velikost databáze)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Informace o šifrování <em>(Je zapnuto? Jaký je výchozí modul?)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Počet sdílení <em>(podle jednotlivých typů a nastavení oprávnění)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP prostředí <em>(verze, limit paměti, max. doba vykonávání, max. velikost souboru)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Podrobnosti o instanci serveru <em>(verze, použití memcache, stav zamykání/náhledů/avatarů)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "Statistika <em>(počet souborů, uživatelů, úložišť jednotlivých typů, komentářů a štítků)</em>",
    "Usage survey" : "Průzkum používání",
    "Help improve Nextcloud" : "Pomozte zlepšit Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Chcete nám pomoci zlepšit Nextcloud poskytnutím některých anonymizovaných údajů o vašem nastavení a použití? Vše můžete opět kdykoli vypnout v nastavení správy.",
    "Send usage" : "Odeslat přehled",
    "Not now" : "Teď ne",
    "Never" : "Nikdy",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Odesílá anonymizovaná data vývojářům Nextcloud a pomáhá tak k jeho zlepšování.",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n\t\talways have full control over the content sent to Nextcloud and can disable\n\t\tit again at any time." : "Odesílá anonymizovaná data vývojářům Nextcloud aby ho na jejich základě mohli dále vylepšovat.\n\t\tVždy máte plnou kontrolu nad odesílaným obsahem a kdykoli tuto funkci můžete opět vypnout.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Můžete pomoci zlepšit Nextcloud tím, že nám pošlete nějaké údaje o vašem aktuálním nastavení a použití.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. To delete the stored usage data, upload an empty report by unchecking all of the boxes then sending a new report." : "Vaše soukromí bereme vážně. Odesílání dat je ve výchozím nastavení vypnuté a pokud se ho rozhodnete zapnout, budou data nejprve anonymizována a budete mít možnost vybrat, které věci sdílet. Nejnovější přijatý přehled na naší straně přepíše ten předchozí. Pokud chcete smazat uložená data ohledně využívání, stačí zrušit zaškrtnutí všech kolonek a odeslat (tím prázdný) přehled.",
    "Send new report now" : "Odeslat nový přehled teď",
    "Send usage survey monthly" : "Odesílat přehled o používání každý měsíc",
    "Data to send" : "Data k odeslání",
    "Last report sent on: %s" : "Poslední přehled odeslán: %s",
    "Last report" : "Poslední přehled"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
