OC.L10N.register(
    "notifications",
    {
    "Hello %s" : "Salam %s",
    "Hello %s," : "Salam %s,",
    "Notifications" : "Xəbərdarlıqlar",
    "Dismiss" : "Rədd et",
    "in {path}" : "{path} daxilində",
    "Never" : "Heç vaxt",
    "Your settings have been updated." : "Sizin configləriniz yenilendi.",
    "None" : "Heç bir",
    "You need to set up your email address before you can receive notification emails." : "Xəbərdarlıq məktubları almazdan öncə, siz mail ünvanınızı təyin etməlisiniz.",
    "seconds ago" : "saniyələr öncə"
},
"nplurals=2; plural=(n != 1);");
