OC.L10N.register(
    "files_sharing",
    {
    "File shares" : "Fildelinger",
    "Downloaded via public link" : "Nedlastet via offentlig lenke",
    "Downloaded by {email}" : "Lastet ned av {email}",
    "{file} downloaded via public link" : "{file} lastet ned via offentlig lenke",
    "{email} downloaded {file}" : "{email} lastet ned {file}",
    "Shared with group {group}" : "Delt med gruppen {group}",
    "Removed share for group {group}" : "Fjernet deling for gruppen {group}",
    "{actor} shared with group {group}" : "{actor} delt med gruppen {group}",
    "{actor} removed share for group {group}" : "{actor} fjernet deling for gruppen {group}",
    "Share for group {group} expired" : "Deling for gruppen {group} utløpt",
    "You shared {file} with group {group}" : "Du delte {file} med gruppen {group}",
    "You removed group {group} from {file}" : "Du fjernet gruppen {group} fra {file}",
    "{actor} shared {file} with group {group}" : "{actor} delte {file} med gruppen {group}",
    "{actor} removed group {group} from {file}" : "{actor} fjernet gruppen {group} fra {file}",
    "Share for file {file} with group {group} expired" : "Deling for filen {file} med gruppen {group} utløpt",
    "Shared as public link" : "Delt som offentlig lenke",
    "Removed public link" : "Fjernet offentlig lenke",
    "Public link expired" : "Offentlig lenke er utløpt",
    "{actor} shared as public link" : "{actor} delte som offentlig lenke",
    "{actor} removed public link" : "{actor} fjernet offentlig lenke",
    "Public link of {actor} expired" : "Offentlig lenke av {actor} er utløpt",
    "You shared {file} as public link" : "Du delte {file} som offentlig lenke",
    "You removed public link for {file}" : "Du fjernet offentlig lenke for {file}",
    "Public link expired for {file}" : "Offentlig lenke er utløpt for {file}",
    "{actor} shared {file} as public link" : "{actor} delte {file} som offentlig lenke",
    "{actor} removed public link for {file}" : "{actor} fjernet offentlig lenke for {file}",
    "Public link of {actor} for {file} expired" : "Offentlig lenke av {actor} for {file} har utløpt",
    "{user} accepted the remote share" : "{user} godtok fjerndelingen",
    "{user} declined the remote share" : "{user} avslo fjerndelingen",
    "You received a new remote share {file} from {user}" : "Du har mottatt en ny fjerndeling {file} fra {user}",
    "{user} accepted the remote share of {file}" : "{user} godtok fjerndelingen av {file}",
    "{user} declined the remote share of {file}" : "{user} avslo fjerndelingen av {file}",
    "{user} unshared {file} from you" : "{user} opphevde deling av {file} med deg",
    "Shared with {user}" : "Delt med {user}",
    "Removed share for {user}" : "Fjernet deling med {user}",
    "You removed yourself" : "Du fjernet deg selv",
    "{actor} removed themselves" : "{actor} fjernet seg selv",
    "{actor} shared with {user}" : "{actor} delte med {user}",
    "{actor} removed share for {user}" : "{actor} fjernet deling med {user}",
    "Shared by {actor}" : "Delt av {actor}",
    "{actor} removed share" : "{actor} fjernet deling",
    "Share for {user} expired" : "Deling for {user} utløpt",
    "Share expired" : "Deling utløpt",
    "You shared {file} with {user}" : "Du delte {file} med {user}",
    "You removed {user} from {file}" : "Du fjernet {user} fra {file}",
    "You removed yourself from {file}" : "Du fjernet deg selv fra {file}",
    "{actor} removed themselves from {file}" : "{actor} fjernet seg selv fra {file}",
    "{actor} shared {file} with {user}" : "{actor} delete {file} med {user}",
    "{actor} removed {user} from {file}" : "{actor} fjernet {user} fra {file}",
    "{actor} shared {file} with you" : "{actor} delte {file} med deg",
    "{actor} removed you from the share named {file}" : "{actor} fjernet deg fra delingen kalt {file}",
    "Share for file {file} with {user} expired" : "Deling for fil {file} med {user} utløpt",
    "Share for file {file} expired" : "Deling for fil {file} utløpt",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Ei fil eller mappe delt via e-post eller offentlig lenke ble <strong>lastet ned</strong>",
    "Files have been <strong>uploaded</strong> to a folder shared by mail or by public link" : "Filer er <strong>lastet opp</strong> til en mappe som deles via e-post eller via offentlig kobling",
    "A file or folder was shared from <strong>another server</strong>" : "En fil eller mappe ble delt fra <strong>en annen server</strong>",
    "Sharing" : "Deling",
    "A file or folder has been <strong>shared</strong>" : "En fil eller mappe ble <strong>delt</strong>",
    "Shared link" : "Delte lenke",
    "Wrong share ID, share does not exist" : "Feil delings-ID, deling eksisterer ikke",
    "Could not delete share" : "Kunne ikke slette ressursen",
    "Please specify a file or folder path" : "Oppgi en fil eller mappesti",
    "Wrong path, file/folder does not exist" : "Feil bane, fil/mappe eksisterer ikke",
    "Could not create share" : "Kunne ikke opprette ressurs",
    "Please specify a valid account to share with" : "Spesifiser en gyldig konto å dele med",
    "Group sharing is disabled by the administrator" : "Gruppedeling er deaktivert av administratoren",
    "Please specify a valid group" : "Oppgi en gyldig gruppe",
    "Public link sharing is disabled by the administrator" : "Administratoren har skrudd av offentlig lenkedeling",
    "Please specify a valid email address" : "Vennligst spesifiser en gyldig e-postadresse",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Deling av %s ved å sende passordet av Nextcloud Talk mislyktes fordi Nextcloud Talk ikke er aktivert",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "Deling av %1$s mislyktes fordi serveren ikke tillater delinger fra typen %2$s",
    "Please specify a valid federated account ID" : "Angi en gyldig sammenknyttet konto-ID",
    "Please specify a valid federated group ID" : "Angi en gyldig sammenknyttet gruppesky-ID",
    "You cannot share to a Team if the app is not enabled" : "Du kan ikke dele til et Lag så lenge appen ikke er aktivert",
    "Please specify a valid team" : "Vennligst spesifiser et gyldig lag",
    "Sharing %s failed because the back end does not support room shares" : "Deling av %s mislyktes fordi serveren ikke støtter romdeling",
    "Sharing %s failed because the back end does not support ScienceMesh shares" : "Deling av %s feilet fordi backend-en ikke støtter ScienceMesh-delinger",
    "Unknown share type" : "Ukjent ressurstype",
    "Not a directory" : "Ikke en mappe",
    "Could not lock node" : "Kunne ikke låse noden",
    "Public upload is only possible for publicly shared folders" : "Offentlig opplasting er kun mulig i offentlig delte mapper",
    "Share must at least have READ or CREATE permissions" : "Deling må minst ha READ- eller CREATE-tillatelser",
    "Share must have READ permission if UPDATE or DELETE permission is set" : "Del må ha READ-tillatelse hvis UPDATE eller DELETE-tillatelse er angitt",
    "Public upload disabled by the administrator" : "Offentlig opplasting er deaktivert av administratoren",
    "Could not lock path" : "Kunne ikke låse sti",
    "no sharing rights on this item" : "Ingen delingsrettigheter på dette elementet",
    "You are not allowed to edit incoming shares" : "Du har ikke lov til å redigere innkommende delinger",
    "Wrong or no update parameter given" : "Feil eller ingen parametre for oppdatering er angitt",
    "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled." : "\"Sende passordet av Nextcloud Talk\" for deling av en fil eller mappe mislyktes fordi Nextcloud Talk ikke er aktivert.",
    "Invalid date. Format must be YYYY-MM-DD" : "Ugyldig dato. Formatet må være YYYY-MM-DD",
    "No sharing rights on this item" : "Ingen delingsrettigheter på dette elementet",
    "Invalid share attributes provided: \"%s\"" : "Ugyldige delingsattributter angitt: \"%s\"",
    "You are not allowed to send mail notifications" : "Du har ikke lov til å sende e-postvarsler",
    "No mail notification configured for this share type" : "Ingen e-postvarsling konfigurert for denne delte ressurstypen",
    "Wrong password" : "Feil passord",
    "Error while sending mail notification" : "Feil under sending av e-postvarsling",
    "This share does not exist or is no longer available" : "Denne delingen eksisterer ikke eller er ikke lenger tilgjengelig",
    "shared by %s" : "delt av %s",
    "Download" : "Last ned",
    "Add to your %s" : "Legg til din %s",
    "Direct link" : "Direkte lenke",
    "Share API is disabled" : "Deling API er deaktivert",
    "File sharing" : "Fildeling",
    "Share will expire tomorrow" : "Deling utløper i morgen",
    "Your share of {node} will expire tomorrow" : "Din deling av {node} vil løpe ut i morgen",
    "You received {share} as a share by {user}" : "Du mottok {share} som en deling fra {user}",
    "You received {share} to group {group} as a share by {user}" : "Du mottok {share} til gruppen {group} som en deling fra {user}",
    "Accept" : "Aksepter",
    "Decline" : "Avslå",
    "This application enables people to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable people can then share files and folders with other accounts and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other people outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation." : "Denne applikasjonen lar personer dele filer i Nextcloud. Hvis aktivert, kan administrator velge hvilke grupper som kan dele filer. De aktuelle personene kan deretter dele filer og mapper med andre kontoer og grupper i Nextcloud. I tillegg, hvis administrator aktiverer delingslenke-funksjonen, kan en ekstern lenke brukes til å dele filer med andre personer utenfor Nextcloud. Administratorer kan også håndheve passord, utløpsdatoer og aktivere server-til-server-deling via delingslenker, samt deling fra mobile enheter.\nHvis du slår av funksjonen, fjernes delte filer og mapper på serveren for alle delingsmottakere, og også på synkroniseringsklienter og mobilapper. Mer informasjon er tilgjengelig i Nextcloud-dokumentasjonen.",
    "People" : "Mennesker",
    "Filter accounts" : "Filtrer kontoer",
    "The request will expire on {date} at midnight and will be password protected." : "Forespørselen utløper {date} ved midnatt og vil være passordbeskyttet.",
    "The request will expire on {date} at midnight." : "Forespørselen utløper {date} ved midnatt.",
    "The request will be password protected." : "Forespørselen vil være passordbeskyttet.",
    "When should the request expire?" : "Når skal forespørselen utløpe?",
    "Set a submission expiration date" : "Angi en utløpsdato for sending",
    "Expiration date" : "Utløpsdato",
    "Select a date" : "Velg en dato",
    "Your administrator has enforced a {count} days expiration policy." : "Systemansvarlig har håndhevet en {count} dagers retningslinjer for utløp.",
    "What password should be used for the request?" : "Hvilket passord skal brukes for forespørselen?",
    "Set a password" : "Sett et passord",
    "Password" : "PassordP",
    "Enter a valid password" : "Angi et gyldig passord",
    "Generate a new password" : "Generer et nytt passord",
    "Your administrator has enforced a password protection." : "Systemansvarlig har håndhevet en passordbeskyttelse.",
    "Automatically copying failed, please copy the share link manually" : "Automatisk kopiering feilet, vennligst kopier delingslenken manuelt",
    "Link copied" : "Lenke kopiert",
    "Email already added" : "E-post allerede lagt til",
    "Invalid email address" : "Ugyldig e-postadresse",
    "_The following email address is not valid: {emails}_::_The following email addresses are not valid: {emails}_" : ["Følgende e-postadresse er ikke gyldig: {emails}","Følgende e-postadresser er ikke gyldige:: {emails}"],
    "You can now share the link below to allow people to upload files to your directory." : "Du kan nå dele lenken nedenfor for å tillate folk å laste opp filer til katalogen din.",
    "Share link" : "Share link",
    "Copy" : "Kopi",
    "Send link via email" : "Send lenke via e-post",
    "Enter an email address or paste a list" : "Skriv inn en e-postadresse eller lim inn en liste",
    "Remove email" : "Fjern e-post",
    "Select a destination" : "Velg en destinasjon",
    "Select" : "Velg",
    "What are you requesting?" : "Hva ber du om?",
    "Request subject" : "Be om emne",
    "Birthday party photos, History assignment…" : "Bursdagsfestbilder, Historieoppgave...",
    "Where should these files go?" : "Hvor skal disse filene gå?",
    "Upload destination" : "Last opp destinasjon",
    "Revert to default" : "Tilbakestill til standard",
    "The uploaded files are visible only to you unless you choose to share them." : "De opplastede filene er bare synlige for deg med mindre du velger å dele dem.",
    "Add a note" : "Legg til et notat",
    "Note for recipient" : "Notat for mottaker",
    "Add a note to help people understand what you are requesting." : "Legg til et notat for å hjelpe andre med å forstå hva du ber om.",
    "You can add links, date or any other information that will help the recipient understand what you are requesting." : "Du kan legge til lenker, dato eller annen informasjon som vil hjelpe mottakeren å forstå hva du ber om.",
    "Close" : "Lukk",
    "_Send email and close_::_Send {count} emails and close_" : ["Send e-post og lukk","Send {count} e-poster og lukk"],
    "Please select a folder, you cannot share the root directory." : "Velg en mappe, du kan ikke dele rotkatalogen.",
    "File request created" : "Filforespørsel opprettet",
    "_File request created and email sent_::_File request created and {count} emails sent_" : ["Filforespørsel opprettet og e-post sendt","Filforespørsel opprettet og {count} e-poster sendt"],
    "Error creating the share: {errorMessage}" : "Feil ved opprettelse av delingen: {errorMessage}",
    "Error creating the share" : "Feil ved oppretting av deling",
    "Error sending emails: {errorMessage}" : "Feil ved sending av e-post: {errorMessage}",
    "Error sending emails" : "Feil ved sending av e-post",
    "Create a file request" : "Opprett en filforespørsel",
    "Collect files from others even if they do not have an account." : "Samle filer fra andre selv om de ikke har en konto.",
    "To ensure you can receive files, verify you have enough storage available." : "For å sikre at du kan motta filer, må du kontrollere at du har nok lagringsplass tilgjengelig.",
    "File request" : "Filforespørsel",
    "Previous step" : "Forrige trinn",
    "Cancel" : "Avbryt",
    "Cancel the file request creation" : "Avbryte opprettelsen av filforespørselen",
    "Close without sending emails" : "Lukk uten å sende e-post",
    "Continue" : "Fortsett",
    "Error while toggling options" : "Feil under veksling av alternativer",
    "Accept shares from other accounts and groups by default" : "Aksepter som standard delte ressurser fra andre kontoer og grupper",
    "Choose a default folder for accepted shares" : "Velg en standardmappe for aksepterte delinger",
    "Invalid path selected" : "Ugyldig angitt sti",
    "Unknown error" : "Ukjent feil",
    "Set default folder for accepted shares" : "Angi standardmappe for aksepterte delinger",
    "Reset" : "Tilbakestill",
    "Reset folder to system default" : "Tilbakestill mappen til standard",
    "group" : "gruppe",
    "conversation" : "samtale",
    "remote" : "ekstern",
    "remote group" : "ekstern gruppe",
    "guest" : "gjest",
    "Shared with the group {user} by {owner}" : "Delt med gruppen {user} av {owner}",
    "Shared with the conversation {user} by {owner}" : "Delt med samtalen {user} av {owner}",
    "Shared with {user} by {owner}" : "Delt med {user} av {owner}",
    "Open Sharing Details" : "Åpne delingsdetaljer",
    "Added by {initiator}" : "Lagt til av {initiator}",
    "Via “{folder}”" : "Via “{folder}”",
    "Unshare" : "Opphev deling",
    "Cannot copy, please copy the link manually" : "Kan ikke kopiere, kopier lenken manuelt",
    "Copy internal link" : "Kopier intern lenke",
    "Internal link" : "Intern lenke",
    "{shareWith} by {initiator}" : "{shareWith} av {initiator}",
    "Shared via link by {initiator}" : "Delt via lenke av {initiator}",
    "File request ({label})" : "Filforespørsel ({label})",
    "Mail share ({label})" : "Deling via e-post ({label})",
    "Share link ({label})" : "Del lenke ({label})",
    "Mail share" : "E-postdeling",
    "Share link ({index})" : "Del lenke ({index})",
    "Create public link" : "Opprett offentlig kobling",
    "Actions for \"{title}\"" : "Valg for \"{title}\"",
    "Error, please enter proper password and/or expiration date" : "Feil, vennligst skriv inn riktig passord og/eller utløpsdato",
    "Link share created" : "Lenkedeling opprettet",
    "Error while creating the share" : "Feil under oppretting av delingen",
    "Please enter the following required information before creating the share" : "Vennligst fyll inn følgende nødvendige informasjon før du oppretter delingen",
    "Password protection (enforced)" : "Passordbeskyttelse (håndhevet)",
    "Password protection" : "Passordbeskyttelse",
    "Enter a password" : "Skriv inn et passord",
    "Create share" : "Opprett deling",
    "Customize link" : "Tilpass lenke",
    "Generate QR code" : "Generer QR-kode",
    "Add another link" : "Legg til en lenke til",
    "Create a new share link" : "Opprett ny delingslenke",
    "Quick share options, the current selected is \"{selectedOption}\"" : "Alternativer for hurtigdeling, gjeldende valgte er \"{selectedOption}\"",
    "View only" : "Kun se",
    "Can edit" : "Kan endre",
    "Custom permissions" : "Egendefinerte tillatelser",
    "Resharing is not allowed" : "Videre deling er ikke tillatt",
    "Name or email …" : "Navn eller epost ...",
    "Name, email, or Federated Cloud ID …" : "Navn, epost eller sammenknyttet sky-ID ...",
    "Searching …" : "Søker ...",
    "No elements found." : "Ingen elementer funnet.",
    "Search everywhere" : "Søk overalt",
    "Guest" : "Gjest",
    "Group" : "Gruppe",
    "Email" : "E-post",
    "Team" : "Lag",
    "Talk conversation" : "Talk-samtale",
    "Deck board" : "Deck tavle",
    "ScienceMesh" : "ScienceMesh",
    "on {server}" : "på {server}",
    "Note from" : "Notat fra",
    "Note:" : "Merk:",
    "File drop" : "Filkasse",
    "Upload files to {foldername}." : "Last opp filer til {foldername}.",
    "By uploading files, you agree to the terms of service." : "Ved å laste opp filer godtar du bruksvilkårene.",
    "View terms of service" : "Vis bruksvilkårene",
    "Terms of service" : "Betingelser for tjenesten",
    "Share with email {email}" : "Del med e-post {email}",
    "Share with group" : "Del med gruppe",
    "Share in conversation" : "Del i samtalen",
    "Share with {user} on remote server {server}" : "Del med {user} på ekstern server {server}",
    "Share with remote group" : "Del med fjerngruppe",
    "Share with guest" : "Del med gjest",
    "Update share" : "Oppdater delt ressurs",
    "Save share" : "Lagre delt ressurs",
    "Read" : "Les",
    "Create" : "Opprett",
    "Edit" : "Rediger",
    "Share" : "Del",
    "Delete" : "Slett",
    "Replace current password" : "Erstatt nåværende passord",
    "Allow upload and editing" : "Tillatt opplasting og redigering",
    "Allow editing" : "Tillat redigering",
    "Upload only" : "Kun opplasting",
    "Advanced settings" : "Avanserte innstillinger",
    "Share label" : "Delingsmerkelapper",
    "Set password" : "Velg passord",
    "Password expires {passwordExpirationTime}" : "Passordet utløper {passwordExpirationTime}",
    "Password expired" : "Passordet er utløpt",
    "Video verification" : "Videobekreftelse",
    "Expiration date (enforced)" : "Utløpsdato (håndhevet)",
    "Set expiration date" : "Sett utløpsdato",
    "Hide download" : "Gjem nedlasting",
    "Allow download and sync" : "Tillat nedlasting og synkronisering",
    "Note to recipient" : "Melding til mottaker",
    "Enter a note for the share recipient" : "Skriv inn en beskjed til mottaker av deling",
    "Delete share" : "Slett delt ressurs",
    "Others with access" : "Andre med tilgang",
    "No other accounts with access found" : "Ingen andre kontoer med tilgang funnet",
    "Toggle list of others with access to this directory" : "Endre liste over andre brukere med tilgang til denne mappen",
    "Toggle list of others with access to this file" : "Endre liste over andre brukere med tilgang til denne filen",
    "Unable to fetch inherited shares" : "Kan ikke hente arvede delinger",
    "Shares" : "Delinger",
    "Unable to load the shares list" : "Kan ikke laste listen over delinger",
    "Expires {relativetime}" : "Utløper {relativetime}",
    "this share just expired." : "denne delingen utløp akkurat.",
    "Shared with you by {owner}" : "Delt med deg av {owner}",
    "Link to a file" : "Lenke til en fil",
    "_Accept share_::_Accept shares_" : ["Aksepter delt ressurs","Aksepter delte ressurser"],
    "Open in Files" : "Åpne i Filer",
    "_Reject share_::_Reject shares_" : ["Avvis delt ressurs","Avvis delte ressurser"],
    "_Restore share_::_Restore shares_" : ["Gjenopprett delt ressurs","Gjenopprett delte ressurser"],
    "Shared" : "Delt",
    "Shared by {ownerDisplayName}" : "Delt av {ownerDisplayName}",
    "Shared multiple times with different people" : "Del flere ganger med forskjellige personer",
    "Shared with others" : "Delt med andre",
    "Create file request" : "Opprett filforespørsel",
    "Upload files to {foldername}" : "Last opp filer til {foldername}",
    "Public file share" : "Offentlig fildeling",
    "Publicly shared file." : "Offentlig delt fil.",
    "No file" : "Ingen fil",
    "The file shared with you will show up here" : "Filen som er delt med deg vil vises her",
    "Public share" : "Offentlig deling",
    "Publicly shared files." : "Offentlig delte filer.",
    "No files" : "Ingen filer",
    "Files and folders shared with you will show up here" : "Filer og mapper delt med deg vil vises her",
    "Overview of shared files." : "Oversikt over delte filer.",
    "No shares" : "Ingen delinger",
    "Files and folders you shared or have been shared with you will show up here" : "Filer og mapper du har delt eller har blitt delt med deg, vises her",
    "Shared with you" : "Delt med deg",
    "List of files that are shared with you." : "Liste over filer som er delt med deg.",
    "Nothing shared with you yet" : "Ingenting er delt med deg enda",
    "Files and folders others shared with you will show up here" : "Filer og mapper andre har delt med deg, vises her",
    "List of files that you shared with others." : "Liste over filer som du delte med andre.",
    "Nothing shared yet" : "Ingenting er delt ennå",
    "Files and folders you shared will show up here" : "Filer og mapper du delte, vises her",
    "Shared by link" : "Delt med lenke",
    "List of files that are shared by link." : "Liste over filer som er delt via kobling.",
    "No shared links" : "Ingen delte lenker",
    "Files and folders you shared by link will show up here" : "Filer og mapper du har delt via kobling, vises her",
    "File requests" : "Filforespørsler",
    "List of file requests." : "Liste over filforespørsler.",
    "No file requests" : "Ingen filforespørsler",
    "File requests you have created will show up here" : "Filforespørsler du har opprettet vil vises her",
    "Deleted shares" : "Slettede delinger",
    "List of shares you left." : "Liste over delte ressurser du forlot.",
    "No deleted shares" : "Ingen slettede delinger",
    "Shares you have left will show up here" : "Delte ressurser du har forlatt, vises her",
    "Pending shares" : "Ventende delinger",
    "List of unapproved shares." : "Liste over ikke godkjente delte ressurser.",
    "No pending shares" : "Ingen ventende delinger",
    "Shares you have received but not approved will show up here" : "Delte ressurser du har mottatt, men ikke godkjent, vises her",
    "Error updating the share: {errorMessage}" : "Feil ved oppdatering av delingen: {errorMessage}",
    "Error updating the share" : "Feil under oppdatering av delingen",
    "File \"{path}\" has been unshared" : "Deling av filen \"{path}\" er opphevd",
    "Folder \"{path}\" has been unshared" : "Deling av mappen \"{path}\" er opphevd",
    "Upload files to {folder}" : "Last opp filer til {folder}",
    "{ownerDisplayName} shared a folder with you." : "{ownerDisplayName} delte en mappe med deg.",
    "Shared by" : "Delt av",
    "Shared with" : "Delt med",
    "Password created successfully" : "Passord opprettet",
    "Error generating password from password policy" : "Feil under generering av passord fra passordregler",
    "Shared with you and the group {group} by {owner}" : "Delt med deg og gruppen {group} av {owner}",
    "Shared with you and {circle} by {owner}" : "Delt med deg og {circle} av {owner}",
    "Shared with you and the conversation {conversation} by {owner}" : "Delt med deg og samtalen {conversation} av {owner}",
    "Shared with you in a conversation by {owner}" : "Delt md deg i samtale med  {owner}",
    "Share not found" : "Deling ikke funnet",
    "Back to %s" : "Tilbake til %s",
    "Add to your Nextcloud" : "Legg til i din Nextcloud",
    "Waiting…" : "Venter...",
    "error" : "feil",
    "finished" : "fullført",
    "This will stop your current uploads." : "Dette fille stoppe dine nåværende opplastinger.",
    "Move or copy" : "Flytt eller kopier",
    "You can upload into this folder" : "Du kan laste opp til denne mappen",
    "Show list view" : "Vis listevisning",
    "Show grid view" : "Vis rutenett-visning",
    "No compatible server found at {remote}" : "Ingen kompatibel server ble funnet på {remote}",
    "Invalid server URL" : "Ugyldig server adresse",
    "Failed to add the public link to your Nextcloud" : "Feil oppsto under oppretting av offentlig lenke til din Nextcloud",
    "You are not allowed to edit link shares that you don't own" : "Du har ikke lov til å redigere delte lenker du ikke eier",
    "Download all files" : "Last ned alle filer",
    "Link copied to clipboard" : "Lenke kopiert til utklippstavlen",
    "_1 email address already added_::_{count} email addresses already added_" : ["1 e-postadresse allerede lagt til","{count} e-postadresser allerede lagt til"],
    "_1 email address added_::_{count} email addresses added_" : ["1 e-postadresse lagt til","{count} e-postadresser lagt til"],
    "Copy to clipboard" : "Kopiert til utklippstavlen",
    "Copy internal link to clipboard" : "Kopier intern lenke til utklippstavlen",
    "Only works for people with access to this folder" : "Fungerer kun for personer med tilgang til denne mappen",
    "Only works for people with access to this file" : "Fungerer kun for personer med tilgang til denne filen",
    "Copy public link of \"{title}\" to clipboard" : "Kopier den offentlige lenken til \"{title}\" til utklippstavlen",
    "Search globally" : "Søk globalt",
    "Search for share recipients" : "Søk etter delingsmottakere",
    "No recommendations. Start typing." : "Ingen forslag. Start skriving.",
    "To upload files, you need to provide your name first." : "For å laste opp filer må du først oppgi navnet ditt.",
    "Enter your name" : "Skriv inn navnet ditt",
    "Submit name" : "Send inn navn",
    "Share with {userName}" : "Del med {userName}",
    "Show sharing options" : "Vis alternativer for deling",
    "Share note" : "Delingsnotat",
    "Upload files to %s" : "Last opp filer til %s",
    "%s shared a folder with you." : "%s delte en mappe med deg.",
    "Note" : "Melding",
    "Select or drop files" : "Velg eller slipp filer",
    "Uploading files" : "Laster opp filer",
    "Uploaded files:" : "Opplastede filer:",
    "By uploading files, you agree to the %1$sterms of service%2$s." : "Ved å laste opp filer godtar du %1$stjenestevilkårene%2$s.",
    "Name" : "Navn",
    "Filename must not be empty." : "Filnavn kan ikke være tomt."
},
"nplurals=2; plural=(n != 1);");
