<?php
namespace Aws\Pinpoint\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Pinpoint** service.
 */
class PinpointException extends AwsException {}
