OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Dashboard",
    "Dashboard app" : "Dashboard-app",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an overview of your upcoming appointments, urgent emails, chat messages, incoming tickets, latest tweets and much more! People can add the widgets they like and change the background to their liking." : "Begin je dag geïnformeerd\n\nHet Nextcloud Dashboard is je startpunt van de dag en biedt je een overzicht van je aankomende afspraken, dringende e-mails, chatberichten, binnenkomende tickets, laatste tweets en nog veel meer! Mensen kunnen de widgets toevoegen die ze leuk vinden en de achtergrond naar wens aanpassen.",
    "Weather" : "Weer",
    "Status" : "Status",
    "Good morning" : "Goedemorgen",
    "Good morning, {name}" : "Goedemorgen, {name}",
    "Good afternoon" : "Goedemiddag",
    "Good afternoon, {name}" : "Goedemiddag, {name}",
    "Good evening" : "Goedenavond",
    "Good evening, {name}" : "Goedenavond, {name}",
    "Hello" : "Hallo",
    "Hello, {name}" : "Hallo, {name}",
    "Happy birthday 🥳🤩🎂🎉" : "Fijne verjaardag 🥳🤩🎂🎉",
    "Happy birthday, {name} 🥳🤩🎂🎉" : "Fijne verjaardag, {name} 🥳🤩🎂🎉",
    "Customize" : "Aanpassen",
    "Edit widgets" : "Widgets bewerken",
    "Get more widgets from the App Store" : "Haal meer widgets op uit de App Store",
    "Weather service" : "Weerberichten",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Voor je privacy worden de weergegevens namens jou opgevraagd door je Nextcloud-server, zodat de weerservice geen persoonlijke informatie ontvangt.",
    "Weather data from Met.no" : "Weerbericht via Met.no",
    "geocoding with Nominatim" : "geocoding met Nominatim",
    "elevation data from OpenTopoData" : "hoogtedata via OpenTopoData"
},
"nplurals=2; plural=(n != 1);");
