OC.L10N.register(
    "app_api",
    {
    "Daemon config not found" : "找不到幕後程式設定",
    "Error starting install of ExApp" : "開始安裝 ExApp 時發生錯誤",
    "ExApp failed to register, check the NC logs" : "ExApp 註冊失敗，請檢查 Nextcloud 紀錄檔",
    "ExApp not found, failed to get status" : "找不到 ExApp，無法取得狀態",
    "This app is not installed from the AppStore. No extra information available. Only enable/disable and remove actions are allowed." : "此應用程式未從 AppStore 安裝。未提供額外資訊。僅允許啟用/停用與移除動作。",
    "Could not perform installation of ExApp" : "無法執行 ExApp 的安裝",
    "Failed to enable ExApp" : "啟用 ExApp 失敗",
    "Failed to disable ExApp" : "停用 ExApp 失敗",
    "Could not update ExApp" : "無法更新 ExApp",
    "Error starting update of ExApp" : "開始更新 ExApp 時發生錯誤",
    "Could not perform update of ExApp" : "無法執行 ExApp 的更新",
    "ExApp not found, failed to get logs" : "找不到 ExApp，無法取得紀錄檔",
    "Failed to get container logs. Note: Downloading Docker container works only for containers with the json-file or journald logging driver. Error: %s" : "無法取得容器紀錄檔。注意：下載 Docker 容器僅適用於有 json 檔案或 journald 紀錄檔驅動程式的容器。錯誤：%s",
    "AppAPI authentication failed" : "AppAPI 驗證失敗",
    "AppAPI ExApp notifier" : "AppAPI ExApp 通知",
    "AppAPI" : "AppAPI",
    "AI Integration Team" : "整合團隊",
    "ExApps Settings" : "ExApp 設定",
    "Nextcloud AppAPI" : "Nextcloud AppAPI",
    "### Boost your Nextcloud with AppAPI and its specially designed applications.\n\n\nThe AppAPI is a project within the Nextcloud ecosystem designed to streamline and enhance the process of\napplication development, deployment, and management.\n\nIt introduces a new methodology that allows developers to create\napplications using a variety of programming languages, not limited to PHP, which was traditionally used in Nextcloud development.\n\n\n### List of applications that require AppAPI:\n\n- [talk_bot_ai_example](https://github.com/cloud-py-api/talk_bot_ai_example)\n- [upscaler_example](https://github.com/cloud-py-api/upscaler_example)\n- [image_to_text_example](https://github.com/cloud-py-api/file_to_text_example)\n- [ai_image_generator_bot](https://github.com/cloud-py-api/ai_image_generator_bot)\n- [SummarAI](https://github.com/nextcloud/sumupbot)\n\n_If you wish to develop an application, we will gladly help and assist you._\n\n### Support\n\nWe appreciate any support for this project:\n\n- ⭐ Star our work on GitHub\n- ❗ Create an Issue or feature request\n- 💁 Resolve an Issue and create a Pull Request\n- 🧑‍💻 Develop your own application using AppAPI\n\nWe are genuinely excited about the future of the AppAPI project and its potential to transform\nthe way applications are developed and experienced within Nextcloud.\n\nAs we embark on this journey, we warmly invite you - developers, thinkers, creators, and visionaries -\nto join us in shaping a more versatile, stable, and secure app landscape.\n\n*Your insights, suggestions, and contributions are invaluable to us.*" : "### 使用 AppAPI 與其專門設計的應用程式強化您的 Nextcloud\n\n\nAppAPI 是 Nextcloud 生態系中的一個專案，旨在簡化並強化\n應用程式開發、部署及管理。\n\n其引入了一種新的方法，讓開發者可以製作\n使用多種程式語言的應用程式，不僅限於 PHP，後者傳統上用於 Nextcloud 開發。\n\n\n### 需要 AppAPI 的應用程式清單：\n\n- [talk_bot_ai_example](https://github.com/cloud-py-api/talk_bot_ai_example)\n- [upscaler_example](https://github.com/cloud-py-api/upscaler_example)\n- [image_to_text_example](https://github.com/cloud-py-api/file_to_text_example)\n- [ai_image_generator_bot](https://github.com/cloud-py-api/ai_image_generator_bot)\n- [SummarAI](https://github.com/nextcloud/sumupbot)\n\n_若您希望開發應用程式，我們將很樂意為您提供協助。_\n\n### 支援\n\n我們感謝對此專案的任何支援：\n\n- ⭐ 在 GitHub 上給我們的作品星星\n- ❗ 建立問題或功能請求\n- 💁 解決問題並建立拉取請求\n- 🧑‍💻 使用 AppAPI 開發您自己的應用程式\n\n我們對 AppAPI 專案的未來及其改變 Nextcloud 中應用程式開發與\n體驗方式的潛力感到由衷的興奮。\n\n當我們踏上這趟旅程時，我們熱烈邀請您（開發者、思想家、創造者和夢想家）\n與我們一起塑造更通用、穩定和安全的應用程式格局。\n\n*您的見解、建議和貢獻對我們來說非常寶貴。*",
    "The AppAPI Project is an exciting initiative that aims to revolutionize the way applications are developed for Nextcloud." : "AppAPI 專案是一項令人興奮的舉措，旨在徹底改變 Nextcloud 的應用程式開發方式。",
    "Deploy Daemons" : "部署幕後程式",
    "Deploy Daemon (DaemonConfig) is an ExApps orchestration daemon." : "部署幕後程式 (DaemonConfig) 是 ExApp 的協作幕後程式。",
    "Deploy Daemons. Deploy Daemon (DaemonConfig) is an ExApps orchestration daemon." : "部署幕後程式。部署幕後程式 (DaemonConfig) 是 ExApp 的協作幕後程式。",
    "Default Deploy Daemon is not accessible. Please verify its configuration" : "預設部署幕後程式無法使用。請驗證其設定",
    "ExApp init timeout (minutes)" : "ExApp 初始化逾時（分鐘）",
    "ExApp initialization process timeout after which AppAPI will mark it as failed" : "ExApp 初始化流程逾時，在此之後 AppAPI 將會標記其為失敗",
    "ExApp init timeout" : "ExApp 初始化逾時",
    "ExApp container restart policy" : "ExApp 容器重新啟動政策",
    "Specify container restart policy, e.g. 'always' to ensure ExApp running after daemon server reboot" : "指定容器重新啟動政策，例如「一律」確保 ExApp 在幕後程式伺服器重新啟動後執行",
    "This settings changes are reflected only for newly created containers" : "此設定變更僅反映在新建立的容器中",
    "External Apps management" : "外部應用程式管理",
    "Admin options saved" : "已儲存管理選項",
    "Failed to save admin options" : "儲存管理選項失敗",
    "Are you sure you want delete Deploy Daemon" : "您確定您想要刪除部署幕後程式嗎",
    "All ExApps on this daemon will be removed" : "所有在此幕後程式上的 ExApp 都將會被移除",
    "All ExApps installed on this daemon will be removed" : "所有安裝在此幕後程式上的 ExApp 都將會被移除",
    "Cancel" : "取消",
    "Delete" : "刪除",
    "Default" : "預設",
    "Set as default" : "設定為預設值",
    "Test deploy" : "測試部署",
    "Edit" : "編輯",
    "\"manual-install\" Deploy Daemon cannot be set as default" : "「手動安裝」部署幕後程式無法設定為預設值",
    "Failed to save admin options. Check the logs" : "儲存管理選項失敗。請檢查紀錄檔",
    "Password confirmation failed" : "密碼確認失敗",
    "Deploy daemon config details" : "部署幕後程式設定詳細資訊",
    "Deploy Daemon" : "部署幕後程式",
    "Default daemon. ExApps will be installed on it" : "預設幕後程式。ExApp 將會安裝在其上",
    "Manual install daemon usually used for development. It cannot be set as default daemon." : "手動安裝幕後程式通常用於開發。其不能被設定為預設幕後程式。",
    "ExApps installed" : "已安裝 ExApp",
    "Name" : "名稱",
    "Protocol" : "協定",
    "Host" : "主機",
    "Deploy config" : "部署設定",
    "Docker network" : "Docker 網路",
    "Nextcloud URL" : "Nextcloud URL",
    "HaProxy password" : "HaProxy 密碼",
    "GPUs support" : "GPU 支援",
    "Compute device" : "計算裝置",
    "Additional options" : "其他選項",
    "Verify connection" : "驗證連線",
    "Daemon connection successful" : "幕後程式連線成功",
    "Failed to connect to Daemon. Check the logs" : "連線至幕後程式失敗。請檢查紀錄檔",
    "Failed to check connection to Daemon. Check the logs" : "檢查至幕後程式的連線失敗。請檢查紀錄檔",
    "Registered Deploy daemons list" : "已註冊的部署幕後程式清單",
    "No Deploy daemons configured" : "未設定部署幕後程式",
    "Register a custom one or setup from available templates" : "從可用範本註冊自訂範本或設定",
    "Register Daemon" : "註冊幕後程式",
    "AppAPI will try to install small skeleton ExApp to verify Daemon configured correctly and deployment steps are passing." : "AppAPI 將嘗試安裝小型 ExApp 骨架來驗證幕後程式是否正確設定以及部署步驟是否通過。",
    "The following Deploy test checks must be passed to succeed:" : "必須通過以下部署測試檢查才能成功：",
    "More info" : "更多資訊",
    "Download ExApp logs" : "下載 ExApp 紀錄檔",
    "Remove test ExApp" : "移除測試 ExApp",
    "Start Deploy test" : "開始部署測試",
    "Stop Deploy test" : "停止部署測試",
    "ExApp is unregistered and container is removed on \"Stop deploy test\"" : "ExApp 已被取消註冊，其容器已在「停止部署測試」中移除",
    "Register ExApp in Nextcloud" : "在 Nextcloud 註冊 ExApp",
    "Check if the ExApp is registered in Nextcloud before deployment" : "部署前檢查 ExApp 是否已在 Nextcloud 中註冊",
    "Image pull" : "拉取映像檔",
    "Check if the image is successfully pulled" : "撿茶室否成功拉取映像檔",
    "Container started" : "容器已啟動",
    "Check if the image successfully pulled and container is created and started" : "檢查是否成功拉取映像檔，以及容器是否已建立並啟動",
    "Heartbeat" : "心跳",
    "Check for the heartbeat is finished and healthy" : "檢查心跳是否完成且健康",
    "Init step" : "初始化步驟",
    "Wait for initialization step to finish" : "等待初始化步驟完成",
    "Enabled" : "已啟用",
    "Check if ExApp successfully handled the enabled event and registered all stuff properly" : "檢查 ExApp 是否成功處理啟用的事件並正確註冊所有內容",
    "Only if ExApp container is preset" : "僅當 ExApp 容器已預設設定時",
    "Deploy test passed successfully!" : "部署測試成功通過！",
    "Deploy test failed at step \"{step}\"" : "部署測試失敗於步驟「{step}」",
    "Edit Deploy Daemon" : "編輯部署幕後程式",
    "Register Deploy Daemon" : "註冊部署幕後程式",
    "Daemon configuration template" : "幕後程式設定範本",
    "Select daemon configuration template" : "選取幕後程式設定範本",
    "Daemon registration form" : "幕後程式註冊表單",
    "Unique Deploy Daemon Name" : "獨一無二的部署幕後程式名稱",
    "Display name" : "顯示名稱",
    "Deployment method" : "部署方法",
    "Select daemon deploy method" : "選取幕後程式部署方法",
    "Daemon host" : "幕後程式主機",
    "Set daemon as default" : "設定幕後程式為預設值",
    "Set as default daemon" : "設定為預設幕後程式",
    "Enable https" : "啟用 https",
    "Show deploy config" : "顯示部署設定",
    "Hide deploy config" : "隱藏部署設定",
    "Network" : "網路",
    "Docker network name" : "Docker 網路名稱",
    "AppAPI Docker Socket Proxy authentication password" : "AppAPI Docker Socket Proxy 驗證密碼",
    "Additional option" : "其他選項",
    "Add additional option" : "新增其他選項",
    "Option key (unique)" : "選項鍵（唯一）",
    "Option key (unique, e.g. my_key)" : "選項鍵（唯一，例如 my_key）",
    "Option key is required" : "選項鍵必填",
    "Option value" : "選項值",
    "Option value is required" : "選項值必填",
    "Confirm" : "確認",
    "Save" : "儲存",
    "Register" : "註冊",
    "Check connection" : "檢查連線",
    "Hostname to access ExApps" : "用來存取 ExApp 的主機名稱",
    "Hostname or path to access Docker daemon (e.g. nextcloud-appapi-dsp:2375, /var/run/docker.sock)" : "存取 Docker 幕後程式的主機名稱或路徑（例如 nextcloud-appapi-dsp:2375, /var/run/docker.sock）",
    "Daemon with this name already exists" : "同名幕後程式已存在",
    "Password must be at least 12 characters long" : "密碼必須至少 12 個字元長",
    "With https enabled network is set to host" : "啟用 https 後，網路設定為主機",
    "Changes would be applied only for newly installed ExApps. For existing ExApps, Docker containers should be recreated." : "變更僅適用於新安裝的 ExApps。對於現有的 ExApps，應重新建立 Docker 容器。",
    "URL should start with http:// or https://" : "URL 應以 http:// 或 https:// 開頭",
    "For HTTPS daemon, Nextcloud URL should be HTTPS" : "對於 HTTPS 幕後程式，Nextcloud URL 應該為 HTTPS",
    "All available GPU devices on daemon host will be requested to be enabled in ExApp containers by Docker." : "Docker 將要求在 ExApp 容器中啟用幕後程式主機上的所有可用 GPU 裝置。",
    "DaemonConfig successfully registered" : "DaemonConfig 成功註冊",
    "Failed to register DaemonConfig. Check the logs" : "註冊 DaemonConfig 失敗。請檢查紀錄檔",
    "DaemonConfig successfully updated" : "DaemonConfig 成功更新",
    "Failed to update DaemonConfig. Check the logs" : "更新 DaemonConfig 失敗。請檢查紀錄檔",
    "External Apps" : "外部應用程式",
    "### Boost your Nextcloud with AppAPI and its specially designed applications.\n\n\nThe AppAPI is a project within the Nextcloud ecosystem designed to streamline and enhance the process of\napplication development, deployment, and management.\n\nIt introduces a new methodology that allows developers to create\napplications using a variety of programming languages, not limited to PHP, which was traditionally used in Nextcloud development.\n\n### Bundled App\n\n**Starting with Nextcloud 30.0.1, this application is included in the default Nextcloud package.**\n\n### Support\n\nWe appreciate any support for this project:\n\n- ⭐ Star our work on GitHub\n- ❗ Create an Issue or feature request\n- 💁 Resolve an Issue and create a Pull Request\n- 🧑‍💻 Develop your own application using AppAPI\n\nWe are genuinely excited about the future of the AppAPI project and its potential to transform\nthe way applications are developed and experienced within Nextcloud.\n\nAs we embark on this journey, we warmly invite you - developers, thinkers, creators, and visionaries -\nto join us in shaping a more versatile, stable, and secure app landscape.\n\n*Your insights, suggestions, and contributions are invaluable to us.*" : "### 使用 AppAPI 與其專門設計的應用程式強化您的 Nextcloud\n\n\nAppAPI 是 Nextcloud 生態系中的一個專案，旨在簡化並強化\n應用程式開發、部署及管理。\n\n其引入了一種新的方法，讓開發者可以製作\n使用多種程式語言的應用程式，不僅限於 PHP，後者傳統上用於 Nextcloud 開發。\n\n\n### 內建應用程式\n\n**從 Nextcloud 30.0.1 開始，此應用程式已包含在預設的 Nextcloud 軟體包中。**\n\n### 支援\n\n我們感謝對此專案的任何支援：\n\n- ⭐ 在 GitHub 上給我們的作品星星\n- ❗ 建立問題或功能請求\n- 💁 解決問題並建立拉取請求\n- 🧑‍💻 使用 AppAPI 開發您自己的應用程式\n\n我們對 AppAPI 專案的未來及其改變 Nextcloud 中應用程式開發與\n體驗方式的潛力感到由衷的興奮。\n\n當我們踏上這趟旅程時，我們熱烈邀請您（開發者、思想家、創造者和夢想家）\n與我們一起塑造更通用、穩定和安全的應用程式格局。\n\n*您的見解、建議和貢獻對我們來說非常寶貴。*",
    "Update to {version}" : "更新到 {version}",
    "Remove" : "移除",
    "Delete data on remove" : "移除時刪除資料",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "此應用程式並未指定最低的 Nextcloud 版本。未來可能會出現錯誤。",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "此應用程式並未指定最高的 Nextcloud 版本。未來可能會出現錯誤。",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "無法安裝此應用程式，因為無法滿足下列的依賴關係：",
    "View in store" : "在商店中檢視",
    "Visit website" : "造訪網站",
    "Report a bug" : "回報問題",
    "User documentation" : "使用者說明文件",
    "Admin documentation" : "管理員說明文件",
    "Developer documentation" : "開發者說明文件",
    "This app is not registered in AppStore. No extra information available. Only enable/disable and remove actions are allowed." : "此應用程式未在 AppStore 註冊。無可用的額外資訊。僅允許啟用/停用與移除動作。",
    "{license}-licensed" : "以 {license} 授權",
    "This app is supported via your current Nextcloud subscription." : "您目前的 Nextcloud 訂閱支援此應用程式。",
    "Supported" : "支援",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "精選應用程式是由社群開發的。它們提供了相當重要的功能，並已準備好在正式環境使用。",
    "Featured" : "精選",
    "Update to {update}" : "更新到 {update}",
    "All ExApps are up-to-date." : "所有 ExApp 均已最新。",
    "Default Deploy daemon is not accessible" : "預設部署幕後程式無法使用",
    "Icon" : "圖示",
    "Version" : "版本",
    "Daemon" : "守護程式",
    "Level" : "層級",
    "Actions" : "動作",
    "Results from other categories" : "其他分類的結果",
    "No apps found" : "找不到應用程式",
    "_%n ExApp has an update available_::_%n apps have an update available_" : ["%n 個應用程式有可用的更新"],
    "_Update_::_Update all_" : ["更新全部"],
    "Type" : "類型",
    "Display Name" : "顯示名稱",
    "Your apps" : "您的應用程式",
    "Documentation" : "文件",
    "Details" : "詳細資訊",
    "Changelog" : "變更紀錄",
    "by {author}\n{license}" : "作者為 {author}\n{license}",
    "Active apps" : "已啟用應用程式",
    "Disabled apps" : "已停用應用程式",
    "Updates" : "更新",
    "Featured apps" : "精選應用程式",
    "Supported apps" : "支援的應用程式",
    "manual-install apps cannot be updated" : "無法更新手動安裝應用程式",
    "{progress}% Deploying" : "{progress}% 部署中",
    "{progress}% Initializing" : "初始化 {progress}%",
    "Healthchecking" : "健康檢查",
    "Deploy and Enable" : "部署與啟用",
    "Enable" : "啟用",
    "Disable" : "停用",
    "Allow untested app" : "允許未經測試的應用程式",
    "Default Deploy daemon is not accessible. Please verify configuration" : "預設部署幕後程式無法使用。請驗證設定",
    "The app will be downloaded from the App Store and deployed on default Deploy Daemon" : "該應用程式將從 App Store 下載並部署在預設的部署幕後程式上",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "此應用程式未被標記為與您的 Nextcloud 版本相容。如果繼續，您仍可安裝應用程式。但請注意應用程式可能無法正常運作。",
    "Your ExApps" : "您的 ExApp",
    "An error occurred during the request. Unable to proceed." : "請求時發生錯誤。無法繼續。",
    "The app has been enabled but needs to be updated." : "應用程式已啟用，但需要更新。",
    "Error: This app cannot be enabled because it makes the server unstable" : "錯誤：此應用程序無法啟用，因為它造成伺服器不穩定"
},
"nplurals=1; plural=0;");
