OC.L10N.register(
    "app_api",
    {
    "Cancel" : "Cancelar",
    "Delete" : "Eliminar",
    "Default" : "Predefinido",
    "Edit" : "Editar",
    "Name" : "Nome",
    "Host" : "Anfitrião",
    "Enabled" : "Activo",
    "Display name" : "Nome a exibir",
    "Network" : "Rede",
    "Confirm" : "Confirmar",
    "Save" : "Guardar",
    "Register" : "Registar",
    "Update to {version}" : "Actualizar para {version}",
    "Remove" : "Remover",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta app não tem a versão mínima do Nextcloud atribuída. Isto será um erro no futuro.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta app não tem a versão máxima do Nextcloud atribuída. Isto será um erro no futuro.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Esta aplicação não pode ser instalada porque as seguintes dependências não podem ser realizadas:",
    "View in store" : "Ver na loja",
    "Visit website" : "Visitar o website",
    "Report a bug" : "Reportar um erro",
    "User documentation" : "Documentação de utilizador",
    "Admin documentation" : "Documentação de administrador",
    "Developer documentation" : "Documentação de programador",
    "Supported" : "Suportado",
    "Featured" : "Destacado",
    "Version" : "Versão",
    "Level" : "Nível",
    "Actions" : "Acções",
    "Results from other categories" : "Resultados de outras categorias",
    "_Update_::_Update all_" : ["Atualizar","Atualizar todos","Atualizar todos"],
    "Type" : "Tipo",
    "Your apps" : "As suas apps",
    "Documentation" : "Documentação",
    "Details" : "Detalhes",
    "Changelog" : "Registo de alterações",
    "Disabled apps" : "Apps desativadas",
    "Updates" : "Actualizações",
    "Enable" : "Activar",
    "Disable" : "Desativar"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
