<?php
/**
 * SPDX-FileCopyrightText: 2022 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */

\OCP\Util::addScript('federatedfilesharing', 'vue-settings-personal');
?>

<div id="vue-personal-federated"></div>
