OC.L10N.register(
    "photos",
    {
    "Videos" : "Tividyutin",
    "Favorites" : "Imenyafen",
    "Tags" : "Tibzimin",
    "Back" : "Retour",
    "Save" : "Sekles",
    "Group" : "Agraw",
    "Favorite" : "Menyif",
    "Home" : "Asnubeg",
    "Remove from favorites" : "Kkes-it seg ismal",
    "Details" : "Talqayt",
    "Add" : "Rnu"
},
"nplurals=2; plural=(n != 1);");
