<?php
// This file is auto-generated. Do not edit!
return array('localeDisplayPattern'=>array('localePattern'=>'%1$s（%2$s）','localeSeparator'=>'%1$s，%2$s','localeKeyTypePattern'=>'%1$s：%2$s'),'subdivisions'=>array('gbeng'=>'英格兰','gbsct'=>'苏格兰','gbwls'=>'威尔士'),'keys'=>array('calendar'=>'日历','cf'=>'货币格式','colAlternate'=>'忽略符号排序','colBackwards'=>'对重音进行逆向排序','colCaseFirst'=>'大写/小写字母排序','colCaseLevel'=>'区分大小写的排序','collation'=>'排序','colNormalization'=>'规范化排序','colNumeric'=>'数字排序','colStrength'=>'排序强度','currency'=>'货币','hc'=>'小时制（12或24）','lb'=>'换行符样式','ms'=>'度量衡制','numbers'=>'数字','timezone'=>'时区','va'=>'语言区域别名','x'=>'专用'),'types'=>array('calendar'=>array('buddhist'=>'佛历','chinese'=>'农历','coptic'=>'科普特历','dangi'=>'檀纪历','ethiopic'=>'埃塞俄比亚历','ethiopic-amete-alem'=>'埃塞俄比亚阿米特阿莱姆日历','gregorian'=>'公历','hebrew'=>'希伯来历','indian'=>'印度国定历','islamic'=>'伊斯兰历','islamic-civil'=>'伊斯兰希吉来日历','islamic-rgsa'=>'沙特阿拉伯伊斯兰历','islamic-tbla'=>'伊斯兰天文历','islamic-umalqura'=>'伊斯兰历（乌姆库拉）','iso8601'=>'国际标准历法','japanese'=>'和历','persian'=>'波斯历','roc'=>'民国纪年'),'cf'=>array('account'=>'会计货币格式','standard'=>'标准货币格式'),'colAlternate'=>array('non-ignorable'=>'对符号进行排序','shifted'=>'忽略符号进行排序'),'colBackwards'=>array('no'=>'对重音进行正常排序','yes'=>'对重音进行逆向排序'),'colCaseFirst'=>array('lower'=>'先对小写字母进行排序','no'=>'对正常大小写顺序进行排序','upper'=>'先对大写字母进行排序'),'colCaseLevel'=>array('no'=>'不区分大小写进行排序','yes'=>'区分大小写进行排序'),'collation'=>array('big5han'=>'繁体中文排序 - Big5','compat'=>'基于兼容性沿用既往排序','dictionary'=>'字典排序','ducet'=>'默认 Unicode 排序','emoji'=>'表情符号排序','eor'=>'欧洲排序规则','gb2312han'=>'简体中文排序 - GB2312','phonebook'=>'电话簿排序','phonetic'=>'语音排序','pinyin'=>'拼音排序','reformed'=>'改良排序','search'=>'常规搜索','searchjl'=>'按韩文字开首辅音来搜索','standard'=>'标准排序','stroke'=>'笔画排序','traditional'=>'传统排序','unihan'=>'部首笔画排序','zhuyin'=>'注音排序'),'colNormalization'=>array('no'=>'非规范化排序','yes'=>'对 Unicode 进行规范化排序'),'colNumeric'=>array('no'=>'对数字进行单独排序','yes'=>'按数字顺序对数字进行排序'),'colStrength'=>array('identical'=>'对所有内容进行排序','primary'=>'只对基本字母进行排序','quaternary'=>'对重音/大小写/长度/假名进行排序','secondary'=>'对重音进行排序','tertiary'=>'对重音/大小写/长度进行排序'),'d0'=>array('fwidth'=>'全角','hwidth'=>'半角','npinyin'=>'数字'),'hc'=>array('h11'=>'12小时制（0–11）','h12'=>'12小时制（1–12）','h23'=>'24小时制（0–23）','h24'=>'24小时制（1–24）'),'lb'=>array('loose'=>'宽松换行符样式','normal'=>'正常换行符样式','strict'=>'严格换行符样式'),'m0'=>array('bgn'=>'美国地名委员会 (BGN)','ungegn'=>'联合国地名专家组 (UNGEGN)'),'ms'=>array('metric'=>'公制','uksystem'=>'英制','ussystem'=>'美制'),'numbers'=>array('ahom'=>'阿霍姆数字','arab'=>'阿拉伯-印度数字','arabext'=>'扩展阿拉伯-印度数字','armn'=>'亚美尼亚数字','armnlow'=>'亚美尼亚小写数字','bali'=>'巴厘文数字','beng'=>'孟加拉数字','brah'=>'婆罗米数字','cakm'=>'查克玛数字','cham'=>'占文数字','cyrl'=>'斯拉夫数字','deva'=>'梵文数字','diak'=>'迪维西阿库鲁数字','ethi'=>'埃塞俄比亚数字','finance'=>'金融数字','fullwide'=>'全角数字','geor'=>'格鲁吉亚数字','gong'=>'马萨拉姆冈德数字','gonm'=>'马萨拉姆冈德数字','grek'=>'希腊数字','greklow'=>'希腊小写数字','gujr'=>'古吉拉特数字','guru'=>'果鲁穆奇数字','hanidec'=>'中文十进制数字','hans'=>'简体中文数字','hansfin'=>'简体中文大写数字','hant'=>'繁体中文数字','hantfin'=>'繁体中文大写数字','hebr'=>'希伯来数字','hmng'=>'杨松录苗文数字','hmnp'=>'尼亚肯蒲丘苗文数字','java'=>'爪哇文数字','jpan'=>'日文数字','jpanfin'=>'日文大写数字','kali'=>'克耶字母数字','kawi'=>'卡维数字','khmr'=>'高棉数字','knda'=>'卡纳达数字','lana'=>'老傣文数字','lanatham'=>'兰纳文数字','laoo'=>'老挝数字','latn'=>'西方数字','lepc'=>'雷布查文数字','limb'=>'林布文数字','mathbold'=>'数学粗体数字','mathdbl'=>'数学空心数字','mathmono'=>'数学等宽数字','mathsanb'=>'数学无衬线粗体数字','mathsans'=>'数学无衬线数字','mlym'=>'马拉雅拉姆数字','modi'=>'莫迪数字','mong'=>'蒙古文数字','mroo'=>'谬文数字','mtei'=>'曼尼普尔数字','mymr'=>'缅甸数字','mymrshan'=>'缅甸掸文数字','mymrtlng'=>'缅甸泰兰数字','nagm'=>'nagm','native'=>'当地数字','nkoo'=>'曼德数字','olck'=>'桑塔利文数字','orya'=>'奥里亚数字','osma'=>'奥斯曼数字','rohg'=>'哈乃斐罗兴亚数字','roman'=>'罗马数字','romanlow'=>'罗马小写数字','saur'=>'索拉什特拉文数字','shrd'=>'夏拉达数字','sind'=>'库达瓦迪数字','sinh'=>'僧伽罗文数字','sora'=>'素拉僧平数字','sund'=>'苏丹文数字','takr'=>'泰克里数字','talu'=>'新傣仂文数字','taml'=>'传统泰米尔数字','tamldec'=>'泰米尔数字','telu'=>'泰卢固数字','thai'=>'泰文数字','tibt'=>'藏文数字','tirh'=>'迈蒂利数字','tnsa'=>'坦萨数字','traditional'=>'传统数字','vaii'=>'瓦伊文数字','wara'=>'瓦郎奇蒂数字','wcho'=>'万秋数字')),'codePatterns'=>array('language'=>'语言：%1$s','script'=>'文字：%1$s','territory'=>'地区：%1$s'));
