OC.L10N.register(
    "files_versions",
    {
    "Versions" : "Versioner",
    "This application automatically maintains older versions of files that are changed." : "Den här applikationen behåller automatiskt äldre versioner av filer som ändras.",
    "This application automatically maintains older versions of files that are changed. When enabled, a hidden versions folder is provisioned in every user's directory and is used to store old file versions. A user can revert to an older version through the web interface at any time, with the replaced file becoming a version. The app automatically manages the versions folder to ensure the account does not run out of Quota because of versions.\n\t\tIn addition to the expiry of versions, the versions app makes certain never to use more than 50% of the account's currently available free space. If stored versions exceed this limit, the app will delete the oldest versions first until it meets this limit. More information is available in the Versions documentation." : "Denna applikation hanterar automatiskt äldre versioner av filer när de ändras. När funktionen är aktiverad tillhandahålls en dold versionsmapp i varje användares katalog som används för att lagra gamla filversioner. En användare kan när som helst återgå till en äldre version via webbgränssnittet, när detta görs blir den ersatta filen en version. Appen hanterar automatiskt versionsmappen för att säkerställa att användaren inte får slut på sin kvot på grund av sparade versioner.\nUtöver hantering av utgångna versioner så förvissar sig appen för versionshantering att den inte använder sig av mer än 50% av användarens tillgängliga ledigt utrymme. Om lagrade versioner överskrider denna gräns, kommer appen att ta bort de äldsta versionerna först tills den inte längre överskrider gränsen. Mer information finns i Versionsdokumentationen.",
    "Current version" : "Aktuell version",
    "Initial version" : "Första versionen",
    "You" : "Du",
    "Actions for version from {versionHumanExplicitDate}" : "Åtgärder för version från {versionHumanExplicitDate}",
    "Name this version" : "Namnge denna version",
    "Edit version name" : "Ändra versionsnamn",
    "Compare to current version" : "Jämför med nuvarande version",
    "Restore version" : "Återställ version",
    "Download version" : "Ladda ner version",
    "Delete version" : "Ta bort version",
    "Cancel" : "Avbryt",
    "Remove version name" : "Ta bort versionsnamn",
    "Save version name" : "Spara versionsnamn",
    "Version name" : "Namn på version",
    "Named versions are persisted, and excluded from automatic cleanups when your storage quota is full." : "Namngivna versioner finns kvar och utesluts från automatiska rensningar när din lagringskvot är full.",
    "Initial version restored" : "Ursprunglig version återställd",
    "Version restored" : "Version återställd",
    "Could not restore version" : "Kunde inte återställa versionen",
    "Could not set version label" : "Det gick inte att ange versionsetikett",
    "Could not delete version" : "Det gick inte att ta bort versionen",
    "File versions" : "Filversioner"
},
"nplurals=2; plural=(n != 1);");
