.material-design-icon[data-v-251fe753]{display:flex;align-self:center;justify-self:center;align-items:center;justify-content:center}.settings-section[data-v-251fe753]{display:block;margin-bottom:auto;padding:30px}.settings-section[data-v-251fe753]:not(:last-child){border-bottom:1px solid var(--color-border)}.settings-section--limit-width>*[data-v-251fe753]{max-width:900px}.settings-section__name[data-v-251fe753]{display:inline-flex;align-items:center;justify-content:center;font-size:20px;font-weight:700;max-width:900px}.settings-section__info[data-v-251fe753]{display:flex;align-items:center;justify-content:center;width:var(--default-clickable-area);height:var(--default-clickable-area);margin:calc((var(--default-clickable-area) - 16px) / 2 * -1);margin-left:0;color:var(--color-text-maxcontrast)}.settings-section__info[data-v-251fe753]:hover,.settings-section__info[data-v-251fe753]:focus,.settings-section__info[data-v-251fe753]:active{color:var(--color-main-text)}.settings-section__desc[data-v-251fe753]{margin-top:-.2em;margin-bottom:1em;color:var(--color-text-maxcontrast);max-width:900px}.settings__field[data-v-a2fa1167]{max-width:500px}
