OC.L10N.register(
    "contactsinteraction",
    {
    "Recently contacted" : "Nýlega haft samband við",
    "Contacts Interaction" : "Gagnvirkni tengiliða",
    "Manages interaction between accounts and contacts" : "Stýrir gagnvirkni milli notendaaðganga og tengiliða",
    "Collect data about accounts and contacts interactions and provide an address book for the data" : "Safnaðu gögnum um samskipti milli notenda og tengiliða og gefðu upp nafnaskrá fyrir gögnin"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
