OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "Downloadlimiet bestanden",
    "File link share download limit" : "Bestand deel link download limiet",
    "Limit downloads" : "Beperk downloads",
    "Set download limit" : "Stel downloadlimiet in",
    "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["1 resterende download toegestaan","{count} resterende downloads toegestaan"],
    "Download limit" : "Downloadlimiet"
},
"nplurals=2; plural=(n != 1);");
