<?php
// This file was auto-generated from sdk-root/src/data/controlcatalog/2018-05-10/paginators-1.json
return [ 'pagination' => [ 'ListCommonControls' => [ 'input_token' => 'NextToken', 'output_token' => 'NextToken', 'limit_key' => 'MaxResults', 'result_key' => 'CommonControls', ], 'ListControls' => [ 'input_token' => 'NextToken', 'output_token' => 'NextToken', 'limit_key' => 'MaxResults', 'result_key' => 'Controls', ], 'ListDomains' => [ 'input_token' => 'NextToken', 'output_token' => 'NextToken', 'limit_key' => 'MaxResults', 'result_key' => 'Domains', ], 'ListObjectives' => [ 'input_token' => 'NextToken', 'output_token' => 'NextToken', 'limit_key' => 'MaxResults', 'result_key' => 'Objectives', ], ],];
