OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Tuvastasin uue sisselogimise asukoha",
    "More info about the suspicious IP address available on %s" : "Lisateave kahtlaste ip-aadresside kohta on saadaval: %s",
    "Open %s ↗" : "Ava %s ↗",
    "Suspicious Login" : "Kahtlane sisselogimine",
    "New login detected" : "Tuvastasin uue sisselogimise",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Tuvasta ja hoiata kahtlaste Nextcloudi sisselogimiste ip-aadressidest\n\t",
    "Suspicious login detection" : "Kahtaste sisselogimiste tuvastamine",
    "IPv4" : "IPv4"
},
"nplurals=2; plural=(n != 1);");
