OC.L10N.register(
    "notifications",
    {
    "Hello %s" : "Здраво %s",
    "Hello %s," : "Здраво %s,",
    "Notifications" : "Obaveštenja",
    "Dismiss" : "Odbaci",
    "in {path}" : "у {path}",
    "No notifications" : "Nema obaveštenja",
    "Never" : "Nikad",
    "1 hour" : "1 sat",
    "3 hours" : "3 sata",
    "Your settings have been updated." : "Ваше поставке су ажуриране.",
    "None" : "Ništa",
    "You need to set up your email address before you can receive notification emails." : "Морате поставити адресу е-поште пре почетка пријема обавештења.",
    "seconds ago" : "pre nekoliko sekundi"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
