OC.L10N.register(
    "files_trashbin",
    {
    "restored" : "بازیابی شد",
    "Deleted files" : "فایل های حذف شده",
    "Deleted files and folders in the trash bin (may expire during export if you are low on storage space)" : "Deleted files and folders in the trash bin (may expire during export if you are low on storage space)",
    "Restore" : "بازیابی",
    "Cancel" : "منصرف شدن",
    "Deleted" : "حذف شده",
    "A long time ago" : "مدت ها پیش",
    "Unknown" : "ناشناخته",
    "All files" : "تمامی فایل‌ها",
    "You" : "You",
    "List of files that have been deleted." : "List of files that have been deleted.",
    "No deleted files" : "هیچ فایل حذف شده وجود ندارد",
    "Files and folders you have deleted will show up here" : "Files and folders you have deleted will show up here",
    "Deletion cancelled" : "Deletion cancelled"
},
"nplurals=2; plural=(n > 1);");
