OC.L10N.register(
    "photos",
    {
    "Public link" : "Avalik link",
    "Photos" : "Fotod",
    "On This Day" : "Täna, läbi ajaloo",
    "Your memories under your control" : "Sinu mälestused sinu kontrolli all",
    "All media" : "Kogu meedia",
    "Videos" : "Videod",
    "Albums" : "Albumid",
    "Collaborative albums" : "Kaastööalbumid",
    "People" : "Inimese",
    "Folders" : "Kaustad",
    "Favorites" : "Lemmikud",
    "On this day" : "Sel päeval",
    "Shared with you" : "Sinuga jagatud",
    "Tags" : "Sildid",
    "Places" : "Kohad",
    "Map" : "Kaart",
    "Photos settings" : "Fotode seaded",
    "Mark selection as favorite" : "Märgi valitud lemmikuks",
    "Add selection to favorites" : "Lisa valitud lemmikute hulka",
    "Remove selection from favorites" : "Eemalda valitud lemmikute hulgast",
    "Name of the album" : "Albumi nimi",
    "Location of the album" : "Albumi asukoht",
    "Back" : "Tagasi",
    "Add collaborators" : "Lisa kaasautorid",
    "Save" : "Salvesta",
    "Create album" : "Loo album",
    "Add to Album" : "Lisa albumisse",
    "Add selection to album {albumName}" : "Lisa valitud albumisse {albumName}",
    "Shared by" : "Jagas",
    "Create a new album." : "Loo uus album.",
    "Create new album" : "Loo uus album",
    "New album" : "Uus album",
    "_%n item_::_%n photos and videos_" : ["%n objekt","%n fotot ja videot"],
    "Failed to fetch collaborators list." : "Kaasautorite loendi laadimine ei õnnestunud.",
    "Failed to update album." : "Albumi muutmine ebaõnnestus.",
    "Add people or groups who can edit your album" : "Lisa inimesi ja gruppe, kes võivad su albumit muuta",
    "Search people or groups" : "Otsi inimesi või gruppe",
    "No recommendations. Start typing." : "Soovitusi pole. Alusta trükkimist.",
    "Group" : "Grupp",
    "Remove {collaboratorLabel} from the collaborators list" : "Eemalda {collaboratorLabel} kaasautorite hulgast",
    "Copy the public link" : "Kopeeri avalik link",
    "Public link copied!" : "Avalik link kopeeritud!",
    "Copy public link" : "Kopeeri avalik link",
    "Delete the public link" : "Kustuta avalik link",
    "Create public link share" : "Jaga avaliku lingiga",
    "Share via public link" : "Jaga avaliku lingi kaudu",
    "This collection does not exist" : "Seda kollektsiooni pole olemas",
    "An error occurred" : "Tekkis tõrge",
    "No picture for this day" : "Selleks päevaks ei ole pilti",
    "Picture taken on this day will show up here." : "Sellel päeval tehtud pilt ilmub siia.",
    "More photos from this day" : "Rohkem pilte tänasest",
    "_%n photos_::_%n photos_" : ["%n foto","%n fotot"],
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n määramata foto","%n määramata fotot"],
    "Favorite" : "Lemmik",
    "Favorite image, open the full size \"{name}\" image" : "Lemmikpilt, ava täissuuruses \"{name}\" pilt",
    "Open the full size \"{name}\" image" : "Ava pilt \"{name}\" täissuuruses",
    "Select image {imageName}" : "Vali pilt {imageName}",
    "Open the \"{name}\" folder" : "Ava kaust \"{name}\"",
    "Go back" : "Mine tagasi",
    "Date range" : "Kuupäevade vahemik",
    "Select a date range" : "Vali kuupäevavahemik",
    "Select places" : "Vali asukohad",
    "Dates" : "Kuupäevad",
    "Jump to specific date in list" : "Hüppa nimekirjas kindlale kuupäevale",
    "Jump to {date}" : "Hüppa {date} juurde",
    "Add to {destination}" : "Lisa {destination}-sse",
    "The destination folder is owned by {owner}" : "Sihtkausta omanik on {owner}",
    "There are no photos or videos yet!" : "Ühtegi fotot ega videot pole veel!",
    "_{years} year ago_::_{years} years ago_" : ["{years} aasta tagasi","{years} aastat tagasi"],
    "Enable squared photos view" : "Luba piltide ruutvaade",
    "Delete source directory" : "Kustuta lähtekaust",
    "Pick folder" : "Vali kaust",
    "Select a source folder for your media" : "Vali oma meediale lähtekaust",
    "All folders" : "Kõik kaustad",
    "Add a Photos source for the timelines" : "Lisa fotode allikas ajajoonele",
    "Add folder" : "Lisa kaust",
    "Select the default upload location for your media" : "Vali oma meediale vaikimisi üleslaadimise kaust",
    "Home" : "Avaleht",
    "Choose default Photos upload and Albums location" : "Vali vaikimisi fotode üleslaadimise ja albumite asukoht",
    "Choose a different folder" : "Vali mõni muu kaust",
    "View" : "Vaata",
    "Media folders" : "Meediakaustad",
    "Choose the folders from where photos and videos are shown." : "Vali kaustad, kust fotosid ja videoid näidatakse.",
    "Upload folder" : "Üleslaadimiskaust",
    "Choose the folder where photos and albums are uploaded to." : "Vali kaust, kuhu fotod ja albumid üles laaditakse",
    "_%n photo_::_%n photos_" : ["%n foto","%n fotot"],
    "Unselect all" : "Eemalda kogu valik",
    "Toggle filter" : "Lülita filter sisse/välja",
    "Add photos to this album" : "Lisa sellesse albumisse fotosid",
    "Manage collaborators for this album" : "Halda selle albumi kaasautoreid",
    "Open actions menu" : "Ava tegevuste menüü",
    "Edit album details" : "Muuda albumi üksikasju",
    "Download all files in album" : "Laadi kõik albumi failid alla",
    "Delete album" : "Kustuta album",
    "Download selected files" : "Laadi valitud failid alla",
    "Remove selection from album" : "Eemalda valitud failid albumist",
    "This album does not have any photos or videos yet!" : "Selles albumis pole veel ühtegi fotot ega videot!",
    "Add photos to {albumName}" : "Lisa fotosid albumisse „{albumName}“",
    "Manage collaborators" : "Halda kaasautoreid",
    "Save collaborators for this album." : "Salvesta selle albumi kaasautorid.",
    "Cover photo for album {albumName}" : " „{albumName}“ albumi kaanepilt",
    "There is no album yet!" : "Ühtegi albumit pole veel!",
    "This person could not be found" : "Seda isikut ei leidu",
    "Rename person" : "Muuda isiku nime",
    "Merge with different person" : "Ühenda teise isikuga",
    "Download selected photos" : "Laadi valitud fotod alla",
    "Remove from favorites" : "Eemalda lemmikutest",
    "Remove person" : "Eemalda isik",
    "Name of this person" : "Isiku nimi",
    "Save." : "Salvesta.",
    "Merge person" : "Ühenda isik",
    "Move to different person" : "Liiguta teise isiku külge",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Liiguta foto teise isiku külge","Liiguta fotod teise isiku külge"],
    "_Remove photo from person_::_Remove photos from person_" : ["Eemalda foto isiku küljest","Eemalda fotod isiku küljest"],
    "This might take some time depending on the size of your photo library." : "See võib sõltuvalt fototeegi suurusest natuke aega võtta.",
    "Recognized people will show up here" : "Siin näidatakse tuvastatud inimesi",
    "This folder does not exist" : "Seda kausta pole olemas",
    "Loading folders …" : "Kaustada laadimine …",
    "No photos in here" : "Siin ei ole fotosid",
    "Taken on {date} at {time}" : "Pildistatud {date} {time}",
    "This place does not have any photos or videos yet!" : "Siin kohas pole veel ühtegi fotot ega videot!",
    "Add photos to this place" : "Lisa siia kohta fotosid",
    "Cover photo for place {placeName}" : "Koha {placeName} kaanepilt",
    "There is no place yet!" : "Ühtegi kohta pole veel!",
    "Cover photo for shared album {albumName}" : "Jagatud albumi „{albumName}“ kaanepilt",
    "Back to tags overview" : "Tagasi siltide ülevaatesse",
    "No photos with this tag yet" : "Selle sildiga pole veel fotosid",
    "No tags yet" : "Silte pole veel",
    "Photos with tags will show up here" : "Siin näidatakse sildistatud fotosid",
    "Popular tags" : "Populaarsed sildid",
    "All tags" : "Kõik sildid",
    "Create new album from filters" : "Loo uus album filtrite alusel",
    "One of the source folders does not exist" : "Ühte lähtekaustadest pole olemas",
    "Add to album" : "Lisa albumisse",
    "Delete selection" : "Kustuta valik",
    "No photos or videos in here" : "Siin pole fotosid ega videosid",
    "Unassigned faces" : "Määramata näod",
    "Failed to fetch collection." : "Kollektsiooni laadimine ebaõnnestus.",
    "Failed to fetch collections list." : "Kollektsioonide loendi laadimine ebaõnnestus.",
    "Failed to fetch faces list." : "Nägude loendi laadimine ebaõnnestus.",
    "Error fetching files" : "Viga failide laadimisel",
    "All your media" : "Kogu su meedia",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "Jagatud albumid",
    "Shared album {title}" : "Jagatud album {title}",
    "Public album {title}" : "Avalik album {title}",
    "Tagged photos" : "Sildistatud fotod",
    "Tagged photo {title}" : "Sildistatud foto {title}",
    "{title}'s face" : "{title} nägu",
    "{startDate} to {endDate}" : "{startDate} kuni {endDate}",
    "Details" : "Üksikasjad",
    "Failed to add {fileBaseName} to collection {collectionFileName}" : "„{fileBaseName}“ lisamine „{collectionFileName}“ kogumikku ei õnnestunud",
    "Failed to delete {fileBaseName}" : "Ei õnnestunud kustutada: „{fileBaseName}“",
    "Failed to create {collectionFileName}" : "„{collectionFileName}“ loomine ei õnnestunud",
    "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "Ei õnnestunud muuta nime: „{currentCollectionFileName}“ → „{newCollectionFileName}“",
    "Failed to update properties of {collectionFileName} with {properties}" : "„{collectionFileName}“ faili „{properties}“ omaduste muutmine ei õnnestunud",
    "Failed to delete {collectionFileName}" : "Ei õnnestunud kustutada: „{collectionFileName}“",
    "Failed to move {fileBaseName} to person {faceName}" : "„{fileBaseName}“ teisaldamine kasutajale „{faceName}“ ei õnnestunud",
    "Failed to remove {fileBaseName}" : "„{fileBaseName}“ eemaldamine ei õnnestunud",
    "Failed to rename {oldName} to {faceName}" : "Ei õnnestunud muuta nime: „{oldName}“ → „{faceName}“",
    "Failed to delete {faceName}" : "Ei õnnestunud kustutada: „{faceName}“",
    "Failed to delete {fileId}" : "Ei õnnestunud kustutada: „{fileId}“",
    "Failed to delete {fileName}" : "Ei õnnestunud kustutada: „{fileName}“",
    "Failed to set favorite state for {fileId}" : "Ei õnnestunud määrata olekut lemmikuna: „{fileId}“",
    "Failed to set favorite state for {fileName}" : "Ei õnnestunud määrata olekut lemmikuna: „{fileName}“",
    "Could not load photos folder" : "Fotode kausta laadimine ei õnnestunud",
    "Back to {folder}" : "Tagasi kausta {folder}",
    "Share this folder" : "Jaga seda kausta",
    "One of the source folders does not exists" : "Ühte lähtekaustadest pole olemas",
    "Add" : "Lisa"
},
"nplurals=2; plural=(n != 1);");
