OC.L10N.register(
    "sharebymail",
    {
    "Shared with {email}" : "Delt med {email}",
    "Shared with {email} by {actor}" : "Delt med {email} af {actor}",
    "Unshared from {email}" : "Slet deling med {email}",
    "Unshared from {email} by {actor}" : "Slet deling med {email} af {actor}",
    "Password for mail share sent to {email}" : "Adgangskode for maildeling er sendt til {email}",
    "Password for mail share sent to you" : "Adgangskode for maildeling er sendt til dig",
    "You shared {file} with {email} by mail" : "Du delte {file} med {email} via e-mail",
    "{actor} shared {file} with {email} by mail" : "{actor} delte {file} med {email} via e-mail",
    "You unshared {file} from {email} by mail" : "Du slettede deling af {file} med {email} via mail",
    "{actor} unshared {file} from {email} by mail" : "{actor} slettede deling af {file} fra {email} via mail",
    "Password to access {file} was sent to {email}" : "Adgangskode for adgang {file} blev sendt til {email}",
    "Password to access {file} was sent to you" : "Adgangskode for adgang {file} blev sendt til dig.",
    "Share by mail" : "Delt med mail",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Deling af %1$s mislykkedes, fordi dette element allerede er delt med bruger%2$s",
    "We cannot send you the auto-generated password. Please set a valid email address in your personal settings and try again." : "Vi kan ikke sende dig det autogenererede kodeord. Angiv en gyldig e-mailadresse i dine personlige indstillinger og prøv igen.",
    "Failed to send share by email. Got an invalid email address" : "Kunne ikke sende deling via mail. Fik en ugyldig mail adresse",
    "Failed to send share by email" : "Kunne ikke sende deling via e-mail",
    "%1$s shared %2$s with you" : " %1$s delte %2$s med dig",
    "Note:" : "Bemærkning:",
    "This share is valid until %s at midnight" : "Denne deling gælder indtil %s ved midnat",
    "Expiration:" : "Udløbsdato:",
    "Open %s" : "Åbn% s",
    "%1$s via %2$s" : "%1$s via %2$s",
    "%1$s shared %2$s with you. You should have already received a separate mail with a link to access it." : "%1$s delte %2$s med dig. Du skulle allerede have modtaget en separat mail med et link til at få adgang til den.",
    "Password to access %1$s shared to you by %2$s" : "Adgangskode for adgang til %1$s delt med dig af %2$s",
    "Password to access %s" : "Adgangskode til adgang %s",
    "It is protected with the following password:" : "Beskyttet med følgende adgangskode:",
    "This password will expire at %s" : "Denne adgangskode udløber den %s",
    "%1$s shared %2$s with you and wants to add:" : " %1$s delte %2$s med dig og ønsker at tilføje:",
    "%1$s shared %2$s with you and wants to add" : " %1$s delte %2$s med dig og ønsker at tilføje",
    "%s added a note to a file shared with you" : "%s tilføjede en note til en fil delt med dig",
    "You just shared %1$s with %2$s. The share was already sent to the recipient. Due to the security policies defined by the administrator of %3$s each share needs to be protected by password and it is not allowed to send the password directly to the recipient. Therefore you need to forward the password manually to the recipient." : "Du delte lige %1$s med %2$s. Delingen blev allerede sendt til modtageren. På grund af sikkerhedspolitikkerne defineret af administratoren af %3$s hver deling skal beskyttes med adgangskode, og det er ikke tilladt at sende adgangskoden direkte til modtageren. Derfor skal du sende adgangskoden manuelt til modtageren.",
    "Password to access %1$s shared by you with %2$s" : "Adgangskode for adgang til %1$s delt af dig med %2$s",
    "This is the password:" : "Dette er adgangskoden:",
    "You can choose a different password at any time in the share dialog." : "Du kan til enhver tid vælge en anden adgangskode i delings dialogen.",
    "Could not find share" : "Kan ikke finde deling",
    "Share provider which allows you to share files by mail" : "Del udbyder, som giver dig mulighed for at dele filer via mail",
    "Unable to update share by mail config" : "Kan ikke opdatere del via mail konfigurationen",
    "Allows people to share a personalized link to a file or folder by putting in an email address." : "Giver folk mulighed for at dele et personlig link til en fil eller mappe ved at indsætte en mail adresse.",
    "Send password by mail" : "Send kodeord på mail",
    "Reply to initiator" : "Svar til initiativtager"
},
"nplurals=2; plural=(n != 1);");
