<?php
// This file is auto-generated. Do not edit!
return array('Ahom'=>'Ahom','Nagm'=>'Nagm','Vith'=>'Vith','Wcho'=>'万秋文','Syrn'=>'东叙利亚文','Ugar'=>'乌加里特文','Sgnw'=>'书写符号','Armn'=>'亚美尼亚文','Sind'=>'信德文','Hrkt'=>'假名表','Lisu'=>'傈僳文','Sinh'=>'僧伽罗文','Kpel'=>'克佩列文','Khoj'=>'克吉奇文字','Copt'=>'克普特文','Kali'=>'克耶李文字','Phag'=>'八思巴文','Lana'=>'兰拿文','Kthi'=>'凯提文','Cher'=>'切罗基文','Lyci'=>'利西亚文','Cans'=>'加拿大土著统一音节','Pauc'=>'包金豪文','Cham'=>'占文','Knda'=>'卡纳达文','Kawi'=>'卡维文','Khar'=>'卡罗须提文','Cari'=>'卡里亚文','Inds'=>'印度河文字','Syrc'=>'叙利亚文','Runr'=>'古代北欧文','Hung'=>'古匈牙利文','Narb'=>'古北方阿拉伯文','Sarb'=>'古南阿拉伯文','Gujr'=>'古吉拉特文','Egyh'=>'古埃及僧侣书写体','Egyp'=>'古埃及象形文','Perm'=>'古彼尔姆文','Ital'=>'古意大利文','Xpeo'=>'古波斯文','Sogo'=>'古粟特文','Visp'=>'可见语言','Egyd'=>'后期埃及文','Lydi'=>'吕底亚文','Rohg'=>'哈乃斐文','Hatr'=>'哈特兰文','Goth'=>'哥特文','Tang'=>'唐古特文','Ougr'=>'回鹘文','Tnsa'=>'坦萨文','Elym'=>'埃利迈文','Ethi'=>'埃塞俄比亚文','Tglg'=>'塔加路文','Thaa'=>'塔安那文','Tagb'=>'塔格班瓦文','Cprt'=>'塞浦路斯文','Cpmn'=>'塞浦路斯米诺斯文','Shrd'=>'夏拉达文','Dogr'=>'多格拉文','Marc'=>'大玛尔文','Deva'=>'天城文','Kits'=>'契丹小字','Osma'=>'奥斯曼亚文','Orya'=>'奥里亚文','Nshu'=>'女书','Jurc'=>'女真文','Brah'=>'婆罗米文字','Beng'=>'孟加拉文','Hluw'=>'安那托利亚象形文字','Hmnp'=>'尼亚肯蒲丘苗文','Newa'=>'尼瓦文','Phlv'=>'巴列维文（书体）','Phlp'=>'巴列维文（圣诗体）','Phli'=>'巴列维文碑铭体','Bali'=>'巴厘文','Batk'=>'巴塔克文','Bamu'=>'巴姆穆文','Bass'=>'巴萨文','Sund'=>'巽他文','Blis'=>'布列斯符号','Bugi'=>'布吉文','Buhd'=>'布希德文','Brai'=>'布莱叶盲文','Hebr'=>'希伯来文','Grek'=>'希腊文','Palm'=>'帕尔迈拉文','Prti'=>'帕提亚文碑铭体','Hira'=>'平假名','Yiii'=>'彝文','Dsrt'=>'德塞莱特文','Sidd'=>'悉昙文','Toto'=>'投投文','Latn'=>'拉丁文','Latf'=>'拉丁文（哥特式字体变体）','Latg'=>'拉丁文（盖尔文变体）','Rjng'=>'拉让文','Bhks'=>'拜克舒克文','Tfng'=>'提非纳文','Mani'=>'摩尼教文','Samr'=>'撒马利亚文','Zmth'=>'数学符号','Talu'=>'新傣文','Jpan'=>'日文','Mtei'=>'曼尼普尔文','Roro'=>'朗格朗格文','Maka'=>'望加锡文','Zzzz'=>'未知文字','Zanb'=>'札那巴札尔方块文字','Dupl'=>'杜普洛伊速记','Hmng'=>'杨松录苗文','Limb'=>'林布文','Guru'=>'果鲁穆奇文','Cakm'=>'查克马文','Gran'=>'格兰塔文','Glag'=>'格拉哥里文','Geor'=>'格鲁吉亚文','Geok'=>'格鲁吉亚文（教堂体）','Olck'=>'桑塔利文','Medf'=>'梅德法伊德林文','Nand'=>'楠迪梵文','Osge'=>'欧塞奇文','Ogam'=>'欧甘文','Hano'=>'汉奴罗文','Hani'=>'汉字','Bopo'=>'汉语拼音','Hanb'=>'汉语注音','Wole'=>'沃莱艾文','Sara'=>'沙拉堤文','Plrd'=>'波拉德音标文字','Aran'=>'波斯体','Tale'=>'泰乐文','Takr'=>'泰克里文','Telu'=>'泰卢固文','Thai'=>'泰文','Taml'=>'泰米尔文','Loma'=>'洛马文','Qaag'=>'照济文','Java'=>'爪哇文','Elba'=>'爱尔巴桑文','Kana'=>'片假名','Maya'=>'玛雅圣符文','Vaii'=>'瓦依文','Wara'=>'瓦郎奇蒂文字','Armi'=>'皇室亚拉姆文','Syre'=>'福音体叙利亚文','Mult'=>'穆尔坦文','Moon'=>'穆恩字母','Zsym'=>'符号','Hans'=>array(''=>'简体','stand-alone'=>array('简体中文')),'Sogd'=>'粟特文','Saur'=>'索拉什特拉文','Sora'=>'索朗桑朋文','Soyo'=>'索永布文','Hant'=>array(''=>'繁体','stand-alone'=>array('繁体中文')),'Nbat'=>'纳巴泰文','Nkgb'=>'纳西格巴文','Lina'=>'线形文字（A）','Linb'=>'线形文字（B）','Mymr'=>'缅甸文','Laoo'=>'老挝文','Phnx'=>'腓尼基文','Teng'=>'腾格瓦文字','Cirt'=>'色斯文','Chrs'=>'花拉子模文','Xsux'=>'苏美尔-阿卡德楔形文字','Modi'=>'莫迪文','Shaw'=>'萧伯纳式文','Mong'=>'蒙古文','Tibt'=>'藏文','Zsye'=>'表情符号','Syrj'=>'西叙利亚文','Cyrl'=>'西里尔文','Cyrs'=>'西里尔文字（古教会斯拉夫文的变体）','Nkoo'=>'西非书面文字（N’Ko）','Hang'=>'谚文','Mroo'=>'谬文','Gong'=>'贡贾拉贡德文','Tavt'=>'越南傣文','Tirh'=>'迈蒂利文','Diak'=>'迪维西阿库鲁文','Zyyy'=>'通用','Zinh'=>'遗传学术语','Orkh'=>'鄂尔浑文','Sylo'=>'锡尔赫特文','Mend'=>'门迪文','Adlm'=>'阿德拉姆文','Arab'=>array(''=>'阿拉伯文','variant'=>array('波斯阿拉伯文')),'Mand'=>'阿拉米文','Afak'=>'阿法卡文','Avst'=>'阿维斯陀文','Yezi'=>'雅兹迪文','Lepc'=>'雷布查文','Zxxx'=>'非书面文字','Kore'=>'韩文','Jamo'=>'韩文字母','Mlym'=>'马拉雅拉姆文','Gonm'=>'马萨拉姆冈德文','Aghb'=>'高加索阿尔巴尼亚文','Khmr'=>'高棉文','Merc'=>'麦罗埃草书','Mero'=>'麦若提克文','Mahj'=>'默哈金文');
