OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "First run wizard",
    "Add your profile information! For example your email is needed to receive notifications." : "Add your profile information! For example your email is needed to receive notifications.",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "Add your profile information! For example your email is needed to receive notifications and reset your password.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Add your profile information! Set a profile picture and full name for easier recognition across all features.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Add your profile information! Set a full name for easier recognition across all features.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Add your profile information! Set a profile picture for easier recognition across all features.",
    "Schedule work & meetings, synced with all your devices." : "Schedule work & meetings, synced with all your devices.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Keep your colleagues and friends in one place without leaking their private info.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Simple email app nicely integrated with Files, Contacts and Calendar.",
    "App recommendation: Tasks" : "App recommendation: Tasks",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "Sync tasks from various devices with your Nextcloud and edit them online.",
    "App recommendation: Deck" : "App recommendation: Deck",
    "Kanban style organization for personal planning and team projects." : "Kanban style organization for personal planning and team projects.",
    "App recommendation: Forms" : "App recommendation: Forms",
    "Simple surveys and questionnaires, self-hosted" : "Simple surveys and questionnaires, self-hosted",
    "App recommendation: Recognize" : "App recommendation: Recognize",
    "Smart media tagging for Nextcloud" : "Smart media tagging for Nextcloud",
    "App recommendation: Group folders" : "App recommendation: Group folders",
    "Admin-configured folders shared by everyone in a group." : "Admin-configured folders shared by everyone in a group.",
    "Connect your calendar" : "Connect your calendar",
    "Connect your contacts" : "Connect your contacts",
    "Access files via WebDAV" : "Access files via WebDAV",
    "Download macOS/iOS configuration profile" : "Download macOS/iOS configuration profile",
    "Desktop client" : "Desktop client",
    "Android app on Google Play Store" : "Android app on Google Play Store",
    "Android app on F-Droid" : "Android app on F-Droid",
    "iOS app" : "iOS app",
    "A welcome and introduction wizard for Nextcloud" : "A welcome and introduction wizard for Nextcloud",
    "This application enables a pop-up window when a user first logs into Nextcloud. This window welcomes new users to Nextcloud, and contains links to the standard desktop client, Android app, and the iOS app. The window also shows a link for accessing Nextcloud via WebDAV. At any time, the first run wizard can be opened again via link \"About\" on settings menu.\nThe First run wizard can be customized to meet specific design goals, or to change links and messages. Create an appropriate theme following the Theming documentation, and changes to the look and feel of this Wizard are simple. More information is available in the first run wizard documentation, as well as the theming documentation." : "This application enables a pop-up window when a user first logs into Nextcloud. This window welcomes new users to Nextcloud, and contains links to the standard desktop client, Android app, and the iOS app. The window also shows a link for accessing Nextcloud via WebDAV. At any time, the first run wizard can be opened again via link \"About\" on settings menu.\nThe First run wizard can be customized to meet specific design goals, or to change links and messages. Create an appropriate theme following the Theming documentation, and changes to the look and feel of this Wizard are simple. More information is available in the first run wizard documentation, as well as the theming documentation.",
    "Download on Apple app store" : "Download on Apple app store",
    "Download on Google play store" : "Download on Google play store",
    "Go to previous page" : "Go to previous page",
    "Close" : "Close",
    "More about Nextcloud" : "More about Nextcloud",
    "Explore more apps ↗" : "Explore more apps ↗",
    "Extend the functionality of Nextcloud with hundreds of community-developed apps." : "Extend the functionality of Nextcloud with hundreds of community-developed apps.",
    "Get involved! ↗" : "Get involved! ↗",
    "Be a part of the community that helps build, design, translate and promote Nextcloud!" : "Be a part of the community that helps build, design, translate and promote Nextcloud!",
    "Need help? ↗" : "Need help? ↗",
    "Find out more about your Nextcloud setup with the admin, user or developer documentation." : "Find out more about your Nextcloud setup with the admin, user or developer documentation.",
    "For large organisations ↗" : "For large organisations ↗",
    "Get Nextcloud Enterprise for mission critical environments where advanced security and compliance are important." : "Get Nextcloud Enterprise for mission critical environments where advanced security and compliance are important.",
    "Seamless integration with your devices." : "Seamless integration with your devices.",
    "Sync your files across your devices with the desktop and mobile apps, and connect your calendar and contacts." : "Sync your files across your devices with the desktop and mobile apps, and connect your calendar and contacts.",
    "Desktop app ↗" : "Desktop app ↗",
    "Download For Windows, Mac OS and Linux." : "Download For Windows, Mac OS and Linux.",
    "Calendar and contacts ↗" : "Calendar and contacts ↗",
    "Connect your calendar and contacts with your devices." : "Connect your calendar and contacts with your devices.",
    "Welcome to {cloudName}!" : "Welcome to {cloudName}!",
    "A collaboration platform that puts you in control" : "A collaboration platform that puts you in control",
    "Privacy" : "Privacy",
    "Host your data and files where you decide." : "Host your data and files where you decide.",
    "Productivity" : "Productivity",
    "Collaborate and communicate across any platform." : "Collaborate and communicate across any platform.",
    "Interoperability" : "Interoperability",
    "Import and export anything you want with open standards." : "Import and export anything you want with open standards.",
    "Community" : "Community",
    "Enjoy constant improvements from a thriving open-source community." : "Enjoy constant improvements from a thriving open-source community.",
    "Get the apps to sync your files" : "Get the apps to sync your files",
    "Server address" : "Server address",
    "Use this link to connect your apps and desktop client to this server:" : "Use this link to connect your apps and desktop client to this server:",
    "What's new?" : "What's new?",
    "Nextcloud on all your devices" : "Nextcloud on all your devices",
    "Read more" : "Read more",
    "Share on social media" : "Share on social media",
    "Get started!" : "Get started!",
    "App recommendation: Nextcloud Calendar" : "App recommendation: Nextcloud Calendar",
    "App recommendation: Nextcloud Contacts" : "App recommendation: Nextcloud Contacts",
    "App recommendation: Nextcloud Mail" : "App recommendation: Nextcloud Mail"
},
"nplurals=2; plural=(n!=1);");
