OC.L10N.register(
    "files_sharing",
    {
    "File shares" : "Dosya paylaşımları",
    "Downloaded via public link" : "Herkese açık bağlantı ile indirildi",
    "Downloaded by {email}" : "{email} tarafından indirildi",
    "{file} downloaded via public link" : "{file} herkese açık bağlantı ile indirildi",
    "{email} downloaded {file}" : "{email} {file} dosyasını indirdi",
    "Shared with group {group}" : "{group} grubuyla paylaşıldı",
    "Removed share for group {group}" : "{group} grubunun paylaşımı kaldırıldı",
    "{actor} shared with group {group}" : "{actor} {group} grubuyla paylaştı",
    "{actor} removed share for group {group}" : "{actor} {group} grubunun paylaşımını kaldırdı",
    "Share for group {group} expired" : "{group} grubuyla paylaşımın geçerlilik süresi dolmuş",
    "You shared {file} with group {group}" : "{file} dosyasını {group} grubuyla paylaştınız",
    "You removed group {group} from {file}" : "{file} dosyasının {group} grubuyla paylaşımını kaldırdınız",
    "{actor} shared {file} with group {group}" : "{actor} {file} dosyasını {group} grubuyla paylaştı",
    "{actor} removed group {group} from {file}" : "{actor} {file} dosyasının {group} grubuyla paylaşımını kaldırdı",
    "Share for file {file} with group {group} expired" : "{file} dosyasının {group} grubuyla paylaşımının geçerlilik süresi dolmuş",
    "Shared as public link" : "Herkese açık bağlantı olarak paylaşıldı",
    "Removed public link" : "Herkese açık bağlantı kaldırıldı",
    "Public link expired" : "Herkese açık bağlantının geçerlilik süresi dolmuş",
    "{actor} shared as public link" : "{actor} herkese açık bağlantı olarak paylaştı",
    "{actor} removed public link" : "{actor} herkese açık paylaşım bağlantısını kaldırdı",
    "Public link of {actor} expired" : "{actor} tarafından paylaşılan herkese açık bağlantının geçerlilik süresi dolmuş",
    "You shared {file} as public link" : "{file} dosyasını herkese açık bağlantı olarak paylaştınız",
    "You removed public link for {file}" : "{file} dosyasının herkese açık paylaşım bağlantısını kaldırdınız",
    "Public link expired for {file}" : "{file} için herkese açık bağlantının geçerlilik süresi dolmuş",
    "{actor} shared {file} as public link" : "{actor} {file} dosyasını herkese açık bağlantı olarak paylaştı",
    "{actor} removed public link for {file}" : "{actor} {file} dosyasının herkese açık paylaşım bağlantısını kaldırdı",
    "Public link of {actor} for {file} expired" : "{actor} tarafından paylaşılan {file} dosyası bağlantısının geçerlilik süresi dolmuş",
    "{user} accepted the remote share" : "{user} uzak paylaşımı kabul etti",
    "{user} declined the remote share" : "{user} uzak paylaşımı reddetti",
    "You received a new remote share {file} from {user}" : "{user} kullanıcısından yeni bir uzak {file} dosya paylaşımı aldınız",
    "{user} accepted the remote share of {file}" : "{user} uzak {file} dosyasının paylaşımını kabul etti",
    "{user} declined the remote share of {file}" : "{user} uzak {file} dosyasının paylaşımını reddetti",
    "{user} unshared {file} from you" : "{user} sizinle {file} dosyasının paylaşımını kaldırdı",
    "Shared with {user}" : "{user} ile paylaşıldı",
    "Removed share for {user}" : "{user} kullanıcı ile paylaşım kaldırıldı",
    "You removed yourself" : "Kendinizi kaldırdınız",
    "{actor} removed themselves" : "{actor} kendini kaldırdı",
    "{actor} shared with {user}" : "{actor} {user} kullanıcısıyla paylaştı",
    "{actor} removed share for {user}" : "{actor} {user} kullanıcısının paylaşımını kaldırdı",
    "Shared by {actor}" : "{actor} tarafından paylaşıldı",
    "{actor} removed share" : "{actor} paylaşımı kaldırdı",
    "Share for {user} expired" : "{user} kullanıcısı ile paylaşımın geçerlilik süresi dolmuş",
    "Share expired" : "Paylaşımın geçerlilik süresi dolmuş",
    "You shared {file} with {user}" : "{file} dosyasını {user} kullanıcısıyla paylaştınız",
    "You removed {user} from {file}" : "{file} dosyasının {user} kullanıcısıyla paylaşımını kaldırdınız",
    "You removed yourself from {file}" : "Kendinizi {file} dosyasından kaldırdınız",
    "{actor} removed themselves from {file}" : "{actor} kendini {file} dosyasından kaldırdı",
    "{actor} shared {file} with {user}" : "{actor} {file} dosyasını {user} kullanıcısı ile paylaştı",
    "{actor} removed {user} from {file}" : "{actor} {file} dosyasının {user} kullanıcısıyla paylaşımını kaldırdı",
    "{actor} shared {file} with you" : "{actor} {file} dosyasını sizinle paylaştı",
    "{actor} removed you from the share named {file}" : "{actor} {file} dosyasının sizinle paylaşımını kaldırdı",
    "Share for file {file} with {user} expired" : "{file} dosyasının {user} kullanıcısıyla paylaşımının geçerlilik süresi dolmuş",
    "Share for file {file} expired" : "{file} dosyasının paylaşımının geçerlilik süresi dolmuş",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "E-posta ya da herkese açık bağlantı ile paylaşılan bir dosya ya da klasör <strong>indirildi</strong>",
    "Files have been <strong>uploaded</strong> to a folder shared by mail or by public link" : "Dosyalar e-posta ya da herkese açık bir bağlantı ile paylaşılmış bir klasöre <strong>yüklendi</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "<strong>Başka bir sunucudan</strong> bir dosya ya da klasör paylaşıldı",
    "Sharing" : "Paylaşım",
    "A file or folder has been <strong>shared</strong>" : "Bir dosya ya da klasör <strong>paylaşıldı</strong>",
    "Shared link" : "Paylaşılmış bağlantı",
    "Wrong share ID, share does not exist" : "Paylaşım kimliği yanlış. Paylaşım bulunamadı",
    "Could not delete share" : "Paylaşım silinemedi",
    "Please specify a file or folder path" : "Lütfen bir dosya ya da klasör yolu belirtin",
    "Wrong path, file/folder does not exist" : "Yol yanlış. Dosya ya da klasör bulunamadı",
    "Could not create share" : "Paylaşılamadı",
    "Please specify a valid account to share with" : "Lütfen paylaşılacak geçerli bir hesap belirtin",
    "Group sharing is disabled by the administrator" : "Grup paylaşımı özelliği BT yöneticisi tarafından kapatılmış",
    "Please specify a valid group" : "Lütfen geçerli bir grup belirtin",
    "Public link sharing is disabled by the administrator" : "Herkese açık bağlantı paylaşımı özelliği BT yöneticisi tarafından kapatılmış",
    "Please specify a valid email address" : "Lütfen geçerli bir e-posta adresi yazın",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Nextcloud Konuş uygulaması kullanıma alınmamış. %s paylaşım parolası Nextcloud Konuş uygulaması ile gönderilemedi",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "Yönetim bölümünden %2$s türündeki paylaşımlar yapılamadığından %1$s paylaşılamadı",
    "Please specify a valid federated account ID" : "Lütfen geçerli bir birleşik hesap kimliği belirtin",
    "Please specify a valid federated group ID" : "Lütfen geçerli bir birleşik grup kimliği belirtin",
    "You cannot share to a Team if the app is not enabled" : "Uygulama kullanıma alınmamışsa bir Takım ile paylaşamazsınız",
    "Please specify a valid team" : "Lütfen geçerli bir takım belirtin",
    "Sharing %s failed because the back end does not support room shares" : "Arka yüz oda paylaşımlarına izin vermediğinden %s paylaşılamadı",
    "Sharing %s failed because the back end does not support ScienceMesh shares" : "Arka yüz ScienceMesh paylaşımlarına izin vermediğinden %s paylaşılamadı",
    "Unknown share type" : "Paylaşım türü bilinmiyor",
    "Not a directory" : "Bir klasör değil",
    "Could not lock node" : "Düğüm kilitlenemedi",
    "Public upload is only possible for publicly shared folders" : "Herkese açık yükleme ancak herkese açık paylaşılmış klasörlere yapılabilir",
    "Share must at least have READ or CREATE permissions" : "Paylaşım için en az OKUMA ve OLUŞTURMA izinleri olmalıdır",
    "Share must have READ permission if UPDATE or DELETE permission is set" : "UPDATE ya da DELETE izinleri verilmiş ise paylaşıma READ izni verilmelidir",
    "Public upload disabled by the administrator" : "Herkese açık yükleme özelliği BT yöneticisi tarafından kapatılmış",
    "Could not lock path" : "Yol kilitlenemedi",
    "no sharing rights on this item" : "bu ögenin herhangi bir paylaşım izni yok",
    "You are not allowed to edit incoming shares" : "Gelen paylaşımları düzenleme izniniz yok",
    "Wrong or no update parameter given" : "Parametre yanlış ya da herhangi bir parametre belirtilmemiş",
    "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled." : "Nextcloud Konuş uygulaması kullanıma alınmamış. Paylaşım parolası Nextcloud Konuş uygulaması ile gönderilemedi.",
    "Custom share link tokens have been disabled by the administrator" : "Özel bağlantı paylaşımı kodları yöneticiniz tarafından kapatılmış",
    "Tokens must contain at least 1 character and may only contain letters, numbers, or a hyphen" : "Kodlar en az 1 karakter uzunluğunda olmalı ve yalnızca harf, sayı veya tire karakterlerini içermelidir",
    "Invalid date. Format must be YYYY-MM-DD" : "Tarih geçersiz. Tarih biçimi YYYY-AA-GG olmalıdır",
    "No sharing rights on this item" : "Bu ögenin herhangi bir paylaşım izni yok",
    "Invalid share attributes provided: \"%s\"" : "Belirtilen paylaşım öznitelikleri geçersiz: \"%s\"",
    "You are not allowed to send mail notifications" : "E-posta bildirimleri gönderme izniniz yok",
    "No mail notification configured for this share type" : "Bu paylaşım türü için bir e-posta bildirimi yapılandırılmamış",
    "Wrong password" : "Parola yanlış",
    "Error while sending mail notification" : "E-posta bildirimi gönderilirken sorun çıktı",
    "Failed to generate a unique token" : "Eşsiz bir kod oluşturulamadı",
    "This share does not exist or is no longer available" : "Bu paylaşım bulunamadı ya da artık kullanılamıyor",
    "shared by %s" : "%s tarafından paylaşıldı",
    "Download" : "İndir",
    "Add to your %s" : "%s uygulamanıza ekleyin",
    "Direct link" : "Doğrudan bağlantı",
    "Share API is disabled" : "Paylaşım API arayüzü kapatılmış",
    "File sharing" : "Dosya paylaşımı",
    "Share will expire tomorrow" : "Paylaşımın geçerlilik süresi yarın dolacak",
    "Your share of {node} will expire tomorrow" : "{node} paylaşımınızın geçerlilik süresi yarın dolacak",
    "You received {share} as a share by {user}" : "{user} kullanıcısından {share} paylaşımını aldınız",
    "You received {share} to group {group} as a share by {user}" : "{user} kullanıcısından {group} grubu için {share} paylaşımını aldınız",
    "Accept" : "Kabul et",
    "Decline" : "Reddet",
    "Remember to upload the files to %s" : "Dosyaları %s üzerine yüklemeyi unutmayın",
    "We would like to kindly remind you that you have not yet uploaded any files to the shared folder." : "Paylaşılan klasöre henüz herhangi bir dosya yüklemediğinizi hatırlatmak isteriz.",
    "Open \"%s\"" : "\"%s\" aç",
    "This application enables people to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable people can then share files and folders with other accounts and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other people outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation." : "Bu uygulama kişilerin Nextcloud üzerinde dosya paylaşabilmesini sağlar. Kullanıma alındığında, yöneticiler dosya paylaşabilecek grupları belirleyebilir. Seçilmiş gruplardaki kişiler Nextcloud üzerindeki diğer kişi ve gruplar ile dosya ve klasör paylaşabilir. Ek olarak, yönetici bağlantı paylaşımı özelliğini açmış ise, Nextcloud üzerinde olmayan kişiler ile dosya paylaşımı bağlantıları kullanılabilir. Yöneticiler ayrıca parola ve geçerlilik sonu tarihi kullanılmasını zorunlu kılmanın yanında, paylaşım bağlantıları ile sunucudan sunucuya paylaşım ve mobil aygıtlar ile paylaşım gibi özellikleri açabilir.\nBu özellik kapatıldığında, sunucu, eşitleme istemcileri ve mobil uygulamalar üzerinden alıcılar ile paylaşılmış dosya ve klasörler kaldırılır. Ayrıntılı bilgi almak için Nextcloud belgelerine bakabilirsiniz.",
    "People" : "Kişiler",
    "Filter accounts" : "Hesapları süz",
    "The request will expire on {date} at midnight and will be password protected." : "İstek {date} gece yarısı geçersiz olacak ve parola ile korunacak.",
    "The request will expire on {date} at midnight." : "İstek {date} gece yarısı geçersiz olacak.",
    "The request will be password protected." : "İstek parola ile korunacak.",
    "When should the request expire?" : "İsteğin geçerlilik sonu ne zaman olsun?",
    "Set a submission expiration date" : "Gönderim geçerlilik sonu tarihini ayarlayın",
    "Expiration date" : "Geçerlilik sonu tarihi",
    "Select a date" : "Bir tarih seçin",
    "Your administrator has enforced a {count} days expiration policy." : "Yöneticiniz geçerlilik sonu ilkesini {count} gün olarak zorunlu kılmış.",
    "What password should be used for the request?" : "İstek için kullanılacak parola nedir?",
    "Set a password" : "Bir parola ayarlayın",
    "Password" : "Parola",
    "Enter a valid password" : "Geçerli bir parola yazın",
    "Generate a new password" : "Yeni parola oluştur",
    "Your administrator has enforced a password protection." : "Yöneticiniz parola korumasını zorunlu kılmış.",
    "Automatically copying failed, please copy the share link manually" : "Otomatik kopyalama tamamlanamadı. Paylaşım bağlantısını el ile kopyalayın",
    "Link copied" : "Bağlantı kopyalandı",
    "Email already added" : "E-posta adresi zaten eklenmiş",
    "Invalid email address" : "E-posta adresi geçersiz",
    "_The following email address is not valid: {emails}_::_The following email addresses are not valid: {emails}_" : ["Şu e-posta adresi geçersiz: {emails}","Şu e-posta adresleri geçersiz: {emails}"],
    "_{count} email address already added_::_{count} email addresses already added_" : ["{count} e-posta adresi zaten eklenmiş","{count} e-posta adresi zaten eklenmiş"],
    "_{count} email address added_::_{count} email addresses added_" : ["{count} e-posta adresi eklendi","{count} e-posta adresi eklendi"],
    "You can now share the link below to allow people to upload files to your directory." : "Artık aşağıdaki bağlantıyı paylaşarak insanların klasörünüze dosya yüklemesini sağlayabilirsiniz.",
    "Share link" : "Paylaşım bağlantısı",
    "Copy" : "Kopyala",
    "Send link via email" : "Bağlantıyı e-posta ile gönder",
    "Enter an email address or paste a list" : "Bir e-posta adresi yazın ya da bir e-posta adresi listesi yapıştırın",
    "Remove email" : "E-posta adresini kaldır",
    "Select a destination" : "Bir hedef seçin",
    "Select" : "Seçin",
    "What are you requesting?" : "Ne yapmak istiyorsunuz?",
    "Request subject" : "İstek konusu",
    "Birthday party photos, History assignment…" : "Doğum günü fotoğraflarını paylaşmak ve tarihleri belirlemek…",
    "Where should these files go?" : "Bu dosyalar nereye kaydedilmeli?",
    "Upload destination" : "Yükleme hedefi",
    "Revert to default" : "Varsayılana sıfırla",
    "The uploaded files are visible only to you unless you choose to share them." : "Yüklenen dosyaları, paylaşmayı seçmediğiniz sürece yalnızca siz görebilirsiniz.",
    "Add a note" : "Bir not ekle",
    "Note for recipient" : "Alıcıya not",
    "Add a note to help people understand what you are requesting." : "İnsanlara isteğinizin ne olduğunu açıklayan bir not ekleyin.",
    "You can add links, date or any other information that will help the recipient understand what you are requesting." : "Alıcının ne istediğinizi anlamasına yardımcı olacak bağlantı, tarih veya başka bilgiler ekleyebilirsiniz.",
    "Close" : "Kapat",
    "_Send email and close_::_Send {count} emails and close_" : ["E-postayı gönder ve kapat","{count} e-postayı gönder ve kapat"],
    "Please select a folder, you cannot share the root directory." : "Lütfen bir klasör seçin, kök klasörü paylaşamazsınız.",
    "File request created" : "Dosya isteği oluşturuldu",
    "_File request created and email sent_::_File request created and {count} emails sent_" : ["Dosya isteği oluşturuldu ve e-posta gönderildi","Dosya isteği oluşturuldu ve {count} e-posta gönderildi"],
    "Error creating the share: {errorMessage}" : "Paylaşım oluşturulurken sorun çıktı: {errorMessage}",
    "Error creating the share" : "Paylaşım oluşturulurken sorun çıktı",
    "Error sending emails: {errorMessage}" : "E-postalar gönderilirken sorun çıktı: {errorMessage}",
    "Error sending emails" : "E-postalar gönderilirken sorun çıktı",
    "Create a file request" : "Bir dosya isteği oluştur",
    "Collect files from others even if they do not have an account." : "Hesabı olmayan kişilerden bile dosyaları toplayın.",
    "To ensure you can receive files, verify you have enough storage available." : "Dosyaları alabileceğinizden emin olmak için yeterli depolama alanınız bulunduğundan emin olun.",
    "File request" : "Dosya isteği",
    "Previous step" : "Önceki adım",
    "Cancel" : "İptal",
    "Cancel the file request creation" : "Dosya isteği oluşturmayı iptal et",
    "Close without sending emails" : "E-postaları göndermeden kapat",
    "Continue" : "Sürdür",
    "Error while toggling options" : "Seçenekler değiştirilirken sorun çıktı ",
    "Accept shares from other accounts and groups by default" : "Diğer hesaplardan ve gruplardan gelen paylaşımlar varsayılan olarak kabul edilsin",
    "Choose a default folder for accepted shares" : "Onaylanmış paylaşımlar için varsayılan bir klasör seçin",
    "Invalid path selected" : "Seçilen yol geçersiz",
    "Unknown error" : "Bilinmeyen sorun",
    "Set default folder for accepted shares" : "Onaylanmış paylaşımların varsayılan klasörünü ayarlayın",
    "Reset" : "Sıfırla",
    "Reset folder to system default" : "Sistem varsayılan klasörüne sıfırlar",
    "Share expiration: {date}" : "Paylaşım geçerlilik sonu: {date}",
    "Share Expiration" : "Paylaşım geçerlilik sonu",
    "group" : "grup",
    "conversation" : "görüşme",
    "remote" : "uzak",
    "remote group" : "uzak grup",
    "guest" : "konuk",
    "by {initiator}" : "{initiator} tarafından",
    "Shared with the group {user} by {owner}" : "{owner} tarafından grup {user} ile paylaşılmış",
    "Shared with the conversation {user} by {owner}" : "{owner} tarafından görüşme {user} ile paylaştırılmış",
    "Shared with {user} by {owner}" : "{owner} tarafından {user} ile paylaşılmış",
    "Open Sharing Details" : "Paylaşım bilgilerini aç",
    "Added by {initiator}" : "{initiator} tarafından eklendi",
    "Via “{folder}”" : "“{folder}” ile",
    "Unshare" : "Paylaşımı kaldır",
    "Cannot copy, please copy the link manually" : "Kopyalanamadı. Lütfen bağlantıyı el ile kopyalayın",
    "Copy internal link" : "İç bağlantıyı kopyala",
    "Internal link" : "İç bağlantı",
    "{shareWith} by {initiator}" : "{initiator} tarafından {shareWith}",
    "Shared via link by {initiator}" : "{initiator} tarafından bağlantı ile paylaşıldı",
    "File request ({label})" : "Dosya isteği ({label})",
    "Mail share ({label})" : "E-posta ile paylaş ({label})",
    "Share link ({label})" : "Bağlantı ile paylaş ({label})",
    "Mail share" : "E-posta ile paylaş",
    "Share link ({index})" : "Paylaşım bağlantısı ({index})",
    "Create public link" : "Herkese açık bağlantı ekle",
    "Actions for \"{title}\"" : "\"{title}\" işlemleri",
    "Error, please enter proper password and/or expiration date" : "Hata. Lütfen uygun bir parola ya da geçerlilik sonu tarihi yazın",
    "Link share created" : "Paylaşım bağlantısı oluşturuldu",
    "Error while creating the share" : "Paylaşım oluşturulurken sorun çıktı",
    "Please enter the following required information before creating the share" : "Lütfen paylaşımı oluşturmadan önce aşağıdaki zorunlu bilgileri yazın",
    "Password protection (enforced)" : "Parola koruması (zorunlu kılınmış)",
    "Password protection" : "Parola koruması",
    "Enter a password" : "Bir parola yazın",
    "Enable link expiration (enforced)" : "Bağlantıya geçerlilik sonu ekle (zorunlu kılınmış)",
    "Enable link expiration" : "Bağlantı geçerlilik sonu kullanılsın",
    "Enter expiration date (enforced)" : "Geçerlilik sonu tarihini yazın (zorunlu kılınmış)",
    "Enter expiration date" : "Geçerlilik sonu tarihini yazın",
    "Create share" : "Paylaşım ekle",
    "Customize link" : "Bağlantıyı özelleştir",
    "Generate QR code" : "Kare kod oluştur",
    "Add another link" : "Başka bir bağlantı ekle",
    "Create a new share link" : "Yeni bir paylaşım bağlantısı ekle",
    "Quick share options, the current selected is \"{selectedOption}\"" : "Hızlı paylaşım seçenekleri, geçerli seçim \"{selectedOption}\"",
    "View only" : "Yalnızca görüntüleme",
    "Can edit" : "Düzenleyebilir",
    "Custom permissions" : "Özel izinler",
    "Resharing is not allowed" : "Yeniden paylaşıma izin verilmiyor",
    "Name or email …" : "Ad ya da e-posta adresi …",
    "Name, email, or Federated Cloud ID …" : "Ad, e-posta ya da birleşik bulut kimliği…",
    "Searching …" : "Aranıyor …",
    "No elements found." : "Herhangi bir bileşen bulunamadı.",
    "Search everywhere" : "Her yerde ara",
    "Guest" : "Konuk",
    "Group" : "Grup",
    "Email" : "E-posta",
    "Team" : "Takım",
    "Talk conversation" : "Konuş görüşmesi",
    "Deck board" : "Tahta panosu",
    "ScienceMesh" : "ScienceMesh",
    "on {server}" : "{server} üzerinde",
    "Enter external recipients" : "Dış alıcıları yazın",
    "Search for internal recipients" : "İç alıcıları arayın",
    "Note from" : "Notu yazan",
    "Note:" : "Not:",
    "File drop" : "Dosya bırakma",
    "Upload files to {foldername}." : "Dosyaları {foldername} klasörüne yükle.",
    "By uploading files, you agree to the terms of service." : "Dosya yükleyerek hizmet koşullarını kabul etmiş olursunuz.",
    "Successfully uploaded files" : "Dosyalar yüklendi",
    "View terms of service" : "Hizmet koşullarını görüntüle",
    "Terms of service" : "Hizmet koşulları",
    "Share with email {email}" : "{email} e-posta adresi ile paylaş",
    "Share with group" : "Grupla paylaş",
    "Share in conversation" : "Görüşmede paylaş",
    "Share with {user} on remote server {server}" : "{server} uzak sunucusundaki {user} ile paylaş",
    "Share with remote group" : "Uzaktaki grupla paylaş",
    "Share with guest" : "Konukla paylaş",
    "Update share" : "Paylaşımı güncelle",
    "Save share" : "Paylaşımı kaydet",
    "Read" : "Okuma",
    "Create" : "Ekle",
    "Edit" : "Düzenleme",
    "Share" : "Paylaş",
    "Delete" : "Sil",
    "Password field cannot be empty" : "Parola alanı boş olamaz",
    "Replace current password" : "Geçerli parolayı değiştir",
    "Failed to generate a new token" : "Yeni bir kod oluşturulamadı",
    "Allow upload and editing" : "Yüklenebilsin ve düzenlenebilsin",
    "Allow editing" : "Düzenlemeye izin ver",
    "Upload only" : "Yalnızca yükleme",
    "Advanced settings" : "Gelişmiş ayarlar",
    "Share label" : "Paylaşım etiketi",
    "Share link token" : "Paylaşım bağlantısı kodu",
    "Set the public share link token to something easy to remember or generate a new token. It is not recommended to use a guessable token for shares which contain sensitive information." : "Herkese açık paylaşım bağlantısı kodunu kolay hatırlanacak bir şey olarak ayarlayın veya yeni bir kod oluşturun. Önemli bilgiler içeren paylaşımlar için öngörülebilir bir kod kullanılması önerilmez.",
    "Generating…" : "Oluşturuluyor…",
    "Generate new token" : "Yeni kod oluştur",
    "Set password" : "Parola ayarla",
    "Password expires {passwordExpirationTime}" : "Parolanın geçerlilik süresi sonu {passwordExpirationTime}",
    "Password expired" : "Parolanın geçerlilik süresi dolmuş",
    "Video verification" : "Görüntü doğrulaması",
    "Expiration date (enforced)" : "Geçerlilik sonu tarihi (zorunlu kılınmış)",
    "Set expiration date" : "Geçerlilik sonu tarihini ayarla",
    "Hide download" : "İndirme gizlensin",
    "Allow download and sync" : "İndirmeye izin ver ve eşitle",
    "Note to recipient" : "Alıcıya not",
    "Enter a note for the share recipient" : "Paylaşım alıcısı için bir not yazın",
    "Show files in grid view" : "Dosyaları ızgara yerleşiminde görüntüle",
    "Delete share" : "Paylaşımı sil",
    "Others with access" : "Erişebilen diğer kişiler",
    "No other accounts with access found" : "Erişebilen başka bir hesap bulunamadı",
    "Toggle list of others with access to this directory" : "Bu klasöre erişme izni olan diğer kişiler listesini aç/kapat",
    "Toggle list of others with access to this file" : "Bu dosyaya erişme izni olan diğer kişiler listesini aç/kapat",
    "Unable to fetch inherited shares" : "Devir alınan paylaşımlar alınamadı",
    "Link shares" : "Bağlantı paylaşımları",
    "Shares" : "Paylaşımlar",
    "Unable to load the shares list" : "Paylaşımlar listesi yüklenemedi",
    "Expires {relativetime}" : "Geçerlilik süresi sonu {relativetime}",
    "this share just expired." : "bu paylaşımın geçerlilik süresi dolmuş.",
    "Shared with you by {owner}" : "{owner} tarafından sizinle paylaşılmış",
    "Internal shares" : "İç paylaşımlar",
    "Internal shares explanation" : "İç paylaşımlar açıklaması",
    "External shares" : "Dış paylaşımlar",
    "External shares explanation" : "Dış paylaşımlar açıklaması",
    "Additional shares" : "Ek paylaşımlar",
    "Additional shares explanation" : "Ek paylaşımlar açıklaması",
    "Link to a file" : "Bir dosya bağlantısı",
    "_Accept share_::_Accept shares_" : ["Paylaşımı kabul et","Paylaşımları kabul et"],
    "Open in Files" : "Dosyalar uygulamasında aç",
    "_Reject share_::_Reject shares_" : ["Paylaşımı reddet","Paylaşımları reddet"],
    "_Restore share_::_Restore shares_" : ["Paylaşımı geri yükle","Paylaşımları geri yükle"],
    "Shared" : "Paylaşılan",
    "Shared by {ownerDisplayName}" : "{ownerDisplayName} tarafından paylaşılmış",
    "Shared multiple times with different people" : "Farklı kişilerle birkaç kez paylaşılmış",
    "Sharing options" : "Paylaşım seçenekleri",
    "Shared with others" : "Diğerleri ile paylaşılmış",
    "Create file request" : "Dosya isteği oluştur",
    "Upload files to {foldername}" : "Dosyaları {foldername} klasörüne yükle",
    "Public file share" : "Herkese açık dosya paylaşımı",
    "Publicly shared file." : "Herkese açık paylaşılmış dosya.",
    "No file" : "Dosya yok",
    "The file shared with you will show up here" : "Sizinle paylaşılan dosyalar burada görüntülenir",
    "Public share" : "Herkese açık paylaş",
    "Publicly shared files." : "Herkese açık paylaşılmış dosyalar.",
    "No files" : "Herhangi bir dosya yok",
    "Files and folders shared with you will show up here" : "Sizinle paylaşılan dosyalar ve klasörler burada görüntülenir",
    "Overview of shared files." : "Paylaşılan dosyaların özeti.",
    "No shares" : "Henüz bir şey paylaşılmamış",
    "Files and folders you shared or have been shared with you will show up here" : "Başkalarıyla paylaştığınız dosya ve klasörler burada görüntülenir",
    "Shared with you" : "Sizinle paylaşılmış",
    "List of files that are shared with you." : "Sizinle paylaşılan dosyaların listesi.",
    "Nothing shared with you yet" : "Sizinle henüz herhangi bir şey paylaşılmamış",
    "Files and folders others shared with you will show up here" : "Başkalarının sizinle paylaştığı dosya ve klasörler burada görüntülenir",
    "List of files that you shared with others." : "Başkalarıyla paylaştığınız dosyaların listesi.",
    "Nothing shared yet" : "Henüz hiçbir şey paylaşılmamış",
    "Files and folders you shared will show up here" : "Paylaştığınız dosya ve klasörler burada görüntülenir",
    "Shared by link" : "Bağlantı ile paylaşılmış",
    "List of files that are shared by link." : "Bağlantı ile paylaşılan dosyaların listesi.",
    "No shared links" : "Paylaşılmış bir bağlantı yok",
    "Files and folders you shared by link will show up here" : "Bağlantı ile paylaştığınız dosya ve klasörler burada görüntülenir",
    "File requests" : "Dosya istekleri",
    "List of file requests." : "Dosya isteklerinin listesi.",
    "No file requests" : "Herhangi bir dosya isteği yok",
    "File requests you have created will show up here" : "Oluşturduğunuz dosya istekleri burada görüntülenir",
    "Deleted shares" : "Silinmiş paylaşımlar",
    "List of shares you left." : "Ayrıldığınız paylaşımların listesi.",
    "No deleted shares" : "Silinmiş bir paylaşım yok",
    "Shares you have left will show up here" : "Ayrıldığınız paylaşımlar burada görüntülenir",
    "Pending shares" : "Bekleyen paylaşımlar",
    "List of unapproved shares." : "Kabul edilmemiş paylaşımların listesi.",
    "No pending shares" : "Bekleyen paylaşım yok",
    "Shares you have received but not approved will show up here" : "Aldığınız ancak henüz kabul etmediğiniz paylaşımlar burada görüntülenir",
    "Error deleting the share: {errorMessage}" : "Paylaşım silinirken sorun çıktı: {errorMessage}",
    "Error deleting the share" : "Paylaşım silinirken sorun çıktı",
    "Error updating the share: {errorMessage}" : "Paylaşım güncellenirken sorun çıktı: {errorMessage}",
    "Error updating the share" : "Paylaşım güncellenirken sorun çıktı",
    "File \"{path}\" has been unshared" : "\"{path}\" dosyası paylaşımdan kaldırıldı",
    "Folder \"{path}\" has been unshared" : "\"{path}\" klasörü paylaşımdan kaldırıldı",
    "Could not update share" : "Paylaşım güncellenemedi",
    "Share saved" : "Paylaşım kaydedildi",
    "Share expiry date saved" : "Paylaşım geçerlilik süresi tarihi kaydedildi",
    "Share hide-download state saved" : "Paylaşımın indirmeyi gizleme durumu kaydedildi",
    "Share label saved" : "Paylaşım etiketi kaydedildi",
    "Share note for recipient saved" : "Alıcı için paylaşım notu kaydedildi",
    "Share password saved" : "Paylaşım parolası kaydedildi",
    "Share permissions saved" : "Paylaşım izinleri kaydedildi",
    "To upload files to {folder}, you need to provide your name first." : "{folder} üzerine dosyalar yükleyebilmek için önce adınızı yazmalısınız.",
    "Upload files to {folder}" : "Dosyaları {folder} klasörüne yükle",
    "Please confirm your name to upload files to {folder}" : "Lütfen {folder} üzerinde dosyalar yükleyebilmek için adınızı doğrulayın",
    "{ownerDisplayName} shared a folder with you." : "{ownerDisplayName} sizinle bir klasör paylaştı.",
    "Names must not be empty." : "Ad boş olamaz.",
    "Names must not start with a dot." : "Ad bir nokta ile başlayamaz.",
    "\"{char}\" is not allowed inside a name." : "Bir ad içinde \"{char}\" karakteri kullanılamaz.",
    "\"{segment}\" is a reserved name and not allowed." : "\"{segment}\" ayrılmış bir ad olduğundan kullanılamaz.",
    "\"{extension}\" is not an allowed name." : "\"{extension}\" adı kullanılamaz.",
    "Names must not end with \"{extension}\"." : "Adlar \"{extension}\" karakteri ile bitemez.",
    "Invalid name." : "Ad geçersiz.",
    "Shared by" : "Paylaşan",
    "Shared with" : "Şunlarla paylaşılmış",
    "Password created successfully" : "Parola oluşturuldu",
    "Error generating password from password policy" : "Parola, parola ilkesine göre oluşturulurken sorun çıktı",
    "Shared with you and the group {group} by {owner}" : "{owner} tarafından sizinle ve {group} gubu ile paylaşılmış",
    "Shared with you and {circle} by {owner}" : "{owner} tarafından sizinle ve {circle} takımı ile paylaşılmış",
    "Shared with you and the conversation {conversation} by {owner}" : "{owner} tarafından sizinle ve {conversation} görüşmesi ile paylaştırılmış",
    "Shared with you in a conversation by {owner}" : "{owner} tarafından sizinle bir görüşmede paylaşılmış",
    "Share not found" : "Paylaşım bulunamadı",
    "Back to %s" : "%s sayfasına dön",
    "Add to your Nextcloud" : "Nextcloud hesabınıza ekleyin",
    "Waiting…" : "Bekleniyor…",
    "error" : "sorun",
    "finished" : "tamamlandı",
    "This will stop your current uploads." : "Bu işlem geçerli yüklemeleri durduracak.",
    "Move or copy" : "Taşı ya da kopyala",
    "You can upload into this folder" : "Bu klasöre yükleme yapabilirsiniz",
    "Show list view" : "Liste görünümüne geç",
    "Show grid view" : "Tablo görünümüne geç",
    "No compatible server found at {remote}" : "{remote} konumunda uyumlu sunucu bulunamadı",
    "Invalid server URL" : "Sunucu adresi geçersiz",
    "Failed to add the public link to your Nextcloud" : "Herkese açık bağlantı Nextcould üzerine eklenemedi",
    "You are not allowed to edit link shares that you don't own" : "Sahibi olmadığınız bağlantı paylaşımlarını düzenleme izniniz yok",
    "Download all files" : "Tüm dosyaları indir",
    "Link copied to clipboard" : "Bağlantı panoya kopyalandı",
    "_1 email address already added_::_{count} email addresses already added_" : ["1 e-posta adresi zaten eklenmiş","{count} e-posta adresi zaten eklenmiş"],
    "_1 email address added_::_{count} email addresses added_" : ["1 e-posta adresi eklendi","{count} e-posta adresi eklendi"],
    "Copy to clipboard" : "Panoya kopyala",
    "Copy internal link to clipboard" : "İç bağlantıyı panoya kopyala",
    "Only works for people with access to this folder" : "Yalnızca bu klasöre erişebilen kişiler için geçerlidir",
    "Only works for people with access to this file" : "Yalnızca bu dosyaya erişebilen kişiler için geçerlidir",
    "Copy public link of \"{title}\" to clipboard" : "Herkese açık \"{title}\" bağlantısını panoya kopyala",
    "Search globally" : "Genel arama",
    "Search for share recipients" : "Paylaşım alıcıları ara",
    "No recommendations. Start typing." : "Herhangi bir öneri yok. Yazmaya başlayın.",
    "To upload files, you need to provide your name first." : "Dosyaları yükleyebilmek için önce adınızı yazmalısınız.",
    "Enter your name" : "Adınızı yazın",
    "Submit name" : "Adı gönder",
    "Share with {userName}" : "{userName} ile paylaş",
    "Show sharing options" : "Paylaşım seçeneklerini görüntüle",
    "Share note" : "Notu paylaş",
    "Upload files to %s" : "Dosyaları %s konumuna yükle",
    "%s shared a folder with you." : "%s sizinle bir klasör paylaştı.",
    "Note" : "Not",
    "Select or drop files" : "Dosyaları seçin ya da sürükleyip bırakın",
    "Uploading files" : "Dosyalar yükleniyor",
    "Uploaded files:" : "Yüklenmiş dosyalar:",
    "By uploading files, you agree to the %1$sterms of service%2$s." : "Dosya yükleyerek %1$shizmet koşullarını%2$s kabul etmiş olursunuz.",
    "Name" : "Ad",
    "Use this method to share files with individuals or teams within your organization. If the recipient already has access to the share but cannot locate it, you can send them the internal share link for easy access." : "Bu yöntemi, dosyaları kuruluşunuzdaki kişilerle veya takımlarla paylaşmak için kullanın. Alıcının paylaşıma zaten erişimi varsa ancak bulamıyorlarsa, kolay erişmeleri için iç paylaşım bağlantısını gönderebilirsiniz.",
    "Use this method to share files with individuals or organizations outside your organization. Files and folders can be shared via public share links and email addresses. You can also share to other Nextcloud accounts hosted on different instances using their federated cloud ID." : "Bu yöntemi, dosyaları kuruluşunuzun dışındaki kişilerle veya kuruluşlarla paylaşmak için kullanın. Dosyalar ve klasörler herkese açık paylaşım bağlantıları ve e-posta adresleri ile paylaşılabilir. Ayrıca, birleşik bulut kimliklerini kullanarak farklı kopyalarda barındırılan diğer Nextcloud hesaplarıyla da paylaşım yapabilirsiniz.",
    "Shares that are not part of the internal or external shares. This can be shares from apps or other sources." : "İç veya dış paylaşımların parçası olmayan paylaşımlar. Bunlar uygulamalardan veya diğer kaynaklardan gelen paylaşımlar olabilir.",
    "Share with accounts, teams, federated cloud id" : "Hesaplar, takımlar ve birleşik bulut kimlikleri ile paylaşın",
    "Share with accounts and teams" : "Hesaplar ve takımlarla paylaşın",
    "Federated cloud ID" : "Birleşik bulut kimliği",
    "Email, federated cloud id" : "E-posta adresi, birleşik bulut kimliği",
    "Filename must not be empty." : "Dosya adı boş olamaz."
},
"nplurals=2; plural=(n > 1);");
