<?php
namespace Aws\Panorama\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Panorama** service.
 */
class PanoramaException extends AwsException {}
