OC.L10N.register(
    "notifications",
    {
    "We want to keep offering our push notification service for free, but large number of users overload our infrastructure. For this reason we have to rate-limit the use of push notifications. If you need this feature, consider using Nextcloud Enterprise." : "我們希望繼續免費提供推送通知服務，但大量使用者會讓我們的基礎架構負荷過重。因此，我們必須限制推送通知的使用率。如果您需要此功能，請考慮使用 Nextcloud 企業版。",
    "User not found" : "找不到使用者",
    "An unexpected error occurred, ask your administration to check the logs." : "發生了未預期的錯誤，請要求您的管理員檢查紀錄檔。",
    "Hello %s" : "嗨 %s",
    "Hello %s," : "嗨 %s，",
    "_New notification for %s_::_%n new notifications for %s_" : ["%s 的 %n 個新通知"],
    "_You have a new notification for %s_::_You have %n new notifications for %s_" : ["您有 %s 的 %n 個新通知"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "您可以變更這些電子郵寄的頻率或在<a href=\"%s\">設定</a>中停用。",
    "You can change the frequency of these emails or disable them in the settings: %s" : "您可以變更這些電子郵寄的頻率或在設定中停用：%s",
    "Admin notifications" : "管理員通知",
    "Notifications" : "通知",
    "Push notifications - Fair use policy" : "推播通知 - 公平使用政策",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server and the limit was reached for this server. For enterprise users, a more scalable gateway is available." : "Nextcloud GmbH 為私人使用者提供免費的推播通知閘道。為了確保良好的服務，閘道限制了每台伺服器的推播通知數量，且此伺服器已達限制。對於企業使用者來說，可以使用更具可擴充性的閘道。",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "此應用程式為 Nextcloud 中提供的通知 API 提供了前後端。",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "此應用程式為 Nextcloud 中提供的通知 API 提供了前後端。\n\t\t其他應用程式使用這個 API 來通知在 Web UI 中的使用者，並同步客戶端。這裡有一些例子：\n\n📬 聯盟檔案分享：您收到了新的遠端分享\n\n📑 留言：其他使用者在檔案中的留言提及您\n\n🚢 更新通知：應用程式或 Nextcloud 自身有可用的更新\n\n📣 公告中新：管理員發佈了公告",
    "Failed to perform action" : "採取動作失敗",
    "Failed to dismiss notification" : "關閉通知失敗",
    "Dismiss" : "關閉",
    "Contact Nextcloud GmbH" : "聯絡 Nextcloud GmbH",
    "in {path}" : "在 {path}",
    "Push notifications might be unreliable" : "推播通知可能不可靠",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server. For enterprise users, a more scalable gateway is available. Contact Nextcloud GmbH for more information." : "Nextcloud GmbH 為私人使用者贊助了一個免費的推送通知閘道。 為了確保良好的服務，閘道限制了每台服務器的推播通知數量。 對於企業使用者，可以使用更具擴展性的閘道。如需更多資訊，請聯絡 Nextcloud GmbH。",
    "Requesting browser permissions to show notifications" : "需要瀏覽器權限以顯示通知",
    "No notifications" : "沒有通知",
    "Failed to dismiss all notifications" : "關閉所有通知失敗",
    "Dismiss all notifications" : "忽略所有通知",
    "Never" : "從不",
    "1 hour" : "1小時",
    "3 hours" : "3小時",
    "1 day" : "1天",
    "1 week" : "1週",
    "Your settings have been updated." : "您的設定已更新。",
    "An error occurred while updating your settings." : "更新您的設定時發生錯誤。",
    "Notifications defaults" : "通知預設值",
    "Configure the default notification settings for new users" : "設定新使用者的預設通知設定",
    "Send email reminders about unhandled notifications after:" : "在多久之後傳送關於未處理通知的電子郵件提醒：",
    "Play sound when a new notification arrives" : "收到新通知時播放音效",
    "Play sound when a call started (requires Nextcloud Talk)" : "通話開始時播放音效（需要 Nextcloud Talk）",
    "None" : "無",
    "You need to set up your email address before you can receive notification emails." : "在您開始接收通知電子郵件前，您必須先設定您的電子郵件地址。",
    "Also repeat sound on a secondary speaker" : "在次要喇叭上重複播放音效",
    "Selection of the speaker device is currently not supported by Safari" : "Safari 目前不支援選擇喇叭裝置",
    "Select a device" : "選取裝置",
    "seconds ago" : "幾秒前"
},
"nplurals=1; plural=0;");
