OC.L10N.register(
    "firstrunwizard",
    {
    "Close" : "Закрыць",
    "Calendar and contacts ↗" : "Каляндар і кантакты",
    "Welcome to {cloudName}!" : "Вітаем у {cloudName}!",
    "Privacy" : "Прыватнасць",
    "Community" : "Супольнасць",
    "URL copied" : "URL-адрас скапіяваны",
    "Server address" : "Адрас сервера",
    "Nextcloud on all your devices" : "Nextcloud на ўсіх вашых прыладах",
    "Read more" : "Больш падрабязна"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
