<?php
// This file was auto-generated from sdk-root/src/data/elastictranscoder/2012-09-25/paginators-1.json
return [ 'pagination' => [ 'ListJobsByPipeline' => [ 'input_token' => 'PageToken', 'output_token' => 'NextPageToken', 'result_key' => 'Jobs', ], 'ListJobsByStatus' => [ 'input_token' => 'PageToken', 'output_token' => 'NextPageToken', 'result_key' => 'Jobs', ], 'ListPipelines' => [ 'input_token' => 'PageToken', 'output_token' => 'NextPageToken', 'result_key' => 'Pipelines', ], 'ListPresets' => [ 'input_token' => 'PageToken', 'output_token' => 'NextPageToken', 'result_key' => 'Presets', ], ],];
