<?php
/**
 * SPDX-FileCopyrightText: 2016 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */
namespace OCP\App;

/**
 * Class AppPathNotFoundException
 *
 * @since 11.0.0
 */
class AppPathNotFoundException extends \Exception {
}
