OC.L10N.register(
    "activity",
    {
    "Activity" : "aktiwnosć",
    "Today" : "dźensa",
    "Yesterday" : "wčera",
    "Open {filename}" : "{filename} wočinić"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
