<?php
namespace Aws\ECRPublic\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Elastic Container Registry Public** service.
 */
class ECRPublicException extends AwsException {}
