OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Chybí heslo ke klíči pro obnovu",
    "Please repeat the recovery key password" : "Zopakujte zadání hesla ke klíči, sloužícímu pro obnovu",
    "Repeated recovery key password does not match the provided recovery key password" : "Zopakované zadání hesla ke klíči, sloužícímu pro obnovu, se neshoduje",
    "Recovery key successfully enabled" : "Záchranný klíč byl úspěšně povolen",
    "Could not enable recovery key. Please check your recovery key password!" : "Nepodařilo se povolit záchranný klíč. Zkontrolujte své heslo k záchrannému klíči!",
    "Recovery key successfully disabled" : "Záchranný klíč úspěšně zakázán",
    "Could not disable recovery key. Please check your recovery key password!" : "Nedaří se zakázat záchranný klíč. Zkontrolujte zadání hesla k němu.",
    "Missing parameters" : "Chybějící parametry",
    "Please provide the old recovery password" : "Zadejte původní heslo pro obnovu",
    "Please provide a new recovery password" : "Zadejte nové heslo pro obnovu",
    "Please repeat the new recovery password" : "Zopakujte zadání nového hesla pro obnovu",
    "Password successfully changed." : "Heslo bylo úspěšně změněno.",
    "Could not change the password. Maybe the old password was not correct." : "Změna hesla se nezdařila. Pravděpodobně nebylo stávající heslo zadáno správně.",
    "Recovery Key disabled" : "Záchranný klíč není povolen",
    "Recovery Key enabled" : "Záchranný klíč povolen",
    "Could not enable the recovery key, please try again or contact your administrator" : "Nedaří se povolit záchranný klíč. Zkuste to znovu nebo se obraťte na svého správce.",
    "Could not update the private key password." : "Nedaří se aktualizovat heslo k soukromému klíči.",
    "The old password was not correct, please try again." : "Původní heslo nebylo zadáno správně, zkuste to znovu.",
    "The current log-in password was not correct, please try again." : "Současné přihlašovací heslo nebylo zadáno správně, zkuste to znovu.",
    "Private key password successfully updated." : "Heslo soukromého klíče úspěšně aktualizováno.",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Neplatný soukromý klíč pro šifrovací aplikaci. Aktualizujte prosím heslo svého soukromého klíče v osobním nastavení, abyste znovu získali přístup ke svým zašifrovaným souborům.",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "Aplikace pro šifrování je zapnuta, ale vaše klíče nejsou inicializované. Odhlaste se a znovu přihlaste.",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "Pokud chcete používat šifrovací modul, zapněte šifrování na straně serveru v nastavení pro správu.",
    "Encryption app is enabled and ready" : "Aplikace šifrování už je povolena a připravena",
    "Bad Signature" : "Nesprávný podpis",
    "Missing Signature" : "Chybějící podpis",
    "one-time password for server-side-encryption" : "jednorázové heslo pro šifrování na straně serveru",
    "Encryption password" : "Šifrovací heslo",
    "The administration enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>." : "Správce zapnul šifrování na straně serveru. Vaše soubory byly zašifrovány pomocí hesla <strong>%s</strong>.",
    "The administration enabled server-side-encryption. Your files were encrypted using the password \"%s\"." : "Správce zapnul šifrování na straně serveru. Vaše soubory byly zašifrovány pomocí hesla „%s“.",
    "Please login to the web interface, go to the \"Security\" section of your personal settings and update your encryption password by entering this password into the \"Old login password\" field and your current login password." : "Přihlaste se do webového rozhraní, jděte do osobních nastavení, sekce „Zabezpečení“ a zaktualizujte své šifrovací heslo zadáním tohoto hesla do kolonky „Původní přihlašovací heslo“ a pak jako nové nastavte to heslo, kterým se nyní přihlašujete do Nexcloud.",
    "Cannot decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Tento soubor se nedaří rozšifrovat – pravděpodobně se jedná o nasdílený soubor. Požádejte jeho vlastníka, aby vám ho znovu nasdílel.",
    "Cannot read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Z tohoto souboru se nedaří číst – pravděpodobně se jedná o nasdílený soubor. Požádejte jeho vlastníka, aby vám ho znovu nasdílel.",
    "Default encryption module" : "Výchozí šifrovací modul",
    "Default encryption module for server-side encryption" : "Výchozí modul pro šifrování na straně serveru",
    "In order to use this encryption module you need to enable server-side encryption in the admin settings. Once enabled this module will encrypt all your files transparently. The encryption is based on AES 256 keys.\nThe module will not touch existing files, only new files will be encrypted after server-side encryption was enabled. It is also not possible to disable the encryption again and switch back to an unencrypted system.\nPlease read the documentation to know all implications before you decide to enable server-side encryption." : "Pro používání tohoto šifrovacího modulu je třeba zapnout šifrování na straně serveru v nastavení správy. Jakmile je zapnutý, tento modul transparentně zašifruje všechny vaše soubory. Šifrování je založeno na AES 256 klíčích.\nModul se nedotkne existujících souborů, zašifrovány budou pouze nové soubory po zapnutí šifrování na straně serveru už není možné ho zase vypnout a vrátit se k nešifrovanému systému.\nNež se rozhodnete zapnout šifrování na straně serveru  přečtěte si dokumentaci, abyste se seznámili se známými důsledky.",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "Aplikace pro šifrování je zapnuta, ale šifrovací klíče ještě nejsou inicializované. Odhlaste se a znovu se přihlaste",
    "Encrypt the home storage" : "Zašifrovat domovské úložiště",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Povolení tohoto nastavení zašifruje všechny soubory uložené v hlavním úložišti, jinak budou šifrovány pouze soubory na externích úložištích.",
    "Enable recovery key" : "Povolit záchranný klíč",
    "Disable recovery key" : "Vypnout záchranný klíč",
    "The recovery key is an additional encryption key used to encrypt files. It is used to recover files from an account if the password is forgotten." : "Záchranný klíč je dodatečný šifrovací klíč sloužící pro šifrování souborů. Slouží k obnovení souborů z účtu, pokud dojde k zapomenutí hesla.",
    "Recovery key password" : "Heslo ke klíči pro obnovu",
    "Repeat recovery key password" : "Zopakovat heslo záchranného klíče",
    "Change recovery key password:" : "Změna hesla klíče pro obnovu:",
    "Old recovery key password" : "Staré heslo záchranného klíče",
    "New recovery key password" : "Nové heslo k záchrannému klíči",
    "Repeat new recovery key password" : "Zopakujte nové heslo záchranného klíče",
    "Change Password" : "Změnit heslo",
    "Basic encryption module" : "Základní šifrovací modul",
    "Your private key password no longer matches your log-in password." : "Heslo k vašemu soukromému klíči se už neshoduje s vaším přihlašovacím heslem.",
    "Set your old private key password to your current log-in password:" : "Změňte své staré heslo soukromého klíče na stejné, jako je vaše současné přihlašovací heslo:",
    "If you do not remember your old password you can ask your administrator to recover your files." : "Pokud si nepamatujete své původní heslo, můžete požádat správce o obnovu vašich souborů.",
    "Old log-in password" : "Původní přihlašovací heslo",
    "Current log-in password" : "Stávající přihlašovací heslo",
    "Update Private Key Password" : "Změnit heslo k soukromé části klíče",
    "Enable password recovery:" : "Povolit obnovu hesla:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Zapnutí této volby vám umožní znovu získat přístup k vašim zašifrovaným souborům pokud ztratíte heslo",
    "Enabled" : "Povoleno",
    "Disabled" : "Zakázáno"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
