OC.L10N.register(
    "profile",
    {
    "Profile" : "Profil",
    "This application provides the profile" : "Cette application fournit le profil",
    "Provides a customisable user profile interface." : "Fournit une interface de profil utilisateur personnalisable",
    "You have not added any info yet" : "Vous n’avez pas ajouté d’informations pour le moment",
    "{user} has not added any info yet" : "{user} n’a pas ajouté d’informations pour le moment",
    "Error opening the user status modal, try hard refreshing the page" : "Erreur lors de l'ouverture du modal du statut de l'utilisateur, essayez d'actualiser la page",
    "Edit Profile" : "Modifier le profil",
    "The headline and about sections will show up here" : "Le titre et la section « À propos » apparaîtront ici",
    "Profile not found" : "Profile introuvable",
    "The profile does not exist." : "Le profile n'existe pas.",
    "Back to %s" : "Retourner à %s"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
