OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Lisätty luotettujen palvelimien luetteloon",
    "Server is already in the list of trusted servers." : "Palvelin on jo luotettujen palvelimien luettelossa.",
    "No server to federate with found" : "Palvelinta, johon liittyä, ei löytynyt",
    "Could not add server" : "Palvelimen lisääminen ei onnistunut",
    "Trusted servers" : "Luotetut palvelimet",
    "Federation" : "Federaatio",
    "+ Add trusted server" : "+ Lisää luotettu palvelin",
    "Trusted server" : "Luotettu palvelin",
    "Add" : "Lisää"
},
"nplurals=2; plural=(n != 1);");
