OC.L10N.register(
    "sharebymail",
    {
    "Shared with {email}" : "Διαμοιράστηκε με {email}",
    "Shared with {email} by {actor}" : "Διαμοιράστηκε με {email} από {actor}",
    "Unshared from {email}" : "Διακοπή διαμοιρασμού από {email}",
    "Unshared from {email} by {actor}" : "Διακοπή διαμοιρασμού με {email} από {actor}",
    "Password for mail share sent to {email}" : "Ο κωδικός πρόσβασης διαμοιρασμού αλληλογραφίας αποστέλλεται στο {email}",
    "Password for mail share sent to you" : " Κωδικός πρόσβασης για διαμοιρασμό αλληλογραφίας σας έχει σταλεί",
    "You shared {file} with {email} by mail" : "Διαμοιραστήκατε {file} με {email} μέσω mail",
    "{actor} shared {file} with {email} by mail" : "{actor} διαμοίρασε {file} με {email} μέσω mail",
    "You unshared {file} from {email} by mail" : "Διακόψατε διαμοιρασμό {file} από {email} με mail",
    "{actor} unshared {file} from {email} by mail" : "Ο {actor} διέκοψε τον διαμοιρασμό το {file} από {email} με mail",
    "Password to access {file} was sent to {email}" : "Ο κωδικός πρόσβασης για πρόσβαση στο {file} έχει αποσταλεί στο {email}",
    "Password to access {file} was sent to you" : "Σας έχει αποσταλεί στο συνθηματικό για πρόσβαση {file}",
    "Share by mail" : "Διαμοιρασμός με ηλεκτρονική αλληλογραφία",
    "We cannot send you the auto-generated password. Please set a valid email address in your personal settings and try again." : "Δεν μπορούμε να σας στείλουμε τον κωδικό πρόσβασης που δημιουργείται αυτόματα. Ορίστε μια έγκυρη διεύθυνση email στις προσωπικές σας ρυθμίσεις και δοκιμάστε ξανά.",
    "Failed to send share by email. Got an invalid email address" : "Αποτυχία αποστολής της κοινής χρήσης μέσω email. Λάβαμε μια μη έγκυρη διεύθυνση email",
    "Failed to send share by email" : "Αποτυχία αποστολής συνδέσμου διαμοιρασμού μέσω Ηλ.ταχυδρομείου",
    "Note:" : "Σημείωση:",
    "Open %s" : "Άνοιγμα %s",
    "%1$s via %2$s" : "%1$s μέσω %2$s",
    "It is protected with the following password:" : "Προστατευμένο με το συνθηματικό:",
    "This password will expire at %s" : "Αυτός ο κωδικός πρόσβασης θα λήξει την %s",
    "This is the password:" : "Αυτό είναι το συνθηματικό:",
    "You can choose a different password at any time in the share dialog." : "Μπορείτε να διαλέξετε ένα διαφορετικό συνθηματικό οποιαδήποτε στιγμή στον διάλογο διαμοιρασμού.",
    "Could not find share" : "Αδυναμία εύρεσης κοινόχρηστου",
    "Share provider which allows you to share files by mail" : "Πάροχος διαμοιρασμού που σας επιτρέπει να διαμοιράζεστε αρχεία μέσω mail",
    "Unable to update share by mail config" : "Αδυναμία ενημέρωσης των ρυθμίσεων κοινής χρήσης μέσω mail",
    "Send password by mail" : "Αποστολή συνθηματικου με ηλεκτρονική αλληλογραφία",
    "Reply to initiator" : "Απάντηση στον αποστολέα"
},
"nplurals=2; plural=(n != 1);");
