OC.L10N.register(
    "bruteforcesettings",
    {
    "Brute-force settings" : "Väsytyshyökkäyksen asetukset",
    "Whitelist IPs" : "Sallitut IP:t",
    "Brute-force IP whitelist" : "Turvallisten IP-osoitteiden lista",
    "Add" : "Lisää"
},
"nplurals=2; plural=(n != 1);");
