OC.L10N.register(
    "circles",
    {
    "Personal" : "Сопствен",
    "System" : "Систем",
    "Visible" : "Видлив",
    "Open" : "Отвори",
    "Invite" : "Покани",
    "Password protected" : "Заштитено со лозинка",
    "Hidden" : "Сокриен",
    "Local" : "Локално",
    "Root" : "Корен",
    "Federated" : "Федерален",
    "Email address" : "Е-пошта адреса",
    "Contact" : "Контакт",
    "Circle" : "Круг",
    "Member" : "Член",
    "Moderator" : "Модератор",
    "Admin" : "Администратор",
    "Owner" : "Сопственик",
    "%s shared »%s« with you." : "%s сподели »%s« со вас.",
    "Password to access »%1$s« shared to you by %2$s" : "Лозинката за пристап до »%1$s« е споделена со вас од %2$s",
    "Password to access »%s«" : "Лозинка за пристап »%s«",
    "It is protected with the following password:" : "Заштитено е со следнава лозинка:",
    "%1$s via %2$s" : "%1$s преку %2$s",
    "Click the button below to open it." : "Кликнете на копчето подолу за да ја отворите.",
    "Open »%s«" : "Отвори »%s«",
    "Files" : "Датотеки",
    "Accept" : "Прифати",
    "%s" : "%s",
    "Open %s" : "Отвори %s",
    "No files in here" : "Тука нема датотеки",
    "No entries found in this folder" : "Нема ништо во оваа папка",
    "Name" : "Име",
    "Size" : "Големина",
    "Modified" : "Изменето",
    "Shared to Circles" : "Споделено со кругови"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
