<?php
namespace Aws\AppRegistry\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Service Catalog App Registry** service.
 */
class AppRegistryException extends AwsException {}
