OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Saio hasiera kokapen berria antzeman da",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "Saio hasiera berri bat antzeman da zure kontuan. %s IP helbidea susmagarritzat sailkatua izan da. Zu izanez gero, mezu honi ezikusi egin diezaiokezu. Bestela zure pasahitza aldatu beharko zenuke. ",
    "Suspicious Login" : "Saio hasiera susmagarria",
    "New login detected" : "Saio hasiera berria antzemana",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Antzeman eta ohartarazi IP susmagarrien saio hasierak Nextcloud-en",
    "Suspicious login detection" : "Saio hasiera susmagarrien antzematea",
    "The suspicious login app is enabled on this instance. It will keep track of IP addresses users successfully log in from and build a classifier that warns if a new login comes from a suspicious IP address." : "Saio hasiera susmagarrien aplikazioa gaituta dago instantzia honetan. Erabiltzaileak arrakastaz saioa hasteko erabiltzen duen IP helbideen erregistroa izango du, eta sailkatzaile bat sortuko du, saio hasiera berri bat IP helbide susmagarri batetik datorren ohartarazteko.",
    "Training data statistics" : "Prestakuntza datuen estatistikak",
    "So far the app has captured {total} logins (including client connections), of which {distinct} are distinct (IP, UID) tuples." : "Orain arte, aplikazioak {total} saio hasiera atzeman ditu (bezeroekiko konexioak barne), eta horietatik {distinct} tupla (IP, UID) desberdinak dira.",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Classifier model statistics" : "Sailkapen ereduen estatistikak",
    "No classifier model has been trained yet. This most likely means that you just enabled the app recently. Because the training of a model requires good data, the app waits until logins of at least {days} days have been captured." : "Oraindik ez da sailkatzaile eredurik trebatu. Ziurrenik horrek aplikazioa duela gutxi gaitu duzula esan nahi du. Eredu baten trebakuntzak datu onak eskatzen dituenez, aplikazioak gutxienez {days} egunetako saio hasierak atzematen diren arte itxaroten du.",
    "During evaluation, the latest model (trained {time}) has shown to capture {recall}% of all suspicious logins (recall), whereas {precision}% of the logins classified as suspicious are indeed suspicious (precision). Below you see a visualization of historic model performance." : "Ebaluazioan, azken ereduak ({time} entrenatuta) erakutsi du hasierako saio susmagarrien guztien %{recall} harrapatzea (gogoratzea), hala ere, susmagarritzat sailkatutako sarbideen %{precision}ak susmagarriak dira (zehaztasuna). Jarraian, eredu historikoen errendimenduaren bistaratzea ikus daiteke.",
    "Precision" : "Zehaztasuna",
    "Recall" : "Berreskuratu"
},
"nplurals=2; plural=(n != 1);");
