OC.L10N.register(
    "bruteforcesettings",
    {
    "IP address" : "IP-address",
    "Add" : "Lisa",
    "Delete entry for {subnet}" : "Kustuta „{subnet}“ kirje"
},
"nplurals=2; plural=(n != 1);");
