<?php
// This file is auto-generated. Do not edit!
return array('digits-ordinal'=>array('-x'=>array('rule'=>'−→→'),'integer'=>array(array('rule'=>'=#,##0=e'))),'%2d-year'=>array('integer'=>array(array('rule'=>'honderd'),array('rule'=>'=%spellout-numbering='))),'spellout-numbering-year'=>array('-x'=>array('rule'=>'min →→'),'x.x'=>array('rule'=>'=0.0='),'integer'=>array(0=>array('rule'=>'=%spellout-numbering='),1100=>array('rule'=>'←←→%%2d-year→','radix'=>100),2000=>array('rule'=>'=%spellout-numbering='),2100=>array('rule'=>'←←→%%2d-year→','radix'=>100),3000=>array('rule'=>'=%spellout-numbering='),3100=>array('rule'=>'←←→%%2d-year→','radix'=>100),4000=>array('rule'=>'=%spellout-numbering='),4100=>array('rule'=>'←←→%%2d-year→','radix'=>100),5000=>array('rule'=>'=%spellout-numbering='),5100=>array('rule'=>'←←→%%2d-year→','radix'=>100),6000=>array('rule'=>'=%spellout-numbering='),6100=>array('rule'=>'←←→%%2d-year→','radix'=>100),7000=>array('rule'=>'=%spellout-numbering='),7100=>array('rule'=>'←←→%%2d-year→','radix'=>100),8000=>array('rule'=>'=%spellout-numbering='),8100=>array('rule'=>'←←→%%2d-year→','radix'=>100),9000=>array('rule'=>'=%spellout-numbering='),9100=>array('rule'=>'←←→%%2d-year→','radix'=>100),10000=>array('rule'=>'=%spellout-numbering='))),'spellout-numbering'=>array('integer'=>array(array('rule'=>'=%spellout-cardinal='))),'%number-en'=>array('integer'=>array(1=>array('rule'=>'een­en­'),2=>array('rule'=>'twee­ën­'),3=>array('rule'=>'drie­ën­'),4=>array('rule'=>'=%spellout-cardinal=­en­'))),'spellout-cardinal'=>array('-x'=>array('rule'=>'min →→'),'x.x'=>array('rule'=>'←← komma →→'),'integer'=>array(0=>array('rule'=>'nul'),1=>array('rule'=>'een'),2=>array('rule'=>'twee'),3=>array('rule'=>'drie'),4=>array('rule'=>'vier'),5=>array('rule'=>'vijf'),6=>array('rule'=>'zes'),7=>array('rule'=>'zeven'),8=>array('rule'=>'acht'),9=>array('rule'=>'negen'),10=>array('rule'=>'tien'),11=>array('rule'=>'elf'),12=>array('rule'=>'twaalf'),13=>array('rule'=>'dertien'),14=>array('rule'=>'veertien'),15=>array('rule'=>'vijftien'),16=>array('rule'=>'zestien'),17=>array('rule'=>'zeventien'),18=>array('rule'=>'achttien'),19=>array('rule'=>'negentien'),20=>array('rule'=>'[→%%number-en→]twintig'),30=>array('rule'=>'[→%%number-en→]dertig'),40=>array('rule'=>'[→%%number-en→]veertig'),50=>array('rule'=>'[→%%number-en→]vijftig'),60=>array('rule'=>'[→%%number-en→]zestig'),70=>array('rule'=>'[→%%number-en→]zeventig'),80=>array('rule'=>'[→%%number-en→]tachtig'),90=>array('rule'=>'[→%%number-en→]negentig'),100=>array('rule'=>'honderd[→→]'),200=>array('rule'=>'←←­honderd[­→→]'),1000=>array('rule'=>'duizend[­→→]'),2000=>array('rule'=>'←←­duizend[­→→]'),100000=>array('rule'=>'←←­duizend[­→→]','radix'=>1000),1000000=>array('rule'=>'←← miljoen[ →→]'),1000000000=>array('rule'=>'←← miljard[ →→]'),'1000000000000'=>array('rule'=>'←← biljoen[ →→]'),'1000000000000000'=>array('rule'=>'←← biljard[ →→]'),'1000000000000000000'=>array('rule'=>'=#,##0='))),'%ord-ste'=>array('integer'=>array(array('rule'=>'ste'),array('rule'=>'­=%spellout-ordinal='))),'spellout-ordinal'=>array('-x'=>array('rule'=>'min →→'),'x.x'=>array('rule'=>'=#,##0.#='),'integer'=>array(0=>array('rule'=>'nulste'),1=>array('rule'=>'eerste'),2=>array('rule'=>'tweede'),3=>array('rule'=>'derde'),4=>array('rule'=>'=%spellout-cardinal=de'),8=>array('rule'=>'=%spellout-cardinal=ste'),9=>array('rule'=>'=%spellout-cardinal=de'),20=>array('rule'=>'=%spellout-cardinal=ste'),100=>array('rule'=>'honderd→%%ord-ste→'),200=>array('rule'=>'←%spellout-cardinal←­honderd→%%ord-ste→'),1000=>array('rule'=>'duizend→%%ord-ste→'),2000=>array('rule'=>'←%spellout-cardinal←­duizend→%%ord-ste→'),1000000=>array('rule'=>'←%spellout-cardinal←­miljoen→%%ord-ste→'),1000000000=>array('rule'=>'←%spellout-cardinal←­miljard→%%ord-ste→'),'1000000000000'=>array('rule'=>'←%spellout-cardinal←­biljoen→%%ord-ste→'),'1000000000000000'=>array('rule'=>'←%spellout-cardinal←­biljard→%%ord-ste→'),'1000000000000000000'=>array('rule'=>'=#,##0=.'))));
