OC.L10N.register(
    "circles",
    {
    "Teams" : "Equipos",
    "You created the team {circle}" : "Creesti l'equipu «{circle}»",
    "{author} created the team {circle}" : "{author} creó l'equipu «{circle}»",
    "You deleted {circle}" : "Desaniciesti «{circle}»",
    "{author} deleted {circle}" : "{author} desanició «{circle}»",
    "You made {member} join {circle}" : "Ficiesti que {member} se xuniere a «{circle}»",
    "{author} made {member} join {circle}" : "{author} fizo que {member} se xuniere a «{circle}»",
    "You added team {member} as member to {circle}" : "Amestesti l'equipu «{member}» como miembru de «{circle}»",
    "You made {member} leave {circle}" : "Ficiesti que {member} colare de: {cicle}",
    "{author} made {member} leave {circle}" : "{author} fizo que {member} colare de: {circle}",
    "You removed {member} from {circle}" : "Quitesti a {member} de: {circle}",
    "You joined {circle}" : "Xuniéstite a «{circle}»",
    "{member} joined {circle}" : "{member} xunióse a «{circle}»",
    "You accepted the invitation to join {circle}" : "Aceptesti la invitación pa xunite a «{circle}»",
    "{member} accepted the invitation to join {circle}" : "{member} aceptó la invitación a xunise a «{circle}»",
    "You added {member} as member to {circle}" : "Metiesti a {member} nel «{circle}»",
    "You have been added as member to {circle} by {author}" : "{author} metióte en: {circle}",
    "{member} has been added as member to {circle} by {author}" : "{author} metió a {member} en: {circle}",
    "You added {external} to {circle}" : "Amestesti «{external}» a «{circle}»",
    "{external} has been added to {circle} by {author}" : "{author} amestó «{external}» a «{circle}»",
    "You accepted {member}'s request to join {circle}" : "Aceptesti la solicitú de {member} pa xunite a «{circle}»",
    "Your request to join {circle} has been accepted by {author}" : "{author} aceptó la to solicitú pa xunise a «{circle}»",
    "{member}'s request to join {circle} has been accepted by {author}" : "{author} aceptó la solicitú de «{member}» pa xunise a «{circle}»",
    "You left {circle}" : "Colesti de: {circle}",
    "{member} left {circle}" : "{member} coló de: {circle}",
    "You declined the invitation to join {circle}" : "Refuguesti la invitación pa xunite a «{circle}«",
    "{member} declined an invitation to join {circle}" : "{member} refugó la invitación pa xunise a «{circle}»",
    "You cancelled your request to join {circle}" : "Anulesti la solicitú pa xunite a «{circle}»",
    "{member} cancelled a request to join {circle}" : "{member} anuló una solicitú pa xunise a «{circle}»",
    "You have been removed from {circle} by {author}" : "{author} quitóte de: {circle}",
    "{member} has been removed from {circle} by {author}" : "{author} quitó a {member} de {circle}",
    "You removed {external} from {circle}" : "Quitesti «{external}» de: {circle}",
    "{external} has been removed from {circle} by {author}" : "{author} quitó «{external}» de: {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "Anulesti la invitación de {member} pa xunise a «{circle}»",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} anuló la invitación pa xunite a «{circle}»",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} anuló la invitación de {member} pa xunise a «{circle}»",
    "You dismissed {member}'s request to join {circle}" : "Escartesti la solicitú de «{member}» pa xunise a: {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "{author} escartó la solicitú pa xunite a {circle}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} escartó la solicitú de {member} pa xunise a «{circle}»",
    "You invited {member} to join {circle}" : "Convidesti a {member} a que se xuniere a «{circle}»",
    "You have been invited to join {circle} by {author}" : "{author} convitóte a que te xunieres a {circle}",
    "{member} has been invited to join {circle} by {author}" : "{author} convidó a {member} a que se xuniere a «{circle}»",
    "You changed {member}'s level in {circle} to %1$s" : "Camudesti'l nivel de {member} en «{circle}» a %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} camudó'l to nivel en «{circle}» a %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} camudó'l nivel de {member} en «{circle}» a %1$s",
    "You sent a request to join {circle}" : "Unvióse una solicitú pa xunite a «{circle}»",
    "{member} sent a request to join {circle}" : "{member} unvióte una solicitú pa xunite a «{circle}»",
    "You are the new owner of {circle}" : "Yes el propietariu nuevu de: {circle}",
    "{member} is the new owner of {circle}" : "{member} ye'l propietariu nuevu de: {circle}",
    "On events happening in a <strong>team</strong> of which you are a member" : "Sobre eventos que pasen nun <strong>equipu</strong> del que seyas miembru",
    "Any important event in a <strong>team</strong> you are moderating" : "Cualesquier eventu nun <strong>equipu</strong> que llendes",
    "On global events happening in any <strong>team</strong>" : "Sobre eventos globales que pasen en cualesquier <strong>equipu</strong>",
    "Single" : "Individual",
    "Personal" : "Personal",
    "System" : "Sistema",
    "Visible" : "Visible",
    "Open" : "Abrir",
    "Invite" : "Convidar",
    "Join request" : "Solicitú de xunión",
    "Friends" : "Amigos",
    "Password protected" : "Proteición con contraseña",
    "No Owner" : "Ensin propietariu",
    "Hidden" : "Anubrióse",
    "Backend" : "Backend",
    "Local" : "Llocal",
    "Root" : "Raigañu",
    "Team invite" : "Invitación el equipu",
    "Federated" : "Federada",
    "Mount point" : "Puntu de montaxe",
    "Nextcloud Account" : "Cuenta de Nextcloud",
    "Nextcloud Group" : "Grupu de Nextcloud",
    "Email address" : "Direición de corréu electrónicu",
    "Contact" : "Contautu",
    "Circle" : "Círculu",
    "Nextcloud App" : "Aplicación Nextcloud",
    "Member" : "Miembru",
    "Moderator" : "Llendador",
    "Admin" : "Alministración",
    "Owner" : "Propietariu",
    "%s shared »%s« with you." : "%s compartió «%s» contigo.",
    "%s shared »%s« with \"%s\"." : "%s compartió «%s» con «%s».",
    "%s on %s" : "%s n %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s compartió «%2$s» contigo.\nHubiesti recibir un corréu electrónicu con un enllaz p'acceder al elementu.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s compartió «%2$s» contigo. Hubiesti recibir un corréu electrónicu con un enllaz p'acceder al elementu.",
    "Password to access »%1$s« shared to you by %2$s" : "%2$s compartió contigo la contraseña p'acceder a «%1$s»",
    "Password to access »%s«" : "La contraseña p'acceder a «%s»",
    "It is protected with the following password:" : "L'elementu ta protexíu cola contraseña siguiente:",
    "%1$s via %2$s" : "%1$s per %2$s",
    "Click the button below to open it." : "Calca nel botón p'abrilo.",
    "Open »%s«" : "Abrir «%s»",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s compartió múltiples ficheros contigo.\nHubiesti recibir un corréu electrónicu con un enllaz p'acceder a elli.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s compartió múltiples ficheros contigo. Hubiesti recibir un corréu electrónicu con un enllaz p'acceder a elli.",
    "Password to access files shared to you by %1$s" : "Contraseña p'acceder a los ficheros que %1$s compartió contigo",
    "Password to access files" : "Contraseña p'acceder a los ficheros",
    "%s shared multiple files with \"%s\"." : "%s compartió múltiples ficheros con «%s».",
    "%s shared multiple files with you." : "%s compartió múltiples ficheros contigo.",
    "Boot up" : "Arrinque",
    "Nextcloud Initialization" : "Aniciu de Nextcloud",
    "Circles App Initialization" : "Aniciu de l'aplicación Círculos",
    "Fresh installation status" : "Estáu de la instalación nueva",
    "Building Local Database" : "Creando la base de datos llocal",
    "Testing Basic Circle Creation" : "Probando la creación d'un círculu básicu",
    "Adding local users and moderators" : "Amestando usuarios y moderadores llocales",
    "Show all teams" : "Amosar tolos equipos",
    "Create a new team" : "Crear un equipu",
    "Files" : "Ficheros",
    "This feature is not available for personal circles" : "Esta función nun ta disponible pa los círculos personales",
    "The team is not federated" : "L'equipu nun ta federáu",
    "You cannot join this team" : "Nun pues xunite a esti equipu",
    "This member is not a moderator" : "Esti miembru nun ye llendador",
    "Insufficient privileges" : "Nun hai abondos privilexos",
    "This member does not exist" : "Esti miembru nun esiste",
    "This member is the owner of the team" : "Esti miembru ye propietariu del equipu",
    "Level cannot be changed for this type of member" : "Nun se pue camudar el nivel d'esti tipu de miembru",
    "You are already a member of this circle" : "Yá yes miembru d'esti círculu",
    "You have been blocked from this circle" : "Bloquiáronte nesti círculu",
    "The account is already a member of this circle" : "La cuenta yá ye miembru d'esti círculu",
    "The account has already been invited into this circle" : "La cuenta yá recibió una invitación d'esti círculu",
    "%s (Team owned by %s)" : "%s (equipu propiedá de: %s)",
    "Accept" : "Aceptar",
    "Refuse" : "Refugar",
    "%s" : "%s",
    "Personal team" : "Equipu personal",
    "%s owned by %s" : "«%s» ye propiedá de: %s",
    "You have no permission to create a new team" : "Nun tienes permisu pa crear un equipu",
    "%s shared a file with \"%s\"." : "%s compartió un ficheru con «%s».",
    "%s shared a file with you." : "%s compartió un ficheru contigo.",
    "Open %s" : "Abrir «%s»",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s compartió conteníu contigo.\nHubiesti recibir un corréu electrónicu con un enllaz p'acceder a elli.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s compartió conteníu contigo. Hubiesti recibir un corréu electrónicu con un enllaz p'acceder a elli.",
    "Password to access content shared with you by %1$s" : "La contraseña p'acceder al conteníu que %1$s compartió contigo",
    "Password to access content" : "La contraseña p'acceder al conteníu",
    "This item is already shared with this team" : "Esti elementu yá ta compartíu con esti equipu",
    "Bring cloud-users closer together." : "Axunta los usuarios de la nube.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Los equipos permiten a les persones crear los sos grupos de xente.\nCualesquier otra aplicación pue usar estos grupos de persones pa compartir.",
    "No files in here" : "Nun hai ficheros",
    "No entries found in this folder" : "Nun s'atopó nenguna entrada nesta carpeta",
    "Name" : "Nome",
    "Size" : "Tamañu",
    "Modified" : "Modificóse",
    "Teams' files" : "Ficheros d'Equipos",
    "Select team to filter by" : "Seleiciona los equipos polos que quies peñerar",
    "No teams found" : "Nun s'atopó nengún equipu",
    "Please select teams to filter by" : "Seleiciona los equipos polos que quies peñerar",
    "No files found for the selected teams" : "Nun s'atopó nengún ficheru pa los equipos seleicionaos",
    "Shared to Circles" : "Compartióse en Círculos"
},
"nplurals=2; plural=(n != 1);");
