<?php
// This file is auto-generated. Do not edit!
return array('minDays'=>array('001'=>1,'AD'=>4,'AN'=>4,'AT'=>4,'AX'=>4,'BE'=>4,'BG'=>4,'CH'=>4,'CZ'=>4,'DE'=>4,'DK'=>4,'EE'=>4,'ES'=>4,'FI'=>4,'FJ'=>4,'FO'=>4,'FR'=>4,'GB'=>4,'GF'=>4,'GG'=>4,'GI'=>4,'GP'=>4,'GR'=>4,'GU'=>1,'HU'=>4,'IE'=>4,'IM'=>4,'IS'=>4,'IT'=>4,'JE'=>4,'LI'=>4,'LT'=>4,'LU'=>4,'MC'=>4,'MQ'=>4,'NL'=>4,'NO'=>4,'PL'=>4,'PT'=>4,'RE'=>4,'RU'=>4,'SE'=>4,'SJ'=>4,'SK'=>4,'SM'=>4,'UM'=>1,'US'=>1,'VA'=>4,'VI'=>1),'firstDay'=>array('001'=>1,'AD'=>1,'AE'=>6,'AF'=>6,'AG'=>0,'AI'=>1,'AL'=>1,'AM'=>1,'AN'=>1,'AR'=>1,'AS'=>0,'AT'=>1,'AU'=>1,'AX'=>1,'AZ'=>1,'BA'=>1,'BD'=>0,'BE'=>1,'BG'=>1,'BH'=>6,'BM'=>1,'BN'=>1,'BR'=>0,'BS'=>0,'BT'=>0,'BW'=>0,'BY'=>1,'BZ'=>0,'CA'=>0,'CH'=>1,'CL'=>1,'CM'=>1,'CN'=>1,'CO'=>0,'CR'=>1,'CY'=>1,'CZ'=>1,'DE'=>1,'DJ'=>6,'DK'=>1,'DM'=>0,'DO'=>0,'DZ'=>6,'EC'=>1,'EE'=>1,'EG'=>6,'ES'=>1,'ET'=>0,'FI'=>1,'FJ'=>1,'FO'=>1,'FR'=>1,'GB'=>1,'GB-alt-variant'=>0,'GE'=>1,'GF'=>1,'GP'=>1,'GR'=>1,'GT'=>0,'GU'=>0,'HK'=>0,'HN'=>0,'HR'=>1,'HU'=>1,'ID'=>0,'IE'=>1,'IL'=>0,'IN'=>0,'IQ'=>6,'IR'=>6,'IS'=>1,'IT'=>1,'JM'=>0,'JO'=>6,'JP'=>0,'KE'=>0,'KG'=>1,'KH'=>0,'KR'=>0,'KW'=>6,'KZ'=>1,'LA'=>0,'LB'=>1,'LI'=>1,'LK'=>1,'LT'=>1,'LU'=>1,'LV'=>1,'LY'=>6,'MC'=>1,'MD'=>1,'ME'=>1,'MH'=>0,'MK'=>1,'MM'=>0,'MN'=>1,'MO'=>0,'MQ'=>1,'MT'=>0,'MV'=>5,'MX'=>0,'MY'=>1,'MZ'=>0,'NI'=>0,'NL'=>1,'NO'=>1,'NP'=>0,'NZ'=>1,'OM'=>6,'PA'=>0,'PE'=>0,'PH'=>0,'PK'=>0,'PL'=>1,'PR'=>0,'PT'=>0,'PY'=>0,'QA'=>6,'RE'=>1,'RO'=>1,'RS'=>1,'RU'=>1,'SA'=>0,'SD'=>6,'SE'=>1,'SG'=>0,'SI'=>1,'SK'=>1,'SM'=>1,'SV'=>0,'SY'=>6,'TH'=>0,'TJ'=>1,'TM'=>1,'TR'=>1,'TT'=>0,'TW'=>0,'UA'=>1,'UM'=>0,'US'=>0,'UY'=>1,'UZ'=>1,'VA'=>1,'VE'=>0,'VI'=>0,'VN'=>1,'WS'=>0,'XK'=>1,'YE'=>0,'ZA'=>0,'ZW'=>0),'weekOfPreference'=>array('af'=>array('weekOfDate','weekOfInterval','weekOfMonth'),'am'=>array('weekOfYear','weekOfMonth'),'az'=>array('weekOfYear','weekOfMonth'),'bs'=>array('weekOfYear','weekOfMonth'),'cs'=>array('weekOfYear','weekOfMonth'),'cy'=>array('weekOfYear','weekOfMonth'),'da'=>array('weekOfYear','weekOfMonth'),'el'=>array('weekOfYear','weekOfMonth'),'et'=>array('weekOfYear','weekOfMonth'),'hi'=>array('weekOfYear','weekOfMonth'),'ky'=>array('weekOfYear','weekOfMonth'),'lt'=>array('weekOfYear','weekOfMonth'),'mk'=>array('weekOfYear','weekOfMonth'),'sk'=>array('weekOfYear','weekOfMonth'),'ta'=>array('weekOfYear','weekOfMonth'),'th'=>array('weekOfYear','weekOfMonth'),'ar'=>array('weekOfMonth'),'fil'=>array('weekOfMonth'),'gu'=>array('weekOfMonth'),'hu'=>array('weekOfMonth'),'hy'=>array('weekOfMonth'),'id'=>array('weekOfMonth'),'kk'=>array('weekOfMonth'),'ko'=>array('weekOfMonth'),'be'=>array('weekOfInterval','weekOfMonth'),'ro'=>array('weekOfInterval','weekOfMonth'),'ru'=>array('weekOfInterval','weekOfMonth'),'bg'=>array('weekOfDate','weekOfMonth','weekOfInterval'),'de'=>array('weekOfDate','weekOfMonth','weekOfInterval'),'he'=>array('weekOfDate','weekOfMonth','weekOfInterval'),'pt'=>array('weekOfDate','weekOfMonth','weekOfInterval'),'ur'=>array('weekOfDate','weekOfMonth','weekOfInterval'),'zh'=>array('weekOfDate','weekOfMonth','weekOfInterval'),'ca'=>array('weekOfDate'),'es'=>array('weekOfDate'),'fr'=>array('weekOfDate'),'gl'=>array('weekOfDate'),'en'=>array('weekOfDate','weekOfMonth'),'bn'=>array('weekOfDate','weekOfMonth'),'ja'=>array('weekOfDate','weekOfMonth'),'ka'=>array('weekOfDate','weekOfMonth'),'eu'=>array('weekOfMonth','weekOfDate'),'fa'=>array('weekOfMonth','weekOfInterval'),'hr'=>array('weekOfMonth','weekOfInterval'),'it'=>array('weekOfMonth','weekOfInterval'),'lv'=>array('weekOfMonth','weekOfInterval'),'pl'=>array('weekOfMonth','weekOfInterval'),'si'=>array('weekOfMonth','weekOfInterval'),'sr'=>array('weekOfMonth','weekOfInterval'),'uk'=>array('weekOfMonth','weekOfInterval'),'uz'=>array('weekOfMonth','weekOfInterval'),'fi'=>array('weekOfYear','weekOfDate','weekOfMonth'),'zh-TW'=>array('weekOfYear','weekOfDate','weekOfMonth'),'is'=>array('weekOfYear','weekOfMonth','weekOfInterval'),'mn'=>array('weekOfYear','weekOfMonth','weekOfInterval'),'nb'=>array('weekOfYear','weekOfMonth','weekOfInterval'),'no'=>array('weekOfYear','weekOfMonth','weekOfInterval'),'sv'=>array('weekOfYear','weekOfMonth','weekOfInterval'),'vi'=>array('weekOfYear','weekOfMonth','weekOfInterval'),'km'=>array('weekOfMonth','weekOfYear'),'mr'=>array('weekOfMonth','weekOfYear'),'kn'=>array('weekOfMonth','weekOfDate','weekOfYear'),'ml'=>array('weekOfMonth','weekOfDate','weekOfYear'),'pa'=>array('weekOfMonth','weekOfDate','weekOfYear'),'lo'=>array('weekOfMonth','weekOfInterval','weekOfDate','weekOfYear'),'sq'=>array('weekOfMonth','weekOfInterval','weekOfDate','weekOfYear'),'ms'=>array('weekOfMonth','weekOfYear','weekOfInterval','weekOfDate'),'tr'=>array('weekOfMonth','weekOfYear','weekOfInterval','weekOfDate'),'nl'=>array('weekOfDate','weekOfYear','weekOfMonth'),'sl'=>array('weekOfInterval'),'sw'=>array('weekOfMonth','weekOfInterval','weekOfYear'),'te'=>array('weekOfMonth','weekOfInterval','weekOfYear'),'und'=>array('weekOfYear'),'zu'=>array('weekOfYear','weekOfInterval')));
