OC.L10N.register(
    "photos",
    {
    "Photos" : "Foto",
    "Videos" : "Video",
    "Favorites" : "Favorit",
    "Shared with you" : "Shared with you",
    "Tags" : "Emneord",
    "Back" : "Tilbake",
    "Save" : "Lagre",
    "Shared by" : "Delt av",
    "Group" : "Gruppe",
    "An error occurred" : "Det oppstod ein feil.",
    "Favorite" : "Favoritt",
    "Home" : "Heim",
    "Remove from favorites" : "Remove from favorites",
    "Details" : "Detaljar",
    "Add" : "Legg til"
},
"nplurals=2; plural=(n != 1);");
