OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Dodano do listy zaufanych serwerów.",
    "No server found with ID: %s" : "Nie znaleziono serwera o ID: %s",
    "Could not remove server" : "Nie można usunąć serwera",
    "Server is already in the list of trusted servers." : "Serwer znajduje się już na liście zaufanych serwerów.",
    "No server to federate with found" : "Nie znaleziono federacyjnego serwera",
    "Could not add server" : "Nie można dodać serwera",
    "Trusted servers" : "Zaufane serwery",
    "Federation" : "Federacja",
    "Federation allows you to connect with other trusted servers to exchange the account directory." : "Federacja umożliwia łączenie się z innymi zaufanymi serwerami w celu wymiany katalogu kont.",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing." : "Federacja umożliwia łączenie się z innymi zaufanymi serwerami w celu wymiany katalogu kont. Na przykład będzie to używane do automatycznego uzupełniania kont zewnętrznych na potrzeby udostępniania federacyjnego.",
    "External documentation for Federated Cloud Sharing" : "Dokumentacja zewnętrzna dla usługi Udostępnienia Chmury Federacyjnej",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "Federacja umożliwia łączenie się z innymi zaufanymi serwerami w celu wymiany katalogu kont. Na przykład zostanie to użyte do automatycznego uzupełniania dla zewnętrznych kont przy udostępnianiu federacyjnym. Nie jest konieczne dodawanie serwera jako serwera zaufanego w celu utworzenia udostępnienia federacyjnego.",
    "Each server must validate the other. This process may require a few cron cycles." : "Każdy serwer musi zweryfikować inny serwer. Ten proces może wymagać kilku cykli cron.",
    "+ Add trusted server" : "+ Dodaj zaufany serwer",
    "Trusted server" : "Zaufany serwer",
    "Add" : "Dodaj"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
