OC.L10N.register(
    "logreader",
    {
    "Logging" : "記錄",
    "Errors in the log" : "紀錄檔中的錯誤",
    "Failed to get an iterator for log entries: %s" : "無法取得日誌條目的迭代器：%s",
    "No errors in the logs since %s" : "從 %s 開始，紀錄檔中沒有錯誤",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["從 %s 開始，紀錄檔中有 %n 個錯誤"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["從 %s 開始，紀錄檔中有 %n 個警告"],
    "Log Reader" : "Log Reader",
    "A log reader for Nextcloud" : "Nextcloud 的紀錄檔閱讀程式",
    "Log reader for Nextcloud" : "Nextcloud 的紀錄檔閱讀程式",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "若您認為這是一個錯誤，請驗證您的 {config} 中的 {setting} 設定，並看看 Nextcloud 管理手冊。",
    "Log reader" : "紀錄檔閱讀程式",
    "Open log reader settings" : "開啟紀錄檔閱讀程式設定",
    "Log reader settings" : "紀錄檔閱讀程式設定",
    "Currently the log file {file} is shown" : "目前顯示紀錄檔 {file}",
    "Show server log" : "顯示伺服器紀錄檔",
    "Live view is disabled" : "即時檢視已停用",
    "No log file" : "無紀錄檔",
    "File-based logging must be enabled to access logs from the Web UI." : "啟用以檔案為基礎的紀錄才能從 Web UI 存取紀錄。",
    "Log entry successfully copied" : "成功複製紀錄檔條目",
    "Level" : "層級",
    "App" : "應用程式",
    "No app in context" : "情境中無應用程式",
    "Time" : "時間",
    "Copy raw entry" : "複製原始項目",
    "Copy formatted entry" : "複製格式化後的項目",
    "Hide exception details" : "隱藏例外詳細資訊",
    "View exception details" : "檢視例外詳細資訊",
    "Raw log entry" : "原始紀錄檔項目",
    "Search log entries" : "搜尋紀錄項目",
    "Caused by {exception}" : "由 {exception} 造成",
    "Line {line}" : "行 {line}",
    "Filter log levels" : "過濾紀錄層級",
    "Set log level" : "設定紀錄層級",
    "Time format" : "時間格式",
    "Live view" : "即時檢視",
    "Download/Upload logs" : "下載/上傳紀錄檔",
    "Ctrl" : "Ctrl",
    "Could not parse local log file" : "無法解析本機紀錄檔",
    "You can also show log entries copied from your clipboard by pasting them on the log view using: {keyboardShortcut}" : "您也可以使用以下命令將從剪貼簿複製的紀錄條目貼上到紀錄檢視中來顯示它們：{keyboardShortcut}",
    "Download logs" : "下載紀錄檔",
    "Show local log file" : "顯示本機紀錄檔",
    "Upload local log file to be displayed" : "上傳要顯示的本機紀錄檔",
    "Time format used for displaying the timestamp" : "用於顯示時間戳的時間格式",
    "(Local log files only support the \"raw\" time format)" : "（本機紀錄檔僅支援「原始」時間格式）",
    "Could not change date time format." : "無法變更日期時間格式",
    "Raw data" : "原始資料",
    "Local time" : "本地時間",
    "UTC time" : "UTC 時間",
    "Relative" : "相對",
    "Could not change live view setting." : "無法變更即時檢視設定。",
    "Polling is disabled because server is not configured to log to file" : "因為伺服器並未設定為紀錄到檔案，所有輪詢已被停用。",
    "Polling (live view)" : "輪詢（即時檢視）",
    "Could not set logging levels to show" : "無法設定要顯示的紀錄層級",
    "Filter logging levels" : "過濾紀錄層級",
    "Could not set logging level" : "無法設定紀錄層級",
    "Set backend loglevel" : "設定後端紀錄層級",
    "Application" : "應用程式",
    "Message" : "訊息",
    "Log entry actions" : "紀錄項目動作",
    "Loading older log entries" : "正在載入較舊的紀錄檔項目",
    "No older log entries available" : "無可用的較舊項目",
    "Collapse row" : "折疊列",
    "Expand row" : "展開列",
    "Show details" : "顯示細節",
    "Debug" : "Debug",
    "Info" : "Info",
    "Warning" : "Warning",
    "Error" : "Error",
    "Fatal" : "Fatal",
    "Could not load log entries" : "無法載入紀錄檔條目",
    "Clipboard" : "剪貼簿",
    "Could not parse clipboard content" : "無法解析剪貼簿內容",
    "Could not fetch new log entries (server unavailable)" : "無法擷取新紀錄項目（伺服器不可用）",
    "Could not fetch new entries" : "無法擷取新項目",
    "Could not copy to clipboard, please copy manually:" : "無法複製到剪貼簿，請手動複製：",
    "\tfrom {address} by {user} at {time}\n" : "\t來自 {address} 由 {user} 於 {time}\n"
},
"nplurals=1; plural=0;");
