OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "دليل التشغيل لأول مرة",
    "Add your profile information! For example your email is needed to receive notifications." : "أضف معلومات ملفك الشخصي! على سبيل المثال، هناك حاجة إلى بريدك الإلكتروني كي تتلقّي الإشعارات.",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "أضف معلومات ملفك الشخصي! على سبيل المثال، يلزم بريدك الإلكتروني كي تتلقّي الإشعارات و كي تعيد تعيين كلمة المرور الخاصة بك.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "أضف معلومات ملفك الشخصي! ضع صورتك و اكتب اسمك الكامل لتسهيل التعرّف عليك في كافة التطبيقات.",
    "Add your profile information! Set a full name for easier recognition across all features." : "قم بإضافة معلومات ملفك الشخصي! اكتب اسمك الكامل لتسهيل التعرّف عليك في كل التطبيقات.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "قم بإضافة معلومات ملفك الشخصي! ضع صورتك لتسهيل التعرّف عليك في كل التطبيقات.",
    "App recommendation: Calendar" : "تطبيق مقترح: التقويم",
    "Schedule work & meetings, synced with all your devices." : "قم بجدولة العمل والاجتماعات ، بالتزامن في جميع أجهزتك.",
    "App recommendation: Contacts" : "تقويم مقترح: جهات الاتصال",
    "Keep your colleagues and friends in one place without leaking their private info." : "احتفظ بزملائك وأصدقائك في مكان واحد دون تسريب معلوماتهم الخاصة.",
    "App recommendation: Mail" : "تطبيق مقترح: البريد الإلكتروني",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "تطبيق بريد إلكتروني بسيط متوافق بشكل ممتاز مع الملفات وجهات الاتصال والتقويم.",
    "App recommendation: Tasks" : "توصية بتطبيق: المهام Tasks",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "قم بمزامنة مهامك مع نكست كلاود بين جميع أجهزتك  ",
    "App recommendation: Deck" : "توصية بتطبيق: البطاقات",
    "Kanban style organization for personal planning and team projects." : "تنظيم الخطط الشخصية و مشاريع الفريق على طراز كانبان kanban.",
    "App recommendation: Forms" : "توصية بتطبيق: النماذج Forms",
    "Simple surveys and questionnaires, self-hosted" : "الاستبيانات على جهازك",
    "App recommendation: Recognize" : "توصية بتطبيق: التعرُّف Recognize",
    "Smart media tagging for Nextcloud" : "الوسم الذكي للوسائط smart media tagging على نكست كلاود",
    "App recommendation: Group folders" : "توصية بتطبيق: مجلدات المجموعة",
    "Admin-configured folders shared by everyone in a group." : "المجلدات التي تم تكوينها بواسطة المدير والتي يتشاركها الجميع في المجموعة.",
    "App recommendation: Whiteboard" : "تطبيقات مقترحة: \"اللوحة البيضاء\" Whileboard",
    "Create and share whiteboards with others and collaborate in real-time." : "إنشاء و مشاركة السبورة مع الآخرين والعمل معاً عليها في الوقت الحقيقي.",
    "Connect your calendar" : "قم بربط مُفكّرتك",
    "Connect your contacts" : "قم بريط قائمة مراسليك",
    "Access files via WebDAV" : "دخول الملفات باستخدام WebDAV",
    "Download macOS/iOS configuration profile" : "قم بتنزيل ملف تعريف التكوين لـ macOS/iOS",
    "Desktop client" : "تطبيق سطح المكتب",
    "Android app on Google Play Store" : "تطبيق أندرويد على متجر تطبيقات قوقل",
    "Android app on F-Droid" : "تطبق أندرويد على متجر F-Droid",
    "iOS app" : "تطبيق iOS",
    "About & What's new" : "حول النظام، و ما الجديد!",
    "A welcome and introduction wizard for Nextcloud" : "ترحيب و دليل تقديمي introduction wizard لنكست كلاود",
    "This application enables a pop-up window when a user first logs into Nextcloud. This window welcomes new users to Nextcloud, and contains links to the standard desktop client, Android app, and the iOS app. The window also shows a link for accessing Nextcloud via WebDAV. At any time, the first run wizard can be opened again via link \"About\" on settings menu.\nThe First run wizard can be customized to meet specific design goals, or to change links and messages. Create an appropriate theme following the Theming documentation, and changes to the look and feel of this Wizard are simple. More information is available in the first run wizard documentation, as well as the theming documentation." : "يتيح هذا التطبيق نافذة منبثقة عند تسجيل دخول المستخدم لأول مرة إلى Nextcloud. تُرحّب هذه النافذة بالمستخدمين الجدد في Nextcloud ، وتحتوي على روابط لعميل سطح المكتب القياسي وتطبيق Android وتطبيق iOS. تعرض النافذة أيضًا ارتباطًا للوصول إلى Nextcloud عبر WebDAV. في أي وقت، يمكن فتح هذا التطبيق مرة أخرى عبر الرابط \"حول\" في قائمة الإعدادات. يمكن تخصيص التطبيق لتلبية أهداف التصميم المحددة ، أو لتغيير الروابط والرسائل. أَنشئ موضوعًا مناسبًا باتباع وثائق الثيمات Theming، وستكون التغييرات في شكل وأسلوب هذا المعالج بسيطة. يتوفر المزيد من المعلومات في وثائق التطبيق، بالإضافة إلى وثائق الثيمات.",
    "Download on Apple app store" : "تنزيل على متجر تطبيقات آبل",
    "Download on Google play store" : "تنزيل على متجر تطبيقات قوقل",
    "Go to previous page" : "عُد إلى الصفحة السابقة",
    "Close" : "إغلاق",
    "More about Nextcloud" : "المزيد عن نكست كلاود",
    "Explore more apps ↗" : "استكشف المزيد من التطبيقات",
    "Extend the functionality of Nextcloud with hundreds of community-developed apps." : "وسِّع نطاق استعمالاتك لنكست كلاود من خلال المئات من التطبيقات المطورة من جماعة المصادر المفتوحة.",
    "Get involved! ↗" : "شارِك! ↗",
    "Be a part of the community that helps build, design, translate and promote Nextcloud!" : "كُن جزءاً من الجماعة التي تساهم في بناء و تصميم و ترجمة و نشر نكست كلاود!",
    "Need help? ↗" : "هل تحتاج إلى مساعدة؟ ↗",
    "Find out more about your Nextcloud setup with the admin, user or developer documentation." : "طالع المزيد عن كيفية إعداد نكست كلاود من خلال وثائق المديرين و المستخدمين و المطورين. ",
    "For large organisations ↗" : "للمؤسسات الكبيرة ↗",
    "Get Nextcloud Enterprise for mission critical environments where advanced security and compliance are important." : "إحصُل على نسخة نكست المؤسسية Nextcloud Enterprise للبيئات ذات طبيعة العمل الحساسة حيث اشتراطات الأمن و الامتثال مهمة و عالية.",
    "Seamless integration with your devices." : "تكامل سلس مع أجهزتك",
    "Sync your files across your devices with the desktop and mobile apps, and connect your calendar and contacts." : "قُم بمزامنة ملفاتك عبر أجهزتك المتعددة من خلال تطبيقات سطح المكتب و الهاتف النقال؛ و تواصل مع جهاتك اتصالك و تقويماتك.",
    "Desktop app ↗" : "تطبيق سطح المكتب ↗",
    "Download For Windows, Mac OS and Linux." : "التنزيل لويندوز، و ماك، و لينكس.",
    "Calendar and contacts ↗" : "التقويم و جهات الاتصال",
    "Connect your calendar and contacts with your devices." : "أوصِل جهات اتصالك و تقويماتك مع أجهزتك",
    "Introducing Nextcloud Hub {version}" : "تقديم نقطة التواصل لنكست كلاود {version}",
    "Welcome to {cloudName}!" : "أهلا بكم في {cloudName}!",
    "This Nextcloud is on version {version}" : "رقم الإصدار لنكست كلاود هذه هو {version}",
    "A collaboration platform that puts you in control" : "منصة تعاونية تتيح لك التحكم",
    "Privacy" : "الخصوصية",
    "Host your data and files where you decide." : "ضع بياناتك و ملفاتك حيثما رغِبت.",
    "Productivity" : "الإنتاجية",
    "Collaborate and communicate across any platform." : "التعاون و التواصل عبر المنصة",
    "Interoperability" : "التبادلية",
    "Import and export anything you want with open standards." : "تصدير و استيراد أي شيء بمعايير قياسية",
    "Community" : "المجتمع",
    "Enjoy constant improvements from a thriving open-source community." : "تمتع بالتطويرات المستمرة من جماعة المصادر المفتوحة.",
    "Nextcloud Hub {version} release" : "رقم إصدار نكست كلاود هب {version}  ",
    "Read more about it on the Nextcloud Hub {version} blog" : "لمزيد المعلومات حول نكست كلاود هب {version}، أنظُر المدونة",
    "Find out more on the blog" : "لمزيد المعلومات، أنظُر المدونة",
    "Read the Nextcloud Hub {version} blog" : "إقرأ مدونة نكست كلاود هب {version}",
    "Share your opinion about Nextcloud Hub {version}" : "شارك برأيك حول نكست كلاود هب {version}",
    "Share via email" : "مُشاركة عبر الإيميل",
    "Share on {socialMedia}" : "شارك على {socialMedia}",
    "New in Nextcloud Hub {version}" : "الجديد في نكست كلاود هب {version}",
    "Connect other apps to {productName}" : "ربط تطبيقات أخرى مع {productName}",
    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to {productName}." : "بالإضافة إلى تطبيقات الموبايل و عميل سطح المكتب، يمكنك التوصيل مع أي برمجيات أخرى تدعم بروتوكولات WebDAV/CalDAV/CardDAV: {productName}.",
    "Apps to connect to {productName}" : "تطبيقات ليتم ربطها مع {productName}",
    "Set up sync clients using an {linkStart}app password{linkEnd}. That way you can make sure you are able to revoke access in case you lose that device." : "إعداد عملاء للمزامنة باستعمال {linkStart}كلمة مرور{linkEnd}. بهذه الطريقة ستكون قادراً على سحب صلاحية الوصول في حال فقدك لذلك الجهاز. ",
    "Get the apps to sync your files" : "احصل على التطبيقات لمزامنة ملفاتك",
    "{productName} gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "{productName} تُمكِّنك من الوصول إلى ملفاتك حيثما كنت. تطبيقاتنا سهلة الاستعمال للموبايل و سطح المكتب متاحة على كافة المنصات الشائعة بدون أي تكلفة.",
    "App for syncing" : "تطبيقات للمزامنة",
    "URL copied" : "تمّ نسخ عنوان URL",
    "Could not copy the URL, please copy manually" : "تعذّر نسخ عنوان URL. يُرجى نسخه يدويّاً",
    "Server address" : "عنوان الخادم",
    "Use this link to connect your apps and desktop client to this server:" : "إستخدم هذا الرابط للربط بين تطبيقاتك و سطح المكتب مع هذا الخادم.",
    "End-to-end encryption in calls and web" : "التشفير من الحدّ للحدّ في المكالمات والوِب",
    "Performance improvements across all our products" : "تحسين الأداء في جميع منتجاتنا",
    "Thousands of tweaks for improved UX and stability" : "آلاف التحسينات في المظهر والاستقرار",
    "Your own new personal assistant" : "مُساعِدُك الخاصُّ الجديد",
    "Seamless file conversions" : "تحويلات سلسة للملفات",
    "Smarter team sharing with Team folders" : "مشاركة أكثر ذكاءً للفريق مع مجلدات الفريق",
    "Schedule meetings directly in Talk" : "جدولة الاجتماع مباشرة على تطبيق \"المحادثة\" Talk",
    "Mail you love again: translations, summaries, and mentions" : "البريد الإلكتروني الذي تحبُّه مجدداً: ترجمات، وملخصات، وإشارات",
    "Get to know the new features of Hub {version}" : "تعرَّف على المزايا الجديدة في \"هَبْ Hub\" {version}",
    "Nextcloud Hub 10 is here – your modular & unified digital workspace! 💫" : "الإصدار 10 من نكست كلود \"هَبْ Hub\" - فضاؤك الرقمي الانتقائي المُوحَّد  💫.",
    "What's new?" : "مالجديد؟",
    "Nextcloud on all your devices" : "نكست كلاود على جميع أجهزتك",
    "Nextcloud Hub {version}" : "نكست كلاود هب {version}",
    "Read more" : "إقرأ أكثر",
    "Share on social media" : "البحث في وسائط التواصل الاجتماعي",
    "Get started!" : "إبدَأ!",
    "App recommendation: Nextcloud Calendar" : "توصية بتطبيق: تقويم نكست كلاود Nextcloud Calendar",
    "App recommendation: Nextcloud Contacts" : "توصية بتطبيق: جهات الاتصال في نكست كلاود Nextcloud Contacts",
    "App recommendation: Nextcloud Mail" : "توصية بتطبيق: البريد الالكتروني في نكست كلاود Nextcloud Mail",
    "Federated collaboration: file sharing, messaging, calls" : "التعاون عبر السحابة الاتحادية: مشاركة الملفات، و التراسل، و المكالمات",
    "Nextcloud Whiteboard" : "سبُّورة نكست كلاود",
    "Workflow Engine" : "محرك سير العمل",
    "Safer and swifter mail" : "بريد أسرع و آمَن",
    "Public Collectives sharing, previews and QR-codes" : "مشاركة و معاينة التجميعات العامة، و أكواد كيو آر QR",
    "Office and PDF templates" : "قوالب مستندات \"أوفس\" و \"بي دي إف\"",
    "Chat mode for Nextcloud Assistant" : "وضعية الدردشة لمساعد نكست كلاود",
    "Get to know the new features of Hub 9" : "تعرَّف على المزايا الجديد لـ Hub 9"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
