OC.L10N.register(
    "sharebymail",
    {
    "Shared with {email}" : "用 {email} 共享",
    "Shared with {email} by {actor}" : "由 {actor} 通过 {email} 共享",
    "Unshared from {email}" : "通过 {email} 取消了共享 ",
    "Unshared from {email} by {actor}" : "{actor} 通过 {email} 取消了共享 ",
    "Password for mail share sent to {email}" : "邮件共享的密码已发送给 {email}",
    "Password for mail share sent to you" : "发送给您的邮件共享的密码",
    "You shared {file} with {email} by mail" : "您通过邮件 {email} 共享了 {file} ",
    "{actor} shared {file} with {email} by mail" : "{actor} 共享 {file} 于 {email} 通过邮件",
    "You unshared {file} from {email} by mail" : "您通过邮件 {email} 取消了 {file} 的共享。",
    "{actor} unshared {file} from {email} by mail" : "{email} 通过邮件取消了 {actor} 共享的 {file}",
    "Password to access {file} was sent to {email}" : "访问 {file} 的密码被发送给 {email}",
    "Password to access {file} was sent to you" : "访问 {file} 的密码已发送给您",
    "Share by mail" : "通过邮件共享",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "共享 %1$s 失败，因为该项目已与账号 %2$s 共享",
    "We cannot send you the auto-generated password. Please set a valid email address in your personal settings and try again." : "我们无法将自动生成的密码发送给您。请在您的个人设置中设置一个有效的电子邮件地址，然后重试。 ",
    "Failed to send share by email. Got an invalid email address" : "无法通过邮箱发送分享。无效邮箱",
    "Failed to send share by email" : "通过邮件发送共享失败",
    "%1$s shared %2$s with you" : "%1$s 与您分享了 %2$s ",
    "Note:" : "说明：",
    "This share is valid until %s at midnight" : "此分享有效期至午夜 %s",
    "Expiration:" : "有效期：",
    "Open %s" : "打开 %s",
    "%1$s via %2$s" : "%1$s 通过 %2$s",
    "%1$s shared %2$s with you. You should have already received a separate mail with a link to access it." : "%1$s 与您分享了 %2$s。您应该已经收到一封单独的邮件，其中包含访问链接。",
    "Password to access %1$s shared to you by %2$s" : "访问 %1$s 的密码已通过 %2$s 与您分享",
    "Password to access %s" : "访问 %s 的密码",
    "It is protected with the following password:" : "其已被以下密码保护：",
    "This password will expire at %s" : "密码将在 %s 后失效",
    "%1$s shared %2$s with you and wants to add:" : "%1$s 与您分享了 %2$s 并想要添加：",
    "%1$s shared %2$s with you and wants to add" : "%1$s 与您分享了 %2$s 并希望添加",
    "%s added a note to a file shared with you" : "%s 为与您共享的文件添加了注释",
    "You just shared %1$s with %2$s. The share was already sent to the recipient. Due to the security policies defined by the administrator of %3$s each share needs to be protected by password and it is not allowed to send the password directly to the recipient. Therefore you need to forward the password manually to the recipient." : "您刚刚与 %2$s 分享了 %1$s。此共享已发送给收件人。根据 %3$s 管理员定义的安全策略，每个共享都需要密码保护，不允许直接将密码发送给收件人。因此，您需要手动将密码转发给收件人。",
    "Password to access %1$s shared by you with %2$s" : "您与 %2$s 分享了访问 %1$s 的密码",
    "This is the password:" : "这是密码：",
    "You can choose a different password at any time in the share dialog." : "您可以随时在共享对话框中选择不同的密码。",
    "Could not find share" : "没有发现共享",
    "Share provider which allows you to share files by mail" : "共享提供程序，可让您通过邮件共享文件",
    "Unable to update share by mail config" : "无法通过邮箱设置更新分享",
    "Allows people to share a personalized link to a file or folder by putting in an email address." : "允许用户通过填入邮箱以分享文件或文件夹的私人链接。",
    "Send password by mail" : "通过电子邮件发送密码",
    "Reply to initiator" : "回复发起人"
},
"nplurals=1; plural=0;");
