OC.L10N.register(
    "app_api",
    {
    "Delete" : "Dileu",
    "Edit" : "Golygu",
    "Name" : "Enw",
    "Confirm" : "Cadarnhau",
    "Save" : "Cadw",
    "Register" : "Cofrestru",
    "User documentation" : "Dogfennaeth defnyddiwr",
    "Admin documentation" : "Dogfennaeth weinyddol",
    "Developer documentation" : "Dogfennaeth datblygwr",
    "Featured" : "Nodwedd",
    "Version" : "Fersiwn",
    "Actions" : "Gweithredoedd",
    "Type" : "Math",
    "Documentation" : "Dogfennaeth",
    "Details" : "Manylion",
    "Changelog" : "Cofnod newid",
    "Featured apps" : "Apiau dan sylw",
    "Disable" : "Analluogi"
},
"nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
