OC.L10N.register(
    "app_api",
    {
    "Daemon config not found" : "Non se atopou a configuración do servizo",
    "Error starting install of ExApp" : "Produciuse un erro ao iniciar a instalación da aplicación externa (ExApp)",
    "ExApp failed to register, check the NC logs" : "Produciuse un fallo ao rexistrar a aplicación externa (ExApp), comprobe os rexistros de Nextcloud",
    "ExApp not found, failed to get status" : "Non se atopou a aplicación externa (ExApp), produciuse un fallo ao obter o estado",
    "This app is not installed from the AppStore. No extra information available. Only enable/disable and remove actions are allowed." : "Esta aplicación non foi instalada desde a tenda de aplicacións. Non hai información adicional dispoñíbel. Só se permiten as accións de activar/desactivar e eliminar.",
    "Could not perform installation of ExApp" : "Non foi posíbel realizar a instalación da aplicación externa (ExApp)",
    "Failed to enable ExApp" : "Produciuse un fallo ao activar a aplicación externa (ExApp)",
    "Failed to disable ExApp" : "Produciuse un fallo ao desactivar a aplicación externa (ExApp)",
    "Could not update ExApp" : "Non foi posíbel actualizar a aplicación externa (ExApp)",
    "Error starting update of ExApp" : "Produciuse un erro ao iniciar a actualización da aplicación externa (ExApp)",
    "Could not perform update of ExApp" : "Non foi posíbel realizar a actualización da aplicación externa (ExApp)",
    "ExApp not found, failed to get logs" : "Non se atopou a aplicación externa (ExApp), produciuse un fallo ao obter os rexistros",
    "Failed to get container logs. Note: Downloading Docker container works only for containers with the json-file or journald logging driver. Error: %s" : "Produciuse un erro ao obter os rexistros do contedor. Nota: a descarga do contedor Docker só funciona para contedores co controlador de rexistro json-file ou journald. Erro: %s",
    "AppAPI authentication failed" : "Fallou a autenticación da AppAPI",
    "AppAPI ExApp notifier" : "Notificador de AppAPI para aplicación externa (ExApp)",
    "AppAPI" : "AppAPI (API de ExApps)",
    "AI Integration Team" : "Equipo de integración de IA",
    "ExApps Settings" : "Axustes da aplicación externa (ExApp)",
    "Nextcloud AppAPI" : "AppAPI (API de ExApps) de Nextcloud",
    "### Boost your Nextcloud with AppAPI and its specially designed applications.\n\n\nThe AppAPI is a project within the Nextcloud ecosystem designed to streamline and enhance the process of\napplication development, deployment, and management.\n\nIt introduces a new methodology that allows developers to create\napplications using a variety of programming languages, not limited to PHP, which was traditionally used in Nextcloud development.\n\n\n### List of applications that require AppAPI:\n\n- [talk_bot_ai_example](https://github.com/cloud-py-api/talk_bot_ai_example)\n- [upscaler_example](https://github.com/cloud-py-api/upscaler_example)\n- [image_to_text_example](https://github.com/cloud-py-api/file_to_text_example)\n- [ai_image_generator_bot](https://github.com/cloud-py-api/ai_image_generator_bot)\n- [SummarAI](https://github.com/nextcloud/sumupbot)\n\n_If you wish to develop an application, we will gladly help and assist you._\n\n### Support\n\nWe appreciate any support for this project:\n\n- ⭐ Star our work on GitHub\n- ❗ Create an Issue or feature request\n- 💁 Resolve an Issue and create a Pull Request\n- 🧑‍💻 Develop your own application using AppAPI\n\nWe are genuinely excited about the future of the AppAPI project and its potential to transform\nthe way applications are developed and experienced within Nextcloud.\n\nAs we embark on this journey, we warmly invite you - developers, thinkers, creators, and visionaries -\nto join us in shaping a more versatile, stable, and secure app landscape.\n\n*Your insights, suggestions, and contributions are invaluable to us.*" : "### Reforce o seu Nextcloud con AppAPI e as súas aplicacións deseñadas especialmente.\n\n\nA AppAPI é un proxecto dentro do ecosistema Nextcloud deseñado para axilizar e mellorar o proceso de\ndesenvolvemento, despregadura e xestión de aplicacións.\n\nIntroduce unha nova metodoloxía que permite aos desenvolvedores crear\naplicacións empregando diversas linguaxes de programación, sen limitarse a PHP, que era o que se usaba tradicionalmente no desenvolvemento de Nextcloud.\n\n\n### Lista de aplicacións que requiren AppAPI:\n\n– [talk_bot_ai_example](https://github.com/cloud-py-api/talk_bot_ai_example)\n– [upscaler_example](https://github.com/cloud-py-api/upscaler_example)\n– [image_to_text_example](https://github.com/cloud-py-api/file_to_text_example)\n– [ai_image_generator_bot](https://github.com/cloud-py-api/ai_image_generator_bot)\n– [SummarAI](https://github.com/nextcloud/sumupbot\n\n_Se quere desenvolver unha aplicación, estaremos encantados de axudarlle._\n\n### Apoio\n\nAgradecemos calquera apoio a este proxecto:\n\n– ⭐ Destaque o noso traballo en GitHub\n– ❗ Cree unha incidencia ou solicitude de funcionalidade\n– 💁 Solucione unha incidencia e faga unha solicitude de extracción (PR)\n\n– 🧑‍💻 Desenvolva a súa propia aplicación usando AppAPI\n\nEstamos moi entusiasmados co futuro do proxecto AppAPI e o seu potencial de transformación do\nxeito como se desenvolven e experimentan as aplicacións dentro de Nextcloud.\n\nMentres nos embarcamos nesta viaxe, convidámosvos cordialmente –desenvolvedores, pensadores, creadores e visionarios–\npara unirse a nós e dar forma a unha paisaxe de aplicacións máis versátil, estábel e segura.\n\n*As súas ideas, suxestións e colaboracións son inestimábeis para nós.*",
    "The AppAPI Project is an exciting initiative that aims to revolutionize the way applications are developed for Nextcloud." : "O Proxecto AppAPI é unha iniciativa emocionante que pretende revolucionar a maneira na que se desenvolven as aplicacións para Nextcloud.",
    "Deploy Daemons" : "Servizos de despregadura",
    "Deploy Daemon (DaemonConfig) is an ExApps orchestration daemon." : "O servizo de despregadura (DaemonConfig) é un servizo de orquestración de aplicacións externas (ExApps).",
    "Deploy Daemons. Deploy Daemon (DaemonConfig) is an ExApps orchestration daemon." : "Servizos de despregadura. O servizo de despregadura (DaemonConfig) é un servizo de orquestración de aplicacións externas (ExApps).",
    "Default Deploy Daemon is not accessible. Please verify its configuration" : "Non é posíbel acceder ao servizo predeterminado de  despregadura. Verifique a súa configuración",
    "ExApp init timeout (minutes)" : "Tempo de espera de inicio da aplicación externa (ExApp) (minutos)",
    "ExApp initialization process timeout after which AppAPI will mark it as failed" : "Tempo de espera do proceso de inicialización da aplicación externa (ExApp) apos do cal AppAPI marcarao como fallado",
    "ExApp init timeout" : "Tempo de espera de inicio da aplicación externa (ExApp)",
    "ExApp container restart policy" : "Directiva de reinicio do contedor da aplicación externa (ExApp)",
    "Specify container restart policy, e.g. 'always' to ensure ExApp running after daemon server reboot" : "Especifique a directiva de reinicio do contedor, p. ex. «sempre» para garantir que a aplicación externa (ExApp) se execute após o reinicio do servidor do servizo",
    "This settings changes are reflected only for newly created containers" : "Os cambios destes axustes só se reflícten nos contedores creados recentemente",
    "External Apps management" : "Xestión de aplicacións externas",
    "Admin options saved" : "Gardáronse as opcións de administración",
    "Failed to save admin options" : "Produciuse un fallo ao gardar as opcións de administración.",
    "Are you sure you want delete Deploy Daemon" : "Confirma que quere eliminar o servizo de despregadura",
    "All ExApps on this daemon will be removed" : "Retiraranse todas as aplicacións externas (ExApps) deste servizo",
    "All ExApps installed on this daemon will be removed" : "Retiraranse todas as aplicacións externas (ExApps) instaladas neste servizo",
    "Cancel" : "Cancelar",
    "Delete" : "Eliminar",
    "Default" : "Predeterminado",
    "Set as default" : "Definir como predeterminado",
    "Test deploy" : "Proba da despregadura",
    "Edit" : "Editar",
    "\"manual-install\" Deploy Daemon cannot be set as default" : "O servizo de despregadura «manual-install» non pode definirse como predeterminado",
    "Failed to save admin options. Check the logs" : "Produciuse un fallo ao gardar as opcións de administración. Comprobe os rexistros",
    "Password confirmation failed" : "Produciuse un fallo ao confirmar o contrasinal",
    "Deploy daemon config details" : "Detalles de configuración do servizo de despregue",
    "Deploy Daemon" : "Servizo de despregadura",
    "Default daemon. ExApps will be installed on it" : "Servizo predeterminado. As aplicacións externas (ExApps) instalaranse nel",
    "Manual install daemon usually used for development. It cannot be set as default daemon." : "O servizo de instalación manual que adoita usarse para o desenvolvemento. Non é posíbel definilo como servizo predeterminado.",
    "ExApps installed" : "Aplicacións externas (ExApps) instaladas",
    "Name" : "Nome",
    "Protocol" : "Protocolo",
    "Host" : "Servidor",
    "Deploy config" : "Configuración da despregadura",
    "Docker network" : "Rede Docker",
    "Nextcloud URL" : "URL de Nextcloud",
    "HaProxy password" : "Contrasinal de HaProxy",
    "GPUs support" : "Compatibilidade con GPU",
    "Compute device" : "Dispositivo de computación",
    "Additional options" : "Opcións adicionais",
    "Verify connection" : "Verificar a conexión",
    "Daemon connection successful" : "Conexión satisfactoria do servizo",
    "Failed to connect to Daemon. Check the logs" : "Produciuse un fallo ao conectar o servizo. Comprobe os rexistros",
    "Failed to check connection to Daemon. Check the logs" : "Produciuse un fallo ao comprobar a conexión co servizo. Comprobe os rexistros",
    "Registered Deploy daemons list" : "Lista de servizos de despregadura rexistrados",
    "No Deploy daemons configured" : "Non se configurou ningún servizo de despregadura",
    "Register a custom one or setup from available templates" : "Rexistre un personalizado ou configúreo a partir dos modelos dispoñíbeis",
    "Register Daemon" : "Rexistrar o servizo",
    "AppAPI will try to install small skeleton ExApp to verify Daemon configured correctly and deployment steps are passing." : "AppAPI tentará instalar un pequeno esqueleto de aplicación externa (ExApp) para verificar que o servizo está configurado correctamente e que se están a cumprir os pasos da despregadura.",
    "The following Deploy test checks must be passed to succeed:" : "As seguintes comprobacións de proba de despregue deben superarse para ser satisfactoria:",
    "More info" : "Máis información",
    "Download ExApp logs" : "Descargar os rexistros da aplicación externa (ExApp)",
    "Remove test ExApp" : "Eliminar a proba da aplicación externa (ExApp)",
    "Start Deploy test" : "Iniciar a proba de despregadura",
    "Stop Deploy test" : "Deter a proba de despregadura",
    "ExApp is unregistered and container is removed on \"Stop deploy test\"" : "A aplicación externa (ExApp) non está rexistrada e o contedor retirarase ao «Deter a proba de despregadura»",
    "Register ExApp in Nextcloud" : "Rexistrar a aplicación externa (ExApp) en Nextcloud",
    "Check if the ExApp is registered in Nextcloud before deployment" : "Comprobar se a aplicación externa (ExApp) está rexistrada en Nextcloud antes da despregadura",
    "Image pull" : "Extraer a imaxe",
    "Check if the image is successfully pulled" : "Comprobe se a imaxe foi extraída correctamente",
    "Container started" : "O contedor foi iniciado",
    "Check if the image successfully pulled and container is created and started" : "Comprobe se a imaxe foi extraída correctamente e se se creou e se iniciou o contedor",
    "Heartbeat" : "Latexo (proba de execución)",
    "Check for the heartbeat is finished and healthy" : "Comprobe se o latexo está rematado e é saudábel",
    "Init step" : "Paso inicial",
    "Wait for initialization step to finish" : "Agarde a que remate o paso de inicio",
    "Enabled" : "Activado",
    "Check if ExApp successfully handled the enabled event and registered all stuff properly" : "Comproba se a aplicación externa (ExApp) xestionou correctamente o evento activado e rexistrou todo correctamente",
    "Only if ExApp container is preset" : "Só se o contedor da aplicación externa (ExApp) está predefinido",
    "Deploy test passed successfully!" : "A proba de despregadura foi superada satisfactoriamente!",
    "Deploy test failed at step \"{step}\"" : "Produciuse un fallo na proba de despregadura no paso «{step}»",
    "Edit Deploy Daemon" : "Editar os servizos de despregadura",
    "Register Deploy Daemon" : "Servizos de despregadura rexistrados",
    "Daemon configuration template" : "Modelo de configuración do servizo",
    "Select daemon configuration template" : "Seleccione o modelo de configuración do servizo",
    "Daemon registration form" : "Formulario de rexistro do servizo",
    "Unique Deploy Daemon Name" : "Nome único do servizo de despregadura",
    "Display name" : "Nome para amosar",
    "Deployment method" : "Método de despregadura",
    "Select daemon deploy method" : "Seleccione o método de despregadura do servizo",
    "Daemon host" : "Servidor do servizo",
    "Set daemon as default" : "Definir o servizo como predeterminado",
    "Set as default daemon" : "Definir como servizo predeterminado",
    "Enable https" : "Activar https",
    "Show deploy config" : "Amosar a configuración da despregadura",
    "Hide deploy config" : "Agochar a configuración da despregadura",
    "Network" : "Rede",
    "Docker network name" : "Nome da rede Docker",
    "AppAPI Docker Socket Proxy authentication password" : "Contrasinal de autenticación do proxy de AppAPI Docker Socket",
    "Additional option" : "Opción adicional",
    "Add additional option" : "Engadir unha opción adicional",
    "Option key (unique)" : "Clave de opción (única)",
    "Option key (unique, e.g. my_key)" : "Clave de opción (única, p. ex., a_miña_clave)",
    "Option key is required" : "É necesaria a clave de opción",
    "Option value" : "Valor da opción",
    "Option value is required" : "É necesario o valor da opción",
    "Confirm" : "Confirmar",
    "Save" : "Gardar",
    "Register" : "Rexistrar",
    "Check connection" : "Comprobar a conexión",
    "Hostname to access ExApps" : "Nome de servidor para acceder a aplicacións externas (ExApps)",
    "Hostname or path to access Docker daemon (e.g. nextcloud-appapi-dsp:2375, /var/run/docker.sock)" : "Nome da máquina ou ruta para acceder ao servizo Docker (p. ex., nextcloud-appapi-dsp:2375, /var/run/docker.sock)",
    "Daemon with this name already exists" : "Xa existe un servizo con ese nome",
    "Password must be at least 12 characters long" : "O contrasinal precisa ser polo menos de 12 caracteres de lonxitude",
    "With https enabled network is set to host" : "Con https activado, a rede defínese como servidor",
    "Changes would be applied only for newly installed ExApps. For existing ExApps, Docker containers should be recreated." : "Os cambios aplicaranse só ás aplicacións externas (ExApp) instaladas recentemente. Para as aplicacións externas (ExApp) existentes, deberían volver crearse os contedores Docker.",
    "URL should start with http:// or https://" : "O URL debe comezar por http:// ou https://",
    "For HTTPS daemon, Nextcloud URL should be HTTPS" : "Para o servizo HTTPS, o URL de Nextcloud debe ser HTTPS",
    "All available GPU devices on daemon host will be requested to be enabled in ExApp containers by Docker." : "Docker solicitará que todos os dispositivos GPU dispoñíbeis no servidor do servizo estean activados nos contedores de aplicación externa (ExApp).",
    "DaemonConfig successfully registered" : "DaemonConfig foi rexistrado satisfactoriamente",
    "Failed to register DaemonConfig. Check the logs" : "Produciuse un fallo ao rexistrar DaemonConfig. Comprobe os rexistros",
    "DaemonConfig successfully updated" : "DaemonConfig foi actualizado satisfactoriamente",
    "Failed to update DaemonConfig. Check the logs" : "Produciuse un fallo ao actualizar DaemonConfig. Comprobe os rexistros",
    "External Apps" : "Aplicacións externas",
    "Update to {version}" : "Actualizar a {version}",
    "Remove" : "Retirar",
    "Delete data on remove" : "Eliminar os datos ao retirar",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación non dispón dunha versión mínima de Nextcloud asignada. Isto será un erro no futuro.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación non dispón dunha versión máxima de Nextcloud asignada. Isto será un erro no futuro.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Non é posíbel instalar esta aplicación por mor de non cumprirse as dependencias:",
    "View in store" : "Ver na tenda",
    "Visit website" : "Visite o sitio web",
    "Report a bug" : "Informar dun fallo",
    "User documentation" : "Documentación do usuario",
    "Admin documentation" : "Documentación da administración da instancia",
    "Developer documentation" : "Documentación para desenvolvedores",
    "This app is not registered in AppStore. No extra information available. Only enable/disable and remove actions are allowed." : "Esta aplicación non está rexistrada na tenda de aplicacións. Non hai información adicional dispoñíbel. Só se permiten as accións de activar/desactivar e eliminar.",
    "{license}-licensed" : "Licenciado baixo a {license}",
    "This app is supported via your current Nextcloud subscription." : "Esta aplicación é compatíbel cos súa subscrición actual a Nextcloud.",
    "Supported" : "Compatíbel",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "As aplicacións destacadas están desenvolvidas por e dentro da comunidade. Ofrecen unha funcionalidade central e están preparadas para o seu uso en produción.",
    "Featured" : "Destacada",
    "Update to {update}" : "Actualizar a {update}",
    "All ExApps are up-to-date." : "Todas as aplicacións externas (ExApps) están actualizadas.",
    "Default Deploy daemon is not accessible" : "Non é posíbel acceder ao servizo predeterminado de despregadura.",
    "Icon" : "Icona",
    "Version" : "Versión",
    "Daemon" : "Servizo",
    "Level" : "Nivel",
    "Actions" : "Accións",
    "Results from other categories" : "Resultados doutras categorías",
    "No apps found" : "Non se atoparon aplicacións",
    "_%n ExApp has an update available_::_%n apps have an update available_" : ["%n aplicación externa (ExApp) ten unha actualización dispoñíbel","%n aplicacións teñen unha actualización dispoñíbel"],
    "_Update_::_Update all_" : ["Actualizar","Actualizar todo"],
    "Type" : "Escribir",
    "Display Name" : "Nome para amosar",
    "Your apps" : "As súas aplicacións",
    "Documentation" : "Documentación",
    "Details" : "Detalles",
    "Changelog" : "Notas da versión",
    "by {author}\n{license}" : "por {author}\n{license}",
    "Active apps" : "Aplicacións activas",
    "Disabled apps" : "Aplicacións desactivadas",
    "Updates" : "Actualizacións",
    "Featured apps" : "Aplicacións destacadas",
    "Supported apps" : "Aplicacións compatíbeis",
    "manual-install apps cannot be updated" : "non é posíbel actualizar as aplicacións de instalación manual",
    "{progress}% Deploying" : "{progress}% Despregando",
    "{progress}% Initializing" : "{progress}% Iniciando",
    "Healthchecking" : "Control de integridade",
    "Deploy and Enable" : "Despregar e activar",
    "Enable" : "Activar",
    "Disable" : "Desactivar",
    "Allow untested app" : "Permitir aplicación non probada",
    "Default Deploy daemon is not accessible. Please verify configuration" : "Non é posíbel acceder ao servizo predeterminado de  despregadura. Verifique a súa configuración",
    "The app will be downloaded from the App Store and deployed on default Deploy Daemon" : "A aplicación descargarase da tenda de aplicacións e despregarase no servizo de despregadura predeterminado",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Esta aplicación non está marcado como compatíbel coa súa versión de Nextcloud. Se continúa, poderá instalar a aplicación. Teña en conta que é probábel que a aplicación non funcione como se agarda.",
    "Your ExApps" : "As súas aplicacións externas (ExApps)",
    "An error occurred during the request. Unable to proceed." : "Produciuse un erro durante a solicitude. Non é posíbel continuar.",
    "The app has been enabled but needs to be updated." : "Activouse a aplicación mais cómpre actualizala.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Erro: non é posíbel activar esta aplicación porque fai que o servidor sexa inestábel"
},
"nplurals=2; plural=(n != 1);");
