OC.L10N.register(
    "settings",
    {
    "Private" : "Privat",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Vizibil doar pentru persoanele care se potrivesc prin integrarea numărului de telefon prin Talk pe mobil",
    "Local" : "Local",
    "Only visible to people on this instance and guests" : "Vizibil doar pentru persoanele din această instanță și pentru oaspeți",
    "Federated" : "Federat",
    "Only synchronize to trusted servers" : "Sincronizează doar cu serverele de încredere",
    "Published" : "Publicat",
    "Synchronize to trusted servers and the global and public address book" : "Sincronizarea cu serverele de încredere și cu cartea de adrese globală și publică",
    "Verify" : "Verifică",
    "Verifying …" : "Se verifică ...",
    "Unable to change password" : "Imposibil de schimbat parola",
    "Very weak password" : "Parolă foarte slabă",
    "Weak password" : "Parolă slabă",
    "So-so password" : "Parolă medie",
    "Good password" : "Parolă bună",
    "Strong password" : "Parolă puternică",
    "Groups" : "Grupuri",
    "Group list is empty" : "Lista de grupuri este goală",
    "Unable to retrieve the group list" : "Nu s-a putut obține lista de grupuri",
    "{actor} added you to group {group}" : "{actor} te-a adăugat în grupul {group}",
    "You added {user} to group {group}" : "Ai adăugat {user} în grupul {group}",
    "{actor} added {user} to group {group}" : "{actor} a adăugat pe {user} în grupul {group}",
    "An administrator added you to group {group}" : "Un administrator te-a adăugat în grupul {group}",
    "An administrator added {user} to group {group}" : "Un administrator a adăugat pe {user} în grupul {group} ",
    "{actor} removed you from group {group}" : "{actor} te-a eliminat din grupul {group}",
    "You removed {user} from group {group}" : "Ai eliminat {user} din grupul {group}",
    "{actor} removed {user} from group {group}" : "{actor} a eliminat {user} din grupul {group}",
    "An administrator removed you from group {group}" : "Un administrator te-a eliminat din grupul {group}",
    "An administrator removed {user} from group {group}" : "Un administrator a eliminat {user} din groupul {group}",
    "Your <strong>group memberships</strong> were modified" : "<strong>Apartenențele de grup</strong>ale dvs. au fost modificate",
    "{actor} changed your password" : "{actor} ți-a schimbat parola",
    "You changed your password" : "Ți-ai schimbat parola",
    "Your password was reset by an administrator" : "Parola dumneavoastră a fost resetată de un administrator",
    "Your password was reset" : "Parola dvs. a fost resetată",
    "{actor} changed your email address" : "{actor} ți-a schimbat adresa de email",
    "You changed your email address" : "Ți-ai schimbat adresa de email",
    "Your email address was changed by an administrator" : "Adresa ta de email a fost modificată de un administrator",
    "You deleted app password \"{token}\"" : "Ai șters parola aplicației \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Ai redenumit parola aplicației \"{token}\" în \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "Ați acordat acces la sistemul de fișiere pentru parola aplicației \"{token}\"",
    "You revoked filesystem access from app password \"{token}\"" : "Ați revocat accesul la sistemul de fișiere din aplicația parola \"{token}\"",
    "Security" : "Securitate",
    "You successfully logged in using two-factor authentication (%1$s)" : "Te-ai conectat cu succes utilizând autentificarea cu doi factori (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "O încercare de autentificare utilizând autentificarea cu doi factori a eșuat (%1$s)",
    "Remote wipe was started on %1$s" : "Ștergerea de la distanță a fost pornită pe %1$s",
    "Remote wipe has finished on %1$s" : "Ștergerea de la distanță s-a încheiat pe %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "<strong>Parola </strong> sau <strong>mailul </strong>a fost modificat",
    "Settings" : "Setări",
    "Wrong password" : "Parolă greșită",
    "Unable to change personal password" : "Nu se poate schimba parola personală",
    "Saved" : "Salvat",
    "Authentication error" : "Eroare la autentificare",
    "Wrong admin recovery password. Please check the password and try again." : "Parolă administrativă de recuperare greșită. Verifică parola și încearcă din nou.",
    "Administrator documentation" : "Documentație pentru administrare",
    "User documentation" : "Documentație utilizator",
    "Invalid SMTP password." : "Parolă SMTP invalidă.",
    "Email setting test" : "Test setări email",
    "Well done, %s!" : "Felicitări, %s!",
    "If you received this email, the email configuration seems to be correct." : "Daca primești acest mail, configurările de email au fost efectuate corect.",
    "Email could not be sent. Check your mail server log" : "Mesajul nu a putut fi trimis. Verifică logul serverului de mail.",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : " A apărut o problemă la trimiterea emailului. Verifică-ți setărie. (Eroare: %s)",
    "Invalid mail address" : "Adresa mail invalidă",
    "Settings saved" : "Setările au fost salvate",
    "Unable to change full name" : "Nu s-a putut schimba numele complet",
    "Unable to change email address" : "Nu s-a putut schimba adresa email",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Pentru a putea verifica contul de Twitter, postați următorul tweet (asigurați-vă că îl postați fără spații):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Pentru a verifica site-ul dvs., stocați următorul conținut în root-ul siteului web la \".well-known / CloudIdVerificationCode.txt\" (asigurați-vă că textul complet este compus dintr-o singură linie):",
    "%1$s changed your password on %2$s." : "%1$s ți-a schimbat parola pe %2$s.",
    "Your password on %s was changed." : "Parola ta pe %s a fost modificată.",
    "Your password on %s was reset by an administrator." : "Parola ta pe %s a fost resetată de către un administrator.",
    "Password for %1$s changed on %2$s" : "Parola pentru %1$s modificată pe %2$s",
    "Password changed for %s" : "Parolă modificată pentru %s",
    "If you did not request this, please contact an administrator." : "Dacă nu ai solicitat aceasta, te rugăm să contactezi un administrator.",
    "Your email address on %s was changed." : "Adresa de mail pe %s a fost modificată.",
    "Your email address on %s was changed by an administrator." : "Adresa de mail pe %s a fost modificată de către un administrator.",
    "Email address for %1$s changed on %2$s" : "Adresa de mail pentru %1$s a fost modificată pe %2$s",
    "Email address changed for %s" : "Adresa de email schimbată în %s",
    "The new email address is %s" : "Adresa de email nouă este%s",
    "Your %s account was created" : "Contul tău %s a fost creat",
    "Welcome aboard" : "Bun venit la bord",
    "Welcome aboard %s" : "Bun venit la bord %s",
    "Set your password" : "Setează parola",
    "Go to %s" : "Salt la %s",
    "Install Client" : "Instalează client",
    "Apps" : "Aplicații",
    "Personal" : "Personal",
    "Administration" : "Administrare",
    "Users" : "Utilizatori",
    "Additional settings" : "Setări adiționale",
    "Assistant" : "Asistent",
    "Administration privileges" : "Privilegii de administrare",
    "Groupware" : "Articole de grup",
    "Overview" : "Prezentare generală",
    "Basic settings" : "Setări de bază",
    "Sharing" : "Partajare",
    "Calendar" : "Calendar",
    "Personal info" : "Informații personale",
    "Mobile & desktop" : "Mobil și desktop",
    "Email server" : "Server de email",
    "Background jobs" : "Proces de fundal",
    "Unlimited" : "Nelimitată",
    "Verifying" : "Se verifică",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Directorul de date și fișierele sunt probabil accesibile din Internet. Fișierul .htaccess nu este funcțional. Se recomandă puternic configurarea serverului web astfel încât directorul de date să nu mai fie accesibil astfel, sau mutați-l în afara rădăcinii documentelor a serverului web.",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Lipsesc coloane opționale din baza de date. Datorită faptului că adăugarea de coloane tabelelor mari durează mult, acestea nu au fost adăugate automat atunci când pot fi opționale. Rulând \"occ db:add-missing-columns\", aceste coloane lipsă pot fi adăugate manual în timp ce instanța este online. Odată ce aceste coloane opționale au fost adăugate, unele funcționalități pot îmbunătăți timpul de răspuns sau uzabilitatea. ",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Bazei de date îi lipsesc câteva chei primare. Datorită faptului că adăugarea cheilor primare la tabelele mari durează mult, acestea nu au fost adăugate automat. Rulând \"occ db:add-missing-primary-keys\", aceste chei primare lipsă pot fi adăugate manual în timp ce instanța rulează. ",
    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Instanța este în modul debug. Folosiți aceasta doar pentru dezvoltare și nu în producție.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Acest server nu are o conexiune funcțională la Internet. Mai multe puncte finale nu pot fi contactate. Aceasta înseamnă că unele funcționalități precum montarea unui spațiu extern de stocare, notificări despre actualizări sau instalarea aplicațiilor din sursă terță nu vor fi accesibile. De asemenea, ar putea să nu funcționeze nici accesarea fișierelor la distanță și transmiterea emailurilor de notificare .",
    "Disabled" : "Dezactivați",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Este activat vechiul format de criptare din partea serverului. Vă recomandăm să dezactivați acest lucru.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "Funcția PHP \"set_time_limit\" nu este disponibilă. Aceasta ar putea avea ca efect ca scripturile să fie oprite în timpul execuției, compromițând instalarea. Se recomandă puternic activarea acestei funcții.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Instalarea PHP nu are suport pentru FreeType, introducând incompatibilități cu imaginile de profil și cu interfața de configurare.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP nu pare să fie configurat corespunzător pentru a interoga variabilele de mediu ale sistemului. Testul cu getenv(\"PATH\") returnează doar un răspuns gol.",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "Modulul PHP OPcache nu este încărcat. Pentru o performanță mai bună, se recomandă să îl încărcați în instalarea PHP.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "A fost activată configurația doar pentru citire. Acest lucru împiedică setarea unor configurații prin intermediul interfeței web. În plus, fișierul trebuie să fie făcut scriere manual la fiecare actualizare.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Baza dumneavoastră de date nu rulează cu nivelul de izolare a tranzacției \"READ COMMITTED\". Acest lucru poate cauza probleme atunci când mai multe acțiuni sunt executate în paralel.",
    "Profile information" : "Informații de profil",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Poza de profil, numele complet, adresa de e-mail, numărul de telefon, adresa, site-ul web, Twitter, organizația, rolul, titlul, biografia și dacă profilul dvs. este activat.",
    "Nextcloud settings" : "Setări Nextcloud",
    "Enable" : "Activare",
    "Here you can decide which group can access certain sections of the administration settings." : "Aici puteți decide ce grup poate accesa anumite secțiuni din setările de administrare.",
    "Unable to modify setting" : "Nu se poate modifica setarea",
    "None" : "Niciuna",
    "Allow apps to use the Share API" : "Permite aplicațiilor să folosească API-ul de partajare",
    "Allow resharing" : "Permite repartajarea",
    "Allow sharing with groups" : "Permite partajarea cu grupuri",
    "Allow public uploads" : "Permite încărcări publice",
    "Enforce password protection" : "Impune protecția prin parolă",
    "Enforce expiration date" : "Impune data de expirare",
    "Two-Factor Authentication" : " Autentificare în doi pași",
    "Enforce two-factor authentication" : "Forțează autentificarea cu doi factori",
    "Limit to groups" : "Limitează pentru grupuri",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Forțarea autentificării cu doi factori poate fi setată doar pentru anumite grupuri.",
    "Two-factor authentication is enforced for all members of the following groups." : "Autentificarea cu doi factori este impusă pentru toți membrii următoarelor grupuri.",
    "Enforced groups" : "Grupuri obligate",
    "Two-factor authentication is not enforced for members of the following groups." : "Autentificarea cu doi factori nu este impusă pentru membrii următoarelor grupuri.",
    "Excluded groups" : "Grupuri excluse",
    "Save changes" : "Salvează modificările",
    "Default" : "Implicită",
    "Remove" : "Șterge",
    "Featured" : "Recomandată",
    "Icon" : "Pictogramă",
    "Name" : "Nume",
    "Version" : "Versiunea",
    "Level" : "Nivel",
    "Actions" : "Acțiuni",
    "No apps found for your version" : "Nu au fost găsite aplicații pentru versiunea ta",
    "Group name" : "Numele grupului",
    "Type" : "Tip",
    "Learn more" : "Află mai mult",
    "Confirm" : "Confirmă",
    "Cancel" : "Anulare",
    "Description" : "Descriere",
    "View in store" : "Vezi în magazin",
    "Visit website" : "Viziteaza pagina web",
    "Admin documentation" : "Documentație pentru administrare",
    "Developer documentation" : "Documentație pentru dezvoltatori",
    "Details" : "Detalii",
    "All" : "Toate ",
    "No results" : "Niciun rezultat",
    "Update to {version}" : "Actualizare la {version}",
    "Author" : "Autor",
    "Categories" : "Categori",
    "Resources" : "Resurse",
    "Documentation" : "Documentație",
    "Interact" : "Interacționați",
    "Report a bug" : "Raportează un defect",
    "Request feature" : "Solicitare funcționalități",
    "Ask questions or discuss" : "Puneți întrebări sau participați la discuții",
    "Changelog" : "Listă modificări",
    "Google Chrome for Android" : "Google Chrome for Android",
    "{productName} Android app" : "{productName} aplicație Android",
    "This session" : "Această sesiune",
    "Device settings" : "Setările dispozitivului",
    "Allow filesystem access" : "Permite accesul la fișierele de sistem",
    "Rename" : "Redenumire",
    "Revoke" : "Revocă",
    "Device" : "Dispozitiv",
    "Last activity" : "Ultima activitate",
    "Devices & sessions" : "Dispozitive și sesiuni",
    "Web, desktop and mobile clients currently logged in to your account." : "Clienții web, desktop și mobil conectați în prezent la contul dvs.",
    "Error while creating device token" : "Eroare la crearea token-ului de dispozitiv",
    "App name" : "Numele aplicației",
    "Create new app password" : "Crează o nouă parolă pentru aplicație",
    "Login" : "Autentificare",
    "Password" : "Parolă",
    "Password confirmation is required" : "Confirmarea parolei este necesară",
    "Server-side encryption" : "Criptare la nivel de server",
    "Enable server-side encryption" : "Activează criptarea pe server",
    "Select default encryption module:" : "Selectează modulul implicit de criptare:",
    "Enable encryption" : "Activează criptarea",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Criptarea, ca unică variantă, nu garantează securitatea sistemului. Consultați documentația pentru mai multe informații despre cum funcționează aplicația de criptare și variantele de utilizare acceptate.",
    "This is the final warning: Do you really want to enable encryption?" : "Aceasta este avertizarea finală: Chiar vrei să activezi criptarea?",
    "Submit" : "Trimite",
    "Current password" : "Parola curentă",
    "New password" : "Noua parolă",
    "No email address set" : "Fără adresă de email setată",
    "Help translate" : "Ajută la traducere",
    "Week starts on {firstDayOfWeek}" : "Săptămâna începe {firstDayOfWeek}",
    "Your phone number" : "Numărul tău de telefon",
    "Add" : "Adaugă",
    "Create" : "Crează",
    "Change" : "Schimbă",
    "Delete" : "Șterge",
    "Reshare" : "Redistribuiți",
    "Default language" : "Limba implicită",
    "Display name" : "Nume afișat",
    "Email" : "Email",
    "Quota" : "Procent",
    "Language" : "Limba",
    "Total rows summary" : "Rezumat total rânduri",
    "Avatar" : "Avatar",
    "Last login" : "Ultima autentificare",
    "{size} used" : "{size} folosită",
    "Done" : "Realizat",
    "Edit" : "Editează",
    "Visibility" : "Vizibil",
    "Show last login" : "Arată ultima autentificare",
    "Send email" : "Expediază mesajul",
    "Server error while trying to complete WebAuthn device registration" : "Eroare de server în timpul încercării de a finaliza înregistrarea dispozitivului WebAuthn",
    "Add WebAuthn device" : "Adăugați dispozitivul WebAuthn",
    "Adding your device …" : "Adăugarea dispozitivului dvs ...",
    "Unnamed device" : "Dispozitiv fără nume",
    "Your browser does not support WebAuthn." : "Browserul dvs. nu acceptă WebAuthn.",
    "Admins" : "Administratori",
    "Sending…" : "Se trimite...",
    "Email sent" : "Mesajul a fost expediat",
    "Location" : "Locație",
    "Profile picture" : "Imagine de profil",
    "About" : "Despre",
    "Full name" : "Nume complet",
    "Headline" : "Titlu",
    "Organisation" : "Organizație",
    "Phone number" : "Număr telefon",
    "Role" : "Rol",
    "Website" : "Site web",
    "Your apps" : "Aplicațiile tale",
    "Disabled apps" : "Aplicații inactive",
    "Updates" : "Actualizări",
    "Featured apps" : "Aplicații recomandate",
    "Hide" : "Ascunde",
    "Disable" : "Dezactivați",
    "Unknown" : "Necunoscut",
    "Never" : "Niciodată",
    "Do you really want to wipe your data from this device?" : "Chiar doriți să vă ștergeți datele de pe acest dispozitiv?",
    "Confirm wipe" : "Confirmați ștergerea",
    "Error while wiping the device with the token" : "Eroare la ștergerea dispozitivului cu token-ul",
    "Error while updating device token name" : "Eroare la actualizarea numelui token-ului dispozitivului",
    "Error while updating device token scope" : "Eroare la actualizarea domeniului de aplicare a token-ului de dispozitiv",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Prea multe cereri din această rețea. Încercați mai târziu sau contactați administratorul.",
    "Error" : "Eroare",
    "Forum" : "Forum",
    "Legal notice" : "Aviz juridic",
    "SSL" : "SSL",
    "Open documentation" : "Deschide documentația",
    "Send mode" : "Modul de expediere",
    "Encryption" : "Încriptare",
    "From address" : "De la adresa",
    "Server address" : "Adresa server-ului",
    "Port" : "Portul",
    "Authentication" : "Autentificare",
    "Authentication required" : "Autentificare necesară",
    "Credentials" : "Detalii de autentificare",
    "SMTP Password" : "Parolă SMTP",
    "Save" : "Salvează",
    "Security & setup warnings" : "Alerte de securitate & configurare",
    "All checks passed." : "Toate verificările s-au terminat fără erori.",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Această versiune comunitară a Nextcloud nu este suportată, iar notificările instantanee nu sunt disponibile."
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
