OC.L10N.register(
    "circles",
    {
    "Personal" : "Personal",
    "Visible" : "Visible",
    "Open" : "Dobrir",
    "Password protected" : "Protegit per senhal",
    "Hidden" : "Amagat",
    "Local" : "Local",
    "Federated" : "Federated",
    "Email address" : "Adreça mail",
    "Contact" : "Contacte",
    "Admin" : "Admin",
    "Owner" : "Owner",
    "Open »%s«" : "Dobrir « %s »",
    "Accept" : "Acceptar",
    "Open %s" : "Dobrir %s",
    "No files in here" : "Cap de fichièr aicí",
    "Name" : "Nom",
    "Size" : "Talha",
    "Modified" : "Modificat"
},
"nplurals=2; plural=(n > 1);");
