OC.L10N.register(
    "lookup_server_connector",
    {
    "Lookup Server Connector" : "Коннектор сервера поиска",
    "Sync public account information with the lookup server" : "Синхронизируйте информацию об общедоступной учетной записи с поисковым сервером"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
