OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Fonte da actividade persoal para %s",
    "Your feed URL is invalid" : "O URL da fonte é incorrecto",
    "Activity feed for %1$s" : "Fonte da actividade para %1$s",
    "Activity feed" : "Fonte da actividade",
    "Your settings have been updated." : "Actualizaronse os axustes.",
    "Settings have been updated." : "Actualizáronse os axustes.",
    "Recent activity" : "Actividade recente",
    "No activities" : "Non hai actividades",
    "More activities" : "Máis actividades",
    "Daily activity summary for %s" : "Resumo diario de actividades para %s",
    "_and %n more…_::_and %n more…_" : ["e %n máis…","e %n máis…"],
    "All activities" : "Todas as actividades",
    "By others" : "Por outros",
    "By you" : "Por Vde.",
    "Activity at %s" : "Actividade en %s",
    "Hello %s" : "Ola %s",
    "Hello %s," : "Ola %s,",
    "There was some activity at %s" : "Houbo actividade en %s",
    "_and %n more _::_and %n more _" : ["e %n máis","e %n máis"],
    "Mail" : "Correo",
    "Push" : "Notificación emerxente",
    "Activity" : "Actividade",
    "Notifications" : "Notificacións",
    "This application enables people to view a log of activities about them, their files or other data." : "Esta aplicación permítelle ás persoas ver un rexistro sobre as súas actividades, os seus ficheiros ou outros datos.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "\tEsta aplicación permite que as persoas vexan accións relacionadas cos seus ficheiros e datos en Nextcloud.\n\t\tCada persoa pode configurar a súa actividade individual nos axustes persoais,\n\t\tpara escoller que actividade debe ser enviada aos teléfonos móbiles, enviada por correo-e\n\t\tou se se envía un resumo diario cada mañá.\n\t\tHai máis información dispoñíbel na documentación de Actividade.",
    "Send email" : "Enviar o correo",
    "Send push notification" : "Enviar unha notificación emerxente",
    "Activity notification configuration" : "Configuración das notificacións de actividade",
    "Today" : "Hoxe",
    "Yesterday" : "Onte",
    "You need to set up your email address before you can receive notification emails." : "É necesario configurar o enderezo de correo para poder recibir correos de notificación.",
    "Send activity emails" : "Enviar correos de actividades",
    "As soon as possible" : "O antes posíbel",
    "Hourly" : "Cada hora",
    "Daily" : "A diario",
    "Weekly" : "Semanalmente",
    "You commented" : "Vde. comentou",
    "Message deleted by author" : "Mensaxe eliminada polo autor",
    "Open {filename}" : "Abrir {filename}",
    "in {path}" : "en {path}",
    "Home" : "Inicio",
    "Could not load activities" : "Non foi posíbel cargar as actividades",
    "Loading activities" : "Cargando actividades",
    "This stream will show events like additions, changes & shares" : "Este fluxo amosará eventos como engadidos, cambios e elementos compartidos",
    "No activity yet" : "Aínda non houbo actividade",
    "Loading more activities" : "Cargando máis actividades",
    "No more activities." : "Non hai máis actividades.",
    "Could not enable RSS link" : "Non foi posíbel activar a ligazón RSS",
    "RSS link copied to clipboard" : "A ligazón RSS foi copiada ao portapapeis",
    "Could not copy the RSS link, please copy manually:" : "Non foi posíbel copiar a ligazón RSS no portapapeis, cópiea manualmente:",
    "Activity settings" : "Axustes da actividade",
    "Enable RSS feed" : "Activar as fontes RSS",
    "RSS feed" : "Fontes RSS",
    "Copy RSS feed link" : "Copiar a ligazón da fonte RSS",
    "Personal notification settings" : "Axustes persoais de notificación",
    "Unable to load the activity list" : "Non é posíbel cargar a lista de actividade",
    "Choose for which activities you want to get an email or push notification." : "Escolla para que actividades quere obter un correo ou notificación emerxente.",
    "Choose for which activities you want to get a push notification." : "Escolla para que actividades quere obter unha notificación emerxente.",
    "Notification" : "Notificación",
    "Enable notification emails" : "Activar os correos de notificación",
    "Daily activity summary" : "Resumo diario de actividade",
    "Send daily activity summary in the morning" : "Enviar un resumo diario da actividade pola mañá",
    "Default settings" : "Axustes predeterminados",
    "Configure the default notification settings for new accounts." : "Configure os axustes de notificación predeterminados para as contas novas.",
    "Unable to save the settings" : "Non é posíbel gardar os axustes",
    "No more events to load" : "Non hai máis eventos para cargar"
},
"nplurals=2; plural=(n != 1);");
