OC.L10N.register(
    "bruteforcesettings",
    {
    "Brute-force settings" : "Socruithe brú-fhórsa",
    "Whitelist IPs" : "IPs liosta bán",
    "Brute-force protection is meant to protect Nextcloud servers from attempts to\nguess account passwords in various ways. Besides the obvious \"*let's try a big\nlist of commonly used passwords*\" attack, it also makes it harder to use\nslightly more sophisticated attacks via the reset password form or trying to\nfind app password tokens.\n\nIf triggered, brute-force protection makes requests coming from an IP on a\nbrute-force protected controller with the same API slower for a 24 hour period.\n\nWith this app, the admin can exempt an IP address or range from this\nprotection which can be useful for testing purposes or when there are false\npositives due to a lot of accounts on one IP address." : "Tá cosaint brú-fhórsa i gceist chun freastalaithe Nextcloud a chosaint ó iarrachtaí chun\npasfhocail cuntais a thomhas ar bhealaí éagsúla. Seachas an rud soiléir \"* déanaimis iarracht mór\nliosta de na pasfhocail a úsáidtear go coitianta*\" ionsaí, déanann sé níos deacra é a úsáid freisin\nionsaithe beagán níos sofaisticiúla tríd an bhfoirm athshocrú pasfhocal nó ag iarraidh a\naimsigh pasfhocail feidhmchláir.\n\nMá spreagtar é, déanann cosaint brúidiúil iarratais a thagann ó IP ar a\nrialtóir cosanta brute-force leis an API céanna níos moille ar feadh tréimhse 24 uair an chloig.\n\nLeis an aip seo, is féidir leis an riarthóir seoladh IP a dhíolmhú nó raon uaidh seo\ncosaint a d'fhéadfadh a bheith úsáideach chun críocha tástála nó nuair a bhíonn bréagach ann\ndearfach mar gheall ar go leor cuntas ar aon seoladh IP amháin.",
    "Your remote address was identified as \"{remoteAddress}\" and is throttled at the moment by {delay}ms." : "Aithníodh do sheoladh cianda mar \"{remoteAddress}\" agus tá {moill}ms mar gheall air faoi láthair.",
    "Your remote address was identified as \"{remoteAddress}\" and is bypassing brute-force protection." : "Aithníodh do sheoladh cianda mar \"{remoteAddress}\" agus tá sé ag seachaint cosaint brúidiúil.",
    "Your remote address was identified as \"{remoteAddress}\" and is not actively throttled at the moment." : "Aithníodh do sheoladh cianda mar \"{remoteAddress}\" agus níl sé faoi sníomh go gníomhach faoi láthair.",
    "There was an error adding the IP to the whitelist." : "Tharla earráid agus an IP á chur leis an liosta bán.",
    "Brute-force IP whitelist" : "Liosta bán IP brute-force",
    "To whitelist IP ranges from the brute-force protection specify them below. Note that any whitelisted IP can perform authentication attempts without any throttling. For security reasons, it is recommended to whitelist as few hosts as possible or ideally even none at all." : "Chun raonta IP bán ón gcosaint brúidiúil sonraigh iad thíos. Tabhair faoi deara gur féidir le haon IP bánliosta iarrachtaí fíordheimhnithe a dhéanamh gan aon stró. Ar chúiseanna slándála, moltar líon beag óstach agus is féidir a bhánú nó fiú gan aon duine ar chor ar bith.",
    "Apply whitelist to rate limit" : "Cuir an liosta bán i bhfeidhm ar an teorainn ráta",
    "Add a new whitelist" : "Cuir liosta bán nua leis",
    "IP address" : "Seoladh IP",
    "Mask" : "Masc",
    "Add" : "Cuir",
    "Delete entry for {subnet}" : "Scrios iontráil le haghaidh {subnet}"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
