OC.L10N.register(
    "files_versions",
    {
    "Versions" : "Εκδόσεις",
    "This application automatically maintains older versions of files that are changed." : "Η εφαρμογή διατηρεί αυτόματα παλαιότερες εκδόσεις των αρχείων που έχουν αλλάξει.",
    "Current version" : "Τρέχουσα έκδοση",
    "Initial version" : "Αρχική έκδοση",
    "You" : "Εσύ",
    "Name this version" : "Ονομασία αυτής της έκδοσης",
    "Edit version name" : "Επεξεργασία ονόματος έκδοσης",
    "Compare to current version" : "Σύγκριση με την τρέχουσα έκδοση",
    "Restore version" : "Επαναφορά έκδοσης",
    "Download version" : "Λήψη έκδοσης",
    "Delete version" : "Διαγραφή έκδοσης",
    "Cancel" : "Ακύρωση",
    "Remove version name" : "Αφαίρεση ονόματος έκδοσης",
    "Save version name" : "Αποθήκευση ονόματος έκδοσης",
    "Version name" : "Όνομα έκδοσης",
    "Initial version restored" : "Η αρχική έκδοση επαναφέρθηκε",
    "Version restored" : "Η έκδοση επαναφέρθηκε",
    "Could not restore version" : "Δεν ήταν δυνατή η επαναφορά της έκδοσης",
    "Could not delete version" : "Δεν ήταν δυνατή η διαγραφή της έκδοσης"
},
"nplurals=2; plural=(n != 1);");
