OC.L10N.register(
    "app_api",
    {
    "Cancel" : "منصرف شدن",
    "Delete" : "حذف",
    "Default" : "پیش‌فرض",
    "Edit" : "ویرایش",
    "Name" : "نام",
    "Host" : "میزبان",
    "Nextcloud URL" : "Nextcloud URL",
    "Enabled" : "فعال شده",
    "Display name" : "Display name",
    "Network" : "شبکه",
    "Confirm" : "تأیید",
    "Save" : "ذخیره",
    "Register" : "ثبت‌نام",
    "Update to {version}" : "به‌روز رسانی به {version}",
    "Remove" : "حذف",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "این برنامه حداقل دارای نسخه بعدی نکست کلود است. این یک خطا در آینده خواهد بود.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "این برنامه حداکثر نسخه نکست کلود اختصاصی ندارد. این یک خطا در آینده خواهد بود.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "امکان نصب این برنامه وجود ندارد، این پیش‌نیازها انجام نشده‌اند:",
    "View in store" : "نمایش در فروشگاه",
    "Visit website" : "سر زدن به پایگاه وب",
    "Report a bug" : "گزارش یک خطا",
    "User documentation" : "مستندات کاربری",
    "Admin documentation" : "مستندات مدیریتی",
    "Developer documentation" : "مستندات توسعه",
    "{license}-licensed" : "دارای مجوز- {license}",
    "This app is supported via your current Nextcloud subscription." : "این کاره از طریق اشتراک فعلی نکست کلودتان پشتیبانی می شود.",
    "Supported" : "پشتیبانی شده",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "برنامه‌های برگزیده توسط و در داخل جامعه توسعه داده می‌شوند. این برنامه‌ها، عملکردهای مرکزی را ارائه می‌دهند و برای استفاده نهایی آماده هستند.",
    "Featured" : "برگزیده",
    "Update to {update}" : "به‌روز رسانی به {update} ",
    "Icon" : "Icon",
    "Version" : "نسخه",
    "Daemon" : "فرایندهای پس زمینه",
    "Level" : "مرحله",
    "Actions" : "کنش‌ها",
    "Results from other categories" : "نتایج از دیگر دسته‌ها",
    "_Update_::_Update all_" : ["به‌روز رسانی","به‌روز رسانی همه"],
    "Type" : "نوع",
    "Your apps" : "برنامه‌های شما",
    "Documentation" : "مستندات",
    "Details" : "جزییات",
    "Changelog" : "تغییر",
    "by {author}\n{license}" : "by {author}\n{license}",
    "Active apps" : "برنامه‌های فعال",
    "Disabled apps" : "برنامه‌های غیرفعال",
    "Updates" : "به روز رسانی ها",
    "Featured apps" : "کاره‌های برگزیده",
    "Supported apps" : "Supported apps",
    "Enable" : "فعالسازی",
    "Disable" : "غیرفعال کردن",
    "Allow untested app" : "Allow untested app",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "این برنامه مطابق با نسخه نکست کلود شما مشخص نشده است. اگر ادامه بدهید همچنان می توانید برنامه را نصب کنید. توجه داشته باشید که برنامه ممکن است مطابق آنچه انتظار می رود کار نکند.",
    "An error occurred during the request. Unable to proceed." : "An error occurred during the request. Unable to proceed.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Error: This app cannot be enabled because it makes the server unstable"
},
"nplurals=2; plural=(n > 1);");
