OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "Federatutako hodei ID baliogabea",
    "Server to server sharing is not enabled on this server" : "Zerbitzaritik zerbitzarirako partekatzea ez dago gaituta zerbitzari honetan",
    "Couldn't establish a federated share." : "Ezin izan da urruneko partekatze federatua gehitu.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Ezin izan da urruneko partekatze federatua gehitu, agian pasahitza gaizki dago.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Federatutako partekatze eskaera bidali da, gonbidapena jasoko duzu. Begiratu jakinarazpenetan.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Ezin izan da federatutako partekatze bat ezarri, badirudi federatu nahi duzun zerbitzaria zaharregia dela (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Ezin dira federatutako talde-partekatzeak bidali zerbitzari honetatik.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "%1$spartekatzeak huts egin du, dagoeneko %2$skontuarekin partekatuta dagoelako",
    "Not allowed to create a federated share to the same account" : "Ezin da partekatze federatu bat sortu kontu berean",
    "Federated shares require read permissions" : "Federatutako partekatzeek irakurtzeko baimenak behar dituzte",
    "File is already shared with %s" : "Fitxategia %s(r)ekin partekatuta dago jada",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "%1$s partekatzeak huts egin du, ezin izan da %2$s aurkitu, agian zerbitzaria lineaz kanpo dago edo bere buruak sinatutako ziurtagiria darabil.",
    "Could not find share" : "Ezin da partekatzea aurkitu",
    "Federated sharing" : "Federatutako partekatzea",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "{user}(r)en {share} jaso duzu urruneko partekatze bezala ({behalf} bidez)",
    "You received {share} as a remote share from {user}" : "{user}(r)en {share} jaso duzu urruneko partekatze bezala",
    "Accept" : "Onartu",
    "Decline" : "Uko egin",
    "Federated Cloud Sharing" : "Federatutako Hodei Partekatzea",
    "Sharing" : "Partekatzea",
    "Federated file sharing" : "Fitxategien partekatze federatua",
    "Provide federated file sharing across servers" : "Eskaini zerbitzarien arteko federatutako partekatzea",
    "Unable to update federated files sharing config" : "Ezin da eguneratu fitxategi partekatze federatuaren konfigurazioa",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Doitu nola parteka dezakeen jendeak zerbitzarien artean. Horrek zerbitzari honetako pertsonen arteko partekatzeak barne hartzen ditu,  partekatze federatua erabiltzen ari badira.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Baimendu zerbitzari honetako pertsonei beste zerbitzari batzuetarako partekatzeak bidaltzea (aukera honek partekatze publikoetara WebDAV sarbidea ere baimentzen du)",
    "Allow people on this server to receive shares from other servers" : "Baimendu zerbitzari honetako pertsonei beste zerbitzarietatik partekatutakoak jasotzeko",
    "Allow people on this server to send shares to groups on other servers" : "Baimendu zerbitzari honetako pertsonei beste zerbitzari batzuetako taldeei elementuak partekatzea.",
    "Allow people on this server to receive group shares from other servers" : "Baimendu zerbitzari honetako pertsonei beste zerbitzarietatik taldeko partekatutakoak jasotzeko",
    "Search global and public address book for people" : "Bilatu pertsonak helbide-liburu global eta publikoan",
    "Allow people to publish their data to a global and public address book" : "Baimena eman pertsonei beren datuak helbide-liburu global eta publikoan argitaratzeko",
    "Trusted federation" : "Federazio fidagarria",
    "Automatically accept shares from trusted federated accounts and groups by default" : "Onartu federatutako kontu eta talde fidagarrien partekatzeak modu lehenetsian",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Partekatu nirekin, nire federatutako #Nextcloud hodei IDa erabiliz, ikus {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Partekatu nirekin, nire federatutako #Nextcloud hodei IDa erabiliz",
    "Share with me via Nextcloud" : "Partekatu nirekin Nextcloud bidez",
    "Copy" : "Kopiatu",
    "Clipboard not available. Please copy the cloud ID manually." : "Arbela ez dago eskuragarri, mesedez kopiatu hodei IDa eskuz.",
    "Copied!" : "Kopiatuta!",
    "Federated Cloud" : "Hodei Federatua",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Nextcloud zerbitzaria darabilen edo Open Cloud Mesh (OCM) zerbitzuarekin bateragarri den zerbitzua erabiltzen duen edonorekin partekatu dezakezu! Ipini beren Federatutako Hodei IDa partekatze leihoan. Horrelako zerbait izan ohi da: erabiltzailea@nextcloud.zerbitzaria.com",
    "Your Federated Cloud ID" : "Zure federatutako hodei IDa",
    "Share it so your friends can share files with you:" : "Bidali lagunei, zurekin fitxategiak parteka ditzaten:",
    "Facebook" : "Facebook",
    "X (formerly Twitter)" : "X (lehen Twitter)",
    "formerly Twitter" : "lehen Twitter",
    "Mastodon" : "Mastodon",
    "Add to your website" : "Gehitu zure webgunera",
    "HTML Code:" : "HTML kodea:",
    "Cancel" : "Ezeztatu",
    "Add remote share" : "Gehitu urruneko partekatzea",
    "Remote share" : "Urruneko partekatzea",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "{owner}@{remote}(r)en {name} urruneko partekatzea gehitu nahi duzu?",
    "Remote share password" : "Urruneko partekatzearen pasahitza",
    "Incoming share could not be processed" : "Sarrerako partekatzea ezin izan da prozesatu",
    "Cloud ID copied to the clipboard" : "Hodei IDa arbelean kopiatu da",
    "Copy to clipboard" : "Kopiatu arbelera"
},
"nplurals=2; plural=(n != 1);");
