OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "First run wizard",
    "Add your profile information! For example your email is needed to receive notifications." : "Ongeza maelezo yako ya wasifu! Kwa mfano barua pepe yako inahitajika ili kupokea arifa.",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "Ongeza maelezo yako ya wasifu! Kwa mfano barua pepe yako inahitajika ili kupokea arifa na kuweka upya nenosiri lako.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Ongeza maelezo yako ya wasifu! Weka picha ya wasifu na jina kamili ili kutambulika kwa urahisi katika vipengele vyote.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Ongeza maelezo yako ya wasifu! Weka jina kamili ili kutambulika kwa urahisi katika vipengele vyote.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Ongeza maelezo yako ya wasifu! Weka picha ya wasifu kwa utambuzi rahisi katika vipengele vyote.",
    "App recommendation: Calendar" : "Mapendekezo ya programu: Kalenda",
    "Schedule work & meetings, synced with all your devices." : "Ratibu kazi na mikutano, iliyosawazishwa na vifaa vyako vyote.",
    "App recommendation: Contacts" : "Mapendekezo ya programu: Anwani",
    "Keep your colleagues and friends in one place without leaking their private info." : "Waweke wenzako na marafiki katika sehemu moja bila kuvujisha taarifa zao za faragha.",
    "App recommendation: Mail" : "Mapendekezo ya programu: Barua",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Programu rahisi ya barua pepe iliyounganishwa vizuri na Faili, Anwani na Kalenda.",
    "App recommendation: Tasks" : "Mapendekezo ya programu: Kazi",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "Sawazisha kazi kutoka kwa vifaa mbalimbali na Nextcloud yako na uzihariri mtandaoni.",
    "App recommendation: Deck" : "Mapendekezo ya programu: Deki",
    "Kanban style organization for personal planning and team projects." : "Shirika la mtindo wa Kanban kwa upangaji wa kibinafsi na miradi ya timu.",
    "App recommendation: Forms" : "Mapendekezo ya programu: Fomu",
    "Simple surveys and questionnaires, self-hosted" : "Tafiti na dodoso rahisi, zinazojiendesha zenyewe",
    "App recommendation: Recognize" : "Mapendekezo ya programu: Tambua",
    "Smart media tagging for Nextcloud" : "Uwekaji lebo kwenye media mahiri kwa Nextcloud",
    "App recommendation: Group folders" : "Mapendekezo ya programu: Folda za kikundi",
    "Admin-configured folders shared by everyone in a group." : "Folda zilizosanidiwa na msimamizi zinazoshirikiwa na kila mtu katika kikundi.",
    "App recommendation: Whiteboard" : "Mapendekezo ya programu: Ubao mweupe",
    "Create and share whiteboards with others and collaborate in real-time." : "Unda na ushiriki ubao mweupe na wengine na ushirikiane katika muda halisi.",
    "Connect your calendar" : "Unganusha kalenda yako",
    "Connect your contacts" : "Unganisha mawasiliano yako",
    "Access files via WebDAV" : "Fikia faili kupitia WebDAV",
    "Download macOS/iOS configuration profile" : " Pakua wasifu wa usanidi wa macOS/iOS",
    "Desktop client" : " Mteja wa eneo-kazi",
    "Android app on Google Play Store" : "Programu ya Android kwenye Google Play Store",
    "Android app on F-Droid" : "Programu ya Android kwenye F-Droid",
    "iOS app" : "Programu ya iOS",
    "About & What's new" : "Kuhusa & nini kipya?",
    "A welcome and introduction wizard for Nextcloud" : "Ukaribisho na utambulisho wa wazadi kwa Nextcloud",
    "This application enables a pop-up window when a user first logs into Nextcloud. This window welcomes new users to Nextcloud, and contains links to the standard desktop client, Android app, and the iOS app. The window also shows a link for accessing Nextcloud via WebDAV. At any time, the first run wizard can be opened again via link \"About\" on settings menu.\nThe First run wizard can be customized to meet specific design goals, or to change links and messages. Create an appropriate theme following the Theming documentation, and changes to the look and feel of this Wizard are simple. More information is available in the first run wizard documentation, as well as the theming documentation." : "Programu tumizi hii huwezesha kidirisha ibukizi mtumiaji anapoingia kwa mara ya kwanza kwenye Nextcloud. Dirisha hili linakaribisha watumiaji wapya kwenye Nextcloud, na lina viungo vya mteja wa kawaida wa eneo-kazi, programu ya Android na programu ya iOS. Dirisha pia linaonyesha kiunga cha kupata Nextcloud kupitia WebDAV. Wakati wowote, mchawi wa kwanza wa kukimbia unaweza kufunguliwa tena kupitia kiungo \"Kuhusu\" kwenye menyu ya mipangilio.\nKichawi cha kwanza cha kukimbia kinaweza kubinafsishwa ili kufikia malengo mahususi ya muundo, au kubadilisha viungo na ujumbe. Unda mandhari yanayofaa kufuatia hati za Mandhari, na mabadiliko ya mwonekano na hisia za Mchawi huyu ni rahisi. Maelezo zaidi yanapatikana katika nyaraka za kwanza za mchawi, pamoja na nyaraka za mandhari.",
    "Download on Apple app store" : "Pakua kwenye Apple app store",
    "Download on Google play store" : "Pakua kwenye Google Play Store",
    "Go to previous page" : "Nenda ukurasa uliopita",
    "Close" : "Funga",
    "More about Nextcloud" : "Zaidi kuhusu Nextcloud",
    "Explore more apps ↗" : "Gundua programu zaidi ↗",
    "Extend the functionality of Nextcloud with hundreds of community-developed apps." : "Panua utendakazi wa Nextcloud kwa mamia ya programu zilizotengenezwa na jumuiya",
    "Get involved! ↗" : "Jihusishe",
    "Be a part of the community that helps build, design, translate and promote Nextcloud!" : "Kuwa sehemu ya jumuiya inayosaidia kujenga, kubuni, kutafsiri na kukuza Nextcloud!",
    "Need help? ↗" : "Je, unahitaji usaidizi? ↗",
    "Find out more about your Nextcloud setup with the admin, user or developer documentation." : "Pata maelezo zaidi kuhusu usanidi wako wa Nextcloud na msimamizi, mtumiaji au nyaraka za msanidi.",
    "For large organisations ↗" : "Kwa mashirika makubwa ↗",
    "Get Nextcloud Enterprise for mission critical environments where advanced security and compliance are important." : "Pata Nextcloud Enterprise kwa mazingira muhimu ya utume ambapo usalama wa hali ya juu na utiifu ni muhimu.",
    "Seamless integration with your devices." : "Ujumuishaji usio na mshono na vifaa vyako.",
    "Sync your files across your devices with the desktop and mobile apps, and connect your calendar and contacts." : "Sawazisha faili zako kwenye vifaa vyako vyote na kompyuta ya mezani na programu za simu, na uunganishe kalenda na anwani zako.",
    "Desktop app ↗" : "Programu ya desktop ↗",
    "Download For Windows, Mac OS and Linux." : " Pakua Kwa Windows, Mac OS na Linux.",
    "Calendar and contacts ↗" : "Kalenda na anwani ↗",
    "Connect your calendar and contacts with your devices." : "Unganisha kalenda yako na anwani na vifaa vyako.",
    "Introducing Nextcloud Hub {version}" : "Tunakuletea Nextcloud Hub{version}",
    "Welcome to {cloudName}!" : "Karibu katika {cloudName}!",
    "This Nextcloud is on version {version}" : "Nextcloud hii iko katika toleo {version}",
    "A collaboration platform that puts you in control" : "Jukwaa la ushirikiano ambalo hukuweka katika udhibiti",
    "Privacy" : "Faragha",
    "Host your data and files where you decide." : "Panga data na faili zako unapoamua.",
    "Productivity" : "Tija",
    "Collaborate and communicate across any platform." : "Shirikiana na uwasiliane kwenye jukwaa lolote.",
    "Interoperability" : "Kushirikiana",
    "Import and export anything you want with open standards." : "Ingiza na kuuza nje chochote unachotaka kwa viwango vilivyo wazi.",
    "Community" : "Jamii",
    "Enjoy constant improvements from a thriving open-source community." : "Furahia maboresho ya mara kwa mara kutoka kwa jumuiya inayostawi ya chanzo-wazi.",
    "Nextcloud Hub {version} release" : "Toleo la Nextcloud Hub {version}",
    "Read more about it on the Nextcloud Hub {version} blog" : "Soma zaidi kuihusu kwenye blogu ya Nextcloud Hub {version}",
    "Find out more on the blog" : "Pata maelezo zaidi kwenye blogu",
    "Read the Nextcloud Hub {version} blog" : "Soma blogu ya Nextcloud Hub{version}",
    "Share your opinion about Nextcloud Hub {version}" : "Shiriki maoni yako kuhusu kitovu cha Nextcloud {version}",
    "Share via email" : "Shirikisha kupitia barua pepe",
    "Share on {socialMedia}" : "Shiriki kwenye {socialMedia}",
    "New in Nextcloud Hub {version}" : "Mpya katika kitovu cha Nextcloud {version}",
    "Connect other apps to {productName}" : "Unganisha programu zingine kwa {productName}",
    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to {productName}." : "Mbali na programu za rununu na mteja wa eneo-kazi unaweza kuunganisha programu nyingine yoyote inayotumia itifaki za WebDAV/CalDAV/CardDAV kwa {productName}.",
    "Apps to connect to {productName}" : "Programu za kuunganisha kwa {productName}",
    "Set up sync clients using an {linkStart}app password{linkEnd}. That way you can make sure you are able to revoke access in case you lose that device." : "Weka usawazishaji wa wateja ukitumia {linkStart} nenosiri la programu{linkEnd}. Kwa njia hiyo unaweza kuhakikisha kuwa unaweza kubatilisha ufikiaji ikiwa utapoteza kifaa hicho.",
    "Get the apps to sync your files" : "Pata programu za kusawazisha faili zako",
    "{productName} gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "{productName} inakupa ufikiaji wa faili zako popote ulipo. Wateja wetu ambao ni rahisi kutumia kompyuta ya mezani na simu wanapatikana kwa mifumo yote mikuu kwa gharama sifuri. ",
    "App for syncing" : "Programu ya kusawazisha",
    "URL copied" : "URL imenakiliwa",
    "Could not copy the URL, please copy manually" : "Haikuweza kunakili URL, tafadhali nakili wewe mwenyewe",
    "Server address" : "Anwani ya seva",
    "Use this link to connect your apps and desktop client to this server:" : "Tumia kiungo hiki kuunganisha programu zako na kiteja cha eneo-kazi kwenye seva hii:",
    "End-to-end encryption in calls and web" : "Usimbaji fiche kutoka mwisho hadi mwisho katika simu na wavuti",
    "Performance improvements across all our products" : "Maboresho ya utendaji katika bidhaa zetu zote",
    "Thousands of tweaks for improved UX and stability" : "Maelfu ya marekebisho ya UX iliyoboreshwa na uthabiti",
    "Your own new personal assistant" : "Msaidizi wako mpya wa kibinafsi",
    "Seamless file conversions" : "Ubadilishaji wa faili usio na mshono",
    "Smarter team sharing with Team folders" : "Kushiriki kwa timu nadhifu na folda za Timu",
    "Schedule meetings directly in Talk" : "Panga mikutano moja kwa moja kwenye Talk",
    "Mail you love again: translations, summaries, and mentions" : "Tuma barua unayopenda tena: tafsiri, muhtasari, na mitajo",
    "Get to know the new features of Hub {version}" : "Pata kufahamu vipengele vipya vya kitovu {version}",
    "Nextcloud Hub 10 is here – your modular & unified digital workspace! 💫" : "Kitovu cha Nextcloud 10 iko hapa - nafasi yako ya kazi ya kawaida na iliyounganishwa ya dijiti! 💫",
    "What's new?" : "Nini kipya?",
    "Nextcloud on all your devices" : "Nextcloud kwenye vifaa vyako vyote",
    "Nextcloud Hub {version}" : "Kitovu cha Nextcloud {version}",
    "Read more" : "Soma zaidi",
    "Share on social media" : "Shirikisha katika mitandao ya kijamii",
    "Get started!" : "Anza",
    "App recommendation: Nextcloud Calendar" : "Mapendekezo ya programu: Kalenda ya Nextcloud",
    "App recommendation: Nextcloud Contacts" : "Mapendekezo ya programu: Anwani za Nextcloud",
    "App recommendation: Nextcloud Mail" : "Mapendekezo ya programu:  Barua ya Nextcloud ",
    "Federated collaboration: file sharing, messaging, calls" : "Ushirikiano wa Shirikisho: kushiriki faili, ujumbe, simu",
    "Nextcloud Whiteboard" : "Ubao mweupe wa Nextcloud",
    "Workflow Engine" : "Injini ya mtiririko wa kazi",
    "Safer and swifter mail" : "Barua salama na ya haraka zaidi",
    "Public Collectives sharing, previews and QR-codes" : "Kushiriki kwa Mikusanyiko ya Umma, muhtasari na misimbo ya QR",
    "Office and PDF templates" : "Violezo vya Office na PDF",
    "Chat mode for Nextcloud Assistant" : "Hali ya gumzo ya msaidizi wa Nextcloud",
    "Get to know the new features of Hub 9" : "Jua vipengele vipya vya kitovu 9"
},
"nplurals=2; plural=(n != 1);");
