OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Οι πληροφορίες επεξεργαστή CPU δεν είναι διαθέσιμες",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Σύνολο: {memTotalBytes}/Τρέχουσα χρήση: {memUsageBytes}",
    "RAM info not available" : "Οι πληροφορίες RAM δεν είναι διαθέσιμες",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Σύνολο: {swapTotalBytes}/Τρέχουσα χρήση: {swapUsageBytes}",
    "SWAP info not available" : "Οι πληροφορίες SWAP δεν είναι διαθέσιμες",
    "Copied!" : "Αντιγράφηκε!",
    "Not supported!" : "Δεν υποστηρίζεται!",
    "Press ⌘-C to copy." : "Για αντιγραφή πατήστε ⌘-C.",
    "Press Ctrl-C to copy." : "Για αντιγραφή πατήστε Ctrl-C.",
    "System" : "Σύστημα",
    "Monitoring" : "Παρακολούθηση",
    "Monitoring app with useful server information" : "Εφαρμογή παρακολούθησης πληροφοριών διακομιστή",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Εμφανίζει χρήσιμες πληροφορίες του διακομιστή, όπως χρήση CPU, RAM, σκληρού δίσκου, αριθμός χρηστών, κλτ.",
    "Operating System:" : "Λειτουργικό σύστημα",
    "Memory:" : "Μνήμη:",
    "Server time:" : "Ώρα διακομιστή:",
    "Uptime:" : "Διάρκεια λειτουργίας:",
    "Temperature" : "Θερμοκρασία",
    "Load" : "Χρήση",
    "Memory" : "Μνήμη",
    "Disk" : "Δίσκος",
    "Mount:" : "Προσάρτηση:",
    "Filesystem:" : "Σύστημα αρχείων:",
    "Size:" : "Μέγεθος:",
    "Available:" : "Διαθέσιμα:",
    "Used:" : "Σε χρήση:",
    "Files:" : "Αρχεία:",
    "Storages:" : "Αποθηκευτικοί χώροι:",
    "Free Space:" : "Ελεύθερος Χώρος:",
    "Network" : "Δίκτυο",
    "Hostname:" : "Όνομα υπολογιστή:",
    "Gateway:" : "Πύλη:",
    "Status:" : "Κατάσταση:",
    "Speed:" : "Ταχύτητα:",
    "Active users" : "Ενεργοί χρήστες",
    "Shares" : "Κοινόχρηστοι φάκελοι",
    "Users:" : "Χρήστες:",
    "Groups:" : "Ομάδες:",
    "Links:" : "Σύνδεσμοι:",
    "Emails:" : "Email:",
    "PHP" : "PHP",
    "Version:" : "Έκδοση:",
    "Memory limit:" : "Όριο μνήμης:",
    "Max execution time:" : "Μέγιστος χρόνος εκτέλεσης:",
    "Upload max size:" : "Μέγιστο μέγεθος μεταφόρτωσης:",
    "Extensions:" : "Επεκτάσεις:",
    "Database" : "Βάση δεδομένων",
    "Type:" : "Τύπος:",
    "External monitoring tool" : "Εξωτερικό εργαλείο παρακολούθησης",
    "Copy" : "Αντιγραφή",
    "To use an access token, please generate one then set it using the following command:" : "Για να χρησιμοποιήσετε ένα αναγνωριστικό πρόσβασης (token), δημιουργήστε ένα και ορίστε το χρησιμοποιώντας την ακόλουθη εντολή:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Στη συνέχεια, περάστε το αναγνωριστικό με την κεφαλίδα \"NC-Token\" όταν υποβάλετε ερώτημα στην παραπάνω διεύθυνση URL."
},
"nplurals=2; plural=(n != 1);");
