OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Přidáno na seznam důvěryhodných serverů",
    "No server found with ID: %s" : "Nenalezen žádný server, který by měl identifikátor: %s",
    "Could not remove server" : "Nebylo možné odebrat server",
    "Server is already in the list of trusted servers." : "Server se už nachází na seznamu těch důvěryhodných.",
    "No server to federate with found" : "Nenalezen žádný server, se kterým by bylo možné federovat",
    "Could not add server" : "Server se nepodařilo přidat",
    "Trusted servers" : "Důvěryhodné servery",
    "Federation" : "Federování",
    "Federation allows you to connect with other trusted servers to exchange the account directory." : "Federování umožňuje propojit s ostatními servery, kterým věříte a vyměňovat si tak adresář účtů.",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing." : "Federování umožňuje propojit s ostatními servery, kterým věříte a vyměňovat si tak adresář uživatelských účtů. Používá se toho například pro automatické doplňování externích účtů při federovaném sdílení.",
    "External documentation for Federated Cloud Sharing" : "Externí dokumentace pro sdílení v rámci federovaného cloudu",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "Federování umožňuje propojit se s ostatními servery, kterým věříte a vyměňovat si tak adresář uživatelských účtů. Používá se toho například pro automatické dokončování externích účtů při federovaném sdílení. Nicméně pro vytvoření federovaného sdílení jako takového není nezbytné přidávat server jako důvěryhodný.",
    "Each server must validate the other. This process may require a few cron cycles." : "Je třeba, aby každý server ověřil ten druhý. Tento proces může vyžadovat několik cyklů plánovače.",
    "+ Add trusted server" : "+ Přidat důvěryhodný server",
    "Trusted server" : "Důvěryhodný server",
    "Add" : "Přidat"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
