OC.L10N.register(
    "notifications",
    {
    "We want to keep offering our push notification service for free, but large number of users overload our infrastructure. For this reason we have to rate-limit the use of push notifications. If you need this feature, consider using Nextcloud Enterprise." : "Vogliamo continuare a offrire il nostro servizio di notifiche push gratuitamente, ma un gran numero di utenti sovraccarica la nostra infrastruttura. Per questo motivo dobbiamo limitare la frequenza di utilizzo delle notifiche push. Se hai bisogno di questa funzionalità, prendi in considerazione l'utilizzo di Nextcloud Enterprise.",
    "User not found" : "Utente non trovato",
    "An unexpected error occurred, ask your administration to check the logs." : "Si è verificato un errore imprevisto, chiedi all'amministratore di sistema di controllare i log.",
    "Hello %s" : "Ciao %s",
    "Hello %s," : "Ciao %s,",
    "_New notification for %s_::_%n new notifications for %s_" : ["Nuova notifica per %s","%n nuove notifiche per %s","%n nuove notifiche per %s"],
    "_You have a new notification for %s_::_You have %n new notifications for %s_" : ["Hai una nuova notifica per %s","Hai %n nuove notifiche per %s","Hai %n nuove notifiche per %s"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Puoi cambiare la frequenza di queste email o disattivarle nelle <a href=\"%s\">impostazioni</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Puoi cambiare la frequenza di queste email o disattivarle nelle impostazioni: %s",
    "Admin notifications" : "Notifiche amministratore ",
    "Notifications" : "Notifiche",
    "Push notifications - Fair use policy" : "Notifiche push - Condizioni di utilizzo",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server and the limit was reached for this server. For enterprise users, a more scalable gateway is available." : "Nextcloud GmbH sponsorizza un gateway di notifica push gratuito per utenti privati. Per garantire un buon servizio, il gateway limita il numero di notifiche push per server; il limite è stato raggiunto. Per utenti aziendali è disponibile un gateway più scalabile.",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "Questa applicazione  fornisce un motore e un'interfaccia per le API di notifica disponibili in Nextcloud.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "Questa applicazione fornisce un motore e un'interfaccia per le API di notifica disponibili in Nextcloud.\n\t\tLe API sono utilizzate da altre applicazioni per notificare gli utenti nell'interfaccia web e nei client di sincronizzazione di varie situazioni. Alcuni esempi sono:\n\n📬 Condivisione file federata: hai ricevuto una nuova condivisione remota\n📑 Commenti: un altro utente ti ha menzionato in un commento su un file\n\n🚢 Notifiche di aggiornamento: aggiornamenti disponibili per un'applicazione o per Nextcloud stesso\n\n📣 Centro annunci: un annuncio è stato pubblicato dall'amministratore",
    "Failed to perform action" : "Esecuzione operazione non riuscita",
    "Failed to dismiss notification" : "Cancellazione notifiche non riuscita",
    "Dismiss" : "Annulla",
    "Contact Nextcloud GmbH" : "Contatta Nextcloud GmbH",
    "in {path}" : "in {path}",
    "Push notifications might be unreliable" : "Le notifiche push possono essere inaffidabili",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server. For enterprise users, a more scalable gateway is available. Contact Nextcloud GmbH for more information." : "Nextcloud GmbH sponsorizza un gateway di notifica push gratuito per utenti privati. Per garantire un buon servizio, il gateway limita il numero di notifiche push per server. Per utenti aziendali è disponibile un gateway più scalabile. Contatta Nextcloud GmbH per informazioni.",
    "Requesting browser permissions to show notifications" : "Richiesta dei permessi del browser per mostrare le notifiche",
    "No notifications" : "Nessuna notifica",
    "Failed to dismiss all notifications" : "Cancellazione di tutte le notifiche non riuscita",
    "Dismiss all notifications" : "Cancella tutte le notifiche",
    "Never" : "Mai",
    "1 hour" : "1 ora",
    "3 hours" : "3 ore",
    "1 day" : "1 giorno",
    "1 week" : "1 settimana",
    "Your settings have been updated." : "Le impostazioni sono state aggiornate.",
    "An error occurred while updating your settings." : "Si è verificato un errore durante l'aggiornamento delle impostazioni.",
    "Notifications defaults" : "Notifiche predefinite",
    "Configure the default notification settings for new users" : "Configura le impostazioni di notifica predefinite per i nuovi utenti",
    "Send email reminders about unhandled notifications after:" : "Invia promemoria via email riguardo notifiche non gestite dopo:",
    "Play sound when a new notification arrives" : "Riproduci un suono quando arriva una nuova notifica",
    "Play sound when a call started (requires Nextcloud Talk)" : "Riproduci un suono all'inizio di una chiamata (richiede Nextcloud Talk)",
    "None" : "Nessuno",
    "You need to set up your email address before you can receive notification emails." : "Devi impostare l'indirizzo di posta prima di poter ricevere le email di notifica.",
    "Also repeat sound on a secondary speaker" : "Ripeti il suono in un'uscita audio secondaria",
    "Selection of the speaker device is currently not supported by Safari" : "La selezione del dispositivo audio attualmente non è supportata da Safari",
    "Select a device" : "Seleziona un dispositivo",
    "seconds ago" : "secondi fa"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
