<?php
namespace Aws\QConnect\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Q Connect** service.
 */
class QConnectException extends AwsException {}
