OC.L10N.register(
    "comments",
    {
    "Comments" : "Comentários",
    "You commented" : "Comentou",
    "{author} commented" : "{author} comentou",
    "You commented on %1$s" : "Você comentou em %1$s",
    "You commented on {file}" : "Você comentou em {file}",
    "%1$s commented on %2$s" : "%1$s comentou em %2$s",
    "{author} commented on {file}" : "{author} comentou em {file}",
    "<strong>Comments</strong> for files" : "<strong>Comentários</strong> aos ficheiros",
    "Files" : "Ficheiros",
    "Files app plugin to add comments to files" : "Plug-in da aplicação de ficheiros para adicionar comentários aos ficheiros",
    "Edit comment" : "Editar comentário",
    "Delete comment" : "Eliminar comentário",
    "Cancel edit" : "Cancelar edição",
    "New comment" : "Novo comentário",
    "Write a comment …" : "Escreva um comentário...",
    "Post comment" : "Publicar comentário",
    "No comments yet, start the conversation!" : "Ainda sem comentários, inicie uma conversação!",
    "No more messages" : "Sem mais mensagens",
    "Retry" : "Repetir",
    "_1 new comment_::_{unread} new comments_" : ["1 novo comentário","{unread} novos comentários","{unread} novos comentários"],
    "Comment" : "Comentário",
    "Comment deleted" : "Comentário eliminado"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
