OC.L10N.register(
    "app_api",
    {
    "Cancel" : "Sguir dheth",
    "Delete" : "Sguab às",
    "Default" : "Bunaiteach",
    "Edit" : "Deasaich",
    "Name" : "Ainm",
    "Save" : "Sàbhail",
    "Remove" : "Thoir air falbh",
    "Version" : "Tionndadh",
    "Type" : "Seòrsa",
    "Details" : "Mion-fhiosrachadh",
    "Disable" : "Cuir à comas"
},
"nplurals=4; plural=(n==1 || n==11) ? 0 : (n==2 || n==12) ? 1 : (n > 2 && n < 20) ? 2 : 3;");
