OC.L10N.register(
    "dav",
    {
    "Calendar" : "Calendário",
    "Tasks" : "Tarefas",
    "Personal" : "Pessoal",
    "{actor} created calendar {calendar}" : "{actor} criou o calendário {calendar}",
    "You created calendar {calendar}" : "Criou o calendario {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} apagou o calendário {calendar}",
    "You deleted calendar {calendar}" : "Apagou o calendário {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} atualizou o calendário {calendar}",
    "You updated calendar {calendar}" : "Atualizou o calendário {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} restaurou o calendário {calendar}",
    "You restored calendar {calendar}" : "restaurou o calendário {calendar}",
    "You shared calendar {calendar} as public link" : "Partilhou o calendário {calendar} como uma hiperligação pública",
    "You removed public link for calendar {calendar}" : "Removeu uma hiperligação pública para o calendário {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} partilhou o calendário {calendar} consigo",
    "You shared calendar {calendar} with {user}" : "Partilhou o calendário {calendar} com {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor}  partilhou o calendário {calendar} com {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} retirou-lhe a partilha do calendário {calendar}",
    "You unshared calendar {calendar} from {user}" : "Retirou a partilha do calendário {calendar} com {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} retirou a partilha do calendário {calendar} com {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} deixou de partilhar o calendário {calendar} de próprio",
    "You shared calendar {calendar} with group {group}" : "partilhou o calendário {calendar} com o grupo {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} partilhou o calendário {calendar} com o grupo {group}",
    "You unshared calendar {calendar} from group {group}" : "deixou de partilhar o calendário {calendar} do grupo {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} deixou de partilhar o calendário {calendar} do grupo {group}",
    "Untitled event" : "Evento sem título",
    "{actor} created event {event} in calendar {calendar}" : "{actor} criou o evento {event} in o calendário {calendar}",
    "You created event {event} in calendar {calendar}" : "criou o evento {event} in o calendário {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} eliminou o evento {event} de o calendário {calendar}",
    "You deleted event {event} from calendar {calendar}" : "eliminou o evento {event} de o calendário {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} atualizou o evento {event} in o calendário {calendar}",
    "You updated event {event} in calendar {calendar}" : "atualizou o evento {event} in o calendário {calendar}",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} moveu o evento {event} de o calendário {sourceCalendar} para o calendário {targetCalendar}",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "moveu o evento {event} de o calendário {sourceCalendar} para o calendário {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} restaurou o evento {event} of o calendário {calendar}",
    "You restored event {event} of calendar {calendar}" : "restaurou o evento {event} of o calendário {calendar}",
    "Busy" : "Ocupado",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} criou to-do {todo} in list {calendar}",
    "You created to-do {todo} in list {calendar}" : "criou to-do {todo} in list {calendar}",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} eliminou to-do {todo} de list {calendar}",
    "You deleted to-do {todo} from list {calendar}" : "eliminou to-do {todo} de list {calendar}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} atualizou to-do {todo} in list {calendar}",
    "You updated to-do {todo} in list {calendar}" : "atualizou to-do {todo} in list {calendar}",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} concluiu a tarefa {todo} na lista {calendar}",
    "You solved to-do {todo} in list {calendar}" : "solved to-do {todo} in list {calendar}",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} reabriu a tarefa {todo} na lista {calendar}",
    "You reopened to-do {todo} in list {calendar}" : "reopened to-do {todo} in list {calendar}",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} moveu to-do {todo} de list {sourceCalendar} para list {targetCalendar}",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "moveu to-do {todo} de list {sourceCalendar} para list {targetCalendar}",
    "Calendar, contacts and tasks" : "Calendário, contactos e tarefas",
    "A <strong>calendar</strong> was modified" : "O <strong>calendário</strong> foi modificado.",
    "A calendar <strong>event</strong> was modified" : "Um <strong>event</strong> do calendário foi modificado",
    "A calendar <strong>to-do</strong> was modified" : "Foi modificada uma <strong>tarefa</strong> do calendário",
    "Contact birthdays" : "Aniversário dos contactos",
    "Death of %s" : "Falecimento de %s",
    "Untitled calendar" : "Calendário sem titulo",
    "Calendar:" : "Calendário:",
    "Date:" : "Data:",
    "Where:" : "Local:",
    "Description:" : "Descrição:",
    "_%n year_::_%n years_" : ["%n ano","%n anos","%n anos"],
    "_%n month_::_%n months_" : ["%n mês","%n meses","%n meses"],
    "_%n day_::_%n days_" : ["%n dia","%n dias","%n dias"],
    "_%n hour_::_%n hours_" : ["%n hora","%n horas","%n horas"],
    "_%n minute_::_%n minutes_" : ["%n minuto","%n minutos","%n minutos"],
    "%s (in %s)" : "%s (em %s)",
    "%s (%s ago)" : "%s (%s atrás)",
    "Calendar: %s" : "Calendário: %s",
    "Date: %s" : "Data: %s",
    "Description: %s" : "Descrição: %s",
    "Where: %s" : "Local: %s",
    "%1$s via %2$s" : "%1$s via %2$s",
    "In the past on %1$s for the entire day" : "No passado em %1$s durante todo o dia",
    "_In a minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["Daqui a um minuto em %1$s para todo o dia","Daqui a %n minutos em %1$s para todo o dia","Daqui a %n minutos em %1$s para todo o dia"],
    "_In a hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["Daqui a um hora em %1$s para todo o dia","Daqui a %n horas em %1$s para todo o dia","Daqui a %n horas em %1$s para todo o dia"],
    "_In a day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["Daqui a um dia em %1$s para todo o dia","Daqui a %n dias em %1$s para todo o dia","Daqui a %n dias em %1$s para todo o dia"],
    "_In a week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["Daqui a um semana em %1$s para todo o dia","Daqui a %n semanas em %1$s para todo o dia","Daqui a %n semanas em %1$s para todo o dia"],
    "_In a month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["Daqui a um mês em %1$s para todo o dia","Daqui a %n meses em %1$s para todo o dia","Daqui a %n meses em %1$s para todo o dia"],
    "_In a year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["Daqui a um ano em %1$s para todo o dia","Daqui a %n anos em %1$s para todo o dia","Daqui a %n anos em %1$s para todo o dia"],
    "In the past on %1$s between %2$s - %3$s" : "No passado em %1$s entre %2$s - %3$s",
    "_In a minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["Daqui a um minuto em %1$s entre %2$s - %3$s","Daqui a %n minutos em %1$s entre %2$s - %3$s","Daqui a %n minutos em %1$s entre %2$s - %3$s"],
    "_In a hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["Daqui a um hora em %1$s entre %2$s - %3$s","Daqui a %n horas em %1$s entre %2$s - %3$s","Daqui a %n horas em %1$s entre %2$s - %3$s"],
    "_In a day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["Daqui a um dia em %1$s entre %2$s - %3$s","Daqui a %n dias em %1$s entre %2$s - %3$s","Daqui a %n dias em %1$s entre %2$s - %3$s"],
    "_In a week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["Daqui a um semana em %1$s entre %2$s - %3$s","Daqui a %n semanas em %1$s entre %2$s - %3$s","Daqui a %n semanas em %1$s entre %2$s - %3$s"],
    "_In a month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["Daqui a um mês em %1$s entre %2$s - %3$s","Daqui a %n meses em %1$s entre %2$s - %3$s","Daqui a %n meses em %1$s entre %2$s - %3$s"],
    "_In a year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["Daqui a um ano em %1$s entre %2$s - %3$s","Daqui a %n anos em %1$s entre %2$s - %3$s","Daqui a %n anos em %1$s entre %2$s - %3$s"],
    "Could not generate when statement" : "Não foi possível gerar a expressão \"quando\"",
    "Every Day for the entire day" : "Todos os dias, dia inteiro",
    "Every Day for the entire day until %1$s" : "Todos os dias, dia inteiro até %1$s",
    "Every Day between %1$s - %2$s" : "Todos os dias entre %1$s e %2$s",
    "Every Day between %1$s - %2$s until %3$s" : "Todos os dias entre %1$s e %2$s até %3$s",
    "Every %1$d Days for the entire day" : "A cada %1$d dias, dia inteiro",
    "Every %1$d Days for the entire day until %2$s" : "A cada %1$d dias, dia inteiro até %2$s",
    "Every %1$d Days between %2$s - %3$s" : "A cada %1$d dias entre %2$s e %3$s",
    "Every %1$d Days between %2$s - %3$s until %4$s" : "A cada %1$d dias entre %2$s e %3$s até %4$s",
    "Could not generate event recurrence statement" : "Não foi possível gerar a expressão de recorrência do evento",
    "Every Week on %1$s for the entire day" : "Todas as semanas, em %1$s, dia inteiro",
    "Every Week on %1$s for the entire day until %2$s" : "Todas as semanas, em %1$s, dia inteiro até %2$s",
    "Every Week on %1$s between %2$s - %3$s" : "Todas as semanas, em %1$s entre %2$s e %3$s",
    "Every Week on %1$s between %2$s - %3$s until %4$s" : "Todas as semanas, em %1$s entre %2$s e %3$s até %4$s",
    "Every %1$d Weeks on %2$s for the entire day" : "A cada %1$d semanas, em %2$s, dia inteiro",
    "Every %1$d Weeks on %2$s for the entire day until %3$s" : "A cada %1$d semanas, em %2$s, dia inteiro até %3$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s" : "A cada %1$d semanas, em %2$s entre %3$s e %4$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s until %5$s" : "A cada %1$d semanas, em %2$s entre %3$s e %4$s até %5$s",
    "Every Month on the %1$s for the entire day" : "Todos os meses, no dia %1$s, dia inteiro",
    "Every Month on the %1$s for the entire day until %2$s" : "Todos os meses, no dia %1$s, dia inteiro até %2$s",
    "Every Month on the %1$s between %2$s - %3$s" : "Todos os meses, no dia %1$s entre %2$s e %3$s",
    "Every Month on the %1$s between %2$s - %3$s until %4$s" : "Todos os meses, no dia %1$s entre %2$s e %3$s até %4$s",
    "Every %1$d Months on the %2$s for the entire day" : "A cada %1$d meses, no dia %2$s, dia inteiro",
    "Every %1$d Months on the %2$s for the entire day until %3$s" : "A cada %1$d meses, no dia %2$s, dia inteiro até %3$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s" : "A cada %1$d meses, no dia %2$s entre %3$s e %4$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s until %5$s" : "A cada %1$d meses, no dia %2$s entre %3$s e %4$s até %5$s",
    "Every Year in %1$s on the %2$s for the entire day" : "Todos os anos em %1$s, no dia %2$s, dia inteiro",
    "Every Year in %1$s on the %2$s for the entire day until %3$s" : "Todos os anos em %1$s, no dia %2$s, dia inteiro até %3$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s" : "Todos os anos em %1$s, no dia %2$s entre %3$s e %4$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s until %5$s" : "Todos os anos em %1$s, no dia %2$s entre %3$s e %4$s até %5$s",
    "Every %1$d Years in %2$s on the %3$s for the entire day" : "A cada %1$d anos em %2$s, no dia %3$s, dia inteiro",
    "Every %1$d Years in %2$s on the %3$s for the entire day until %4$s" : "A cada %1$d anos em %2$s, no dia %3$s, dia inteiro até %4$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s" : "A cada %1$d anos em %2$s, no dia %3$s entre %4$s e %5$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "A cada %1$d anos em %2$s, no dia %3$s entre %4$s e %5$s até %6$s",
    "On specific dates for the entire day until %1$s" : "Em datas específicas, dia inteiro até %1$s",
    "On specific dates between %1$s - %2$s until %3$s" : "Em datas específicas entre %1$s e %2$s até %3$s",
    "In the past on %1$s" : "No passado em %1$s",
    "_In a minute on %1$s_::_In %n minutes on %1$s_" : ["Daqui a um minuto em %1$s","Daqui a %n minutos em %1$s","Daqui a %n minutos em %1$s"],
    "_In a hour on %1$s_::_In %n hours on %1$s_" : ["Daqui a um hora em %1$s","Daqui a %n horas em %1$s","Daqui a %n horas em %1$s"],
    "_In a day on %1$s_::_In %n days on %1$s_" : ["Daqui a um dia em %1$s","Daqui a %n dias em %1$s","Daqui a %n dias em %1$s"],
    "_In a week on %1$s_::_In %n weeks on %1$s_" : ["Daqui a um semana em %1$s","Daqui a %n semanas em %1$s","Daqui a %n semanas em %1$s"],
    "_In a month on %1$s_::_In %n months on %1$s_" : ["Daqui a um mês em %1$s","Daqui a %n meses em %1$s","Daqui a %n meses em %1$s"],
    "_In a year on %1$s_::_In %n years on %1$s_" : ["Daqui a um ano em %1$s","Daqui a %n anos em %1$s","Daqui a %n anos em %1$s"],
    "In the past on %1$s then on %2$s" : "No passado em %1$s e depois %2$s",
    "_In a minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["Daqui a um minuto em %1$s e depois em %2$s","Daqui a %n minutos em %1$s e depois em %2$s","Daqui a %n minutos em %1$s e depois em %2$s"],
    "_In a hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["Daqui a um hora em %1$s e depois em %2$s","Daqui a %n horas em %1$s e depois em %2$s","Daqui a %n horas em %1$s e depois em %2$s"],
    "_In a day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["Daqui a um dia em %1$s e depois em %2$s","Daqui a %n dias em %1$s e depois em %2$s","Daqui a %n dias em %1$s e depois em %2$s"],
    "_In a week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["Daqui a um semana em %1$s e depois em %2$s","Daqui a %n semanas em %1$s e depois em %2$s","Daqui a %n semanas em %1$s e depois em %2$s"],
    "_In a month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["Daqui a um mês em %1$s e depois em %2$s","Daqui a %n meses em %1$s e depois em %2$s","Daqui a %n meses em %1$s e depois em %2$s"],
    "_In a year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["Daqui a um ano em %1$s e depois em %2$s","Daqui a %n anos em %1$s e depois em %2$s","Daqui a %n anos em %1$s e depois em %2$s"],
    "In the past on %1$s then on %2$s and %3$s" : "No passado em %1$s e depois em %2$s e %3$s",
    "_In a minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["Daqui a um minuto em %1$s e depois em %2$s e %3$s","Daqui a %n minutos em %1$s e depois em %2$s e %3$s","Daqui a %n minutos em %1$s e depois em %2$s e %3$s"],
    "_In a hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["Daqui a um hora em %1$s e depois em %2$s e %3$s","Daqui a %n horas em %1$s e depois em %2$s e %3$s","Daqui a %n horas em %1$s e depois em %2$s e %3$s"],
    "_In a day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["Daqui a um dia em %1$s e depois em %2$s e %3$s","Daqui a %n dias em %1$s e depois em %2$s e %3$s","Daqui a %n dias em %1$s e depois em %2$s e %3$s"],
    "_In a week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["Daqui a um semana em %1$s e depois em %2$s e %3$s","Daqui a %n semanas em %1$s e depois em %2$s e %3$s","Daqui a %n semanas em %1$s e depois em %2$s e %3$s"],
    "_In a month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["Daqui a um mês em %1$s e depois em %2$s e %3$s","Daqui a %n meses em %1$s e depois em %2$s e %3$s","Daqui a %n meses em %1$s e depois em %2$s e %3$s"],
    "_In a year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["Daqui a um ano em %1$s e depois em %2$s e %3$s","Daqui a %n anos em %1$s e depois em %2$s e %3$s","Daqui a %n anos em %1$s e depois em %2$s e %3$s"],
    "Could not generate next recurrence statement" : "Não foi possível gerar a próxima expressão de recorrência",
    "Cancelled: %1$s" : "Cancelado: %1$s",
    "\"%1$s\" has been canceled" : "\"%1$s\" foi cancelado",
    "Re: %1$s" : "Re: %1$s",
    "%1$s has accepted your invitation" : "%1$s aceitou o seu convite",
    "%1$s has tentatively accepted your invitation" : "%1$s aceitou provisoriamente o seu convite",
    "%1$s has declined your invitation" : "%1$s recusou o seu convite",
    "%1$s has responded to your invitation" : "%1$s respondeu ao seu convite",
    "Invitation updated: %1$s" : "Convite atualizado: %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s atualizou o evento \"%2$s\"",
    "Invitation: %1$s" : "Convite: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s gostaria de convidá‑lo para \"%2$s\"",
    "Organizer:" : "Organizador:",
    "Attendees:" : "Participantes:",
    "Title:" : "Titulo: ",
    "When:" : "Quando:",
    "Location:" : "Localização:",
    "Link:" : "Ligação:",
    "Occurring:" : "Ocorrências:",
    "Accept" : "Aceitar",
    "Decline" : "Recusar",
    "More options …" : "Mais opções…",
    "More options at %s" : "Mais opções em %s",
    "Monday" : "Segunda",
    "Tuesday" : "Terça",
    "Wednesday" : "Quarta",
    "Thursday" : "Quinta",
    "Friday" : "Sexta",
    "Saturday" : "Sábado",
    "Sunday" : "Domingo",
    "January" : "Janeiro",
    "February" : "Fevereiro",
    "March" : "Março",
    "April" : "Abril",
    "May" : "Maio",
    "June" : "Junho",
    "July" : "Julho",
    "August" : "Agosto",
    "September" : "Setembro",
    "October" : "Outubro",
    "November" : "Novembro",
    "December" : "Dezembro",
    "First" : "Primeiro",
    "Second" : "Segundo",
    "Third" : "Terceiro",
    "Fourth" : "Quarto",
    "Fifth" : "Quinto",
    "Last" : "Último",
    "Second Last" : "Penúltimo",
    "Third Last" : "Antepenúltimo",
    "Fourth Last" : "Quarto do fim",
    "Fifth Last" : "Quinto do fim",
    "Contacts" : "Contactos",
    "{actor} created address book {addressbook}" : "{actor} criou address book {addressbook}",
    "You created address book {addressbook}" : "criou address book {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} eliminou address book {addressbook}",
    "You deleted address book {addressbook}" : "eliminou address book {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} atualizou address book {addressbook}",
    "You updated address book {addressbook}" : "atualizou address book {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} partilhou address book {addressbook} com you",
    "You shared address book {addressbook} with {user}" : "partilhou address book {addressbook} com {user}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} partilhou address book {addressbook} com {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} deixou de partilhar address book {addressbook} de you",
    "You unshared address book {addressbook} from {user}" : "deixou de partilhar address book {addressbook} de {user}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} deixou de partilhar address book {addressbook} de {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} deixou de partilhar address book {addressbook} de próprio",
    "You shared address book {addressbook} with group {group}" : "partilhou address book {addressbook} com o grupo {group}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} partilhou address book {addressbook} com o grupo {group}",
    "You unshared address book {addressbook} from group {group}" : "deixou de partilhar address book {addressbook} do grupo {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} deixou de partilhar address book {addressbook} do grupo {group}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} criou contact {card} in address book {addressbook}",
    "You created contact {card} in address book {addressbook}" : "criou contact {card} in address book {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} eliminou contact {card} de address book {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "eliminou contact {card} de address book {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} atualizou contact {card} in address book {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "atualizou contact {card} in address book {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "Foi modificado um <strong>contacto</strong> ou <strong>livro de endereços</strong>",
    "Accounts" : "Contas",
    "System address book which holds all accounts" : "Livro de endereços do sistema que contém todas as contas",
    "File is not updatable: %1$s" : "O ficheiro não pode ser atualizado: %1$s",
    "Failed to get storage for file" : "Falha ao obter armazenamento para o ficheiro",
    "Could not write to final file, canceled by hook" : "Não foi possível escrever no ficheiro final, cancelado por hook",
    "Could not write file contents" : "Não foi possível escrever o conteúdo do ficheiro",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes","%n bytes"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "Erro ao copiar ficheiro para o destino (copiado: %1$s, tamanho esperado: %2$s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "Tamanho esperado de %1$s, mas leitura diferente (do cliente Nextcloud) e escreveu (para armazenamento Nextcloud) %2$s. Possível problema do lado do cliente ou ao escrever no armazenamento do servidor.",
    "Could not rename part file to final file, canceled by hook" : "Não foi possível renomear o ficheiro parcial para ficheiro final, cancelado por hook",
    "Could not rename part file to final file" : "Não foi possível renomear o ficheiro parcial para ficheiro final",
    "Failed to check file size: %1$s" : "Falha ao verificar o tamanho do ficheiro: %1$s",
    "Could not open file: %1$s, file does seem to exist" : "Não foi possível abrir o ficheiro: %1$s, o ficheiro parece existir",
    "Could not open file: %1$s, file doesn't seem to exist" : "Não foi possível abrir o ficheiro: %1$s, o ficheiro não parece existir",
    "Encryption not ready: %1$s" : "Encriptação não pronta: %1$s",
    "Failed to open file: %1$s" : "Falha ao abrir o ficheiro: %1$s",
    "Failed to unlink: %1$s" : "Falha ao eliminar: %1$s",
    "Failed to write file contents: %1$s" : "Falha ao escrever o conteúdo do ficheiro: %1$s",
    "File not found: %1$s" : "Ficheiro não encontrado: %1$s",
    "Invalid target path" : "Caminho de destino inválido",
    "System is in maintenance mode." : "O sistema está em modo de manutenção.",
    "Upgrade needed" : "É necessária atualização",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "O seu %s precisa de estar configurado para usar HTTPS para que possa utilizar CalDAV e CardDAV com iOS/macOS.",
    "Configures a CalDAV account" : "Configura uma conta CalDAV",
    "Configures a CardDAV account" : "Configura uma conta CardDAV",
    "Events" : "Eventos",
    "Untitled task" : "Tarefa sem título",
    "Completed on %s" : "Concluída em %s",
    "Due on %s by %s" : "Vence em %s às %s",
    "Due on %s" : "Vence em %s",
    "System Address Book" : "Livro de endereços do sistema",
    "The system address book contains contact information for all users in your instance." : "O livro de endereços do sistema contém informação de contacto de todos os utilizadores da sua instância.",
    "Enable System Address Book" : "Ativar livro de endereços do sistema",
    "DAV system address book" : "Livro de endereços DAV do sistema",
    "No outstanding DAV system address book sync." : "Sem sincronizações pendentes do livro de endereços DAV do sistema.",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "A sincronização do livro de endereços DAV do sistema ainda não foi executada porque a sua instância não tem utilizadores; execute‑a manualmente com \"occ dav:sync-system-addressbook\".",
    "WebDAV endpoint" : "Endpoint WebDAV",
    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "Não foi possível verificar se o seu servidor web está corretamente configurado para permitir a sincronização de ficheiros via WebDAV. Verifique manualmente.",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "O seu servidor da Web não está configurado corretamente para permitir a sincronização de ficheiros, porque a interface WebDAV parece estar com problemas.",
    "Your web server is properly set up to allow file synchronization over WebDAV." : "O seu servidor web está corretamente configurado para permitir a sincronização de ficheiros via WebDAV.",
    "Migrated calendar (%1$s)" : "Calendário migrado (%1$s)",
    "Calendars including events, details and attendees" : "Calendários incluindo eventos, detalhes e participantes",
    "Contacts and groups" : "Contactos e grupos",
    "WebDAV" : "WebDAV",
    "Absence saved" : "Ausência guardada",
    "Failed to save your absence settings" : "Falha ao guardar as suas definições de ausência",
    "Absence cleared" : "Ausência removida",
    "Failed to clear your absence settings" : "Falha ao remover as suas definições de ausência",
    "First day" : "Primeiro dia",
    "Last day (inclusive)" : "Último dia (inclusive)",
    "Out of office replacement (optional)" : "Substituto durante ausência (opcional)",
    "Name of the replacement" : "Nome do substituto",
    "No results." : "Sem resultados.",
    "Start typing." : "Comece a escrever.",
    "Short absence status" : "Estado de ausência curto",
    "Long absence Message" : "Mensagem de ausência longa",
    "Save" : "Guardar",
    "Disable absence" : "Desativar ausência",
    "Failed to load availability" : "Falha ao carregar disponibilidade",
    "Saved availability" : "Disponibilidade guardada",
    "Failed to save availability" : "Falha ao guardar disponibilidade",
    "Time zone:" : "Fuso horário:",
    "to" : "Para",
    "Delete slot" : "Eliminar intervalo",
    "No working hours set" : "Sem horário de trabalho definido",
    "Add slot" : "Adicionar intervalo",
    "Weekdays" : "Dias da semana",
    "Pick a start time for {dayName}" : "Escolha uma hora de início para {dayName}",
    "Pick a end time for {dayName}" : "Escolha uma hora de fim para {dayName}",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Definir automaticamente o estado para \"Não incomodar\" fora do horário de disponibilidade para silenciar todas as notificações.",
    "Cancel" : "Cancelar",
    "Import" : "Importar",
    "Error while saving settings" : "Erro ao guardar definições",
    "Contact reset successfully" : "Contacto reposto com sucesso",
    "Error while resetting contact" : "Erro ao repor contacto",
    "Contact imported successfully" : "Contacto importado com sucesso",
    "Error while importing contact" : "Erro ao importar contacto",
    "Import contact" : "Importar contacto",
    "Reset to default" : "Repor original",
    "Import contacts" : "Importar contactos",
    "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "A importação de um novo ficheiro .vcf eliminará o contacto predefinido existente e substituí‑lo‑á pelo novo. Deseja continuar?",
    "Failed to save example event creation setting" : "Falha ao guardar a definição de criação de evento de exemplo",
    "Failed to upload the example event" : "Falha ao carregar o evento de exemplo",
    "Custom example event was saved successfully" : "Evento de exemplo personalizado guardado com sucesso",
    "Failed to delete the custom example event" : "Falha ao eliminar o evento de exemplo personalizado",
    "Custom example event was deleted successfully" : "Evento de exemplo personalizado eliminado com sucesso",
    "Import calendar event" : "Importar evento de calendário",
    "Uploading a new event will overwrite the existing one." : "O carregamento de um novo evento substituirá o existente.",
    "Upload event" : "Carregar evento",
    "Availability" : "Disponibilidade",
    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Se configurar o seu horário de trabalho, outras pessoas saberão quando está fora do escritório ao marcar uma reunião.",
    "Absence" : "Ausência",
    "Configure your next absence period." : "Configure o seu próximo período de ausência.",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Instale também a {calendarappstoreopen}aplicação Calendário {linkclose}, ou {calendardocopen} ligue o seu computador e telemóvel para sincronizar ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Certifique‑se de configurar corretamente {emailopen}o servidor de email{linkclose}.",
    "Calendar server" : "Servidor de calendário",
    "Send invitations to attendees" : "Enviar convites aos participantes",
    "Automatically generate a birthday calendar" : "Gerar automaticamente um calendário de aniversários",
    "Birthday calendars will be generated by a background job." : "Os calendários de aniversário serão gerados por uma tarefa em segundo plano.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Por isso, não estarão disponíveis imediatamente após a ativação, mas aparecerão após algum tempo.",
    "Send notifications for events" : "Enviar notificações de eventos",
    "Notifications are sent via background jobs, so these must occur often enough." : "As notificações são enviadas através de tarefas em segundo plano; estas devem ser executadas com frequência suficiente.",
    "Send reminder notifications to calendar sharees as well" : "Enviar também notificações de lembrete aos partilhados do calendário",
    "Reminders are always sent to organizers and attendees." : "Os lembretes são sempre enviados aos organizadores e participantes.",
    "Enable notifications for events via push" : "Ativar notificações push para eventos",
    "Example content" : "Conteúdo de exemplo",
    "Example content serves to showcase the features of Nextcloud. Default content is shipped with Nextcloud, and can be replaced by custom content." : "O conteúdo de exemplo serve para demonstrar as funcionalidades do Nextcloud. É fornecido com o Nextcloud e pode ser substituído por conteúdo personalizado.",
    "There was an error updating your attendance status." : "Ocorreu um erro ao atualizar o seu estado de participação.",
    "Please contact the organizer directly." : "Contacte diretamente o organizador.",
    "Are you accepting the invitation?" : "Aceita o convite?",
    "Tentative" : "Tentativa",
    "Your attendance was updated successfully." : "O seu estado de participação foi atualizado com sucesso."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
