<?php
namespace Aws\DatabaseMigrationService\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Database Migration Service** service.
 */
class DatabaseMigrationServiceException extends AwsException {}
