OC.L10N.register(
    "recommendations",
    {
    "Recommended files" : "Priporočene datoteke",
    "Recommendations" : "Priporočila",
    "Shows recommended files" : "Pokaži priporočene datoteke",
    "Shows recommended files for quick access of files and folders with recent activity" : "Program omogoča prikaz priporočenih predmetov za hiter dostop do datotek in map z največ dejavnosti.",
    "No recommendations yet" : "Ni še dodanih priporočil",
    "Path name {path}" : "Naziv poti {path}",
    "Show recommendations" : "Pokaži priporočila",
    "Recently commented" : "Nedavno dodane opombe",
    "Recently edited" : "Nedavno urejano",
    "Recently shared" : "Nedavno v souporabi"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
