OC.L10N.register(
    "files_sharing",
    {
    "File shares" : "Cumpartziduras de archìvios",
    "Downloaded via public link" : "Iscarrigadu cun ligòngiu pùblicu",
    "Downloaded by {email}" : "Iscarrigadu dae {email}",
    "{file} downloaded via public link" : "{file} iscarrigadu cun ligòngiu pùblicu",
    "{email} downloaded {file}" : "{email} at iscarrigadu {file}",
    "Shared with group {group}" : "Cumpartzidu cun su grupu {group}",
    "Removed share for group {group}" : "Cumpartzidura bogada pro su grupu {group}",
    "{actor} shared with group {group}" : "{actor} at cumpartzidu cun su grupu {group}",
    "{actor} removed share for group {group}" : "{actor} at bogadu sa cumpartzidura pro su grupu {group}",
    "Share for group {group} expired" : "Cumpartzidura pro su grupu {group} iscadida",
    "You shared {file} with group {group}" : "As cumpartzidu {file} cun su grupu {group}",
    "You removed group {group} from {file}" : "As bogadu su grupu {group} dae {file}",
    "{actor} shared {file} with group {group}" : "{actor} at cumpartzidu {file} cun su grupu {group}",
    "{actor} removed group {group} from {file}" : "{actor} at bogadu su grupu {group} dae {file}",
    "Share for file {file} with group {group} expired" : "Cumpartzidura pro s'archìviu {file} cun su grupu {group} iscadida",
    "Shared as public link" : "Cumpartzidu comente ligòngiu pùblicu",
    "Removed public link" : "Ligòngiu pùblicu bogadu",
    "Public link expired" : "Ligòngiu pùblicu iscadidu",
    "{actor} shared as public link" : "{actor} at cumpartzidu comente ligòngiu pùblicu",
    "{actor} removed public link" : "{actor} at bogadu su ligòngiu pùblicu",
    "Public link of {actor} expired" : "Ligòngiu pùblicu de {actor} iscadidu",
    "You shared {file} as public link" : "As cumpartzidu {file} comente ligòngiu pùblicu",
    "You removed public link for {file}" : "As bogadu su ligòngiu pùblicu pro {file}",
    "Public link expired for {file}" : "Ligòngiu pùblicu iscadidu pro {file}",
    "{actor} shared {file} as public link" : "{actor} at cumpartzidu {file} comente ligòngiu pùblicu",
    "{actor} removed public link for {file}" : "{actor} at bogadu ligòngiu pùblicu pro {file}",
    "Public link of {actor} for {file} expired" : "Ligòngiu pùblicu de {actor} pro {file} iscadidu",
    "{user} accepted the remote share" : "{user} at atzetadu sa cumpartzidura remota",
    "{user} declined the remote share" : "{user} at refudadu sa cumpartzidura remota",
    "You received a new remote share {file} from {user}" : "As retzidu una cumpartzidura remota noa {file} dae {user}",
    "{user} accepted the remote share of {file}" : "{user} at atzetadu sa cumpartzidura remota de {file}",
    "{user} declined the remote share of {file}" : "{user} at refudadu sa cumpartzidura remota de {file}",
    "{user} unshared {file} from you" : "{user} at annulladu sa cumpartzidura de {file} cun tegus",
    "Shared with {user}" : "Cumpartzidu cun {user}",
    "Removed share for {user}" : "Cumpartzidura bogada pro {user}",
    "You removed yourself" : "Nch'as bogadu a te etotu",
    "{actor} removed themselves" : "{actor} nch'at bogadu a isse etotu",
    "{actor} shared with {user}" : "{actor} at cumpartzidu cun {user}",
    "{actor} removed share for {user}" : "{actor} at bogadu sa cumpartzidura pro {user}",
    "Shared by {actor}" : "Cumpartzidu dae {actor}",
    "{actor} removed share" : "{actor} at bogadu sa cumpartzidura",
    "Share for {user} expired" : "Cumpartzidura pro {user} iscadida",
    "Share expired" : "Cumpartzidura iscadida",
    "You shared {file} with {user}" : "As cumpartzidu {file} cun {user}",
    "You removed {user} from {file}" : "Nch'as bogadu a {user} dae {file}",
    "You removed yourself from {file}" : "Nch'as bogadu a te etotu dae {file}",
    "{actor} removed themselves from {file}" : "{actor} nch'at bogadu a isse etotu dae {file}",
    "{actor} shared {file} with {user}" : "{actor} at cumpartzidu {file} cun {user}",
    "{actor} removed {user} from {file}" : "{actor} nch'at bogadu a {user} dae {file}",
    "{actor} shared {file} with you" : "{actor} at cumpartzidu {file} cun tegus",
    "{actor} removed you from the share named {file}" : "{actor} ti nch'at bogadu dae sa cumpartzidura numenada {file}",
    "Share for file {file} with {user} expired" : "Cumpartzidura pro s'archìviu {file} cun {user} iscadida",
    "Share for file {file} expired" : "Cumpartzidura pro s'archìviu {file} iscadida",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Un'archìviu o cartella cumpartzida tràmite posta o ligòngiu pùblicu est istada <strong>iscarrigada</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "<strong>Un'àteru serbidore</strong> at cumpartzidu un'archìviu o una cartella",
    "Sharing" : "Cumpartzidura",
    "A file or folder has been <strong>shared</strong>" : "Ant <strong>cumpartzidu</strong> un'archìviu o una cartella",
    "Shared link" : "Ligòngiu cumpartzidu",
    "Could not delete share" : "No at fatu a cantzellare sa cumpartzidura",
    "Please specify a file or folder path" : "Ispetzìfica unu percursu de una cartella o un'archìviu",
    "Could not create share" : "No at fatu a creare sa cumpartzidura",
    "Group sharing is disabled by the administrator" : "Sa cumpartzidura de grupu est disativada dae s'amministratzione",
    "Please specify a valid group" : "Ispetzìfica unu grupu bàlidu",
    "Public link sharing is disabled by the administrator" : "Sa cumpartzidura de ligòngios pùblicos est disativada dae s'amministratzione",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Sa cumpartzidura de%scun s'imbiu de sa crae dae Nextcloud Talk est faddida ca Nextcloud Talk est disativadu",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "Sa cumpartzidura de %1$s est faddida ca su motore non permitit cumpartziduras de genia %2$s",
    "Please specify a valid federated group ID" : "Ispetzìfica un'id de grupu federadu bàlidu",
    "Sharing %s failed because the back end does not support room shares" : "Sa cumpartzidura de %s est faddida ca su motore non suportat cumpartzidura de istantzas",
    "Unknown share type" : "Genia de cumpartzidura disconnota",
    "Not a directory" : "No est una cartella",
    "Could not lock node" : "No at fatu a blocare su nodu",
    "Public upload is only possible for publicly shared folders" : "Su carrigamentu pùblicu si podet fàghere isceti cun cartellas cumpartzidas pùblicas",
    "Public upload disabled by the administrator" : "Su carrigamentu pùblicu est disativadu dae s'amministradore",
    "Could not lock path" : "No at fatu a blocare su percursu",
    "Wrong or no update parameter given" : "Su paràmetru frunidu est isballiadu o no agiornadu",
    "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled." : "\"S'imbiu de sa crae dae Nextcloud Talk\" pro cumpartzire un'archìviu o cartella est faddida ca Nextcloud Talk est disativadu.",
    "shared by %s" : "cumpartzidu dae %s",
    "Download" : "Iscàrriga",
    "Add to your %s" : "Agiunghe a su %s tuo",
    "Direct link" : "Ligòngiu deretu",
    "Share API is disabled" : "API de cumpartzidura disativadu",
    "File sharing" : "Cumpartzidura de archìvios",
    "Share will expire tomorrow" : "Sa cumpartzidura at a iscadire cras",
    "Your share of {node} will expire tomorrow" : "Sa cumpartzidura tua {node} at a iscadire cras",
    "You received {share} as a share by {user}" : "As retzidu {share} cumpartzidu dae {user}",
    "You received {share} to group {group} as a share by {user}" : "As retzidu {share} a su grupu {group} cumpartzidu dae {user}",
    "Accept" : "Atzeta",
    "Decline" : "Refuda",
    "People" : "Gente",
    "Expiration date" : "Data de iscadèntzia",
    "Set a password" : "Cunfigura una crae",
    "Password" : "Crae",
    "Generate a new password" : "Gènera una crae noa",
    "Link copied" : "Ligòngiu copiadu",
    "Share link" : "Cumpartzi ligòngiu",
    "Copy" : "Còpia",
    "Select" : "Seletziona",
    "Close" : "Serra",
    "File request created" : "Rechesta de archìviu creada",
    "Error creating the share: {errorMessage}" : "Errore in sa creatzione de sa cumpartzidura: {errorMessage}",
    "Error creating the share" : "Errore in sa creatzione de sa cumpartzidura",
    "Create a file request" : "Crea rechesta de archìviu",
    "Cancel" : "Annulla",
    "Invalid path selected" : "Percursu seletzionadu non bàlidu",
    "Unknown error" : "Errore disconnotu",
    "Reset" : "Torra a cunfigurare",
    "group" : "grupu",
    "conversation" : "resonada",
    "remote" : "remota",
    "remote group" : "grupu remotu",
    "guest" : "persone invitada",
    "Shared with the group {user} by {owner}" : "Cumpartzidu cun su grupu {user} dae {owner}",
    "Shared with the conversation {user} by {owner}" : "Cumpartzidu cun sa resonada {user} dae {owner}",
    "Shared with {user} by {owner}" : "Cumpartzidu cun {user} dae {owner}",
    "Added by {initiator}" : "Agiuntu dae {initiator}",
    "Via “{folder}”" : "Tràmite “{folder}”",
    "Unshare" : "Annulla sa cumpartzidura",
    "Cannot copy, please copy the link manually" : "No at fatu a copiare, copia su ligòngiu a manu",
    "Copy internal link" : "Còpia ligòngiu internu",
    "Internal link" : "Ligòngiu internu",
    "{shareWith} by {initiator}" : "{shareWith} dae {initiator}",
    "Shared via link by {initiator}" : "Cumpartzidu cun ligòngiu dae {initiator}",
    "Mail share ({label})" : "Cumpartzidura cun posta eletrònica ({label})",
    "Share link ({label})" : "Cumpartzi ligòngiu ({label})",
    "Create public link" : "Crea unu ligòngiu pùblicu",
    "Error, please enter proper password and/or expiration date" : "Errore, inserta una crae giusta e/o sa data de iscadèntzia",
    "Please enter the following required information before creating the share" : "Inserta is informatziones rechertas in fatu in antis de creare sa cumpartzidura",
    "Password protection (enforced)" : "Bardiadura cun crae (posta)",
    "Password protection" : "Bardiadura cun crae",
    "Enter a password" : "Inserta una crae",
    "Create share" : "Crea cumpartzidura",
    "Customize link" : "Personaliza su ligòngiu",
    "Generate QR code" : "Gènera unu còdighe QR",
    "Add another link" : "Agiunghe un'àteru ligòngiu",
    "Create a new share link" : "Crea unu ligòngiu de cumpartzidura nou",
    "View only" : "Isceti in visualizatzione",
    "Can edit" : "Podet modificare",
    "Custom permissions" : "Permissos personalizados",
    "Resharing is not allowed" : "Non faghet a torrare a cumpartzire",
    "Name or email …" : "Nùmene o indiritzu de posta ...",
    "Name, email, or Federated Cloud ID …" : "Nùmene, indiritzu de posta o ID de sa nue federada ...",
    "Searching …" : "Chirchende …",
    "No elements found." : "Perunu elementu agatadu.",
    "Guest" : "Persone invitada",
    "Group" : "Grupu",
    "Email" : "Posta eletrònica",
    "Talk conversation" : "Resonada de Talk",
    "Deck board" : "Tabella in Deck",
    "on {server}" : "in {server}",
    "Terms of service" : "Cunditziones de servìtziu",
    "Update share" : "Agiorna sa cumpartzidura",
    "Read" : "Leghe",
    "Create" : "Crea",
    "Edit" : "Modìfica",
    "Share" : "Cumpartzi",
    "Delete" : "Cantzella",
    "Allow upload and editing" : "Permite carrigamentu e modìficas",
    "Allow editing" : "Cunsenti sa modìfica",
    "Advanced settings" : "Cunfiguratziones avantzadas",
    "Share label" : "Cumpartzi eticheta",
    "Set password" : "Cunfigura sa crae",
    "Video verification" : "Verìfica vìdeu",
    "Expiration date (enforced)" : "Data de iscadèntzia (posta)",
    "Set expiration date" : "Cunfigura sa data de iscadèntzia",
    "Hide download" : "Cua iscarrigamentu",
    "Note to recipient" : "Nota a sa persone destinatària",
    "Enter a note for the share recipient" : "Inserta una nota pro sa persone destinatària",
    "Delete share" : "Cantzella sa cumpartzidura",
    "Others with access" : "Àtere cun atzessu",
    "No other accounts with access found" : "Nissunu àteru contu cun atzessu",
    "Toggle list of others with access to this directory" : "Ativa sa lista de àtere cun atzessu a custa cartella",
    "Toggle list of others with access to this file" : "Ativa sa lista de àtere cun atzessu a custu archìviu",
    "Unable to fetch inherited shares" : "Non faghet a recuperare is cumpartziduras eredadas",
    "Shares" : "Cumpartziduras",
    "Unable to load the shares list" : "Non faghet a carrigare sa lista de cumpartziduras",
    "Expires {relativetime}" : "Iscadit {relativetime}",
    "this share just expired." : "custa cumpartzidura est iscadida.",
    "Shared with you by {owner}" : "Cumpartzidu cun tegus dae {owner}",
    "Link to a file" : "Ligòngiu a archìviu",
    "Open in Files" : "Aberi in Archìvios",
    "Shared" : "Cumpartzidu",
    "Shared by {ownerDisplayName}" : "Cumpartzidu dae {ownerDisplayName}",
    "Shared with others" : "Cumpartzidu cun àtere",
    "Create file request" : "Crea rechesta de archìviu",
    "No shares" : "Peruna cumpartzidura",
    "Shared with you" : "Cumpartzidu cun tegus",
    "Nothing shared with you yet" : "Ancora peruna cumpartzidura cun tegus",
    "Nothing shared yet" : "Ancora peruna cumpartzidura",
    "Shared by link" : "Cumpartzidu cun ligòngiu",
    "List of files that are shared by link." : "Lista de archìvios cumpartzidos cun ligòngiu.",
    "No shared links" : "Perunu ligòngiu cumpartzidu",
    "File requests" : "Archìvios rechestos",
    "List of file requests." : "Lista de archìvios rechestos.",
    "No file requests" : "Perunu archìviu rechestu",
    "File requests you have created will show up here" : "Is rechestas de archìviu chi crees ant a èssere mustradas inoghe",
    "Deleted shares" : "Cumpartziduras cantzelladas",
    "No deleted shares" : "Peruna cumpartzidura cantzellada",
    "Pending shares" : "Cumpartziduras in suspesu",
    "No pending shares" : "Peruna cumpartzidura in suspesu",
    "Error updating the share: {errorMessage}" : "Errore in s'agiornamentu de sa cumpartzidura: {errorMessage}",
    "Error updating the share" : "Errore in s'agiornamentu de sa cumpatzidura",
    "Could not update share" : "No at fatu a agiornare sa cumpartzidura",
    "Shared by" : "Cumpartzidu dae",
    "Shared with" : "Cumpartzidu cun",
    "Shared with you and the group {group} by {owner}" : "Cumpartzidu cun tegus e su grupu {group} dae {owner}",
    "Shared with you and {circle} by {owner}" : "Cumpartzidu cun tegus {circle} dae {owner}",
    "Shared with you and the conversation {conversation} by {owner}" : "Cumpartzidu cun tegus e sa resonada {conversation} dae {owner}",
    "Shared with you in a conversation by {owner}" : "Cumpartzidu cun tegus in una resonada dae {owner}",
    "Share not found" : "Cumpartzidura no agatada",
    "Back to %s" : "Torra a %s",
    "Add to your Nextcloud" : "Agiunghe a su Nextcloud tuo",
    "Waiting…" : "Abeta…",
    "error" : "errore",
    "finished" : "agabbadu",
    "This will stop your current uploads." : "Custu at a firmare is carrigamentos tuos atuales.",
    "Move or copy" : "Tràmuda o còpia",
    "You can upload into this folder" : "Podes carrigare in custa cartella",
    "Show list view" : "Mustra sa visualizatzione de lista",
    "Show grid view" : "Mustra sa visualizatzione de mosàicu",
    "No compatible server found at {remote}" : "Perunu serbidore cumpatìbile agatadu in {remote}",
    "Invalid server URL" : "URL de su serbidore non vàlidu",
    "Failed to add the public link to your Nextcloud" : "No at fatu a agiùnghere su ligòngiu pùblicu in Nextcloud",
    "Download all files" : "Iscàrriga totu is archìvios",
    "Link copied to clipboard" : "Ligòngiu copiadu in punta de billete",
    "Copy to clipboard" : "Còpia in is punta de billete",
    "Copy internal link to clipboard" : "Còpia su ligòngiu internu in punta de billete",
    "Only works for people with access to this folder" : "Funtzionat isceti pro gente cun atzessu a custa cartella",
    "Only works for people with access to this file" : "Funtzionat isceti pro gente cun atzessu a custu archìviu",
    "Copy public link of \"{title}\" to clipboard" : "Còpia in punta de billete su ligòngiu pùblicu pro: \"{title}\"",
    "Search globally" : "Chirca globale",
    "Search for share recipients" : "Chirca destinatàrios de cumpartziduras",
    "No recommendations. Start typing." : "Peruna racumandatzione. Cumintza a iscrìere.",
    "Enter your name" : "Inserta•nche su nùmene tuo",
    "Share note" : "Cumpartzi sa nota",
    "Upload files to %s" : "Càrriga archìvios in %s",
    "Note" : "Nota",
    "Select or drop files" : "Sèbera o iscapa archìvios",
    "Uploading files" : "Carrighende archìvios",
    "Uploaded files:" : "Archìvios carrigados:",
    "By uploading files, you agree to the %1$sterms of service%2$s." : "Carrighende is archìvios, cuncordas cun is %1$scunditziones de servìtziu%2$s.",
    "Name" : "Nùmene"
},
"nplurals=2; plural=(n != 1);");
