OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "Downloadlimit für Dateien",
    "File link share download limit" : "Downloadlimit für Dateifreigabe",
    "This app allows limiting the number of downloads for external link shares." : "Mit dieser App können Sie die Anzahl der Downloads für externe Linkfreigaben begrenzen.",
    "The minimum limit is 1" : "Die Mindestgrenze beträgt 1",
    "Failed to set download limit" : "Download-Limit konnte nicht festgelegt werden",
    "Failed to remove download limit" : "Download-Limit konnte nicht entfernt werden",
    "Limit downloads" : "Downloads begrenzen",
    "Set download limit" : "Download-Limit festlegen",
    "Setting a new limit will reset the download count" : "Das Festlegen eines neuen Limits setzt die Download-Zählung zurück.",
    "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["1 verbleibender Download erlaubt","{count} verbleibende Downloads erlaubt"],
    "Failed to set default download limit" : "Standard-Downloadlimit konnte nicht festgelegt werden",
    "Download limit" : "Download-Limit",
    "Configure the default download limit for external shares." : "Standard-Downloadlimit für externe Freigaben konfigurieren.",
    "Set default download limit" : "Standard-Downloadlimit festlegen",
    "You have reached the maximum amount of downloads allowed" : "Sie haben die maximal zulässige Anzahl an Downloads erreicht",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "Diese Freigabe hat eine begrenzte Anzahl von Downloads. Möchten Sie wirklich einen neuen Download auslösen?"
},
"nplurals=2; plural=(n != 1);");
