OC.L10N.register(
    "files_external",
    {
    "Grant access" : "Autoriser l’accès",
    "Error configuring OAuth2" : "Erreur lors de la configuration de OAuth2",
    "Generate keys" : "Générer des clés",
    "Error generating key pair" : "Erreur lors de la génération des clés",
    "You are not logged in" : "Vous n'êtes pas connecté",
    "Permission denied" : "Autorisation refusée",
    "Forbidden to manage local mounts" : "Interdiction de gérer les montages locaux.",
    "Storage with ID \"%d\" not found" : "Stockage avec l'ID \"%d\" non trouvé",
    "Invalid backend or authentication mechanism class" : "Service ou méthode d'authentification non valable",
    "Invalid mount point" : "Point de montage non valide",
    "Objectstore forbidden" : "« Objectstore » interdit",
    "Invalid storage backend \"%s\"" : "Service de stockage non valide : « %s »",
    "Not permitted to use backend \"%s\"" : "Non autorisé à utiliser le service « %s »",
    "Not permitted to use authentication mechanism \"%s\"" : "Non autorisé à utiliser le mécanisme d'authentification « %s »",
    "Unsatisfied backend parameters" : "Paramètres manquants pour le service",
    "Unsatisfied authentication mechanism parameters" : "Paramètres manquants pour la méthode d'authentification",
    "Insufficient data: %s" : "Données insuffisantes : %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not editable by non-admins" : "Le support de stockage avec l'ID « %d » n'est pas modifiable par les non-administrateurs.",
    "Access key" : "Clé d'accès",
    "Secret key" : "Clé secrète",
    "Builtin" : "Intégré",
    "None" : "Aucun",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID Client",
    "Client secret" : "Secret client",
    "OpenStack v2" : "OpenStack v2",
    "Login" : "Identifiant",
    "Password" : "Mot de passe",
    "Tenant name" : "Nom du locataire",
    "Identity endpoint URL" : "URL de l'identity endpoint",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Domaine",
    "Rackspace" : "Rackspace",
    "API key" : "Clé API",
    "Global credentials" : "Informations d'identification globales",
    "Log-in credentials, save in database" : "Identifiants de connexion, sauvegarder dans la base de données",
    "Login and password" : "Identifiant et mot de passe",
    "Log-in credentials, save in session" : "Identifiants de connexion, sauvegardés pour la session",
    "Global credentials, manually entered" : "Identifiants globaux, manuellement saisi",
    "Manually entered, store in database" : "Manuellement saisi, stocké dans la base de données",
    "RSA public key" : "Clé publique RSA",
    "Public key" : "Clé publique",
    "RSA private key" : "Clé privée RSA",
    "Private key" : "Clé privée",
    "Kerberos default realm, defaults to \"WORKGROUP\"" : "Domaine Kerberos par défault, valeur par défaut \"WORKGROUP\"",
    "Kerberos ticket Apache mode" : "Ticket Kerberos, mode Apache",
    "Kerberos ticket" : "Ticket Kerberos",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Nom de l’hôte",
    "Port" : "Port",
    "Region" : "Région",
    "Storage Class" : "Classe de stockage",
    "Enable SSL" : "Activer SSL",
    "Enable Path Style" : "Accès par path",
    "Legacy (v2) authentication" : "Authentification héritée (v2)",
    "Enable multipart copy" : "Activer la copie multiple",
    "SSE-C encryption key" : "Clé de chiffrement SSE-C",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Sous-dossier distant",
    "Secure https://" : "Sécurisation https://",
    "FTP" : "FTP",
    "Host" : "Hôte",
    "Secure ftps://" : "Sécurisation ftps://",
    "Local" : "Local",
    "Location" : "Emplacement",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Racine",
    "SFTP with secret key login" : "SFTP avec identification par clé",
    "SMB/CIFS" : "SMB/CIFS",
    "Share" : "Partage",
    "Show hidden files" : "Afficher les fichiers masqués",
    "Case sensitive file system" : "Système de fichiers sensible à la casse",
    "Disabling it will allow to use a case insensitive file system, but comes with a performance penalty" : "Le désactiver va permettre d'utiliser un système de fichiers insensible à la casse mais cela a un impact sur les performances.",
    "Verify ACL access when listing files" : "Vérifier l'accès à l'ACL lors de l'affichage de la liste des fichiers",
    "Check the ACL's of each file or folder inside a directory to filter out items where the account has no read permissions, comes with a performance penalty" : "Contrôler les ACL de chaque fichier ou dossier à l'intérieur d'un répertoire afin de filtrer les éléments pour lesquels le compte n'a pas d'accès en lecture, ceci engendre une dégradation des performances",
    "Timeout" : "Délai d'attente",
    "SMB/CIFS using OC login" : "SMB/CIFS en utilisant le login OC",
    "Login as share" : "Connectez-vous en tant que share.",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Nom du service",
    "Request timeout (seconds)" : "Délai d'expiration des requêtes (en secondes)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Le support de cURL dans PHP n'est pas activé ou installé. Le montage de %s n'est pas possible. Veuillez demander à votre administrateur système de l'installer.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Le support du FTP dans PHP n'est pas activé ou installé. Le montage de %s n'est pas possible. Merci de demander à votre administrateur de l'installer.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "\"%1$s\" n'est pas installé. Le montage de %2$s n'est pas possible. Merci de demander à l'administrateur système de l'installer.",
    "External storage" : "Stockage externe",
    "External storage support" : "Support de stockage externe",
    "Adds basic external storage support" : "Ajoute la prise en charge de base du stockage externe",
    "This application enables administrators to configure connections to external storage providers, such as FTP servers, S3 or SWIFT object stores, other Nextcloud servers, WebDAV servers, and more. Administration can choose which types of storage to enable and can mount these storage locations for an account, a group, or the entire system. Users will see a new folder appear in their root Nextcloud directory, which they can access and use like any other Nextcloud folder. External storage also allows people to share files stored in these external locations. In these cases, the credentials for the owner of the file are used when the recipient requests the file from external storage, thereby ensuring that the recipient can access the shared file.\n\nExternal storage can be configured using the GUI or at the command line. This second option provides the administration with more flexibility for configuring bulk external storage mounts and setting mount priorities. More information is available in the external storage GUI documentation and the external storage Configuration File documentation." : "Cette application permet aux administrateurs de configurer des connexions à des stockage externes, tels que des serveurs FTP, des magasins d'objets S3 ou SWIFT, d'autres serveurs Nextcloud, des serveurs WebDAV, etc. L'administration peut choisir les types de stockage à activer et peut monter ces emplacements de stockage pour un compte, un groupe ou l'ensemble du système. Les utilisateurs verront apparaître un nouveau dossier dans leur répertoire racine Nextcloud, auquel ils pourront accéder et utiliser comme n'importe quel autre dossier Nextcloud. Le stockage externe permet également aux personnes de partager des fichiers stockés dans ces emplacements externes. Dans ce cas, les informations d'identification du propriétaire du fichier sont utilisées lorsque le destinataire demande le fichier à partir du stockage externe, garantissant ainsi que le destinataire peut accéder au fichier partagé.\n\nLe stockage externe peut être configuré à l'aide de l'interface graphique ou via l'interface en ligne de commande. Cette deuxième option offre à l'administration une plus grande flexibilité pour configurer les montages de stockage externes en masse et définir les priorités de montage. D'autres informations sont disponibles dans la documentation de l'interface graphique de stockage externe et la documentation du fichier de configuration de stockage externe.",
    "Confirm" : "Confirmer",
    "Storage credentials" : "informations d'identification du stockage ",
    "To access the storage, you need to provide the authentication credentials." : "Pour accéder au stockage, vous devez fournir les informations d’authentification.",
    "Enter the storage login" : "Entrez le login du stockage",
    "Enter the storage password" : "Entrez le mot de passe du stockage",
    "Unable to update this external storage config. {statusMessage}" : "Impossible de mettre à jour la configuration de ce stockage externe. {statusMessage}",
    "New configuration successfully saved" : "Nouvelle configuration entrée avec succès",
    "Enter missing credentials" : "Saisissez les identifiants de connexion manquants",
    "Credentials successfully set" : "Identifiants enregistrés avec succès",
    "Error while setting credentials: {error}" : "Erreur lors de l'envoi des identifiants: {error}",
    "Checking storage …" : "Vérification du stockage ...",
    "There was an error with this external storage." : "Il y a eu une erreur avec ce stockage externe.",
    "We were unable to check the external storage {basename}" : "Nous n'avons pas pu vérifier le stockage externe {basename}",
    "Examine this faulty external storage configuration" : "Examiner la configuration de ce stockage externe défaillant",
    "Open in Files" : "Ouvrir dans Fichiers",
    "There was an error with this external storage. Do you want to review this mount point config in the settings page?" : "Il y a eu une erreur avec ce stockage externe. Voulez-vous examiner la configuration de ce point de montage sur la page des paramètres ?",
    "External mount error" : "Erreur de point de montage externe",
    "List of external storage." : "Liste du stockage externe.",
    "There is no external storage configured. You can configure them in your Personal settings." : "Aucun stockage externe n'est configuré. Vous pouvez le configurer dans votre paramètres personnels.",
    "There is no external storage configured and you don't have the permission to configure them." : "Il n'y a aucun stockage externe configuré et vous n'avez pas l'autorisation pour les configurer.",
    "No external storage" : "Aucun stockage externe",
    "Storage type" : "Type de stockage",
    "Unknown" : "Inconnu",
    "Scope" : "Portée",
    "Personal" : "Personnel",
    "System" : "Système",
    "Type to select account or group." : "Tapez pour sélectionner un compte ou un groupe.",
    "(Group)" : "(Groupe)",
    "Compatibility with Mac NFD encoding (slow)" : "Compatibilité avec l'encodage Mac NFD (lent)",
    "Enable encryption" : "Activer le chiffrement",
    "Enable previews" : "Activer les prévisualisations",
    "Enable sharing" : "Permettre le partage",
    "Check for changes" : "Rechercher les modifications",
    "Never" : "Jamais",
    "Once every direct access" : "Une fois à chaque accès direct",
    "Read only" : "Lecture seule",
    "Disconnect" : "Se déconnecter",
    "Unknown backend: {backendName}" : "Backend inconnu: {backendName}",
    "Admin defined" : "Défini par l'administrateur",
    "Automatic status checking is disabled due to the large number of configured storages, click to check status" : "La vérification automatique d'état est désactivée à cause du grand nombre de stockages configurés, cliquez pour vérifier l'état",
    "Are you sure you want to disconnect this external storage? It will make the storage unavailable in Nextcloud and will lead to a deletion of these files and folders on any sync client that is currently connected but will not delete any files and folders on the external storage itself." : "Êtes-vous certain de vouloir déconnecter ce stockage externe ? Cela rendra ce stockage indisponible dans Nextcloud et entraînera la suppression de ces fichiers et dossiers sur tous les clients actuellement connectés, mais ne supprimera aucun fichier ni dossier du stockage externe lui-même.",
    "Delete storage?" : "Supprimer ce support de stockage ?",
    "Click to recheck the configuration" : "Cliquer pour revérifier la configuration",
    "Saved" : "Enregistré",
    "Saving …" : "Enregistrement ...",
    "Save" : "Enregistrer",
    "Failed to save global credentials" : "Échec de l'enregistrement des identifiants globaux",
    "Failed to save global credentials: {message}" : "Échec de l'enregistrement des identifiants globaux : {message}",
    "No external storage configured or you don't have the permission to configure them" : "Aucun stockage externe configuré ou vous n'avez pas l'autorisation de les configurer",
    "Open documentation" : "Voir la documentation",
    "External storage enables you to mount external storage services and devices as secondary Nextcloud storage devices. You may also allow people to mount their own external storage services." : "Le stockage externe vous permet de monter des périphériques et services externes en tant que périphériques de stockage secondaires sous Nextcloud. Vous pouvez aussi autoriser les personnes à monter leurs propres services de stockage externes.",
    "Folder name" : "Nom du dossier",
    "Authentication" : "Authentification",
    "Configuration" : "Configuration",
    "Available for" : "Disponible pour",
    "Add storage" : "Ajouter un support de stockage",
    "All people" : "Toutes les personnes",
    "Advanced settings" : "Paramètres avancés",
    "Allow people to mount external storage" : "Autoriser les personnes à monter des espaces de stockage externes",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Les identifiants globaux peuvent être utilisés pour s'authentifier auprès de multiples stockages externes qui ont les mêmes identifiants.",
    "Error configuring OAuth1" : "Erreur lors de la configuration de OAuth1",
    "Please provide a valid app key and secret." : "Veuillez fournir une clé d'application et un mot de passe valides.",
    "OAuth1" : "OAuth1",
    "App key" : "Clé d'application",
    "App secret" : "Secret de l'application"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
