OC.L10N.register(
    "nextcloud_announcements",
    {
    "Nextcloud announcements" : "Ανακοινώσεις Nextcloud",
    "Nextcloud announcement" : "Ανακοίνωση Nextcloud",
    "Read more" : "Διαβάστε περισσότερα",
    "Disable announcements" : "Απενεργοποίηση ανακοινώσεων",
    "(These announcements are only shown to administrators)" : "(Αυτές οι ανακοινώσεις εμφανίζονται μόνο στους διαχειριστές)",
    "Nextcloud announcements brings the latest news of Nextcloud into your notifications" : "Οι ανακοινώσεις του Nextcloud φέρνουν τα τελευταία νέα για το Nextcloud στις ειδοποιήσεις σας"
},
"nplurals=2; plural=(n != 1);");
