<?php return array(
    'root' => array(
        'name' => 'files_external/3rdparty',
        'pretty_version' => 'dev-master',
        'version' => 'dev-master',
        'reference' => '05e64418a77134e55824fc8c1a91125805428f3f',
        'type' => 'library',
        'install_path' => __DIR__ . '/../',
        'aliases' => array(),
        'dev' => true,
    ),
    'versions' => array(
        'files_external/3rdparty' => array(
            'pretty_version' => 'dev-master',
            'version' => 'dev-master',
            'reference' => '05e64418a77134e55824fc8c1a91125805428f3f',
            'type' => 'library',
            'install_path' => __DIR__ . '/../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'icewind/smb' => array(
            'pretty_version' => 'v3.7.0',
            'version' => '3.7.0.0',
            'reference' => 'e6904cbe75f678335092f4861c60c656b1a99e84',
            'type' => 'library',
            'install_path' => __DIR__ . '/../icewind/smb',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'icewind/streams' => array(
            'pretty_version' => 'v0.7.8',
            'version' => '0.7.8.0',
            'reference' => 'cb2bd3ed41b516efb97e06e8da35a12ef58ba48b',
            'type' => 'library',
            'install_path' => __DIR__ . '/../icewind/streams',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
