OC.L10N.register(
    "recommendations",
    {
    "Recommended files" : "Tệp được đề xuất",
    "Recommendations" : "Đề xuất",
    "Shows recommended files" : "Hiển thị tệp đề xuất",
    "Shows recommended files for quick access of files and folders with recent activity" : "Hiển thị các tệp được đề xuất để truy cập nhanh vào các tệp và thư mục có hoạt động gần đây",
    "No recommendations yet" : "Không có đề xuất",
    "Show recommendations" : "Hiển thị đề xuất",
    "Recently commented" : "Bình luận gần đây",
    "Recently edited" : "Chỉnh sửa gần đây",
    "Recently shared" : "Chia sẻ gần đây"
},
"nplurals=1; plural=0;");
