OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Довод личних активности корисника %s",
    "Your feed URL is invalid" : "УРЛ вашег довода није исправан",
    "Activity feed for %1$s" : "Вести о активности %1$s",
    "Activity feed" : "Довод активности",
    "Your settings have been updated." : "Ваше поставке су ажуриране.",
    "Settings have been updated." : "Поставке су ажуриране.",
    "remote user" : "удаљени корисник",
    "Recent activity" : "Скорашње активности",
    "No activities" : "Нема активности",
    "More activities" : "Још активности",
    "Daily activity summary for %s" : "Извештај дневних активности за %s",
    "_and %n more…_::_and %n more…_" : ["и још %n…","и још %n…","и још %n…"],
    "All activities" : "Све активности",
    "By others" : "туђе",
    "By you" : "ваше",
    "Activity at %s" : "Активност у %s",
    "Hello %s" : "Здраво %s",
    "Hello %s," : "Здраво %s,",
    "There was some activity at %s" : "Било је активности у %s ",
    "_and %n more _::_and %n more _" : ["и још %n","и још %n","и још %n"],
    "Mail" : "поштом",
    "Push" : "Гурај",
    "Activity" : "Активност",
    "Notifications" : "Обавештења",
    "This application enables people to view a log of activities about them, their files or other data." : "Ова апликација омогућава људима да погледају дневник активности у вези са њима, своје фајлове, или остале податке.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Ова апликација омогућава људима да погледају акције у вези са њиховим фајловима и подацима у Nextcloud.\n\t\tСвака особа може да конфигурише подешавања за индивидуалне активности у личним подешавањима,\n\t\tзда изабере које активности би требало да се проследе на мобилне телефоне, пошаљу е-поштом\n\t\tили да ли се дневни извештај шаље свако јутро.\n\t\tВише информација се налази у документацији апликације Activity.",
    "Send email" : "Пошаљи е-пошту",
    "Send push notification" : "Слање брзих обавештења",
    "Activity notification configuration" : "Подешавање обавештења о активностима",
    "Today" : "данас",
    "Yesterday" : "јуче",
    "You need to set up your email address before you can receive notification emails." : "Морате поставити адресу е-поште пре почетка пријема обавештења.",
    "Send activity emails" : "Шаљи е-пошту са активностима",
    "As soon as possible" : "Што је пре могуће",
    "Hourly" : "сваки сат",
    "Daily" : "дневно",
    "Weekly" : "недељно",
    "You commented" : "Коментарисали сте",
    "Message deleted by author" : "Аутор је обрисао поруку",
    "Open {filename}" : "Отвори {filename}",
    "in {path}" : "у {path}",
    "Home" : "Почетна",
    "Could not load activities" : "Није успело учитавање активности",
    "Loading activities" : "Учитавају се активности",
    "This stream will show events like additions, changes & shares" : "Овде ће се приказати догађаји попут додавања, измена или дељења",
    "No activity yet" : "Још нема активности",
    "Loading more activities" : "Учитава се још активности",
    "No more activities." : "Нема више активности.",
    "Could not enable RSS link" : "Није успело укључивање RSS линка",
    "RSS link copied to clipboard" : "RSS линк је копиран у клипборд",
    "Could not copy the RSS link, please copy manually:" : "Није успело копирање RSS линка, молимо вас да га ручно копирате:",
    "Activity settings" : "Подешавања активности",
    "Enable RSS feed" : "Укључи РСС довод",
    "RSS feed" : "РСС довод",
    "Copy RSS feed link" : "Копирај линк RSS вести",
    "Personal notification settings" : "Подешавања личних обавештења",
    "Unable to load the activity list" : "Учитавање листе активности није било успешно",
    "Choose for which activities you want to get an email or push notification." : "Одаберите за које активности желите да добијате е-пошту или брза обавештења.",
    "Choose for which activities you want to get a push notification." : "Одаберите за које активности желите да добијате брза обавештења.",
    "Notification" : "Обавештење",
    "Enable notification emails" : "Укључи обавештења е-поштом",
    "Daily activity summary" : "Извештај дневних активности",
    "Send daily activity summary in the morning" : "Шаљи сумарни извештај дневних активности изјутра",
    "Default settings" : "Подразумеване поставке",
    "Configure the default notification settings for new accounts." : "Подешавање подразумеваних поставки обавештења за нове налоге.",
    "Unable to save the settings" : "Чување поставки није успело.",
    "No more events to load" : "Нема више догађаја за приказ"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
