OC.L10N.register(
    "app_api",
    {
    "Daemon config not found" : "Није пронађена конфигурација даемона",
    "Error starting install of ExApp" : "Грешка приликом покретања инсталације ExApp",
    "ExApp failed to register, check the NC logs" : "Није успела регистрација ExApp, погледајте NC дневнике",
    "ExApp not found, failed to get status" : "ExApp није пронађена, није успело добављање статуса",
    "This app is not installed from the AppStore. No extra information available. Only enable/disable and remove actions are allowed." : "Ова апликација није инсталирана из Продавнице апликација. Нема доступних додатних информација. Дозвољене су само акције укључи/искључи и уклони.",
    "Could not perform installation of ExApp" : "Није могла да се изврши инсталација ExApp",
    "Failed to enable ExApp" : "Није успело укључивање ExApp",
    "Failed to disable ExApp" : "Није успело искључивање ExApp",
    "Could not update ExApp" : "Није успело ажурирање ExApp",
    "Error starting update of ExApp" : "Грешка приликом покретања ажурирања ExApp",
    "Could not perform update of ExApp" : "Није могло да се изврши ажурирање ExApp",
    "ExApp not found, failed to get logs" : "ExApp није пронађена, није успело добављање дневника",
    "Failed to get container logs. Note: Downloading Docker container works only for containers with the json-file or journald logging driver. Error: %s" : "Није успело преузимање дневника контејнера. Напомена: преузимање Docker контејнера функционише само за контејнере који имају драјвер дневника типа json-фајл или journald. Грешка: %s",
    "AppAPI authentication failed" : "Није успела AppAPI провера идентитета",
    "AppAPI ExApp notifier" : "AppAPI ExApp обавештавач",
    "AppAPI" : "AppAPI",
    "AI Integration Team" : "Тим за интеграцију AI",
    "ExApps Settings" : "Подешавања за ExApp",
    "Nextcloud AppAPI" : "Nextcloud AppAPI",
    "### Boost your Nextcloud with AppAPI and its specially designed applications.\n\n\nThe AppAPI is a project within the Nextcloud ecosystem designed to streamline and enhance the process of\napplication development, deployment, and management.\n\nIt introduces a new methodology that allows developers to create\napplications using a variety of programming languages, not limited to PHP, which was traditionally used in Nextcloud development.\n\n\n### List of applications that require AppAPI:\n\n- [talk_bot_ai_example](https://github.com/cloud-py-api/talk_bot_ai_example)\n- [upscaler_example](https://github.com/cloud-py-api/upscaler_example)\n- [image_to_text_example](https://github.com/cloud-py-api/file_to_text_example)\n- [ai_image_generator_bot](https://github.com/cloud-py-api/ai_image_generator_bot)\n- [SummarAI](https://github.com/nextcloud/sumupbot)\n\n_If you wish to develop an application, we will gladly help and assist you._\n\n### Support\n\nWe appreciate any support for this project:\n\n- ⭐ Star our work on GitHub\n- ❗ Create an Issue or feature request\n- 💁 Resolve an Issue and create a Pull Request\n- 🧑‍💻 Develop your own application using AppAPI\n\nWe are genuinely excited about the future of the AppAPI project and its potential to transform\nthe way applications are developed and experienced within Nextcloud.\n\nAs we embark on this journey, we warmly invite you - developers, thinkers, creators, and visionaries -\nto join us in shaping a more versatile, stable, and secure app landscape.\n\n*Your insights, suggestions, and contributions are invaluable to us.*" : "### Унапредите свој Nextcloud са AppAPI и његовим специјално дизајнираним апликацијама.\n\n\nAppAPI је пројекат унутар Nextcloud екосистема који је дизајниран тако да поједностави и унапреди процес развоја \nапликације, постављање и управљање.\n\nУводи нову методологију која програмерима омогућава да\nкреирају апликације користећи разне програмске језике, а не само PHP, који се традиционално користио за Nextcloud програмирање.\n\n\n### Листа апликација које захтевају AppAPI:\n\n- [talk_bot_ai_example](https://github.com/cloud-py-api/talk_bot_ai_example)\n- [upscaler_example](https://github.com/cloud-py-api/upscaler_example)\n- [image_to_text_example](https://github.com/cloud-py-api/file_to_text_example)\n- [ai_image_generator_bot](https://github.com/cloud-py-api/ai_image_generator_bot)\n- [SummarAI](https://github.com/nextcloud/sumupbot)\n\n_Ако желите да направите апликацију, радо ћемо вам помоћи у томе._\n\n### Подршка\n\nЦенимо сваку подршку овом пројекту:\n\n- ⭐ Дајте звездицу нашем раду на GitHub сервису\n- ❗ Креирајте Извештај о проблему или захтев са новом функцијом\n- 💁 Решите проблем и креирајте Захтев за повлачење\n- 🧑‍💻 Направите сопствену апликацију користећи AppAPI\n\nЗаиста смо узбуђени у вези са будућности AppAPI пројекта и његовог потенцијала да трансформише\nначин на који се апликације програмирају и доживљавају унутар Nextcloud платформе.\n\nДок се укрцавамо на ово путовање, срдачно вас позивамо - програмере, мислиоце, креаторе и визионаре -\nда нам се придружите у обликовању свестранијег, стабилнијег и безбеднијег пејсажа апликација.\n\n*Ваши увиди, сугестије и доприноси су од непроцењивог значаја за нас.*",
    "The AppAPI Project is an exciting initiative that aims to revolutionize the way applications are developed for Nextcloud." : "AppAPI Пројекат је узбудљива иницијатива која има циљ да уведе револуцију у начин на који се развијају апликације за Nextcloud.",
    "Deploy Daemons" : "Даемони за постављање",
    "Deploy Daemon (DaemonConfig) is an ExApps orchestration daemon." : "Даемон за постављање (DaemonConfig) је даемон за оркестрацију ExApps.",
    "Deploy Daemons. Deploy Daemon (DaemonConfig) is an ExApps orchestration daemon." : "Даемони за постављање Даемон за постављање (DaemonConfig) је даемон за оркестрацију ExApps.",
    "Default Deploy Daemon is not accessible. Please verify its configuration" : "Подразумевани даемон за постављање није доступан. Молимо вас да проверите његову конфигурацију",
    "ExApp init timeout (minutes)" : "Тајмаут иницијализације ExApp (минута)",
    "ExApp initialization process timeout after which AppAPI will mark it as failed" : "Истекло је време иницијализације ExApp након којег ће је AppAPI означити као неуспешну",
    "ExApp init timeout" : "Тајмаут иницијализације ExApp",
    "ExApp container restart policy" : "Политика поновног покретања ExApp контејнера",
    "Specify container restart policy, e.g. 'always' to ensure ExApp running after daemon server reboot" : "Наведите политику поновног покретања, нпр. ’увек’ тако да се обезбеди да се ExApp извршава након поновног покретања даемона сервера",
    "This settings changes are reflected only for newly created containers" : "Ове измене подешавања се примењују само на контејнере који се креирају накнадно",
    "External Apps management" : "Управљање спољним апликацијама",
    "Admin options saved" : "Сачуване су админ опције",
    "Failed to save admin options" : "Није успело чување админ опција",
    "Are you sure you want delete Deploy Daemon" : "Да ли сте сигурни да желите да обришете Даемон за постављање",
    "All ExApps on this daemon will be removed" : "Обрисаће се све ExApps на овом даемону",
    "All ExApps installed on this daemon will be removed" : "Уклониће се све ExApps инсталиране на овом даемону",
    "Cancel" : "Откажи",
    "Delete" : "Избриши",
    "Default" : "Подразумевано",
    "Set as default" : "Постави као подразумевано",
    "Test deploy" : "Тестирај постављање",
    "Edit" : "Измени",
    "\"manual-install\" Deploy Daemon cannot be set as default" : "„manual-install” Даемон за постављање не може да се постави као подразумевани",
    "Failed to save admin options. Check the logs" : "Није успело чување админ опција. Погледајте дневнике",
    "Password confirmation failed" : "Није успело потврђивање лозинке",
    "Deploy daemon config details" : "Детаљи конфигурације даемона за постављање",
    "Deploy Daemon" : "Даемон за постављање",
    "Default daemon. ExApps will be installed on it" : "Подразумевани даемон. ExApps ће се инсталиранти на њему.",
    "Manual install daemon usually used for development. It cannot be set as default daemon." : "Даемон за ручно инсталирање се обично користи за развој. Он не може да се постави као подразумевани даемон.",
    "ExApps installed" : "ExApp су инсталиране",
    "Name" : "Име",
    "Protocol" : "Протокол",
    "Host" : "Домаћин",
    "Deploy config" : "Конфигурација постављања",
    "Docker network" : "Docker мрежа",
    "Nextcloud URL" : "Nextcloud URL",
    "HaProxy password" : "HaProxy лозинка",
    "GPUs support" : "Подршка за GPU",
    "Compute device" : "Рачунарски уређај",
    "Additional options" : "Додатне опције",
    "Verify connection" : "Провери везу",
    "Daemon connection successful" : "Веза са даемоном је успела",
    "Failed to connect to Daemon. Check the logs" : "Није успело повезивање са Даемоном. Погледајте дневнике",
    "Failed to check connection to Daemon. Check the logs" : "Није успела провера везе са Даемоном. Погледајте дневнике",
    "Registered Deploy daemons list" : "Листа регистрованих Даемона за постављање",
    "No Deploy daemons configured" : "Није подешен ниједан Даемон за постављање",
    "Register a custom one or setup from available templates" : "Региструјте произвољни или подесите неки према доступном шаблону",
    "Register Daemon" : "Региструј Даемон",
    "AppAPI will try to install small skeleton ExApp to verify Daemon configured correctly and deployment steps are passing." : "AppAPI ће покушати да инсталира малу костур ExApp да би се поверило да ли је Даемон исправно подешен и да ли се успешно пролазе кораци постављања.",
    "The following Deploy test checks must be passed to succeed:" : "Да би се успело, потребно је да прођу следећи тестови постављања:",
    "More info" : "Више информација",
    "Download ExApp logs" : "Преузми ExApp дневнике",
    "Remove test ExApp" : "Уклони тест ExApp",
    "Start Deploy test" : "Покрени тест постављања",
    "Stop Deploy test" : "Заустави тест постављања",
    "ExApp is unregistered and container is removed on \"Stop deploy test\"" : "ExApp више није регистрована и контејтер се брише приликом „Заустави тест постављања”",
    "Register ExApp in Nextcloud" : "Региструј ExApp у Nextcloud",
    "Check if the ExApp is registered in Nextcloud before deployment" : "Проверава да ли је ExApp регистрована у Nextcloud пре постављања",
    "Image pull" : "Повлачење слике",
    "Check if the image is successfully pulled" : "Проверава да ли је слика успешно повучена",
    "Container started" : "Контејнер се покренуо",
    "Check if the image successfully pulled and container is created and started" : "Проверава да ли је слика успешно повучена и да ли се контејнтер креирао и покренуо",
    "Heartbeat" : "Пулс",
    "Check for the heartbeat is finished and healthy" : "Провера пулса је завршена и све је како треба",
    "Init step" : "Корак иницијализације",
    "Wait for initialization step to finish" : "Чека се да се заврши корак иницијализације",
    "Enabled" : "укључено",
    "Check if ExApp successfully handled the enabled event and registered all stuff properly" : "Проверава да ли је ExApp успешно обрадила уљкучени догађај и регистровала све ствари како треба",
    "Only if ExApp container is preset" : "Само ако је присутан ExApp контејтнер",
    "Deploy test passed successfully!" : "Тест постављања је успешно прошао!",
    "Deploy test failed at step \"{step}\"" : "Тест постављања је пао на кораку „{step}”",
    "Edit Deploy Daemon" : "Уреди Даемона за постављање",
    "Register Deploy Daemon" : "Региструје Даемон за постављање",
    "Daemon configuration template" : "Шаблон подешавања Даемона",
    "Select daemon configuration template" : "Изаберите шаблон за даемон постављања",
    "Daemon registration form" : "Формулар за регистрацију Даемона",
    "Unique Deploy Daemon Name" : "Јединствено име Даемона за постављање",
    "Display name" : "Име за приказ",
    "Deployment method" : "Метода постављања",
    "Select daemon deploy method" : "Изаберте методу за постављање даемона",
    "Daemon host" : "Хост даемона",
    "Set daemon as default" : "Постави даемон као подразумевани",
    "Set as default daemon" : "Поставља даемон као подразумевани",
    "Enable https" : "Укључи https",
    "Show deploy config" : "Прикажи конфигурацију постављања",
    "Hide deploy config" : "Сакриј конфигурацију постављања",
    "Network" : "Мрежа",
    "Docker network name" : "Име Docker мреже: ",
    "AppAPI Docker Socket Proxy authentication password" : "Лозинка за AppAPI Docker Socket Proxy потврђивање идентитета",
    "Additional option" : "Додатна опција",
    "Add additional option" : "Додај додатну опцију",
    "Option key (unique)" : "Кључ опције (јединствени)",
    "Option key (unique, e.g. my_key)" : "Кључ опције (једиствен, нпр. my_key)",
    "Option key is required" : "Потребан је кључ опције",
    "Option value" : "Вредност опције",
    "Option value is required" : "Потребна је вредност опције",
    "Confirm" : "Потврди",
    "Save" : "Сачувај",
    "Register" : "Региструј се",
    "Check connection" : "Провера везе",
    "Hostname to access ExApps" : "Име хоста за приступ ExApps",
    "Hostname or path to access Docker daemon (e.g. nextcloud-appapi-dsp:2375, /var/run/docker.sock)" : "Име хоста или путања за приступ Docker даемону (нпр. nextcloud-appapi-dsp:2375, /var/run/docker.sock)",
    "Daemon with this name already exists" : "Даемон са овим именом већ постоји",
    "Password must be at least 12 characters long" : "Дужина лозинке мора да буде барем 12 карактера",
    "With https enabled network is set to host" : "Са укљученим https мрежа се поставља на хост",
    "Changes would be applied only for newly installed ExApps. For existing ExApps, Docker containers should be recreated." : "Измене би се примениле само на ExApps које се инсталирају касније. У случају постојећих ExApps, требало би да се рекреирају Docker контејнери.",
    "URL should start with http:// or https://" : "URL би требало да почиње са http:// или https://",
    "For HTTPS daemon, Nextcloud URL should be HTTPS" : "Nextcloud URL би за HTTPS даемон требало да буде HTTPS",
    "All available GPU devices on daemon host will be requested to be enabled in ExApp containers by Docker." : "Захтеваће се да Docker укључи све доступне GPU уређаје у ExApp контејнерима.",
    "DaemonConfig successfully registered" : "DaemonConfig је успешно регистрована",
    "Failed to register DaemonConfig. Check the logs" : "Није успело регистровање DaemonConfig. Погледајте дневнике",
    "DaemonConfig successfully updated" : "DaemonConfig је успешно ажуриран",
    "Failed to update DaemonConfig. Check the logs" : "Није успело ажурирање DaemonConfig. Погледајте дневнике",
    "External Apps" : "Спољне апликације",
    "Update to {version}" : "Ажурирај на верзију {version}",
    "Remove" : "Уклони",
    "Delete data on remove" : "Обриши податке приликом уклањања",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ова апликација нема дефинисану минималну верзију Некстклауда на којој ради. Ово ће у будућности постати грешка.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ова апликација нема дефинисану максималну верзију Некстклауда на којој ради. Ово ће у будућности постати грешка.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Апликација се не може инсталирати јер следеће зависности нису испуњене:",
    "View in store" : "Погледај у продавници",
    "Visit website" : "Посети веб сајт",
    "Report a bug" : "Пријави грешку",
    "User documentation" : "Корисничка документација",
    "Admin documentation" : "Администраторска документација",
    "Developer documentation" : "Програмерска документација",
    "This app is not registered in AppStore. No extra information available. Only enable/disable and remove actions are allowed." : "Ова апликација није регистрована у Продавници апликација. Нема доступних додатних информација. Дозвољене су само акције укључи/искључи и уклони.",
    "{license}-licensed" : "{license}-лиценцирано",
    "This app is supported via your current Nextcloud subscription." : "Ова апликација је подржана са Вашом тренутном Некстклауд претплатом.",
    "Supported" : "Подржана",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Препоручене апликације су развијене за и од стране заједнице. Нуде главне функционалности и спремне су за продукциону употребу.",
    "Featured" : "Препоручене",
    "Update to {update}" : "Ажурирај на {update}",
    "All ExApps are up-to-date." : "Све ExApps су ажуриране.",
    "Default Deploy daemon is not accessible" : "Није доступан подразумевани даемон за постављање ",
    "Icon" : "Икона",
    "Version" : "Верзија",
    "Daemon" : "Сервис",
    "Level" : "Ниво",
    "Actions" : "Радње",
    "Results from other categories" : "Резултати из других категорија",
    "No apps found" : "Није пронађена ниједна апликација",
    "_%n ExApp has an update available_::_%n apps have an update available_" : ["Доступно је ажурирање за %n апликацију","Доступно је ажурирање за %n апликације","Доступно је ажурирање за %n апликација"],
    "_Update_::_Update all_" : ["Ажурирај","Ажурирај све","Ажурирај све"],
    "Type" : "Тип",
    "Display Name" : "Име за приказ",
    "Your apps" : "Ваше апликације",
    "Documentation" : "Документација",
    "Details" : "Детаљи",
    "Changelog" : "Дневник измена",
    "by {author}\n{license}" : "од {author}\n{license}",
    "Active apps" : "Активне апликације",
    "Disabled apps" : "Искључене апликације",
    "Updates" : "Ажурирања",
    "Featured apps" : "Препоручене апликације",
    "Supported apps" : "Подржане апликације",
    "manual-install apps cannot be updated" : "ручно инсталиране апликације не могу да се ажурирају",
    "{progress}% Deploying" : "{progress}% Поставља се",
    "{progress}% Initializing" : "{progress}% иницијализовано",
    "Healthchecking" : "Провера здравља",
    "Deploy and Enable" : "Постави и укључи",
    "Enable" : "Укључи",
    "Disable" : "Искључи",
    "Allow untested app" : "Дозволи нетестиране апликације",
    "Default Deploy daemon is not accessible. Please verify configuration" : "Подразумевани даемон за постављање није доступан. Молимо вас да проверите конфигурацију",
    "The app will be downloaded from the App Store and deployed on default Deploy Daemon" : "Апликација ће се преузети са Продавнице апликација и поставити на подразумеваном Даемону за постављање",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ова апликација није означена као компатибилна са Вашом верзијом Некстклауда. Ако наставите, моћи ћете свеједно да инсталирате апликацију. Врло је могуће да апликација неће радити како је планирано.",
    "Your ExApps" : "Ваше ExApps",
    "An error occurred during the request. Unable to proceed." : "Током захтева је дошло до грешке. Не може да се настави.",
    "The app has been enabled but needs to be updated." : "Апликација је уљкучена, али је потребно да се ажурира.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Грешка: Ова апликација не може да се обрише јер ће сервер постати нестабилан"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
