OC.L10N.register(
    "files_trashbin",
    {
    "restored" : "endurheimt",
    "Deleted files" : "eyddar skrár",
    "Deleted files and folders in the trash bin (may expire during export if you are low on storage space)" : "Eyddar skrár og möppur í ruslinu (gæru runnið út við útflutning ef þú átt lítið geymslupláss eftir)",
    "This application enables people to restore files that were deleted from the system." : "Þetta forrit gerir notendum kleift að endurheimta skrár sem eytt hefur verið af kerfinu.",
    "Restore" : "Endurheimta",
    "Empty deleted files" : "Tæma eyddar skrár",
    "Confirm permanent deletion" : "Staðfesta endanlega eyðingu",
    "Are you sure you want to permanently delete all files and folders in the trash? This cannot be undone." : "Ertu viss um að þú viljir eyða öllum skrám og möppum úr ruslinu? Þessi aðgerð er óafturkræf.",
    "Cancel" : "Hætta við",
    "Original location" : "Upprunaleg staðsetning",
    "Deleted by" : "Eytt af",
    "Deleted" : "Eytt",
    "A long time ago" : "Fyrir löngu síðan",
    "Unknown" : "Óþekkt",
    "All files" : "Allar skrár",
    "You" : "Þú",
    "List of files that have been deleted." : "Listi yfir skrár sem hefur verið eytt.",
    "No deleted files" : "Engar eyddar skrár",
    "Files and folders you have deleted will show up here" : "Skrár og möppur sem þú hefur eytt birtast hér",
    "Deletion cancelled" : "Hætt við eyðingu"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
