OC.L10N.register(
    "app_api",
    {
    "Daemon config not found" : "Configuração do Daemon não encontrada",
    "Error starting install of ExApp" : "Erro ao iniciar a instalação do ExApp",
    "ExApp failed to register, check the NC logs" : "ExApp falhou ao registrar, verifique os logs NC",
    "ExApp not found, failed to get status" : "ExApp não encontrado, falha ao obter status",
    "This app is not installed from the AppStore. No extra information available. Only enable/disable and remove actions are allowed." : "Este aplicativo não está instalado na AppStore. Sem informações extras disponíveis. Somente ativar/desativar e remover ações são permitidas.",
    "Could not perform installation of ExApp" : "Não foi possível realizar a instalação do ExApp",
    "Failed to enable ExApp" : "Falha ao habilitar ExApp",
    "Failed to disable ExApp" : "Falha ao desativar ExApp",
    "Could not update ExApp" : "Não foi possível atualizar o ExApp",
    "Error starting update of ExApp" : "Erro ao iniciar a atualização do ExApp",
    "Could not perform update of ExApp" : "Não foi possível realizar a atualização do ExApp",
    "ExApp not found, failed to get logs" : "ExApp não encontrado, falha ao obter registros",
    "Failed to get container logs. Note: Downloading Docker container works only for containers with the json-file or journald logging driver. Error: %s" : "Falha ao obter logs de contêiner. Observação: o download do contêiner do Docker funciona apenas para contêineres com arquivo json ou driver de registro do journald. Erro:%s",
    "AppAPI authentication failed" : "Falha na autenticação AppAPI",
    "AppAPI ExApp notifier" : "Notificador AppAPI ExApp",
    "AppAPI" : "AppAPI",
    "AI Integration Team" : "Equipe de integração de IA",
    "ExApps Settings" : "Configurações de ExApps",
    "Nextcloud AppAPI" : "Nextcloud AppAPI",
    "### Boost your Nextcloud with AppAPI and its specially designed applications.\n\n\nThe AppAPI is a project within the Nextcloud ecosystem designed to streamline and enhance the process of\napplication development, deployment, and management.\n\nIt introduces a new methodology that allows developers to create\napplications using a variety of programming languages, not limited to PHP, which was traditionally used in Nextcloud development.\n\n\n### List of applications that require AppAPI:\n\n- [talk_bot_ai_example](https://github.com/cloud-py-api/talk_bot_ai_example)\n- [upscaler_example](https://github.com/cloud-py-api/upscaler_example)\n- [image_to_text_example](https://github.com/cloud-py-api/file_to_text_example)\n- [ai_image_generator_bot](https://github.com/cloud-py-api/ai_image_generator_bot)\n- [SummarAI](https://github.com/nextcloud/sumupbot)\n\n_If you wish to develop an application, we will gladly help and assist you._\n\n### Support\n\nWe appreciate any support for this project:\n\n- ⭐ Star our work on GitHub\n- ❗ Create an Issue or feature request\n- 💁 Resolve an Issue and create a Pull Request\n- 🧑‍💻 Develop your own application using AppAPI\n\nWe are genuinely excited about the future of the AppAPI project and its potential to transform\nthe way applications are developed and experienced within Nextcloud.\n\nAs we embark on this journey, we warmly invite you - developers, thinkers, creators, and visionaries -\nto join us in shaping a more versatile, stable, and secure app landscape.\n\n*Your insights, suggestions, and contributions are invaluable to us.*" : "### Impulsione seu Nextcloud com AppAPI e seus aplicativos especialmente projetados.\n\n\nO AppAPI é um projeto dentro do ecossistema Nextcloud desenvolvido para agilizar e aprimorar o processo de\ndesenvolvimento, implantação e gerenciamento de aplicativos.\n\nEle introduz uma nova metodologia que permite aos desenvolvedores criar\naplicativos usando uma variedade de linguagens de programação, não se limitando ao PHP, que era tradicionalmente usado no desenvolvimento do Nextcloud.\n\n\n### Lista de aplicativos que requerem AppAPI:\n\n- [talk_bot_ai_example](https://github.com/cloud-py-api/talk_bot_ai_example)\n- [upscaler_example](https://github.com/cloud-py-api/upscaler_example)\n- [image_to_text_example](https://github.com/cloud-py-api/file_to_text_example)\n- [ai_image_generator_bot](https://github.com/cloud-py-api/ai_image_generator_bot)\n- [SummarAI](https://github.com/nextcloud/sumupbot)\n\n_Se você deseja desenvolver um aplicativo, teremos prazer em ajudá-lo e auxiliá-lo._\n\n### Suporte\n\nAgradecemos qualquer apoio a este projeto:\n\n- ⭐ Dê uma estrela ao nosso trabalho no GitHub\n- ❗ Crie um problema ou solicitação de recurso\n- 💁 Resolva um problema e crie uma solicitação pull\n- 🧑‍💻 Desenvolva seu próprio aplicativo usando AppAPI\n\nEstamos genuinamente entusiasmados com o futuro do projeto AppAPI e seu potencial para transformar\na forma como os aplicativos são desenvolvidos e experimentados no Nextcloud.\n\nAo embarcarmos nesta jornada, convidamos vocês - desenvolvedores, pensadores, criadores e visionários -\npara se juntar a nós na criação de um cenário de aplicativos mais versátil, estável e seguro.\n\n*Seus insights, sugestões e contribuições são inestimáveis ​​para nós.*",
    "The AppAPI Project is an exciting initiative that aims to revolutionize the way applications are developed for Nextcloud." : "O Projeto AppAPI é uma iniciativa empolgante que tem como objetivo revolucionar a forma como os aplicativos são desenvolvidos para o Nextcloud.",
    "Deploy Daemons" : "Deploy de Daemons",
    "Deploy Daemon (DaemonConfig) is an ExApps orchestration daemon." : "Deploy Daemon (DaemonConfig) é um daemon orquestrador de ExApps",
    "Deploy Daemons. Deploy Daemon (DaemonConfig) is an ExApps orchestration daemon." : "Implante Daemons. Deploy Daemon (DaemonConfig) é um daemon de orquestração ExApps.",
    "Default Deploy Daemon is not accessible. Please verify its configuration" : "O Daemon de Deploy Padrão não está acessível. Por favor, verifique sua configuração.",
    "ExApp init timeout (minutes)" : "Tempo limite de inicialização do ExApp (minutos)",
    "ExApp initialization process timeout after which AppAPI will mark it as failed" : "empo limite do processo de inicialização do ExApp após o qual o AppAPI o marcará como com falha",
    "ExApp init timeout" : "Tempo limite de inicialização do ExApp",
    "ExApp container restart policy" : "Política de reinicialização do contêiner ExApp",
    "Specify container restart policy, e.g. 'always' to ensure ExApp running after daemon server reboot" : "Especifique a política de reinicialização do contêiner, por exemplo. 'sempre' para garantir que o ExApp seja executado após a reinicialização do servidor daemon",
    "This settings changes are reflected only for newly created containers" : "Essas alterações nas configurações são refletidas apenas para contêineres recém-criados",
    "External Apps management" : "Gestão de Aplicativos Externos",
    "Admin options saved" : "Opções de administrador salvas",
    "Failed to save admin options" : "Falha ao salvar as opções do administrador",
    "Are you sure you want delete Deploy Daemon" : "Tem certeza de que deseja excluir o Deploy Daemon",
    "All ExApps on this daemon will be removed" : "Todos os ExApps neste daemon serão removidos",
    "All ExApps installed on this daemon will be removed" : "Todos os ExApps instalados neste daemon serão removidos",
    "Cancel" : "Cancelar",
    "Delete" : "Excluir",
    "Default" : "Padrão",
    "Set as default" : "Definir como padrão",
    "Test deploy" : "Implantação de teste",
    "Edit" : "Editar",
    "\"manual-install\" Deploy Daemon cannot be set as default" : "O Daemon de Implantação \"manual-install\" não pode ser definido como padrão",
    "Failed to save admin options. Check the logs" : "Falha ao salvar as opções do administrador. Verifique os logs.",
    "Password confirmation failed" : "Falha na confirmação da senha",
    "Deploy daemon config details" : "Implantar detalhes de configuração do daemon",
    "Deploy Daemon" : "Deploy Daemon",
    "Default daemon. ExApps will be installed on it" : "Daemon padrão. ExApps serão instalados nele.",
    "Manual install daemon usually used for development. It cannot be set as default daemon." : "Instalação manual do daemon geralmente usada para desenvolvimento. Não pode ser definido como daemon padrão.",
    "ExApps installed" : "ExApps instalados",
    "Name" : "Nome",
    "Protocol" : "Protocolo",
    "Host" : "Servidor",
    "Deploy config" : "Configuração de Deploy",
    "Docker network" : "Rede Docker",
    "Nextcloud URL" : "URL Nextcloud",
    "HaProxy password" : "Senha HaProxy",
    "GPUs support" : "Suporte a GPUs",
    "Compute device" : "Dispositivo de computação",
    "Additional options" : "Opções adicionais",
    "Verify connection" : "Verificar conexão",
    "Daemon connection successful" : "Conexão do daemon bem-sucedida",
    "Failed to connect to Daemon. Check the logs" : "Falha ao conectar ao Daemon. Verifique os logs.",
    "Failed to check connection to Daemon. Check the logs" : "Falha ao verificar a conexão com o Daemon. Verifique os logs.",
    "Registered Deploy daemons list" : "Lista de daemons de implantação registrados",
    "No Deploy daemons configured" : "Nenhum daemon de implantação configurado",
    "Register a custom one or setup from available templates" : "Registre um personalizado ou configure a partir dos modelos disponíveis",
    "Register Daemon" : "Registrar Daemon",
    "AppAPI will try to install small skeleton ExApp to verify Daemon configured correctly and deployment steps are passing." : "AppAPI tentará instalar o esqueleto pequeno do ExApp para verificar se o Daemon está configurado corretamente e se as etapas de implantação estão sendo aprovadas.",
    "The following Deploy test checks must be passed to succeed:" : "As seguintes verificações de teste de implantação devem ser aprovadas para serem bem-sucedidas:",
    "More info" : "Mais informações",
    "Download ExApp logs" : "Baixar registros do ExApp",
    "Remove test ExApp" : "Remover ExApp de teste",
    "Start Deploy test" : "Iniciar teste de implantação",
    "Stop Deploy test" : "Parar o teste de implantação",
    "ExApp is unregistered and container is removed on \"Stop deploy test\"" : "ExApp não está registrado e o contêiner é removido em \"Parar teste de implantação\"",
    "Register ExApp in Nextcloud" : "Registre ExApp no ​​Nextcloud",
    "Check if the ExApp is registered in Nextcloud before deployment" : "Verifique se o ExApp está registrado no Nextcloud antes da implantação",
    "Image pull" : "Extração de imagem",
    "Check if the image is successfully pulled" : "Verifique se a imagem foi extraída com sucesso",
    "Container started" : "Contêiner iniciado",
    "Check if the image successfully pulled and container is created and started" : "Verifique se a imagem extraída com sucesso e o contêiner foi criado e iniciado",
    "Heartbeat" : "Batimento cardiaco",
    "Check for the heartbeat is finished and healthy" : "Verifique se o batimento cardíaco está finalizado e saudável",
    "Init step" : "Etapa inicial",
    "Wait for initialization step to finish" : "Aguarde a conclusão da etapa de inicialização",
    "Enabled" : "Habilitada",
    "Check if ExApp successfully handled the enabled event and registered all stuff properly" : "Verifique se o ExApp tratou com sucesso o evento habilitado e registrou tudo corretamente",
    "Only if ExApp container is preset" : "Somente se o contêiner ExApp estiver predefinido",
    "Deploy test passed successfully!" : "Teste de implantação aprovado com sucesso!",
    "Deploy test failed at step \"{step}\"" : "O teste de implantação falhou na etapa \"{step}\"",
    "Edit Deploy Daemon" : "Editar Deploy Daemon",
    "Register Deploy Daemon" : "Registrar Daemon de Deploy",
    "Daemon configuration template" : "Modelo de configuração do daemon",
    "Select daemon configuration template" : "Selecione o modelo de configuração do daemon",
    "Daemon registration form" : "Formulário de registro do Daemon",
    "Unique Deploy Daemon Name" : "Nome exclusivo do Daemon de Deploy",
    "Display name" : "Nome de exibição",
    "Deployment method" : "Método de implantação",
    "Select daemon deploy method" : "Selecione o método de implantação do daemon",
    "Daemon host" : "Daemon host",
    "Set daemon as default" : "Definir daemon como padrão",
    "Set as default daemon" : "Definir como daemon padrão",
    "Enable https" : "Habilitar https",
    "Show deploy config" : "Mostrar configuração de deploy",
    "Hide deploy config" : "Ocultar configuração de deploy",
    "Network" : "Rede",
    "Docker network name" : "Nome da rede do Docker",
    "AppAPI Docker Socket Proxy authentication password" : "Senha de autenticação AppAPI Docker Socket Proxy",
    "Additional option" : "Opção adicional",
    "Add additional option" : "Adicionar opção adicional",
    "Option key (unique)" : "Chave de opção (exclusiva)",
    "Option key (unique, e.g. my_key)" : "Chave de opção (exclusiva, por exemplo, my_key)",
    "Option key is required" : "A chave de opção é necessária",
    "Option value" : "Valor da opção",
    "Option value is required" : "O valor da opção é obrigatório",
    "Confirm" : "Confirmar",
    "Save" : "Salvar",
    "Register" : "Registro ",
    "Check connection" : "Verifique a conexão",
    "Hostname to access ExApps" : "Nome do host para acessar ExApps",
    "Hostname or path to access Docker daemon (e.g. nextcloud-appapi-dsp:2375, /var/run/docker.sock)" : "Nome do host ou caminho para acessar o daemon Docker (por exemplo, nextcloud-appapi-dsp:2375, /var/run/docker.sock)",
    "Daemon with this name already exists" : "Daemon com este nome já existe",
    "Password must be at least 12 characters long" : "A senha deve ter pelo menos 12 caracteres",
    "With https enabled network is set to host" : "Com https habilitado, a rede está configurada para hospedar",
    "Changes would be applied only for newly installed ExApps. For existing ExApps, Docker containers should be recreated." : "As alterações seriam aplicadas somente para ExApps recém-instalados. Para ExApps existentes, os contêineres Docker devem ser recriados.",
    "URL should start with http:// or https://" : "A URL deve começar com http:// ou https://",
    "For HTTPS daemon, Nextcloud URL should be HTTPS" : "Para o daemon HTTPS, a URL do Nextcloud deve ser HTTPS",
    "All available GPU devices on daemon host will be requested to be enabled in ExApp containers by Docker." : "Todos os dispositivos GPU disponíveis no host daemon serão solicitados a serem habilitados em contêineres ExApp pelo Docker.",
    "DaemonConfig successfully registered" : "DaemonConfig registrado com sucesso",
    "Failed to register DaemonConfig. Check the logs" : "Falha ao registrar o DaemonConfig. Verifique os logs.",
    "DaemonConfig successfully updated" : "DaemonConfig atualizado com sucesso",
    "Failed to update DaemonConfig. Check the logs" : "Falha ao atualizar o DaemonConfig. Verifique os logs",
    "External Apps" : "Apps Externos",
    "Update to {version}" : "Atualizar para {version}",
    "Remove" : "Remover",
    "Delete data on remove" : "Excluir dados ao remover",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Este aplicativo não possui uma versão mínima atribuída para uso no Nextcloud. Isto poderá se converter em um erro no futuro.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Este aplicativo não possui uma versão máxima atribuida para uso no Nextcloud. Isto poderá se converter em um erro no futuro.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Este aplicativo não pode ser instalado pois as seguintes dependências não forão cumpridas:",
    "View in store" : "Ver na loja",
    "Visit website" : "Visitar website",
    "Report a bug" : "Reportar um erro",
    "User documentation" : "Documentação do usuário",
    "Admin documentation" : "Documentação do administrador",
    "Developer documentation" : "Documentação do desenvolvedor",
    "This app is not registered in AppStore. No extra information available. Only enable/disable and remove actions are allowed." : "Este aplicativo não está registrado na AppStore. Nenhuma informação extra disponível. Somente ações de ativar/desativar e remover são permitidas.",
    "{license}-licensed" : "{license}-licenciado",
    "This app is supported via your current Nextcloud subscription." : "Este aplicativo é suportado pela sua assinatura atual do Nextcloud.",
    "Supported" : "Suportado",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Os aplicativos em destaque são desenvolvidos pela comunidade. Eles oferecem funcionalidade central e estão prontos para uso em produção.",
    "Featured" : "Destaques",
    "Update to {update}" : "Atualizar para {update}",
    "All ExApps are up-to-date." : "Todos os ExApps estão atualizados.",
    "Default Deploy daemon is not accessible" : "O Daemon de Deploy padrão não está acessível.",
    "Icon" : "Ícone",
    "Version" : "Versão",
    "Daemon" : "Daemon",
    "Level" : "Nível",
    "Actions" : "Ações",
    "Results from other categories" : "Resultados de outras categorias",
    "No apps found" : "Nenhum app encontrado",
    "_%n ExApp has an update available_::_%n apps have an update available_" : ["%n ExApp tem uma atualização disponível.","%n apps têm uma atualização disponível","%n apps têm uma atualização disponível"],
    "_Update_::_Update all_" : ["Atualizar","Atualize tudo","Atualize tudo"],
    "Type" : "Tipo",
    "Display Name" : "Nome",
    "Your apps" : "Seus aplicativos",
    "Documentation" : "Documentação",
    "Details" : "Detalhes",
    "Changelog" : "Log de alterações",
    "by {author}\n{license}" : "por {author}\n{license}",
    "Active apps" : "Aplicativos ativados",
    "Disabled apps" : "Aplicativos desativados",
    "Updates" : "Atualizações",
    "Featured apps" : "Aplicativos em destaque",
    "Supported apps" : "Aplicativos compatíveis",
    "manual-install apps cannot be updated" : "aplicativos de instalação manual não podem ser atualizados",
    "{progress}% Deploying" : "{progress}% Implantação",
    "{progress}% Initializing" : "{progress}% Inicializando",
    "Healthchecking" : "Verificação de saúde",
    "Deploy and Enable" : "Implantar e Habilitar",
    "Enable" : "Ativar",
    "Disable" : "Desativar",
    "Allow untested app" : "Permitir app não testado",
    "Default Deploy daemon is not accessible. Please verify configuration" : "O daemon de deploy padrão não está acessível. Por favor, verifique a configuração.",
    "The app will be downloaded from the App Store and deployed on default Deploy Daemon" : "O aplicativo será baixado da App Store e implantado no Deploy Daemon padrão.",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Este aplicativo não está marcado como compatível com sua versão do Nextcloud. Se você continuar, ainda poderá instalar o aplicativo mas poderá não funcionar como esperado.",
    "Your ExApps" : "Seus ExApps",
    "An error occurred during the request. Unable to proceed." : "Ocorreu um erro durante a solicitação. Não foi possível prosseguir.",
    "The app has been enabled but needs to be updated." : "O aplicativo foi habilitado, mas precisa ser atualizado.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Erro: Este aplicativo não pode ser habilitado pois torna o servidor instável."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
