<?php
namespace Aws\LicenseManagerUserSubscriptions\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS License Manager User Subscriptions** service.
 */
class LicenseManagerUserSubscriptionsException extends AwsException {}
