<?php
namespace Aws\MediaTailor\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS MediaTailor** service.
 */
class MediaTailorException extends AwsException {}
