OC.L10N.register(
    "files_sharing",
    {
    "File shares" : "Skráasameignir",
    "Downloaded via public link" : "Náð í með almenningstengli",
    "Downloaded by {email}" : "Náð í með {email}",
    "{file} downloaded via public link" : "{file} sótt með almenningstengli",
    "{email} downloaded {file}" : "{email} sótti {file}",
    "Shared with group {group}" : "Deilt með hópnum {group}",
    "Removed share for group {group}" : "Fjarlægði sameign af hópnum {group}",
    "{actor} shared with group {group}" : "{actor} deildi með hópnum {group}",
    "{actor} removed share for group {group}" : "{actor} fjarlægði sameign af hópnum {group}",
    "Share for group {group} expired" : "Sameign fyrir hópinn {group} er útrunnin",
    "You shared {file} with group {group}" : "Þú deildir {file} með hópnum {group}",
    "You removed group {group} from {file}" : "Þú fjarlægðir hópinn {group} af {file}",
    "{actor} shared {file} with group {group}" : "{actor} deildi {file} með hópnum {group}",
    "{actor} removed group {group} from {file}" : "{actor} fjarlægði hópinn {group} af {file}",
    "Share for file {file} with group {group} expired" : "Sameign fyrir skrána{file} með hópnum {group} er útrunnin",
    "Shared as public link" : "Deilt sem almenningstengill",
    "Removed public link" : "Fjarlægði almenningstengil",
    "Public link expired" : "Almenningstengill er útrunninn",
    "{actor} shared as public link" : "{actor} deildi sem almenningstengill",
    "{actor} removed public link" : "{actor} fjarlægði almenningstengil",
    "Public link of {actor} expired" : "Almenningstengill {actor} er útrunninn",
    "You shared {file} as public link" : "Þú deildir {file} sem almenningstengli",
    "You removed public link for {file}" : "Þú fjarlægðir almenningstengilinn fyrir {file}",
    "Public link expired for {file}" : "Almenningstengill er útrunninn fyrir {file}",
    "{actor} shared {file} as public link" : "{actor} deildi {file} sem almenningstengli",
    "{actor} removed public link for {file}" : "{actor} fjarlægði almenningstengil fyrir {file}",
    "Public link of {actor} for {file} expired" : "Almenningstengill frá {actor} fyrir {file} er útrunninn",
    "{user} accepted the remote share" : "{user} samþykkti fjartengda sameign",
    "{user} declined the remote share" : "{user} hafnaði fjartengdri sameign",
    "You received a new remote share {file} from {user}" : "Þú tókst við nýrri fjartengdri sameign {file} frá {user}",
    "{user} accepted the remote share of {file}" : "{user} samþykkti fjartengdu sameignina {file}",
    "{user} declined the remote share of {file}" : "{user} hafnaði fjartengdu sameigninni {file}",
    "{user} unshared {file} from you" : "{user} tók af deilingu á {file} frá þér",
    "Shared with {user}" : "Deilt með {user}",
    "Removed share for {user}" : "Fjarlægði deilingu með {user}",
    "You removed yourself" : "Þú fjarlægðir sjálfan þig",
    "{actor} removed themselves" : "{actor} fjarlægði sig sjálfan",
    "{actor} shared with {user}" : "{actor} deildi með {user}",
    "{actor} removed share for {user}" : "{actor} fjarlægði deilingu með {user}",
    "Shared by {actor}" : "Deilt af {actor}",
    "{actor} removed share" : "{actor} fjarlægði deilingu",
    "Share for {user} expired" : "Sameign fyrir {user} er útrunnin",
    "Share expired" : "Sameignin er útrunnin",
    "You shared {file} with {user}" : "Þú deildir {file} með {user}",
    "You removed {user} from {file}" : "Þú fjarlægðir {user} af {file}",
    "You removed yourself from {file}" : "Þú fjarlægðir sjálfan þig af {file}",
    "{actor} removed themselves from {file}" : "{actor} fjarlægði sig sjálfan af {file}",
    "{actor} shared {file} with {user}" : "{actor} deildi {file} með {user}",
    "{actor} removed {user} from {file}" : "{actor} fjarlægði {user} af {file}",
    "{actor} shared {file} with you" : "{actor} deildi {file} með þér",
    "{actor} removed you from the share named {file}" : "{actor} fjarlægði þig af sameign með heitinu {file}",
    "Share for file {file} with {user} expired" : "Sameign fyrir skrána {file} með {user} er útrunnin",
    "Share for file {file} expired" : "Sameign fyrir skrána {file} er útrunnin",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Skrá eða mappa sem deilt var með tölvupósti eða almenningstengli var <strong>sótt</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Skjali eða möppu hefur verið deilt <strong>frá öðrum þjóni</strong>",
    "Sharing" : "Deiling",
    "A file or folder has been <strong>shared</strong>" : "Skjali eða  möppu hefur verið <strong>deilt</strong>",
    "Shared link" : "Deilitengill",
    "Wrong share ID, share does not exist" : "Rangt auðkenni sameignar, sameign er ekki til",
    "Could not delete share" : "Tókst ekki að eyða sameign",
    "Please specify a file or folder path" : "Tiltaktu skrá eða slóð á möppu",
    "Wrong path, file/folder does not exist" : "Röng slóð, skráin/mappan er ekki til",
    "Could not create share" : "Ekki tókst að búa til sameign",
    "Please specify a valid account to share with" : "Tilgreindu gildan aðgang til að nota til að deila",
    "Group sharing is disabled by the administrator" : "Deiling innan hóps hefur verið gerð óvirk af kerfisstjóra.",
    "Please specify a valid group" : "Settu inn gildan hóp",
    "Public link sharing is disabled by the administrator" : "Deiling opinberra sameignartengla hefur verið gerð óvirk af kerfisstjóra.",
    "Please specify a valid email address" : "Tilgreindu gilt tölvupóstfang",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Deiling á %s með því að senda lykilorð með Nextcloud Talk mistókst því að Nextcloud Talk er ekki virkt",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "Deiling %1$s mistókst, því bakvinnslukerfið leyfir ekki sameignir af gerðinni %2$s",
    "Please specify a valid federated account ID" : "Tilgreindu gilt skýjasambandsauðkenni aðgangs",
    "Please specify a valid federated group ID" : "Skilgreindu gilt skýjasambandsauðkenni hóps",
    "You cannot share to a Team if the app is not enabled" : "Þú getur ekki deilt með teymi ef forritið er ekki virkt",
    "Please specify a valid team" : "Settu inn gilt teymi",
    "Sharing %s failed because the back end does not support room shares" : "Deiling %s mistókst því bakvinnslukerfið leyfir ekki spjallsvæðasameignir",
    "Sharing %s failed because the back end does not support ScienceMesh shares" : "Deiling %s mistókst því bakvinnslukerfið leyfir ekki ScienceMesh-sameignir",
    "Unknown share type" : "Óþekkt tegund sameignar",
    "Not a directory" : "Er ekki mappa",
    "Could not lock node" : "Gat ekki læst hnút",
    "Public upload is only possible for publicly shared folders" : "Opinber innsending er einungis möguleg í möppur sem er deilt opinberlega",
    "Share must at least have READ or CREATE permissions" : "Sameign verður að hafa að minnsta kosti LESA eða ÚTBÚA heimildir",
    "Share must have READ permission if UPDATE or DELETE permission is set" : "Sameign verður að hafa LESA heimild ef UPPFÆRA eða EYÐA heimildir eru veittar",
    "Public upload disabled by the administrator" : "Opinber innsending hefur verið gerð óvirk af kerfisstjóra.",
    "Could not lock path" : "Gat ekki læst slóð",
    "no sharing rights on this item" : "engin heimild til deilingar þessu atriði",
    "You are not allowed to edit incoming shares" : "Þú hefur ekki heimild til að breyta innkomandi sameignum",
    "Wrong or no update parameter given" : "Rangt eða ekkert uppfærsluviðfang gefið",
    "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled." : "Deiling með því að senda lykilorð með Nextcloud Talk til að deila skrá eða möppu mistókst því að Nextcloud Talk er ekki virkt.",
    "Invalid date. Format must be YYYY-MM-DD" : "Ógild dagsetning. Sniðið verður að vera ÁÁÁÁ-MM-DD",
    "No sharing rights on this item" : "Engin heimild til deilingar þessu atriði",
    "You are not allowed to send mail notifications" : "Þú hefur ekki heimild til að senda tilkynningar í tölvupósti",
    "Wrong password" : "Rangt lykilorð",
    "Error while sending mail notification" : "Villa við að senda tilkynningu í tölvupósti",
    "Failed to generate a unique token" : "Mistókst að búa til einstakt teikn",
    "This share does not exist or is no longer available" : "Þessi sameign er ekki til eða ekki lengur tiltæk",
    "shared by %s" : "Deilt af %s",
    "Download" : "Sækja",
    "Add to your %s" : "Bæta við þitt %s",
    "Direct link" : "Beinn tengill",
    "Share API is disabled" : "Deilingar-API er óvirkt",
    "File sharing" : "Skráadeiling",
    "Share will expire tomorrow" : "Sameignin rennur út á morgun",
    "Your share of {node} will expire tomorrow" : "Sameign þín á {node} rennur út á morgun",
    "You received {share} as a share by {user}" : "Þú tókst við {share} sem sameign frá {user}",
    "You received {share} to group {group} as a share by {user}" : "Þú tókst við {share} fyrir hópinn {group} sem sameign frá {user}",
    "Accept" : "Samþykkja",
    "Decline" : "Hafna",
    "Remember to upload the files to %s" : "Mundu að senda skrárnar inn til %s",
    "Open \"%s\"" : "Opna \"%s\"",
    "This application enables people to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable people can then share files and folders with other accounts and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other people outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation." : "Þetta forrit gerir notendum kleift að deila skrám innan Nextcloud. Ef þetta er virkt getur stjórnandi valið hvaða hópar geti deilt skrám. Viðkomandi notendur geta þá deilt skrám og möppum með öðrum notendum og hópum innan Nextcloud. Að auki, ef stjórnandinn virkjar eiginleikan til að deila með tenglum, er hægt að nota ytri tengil til að deila skrám með öðrum notendum utan Nextcloud. Stjórnendur geta líka krafist notkunar lykilorða, gildistíma og virkjað þjónn-í-þjón deilingu með deilitenglum, rétt eins og deilingu með snjalltækjum.\nSé slökkt á þessum eiginleika, eru deildar skrár og möppur fjarlægðar af þjóninum fyrir alla notendur þessara sameigna, og einnig úr samstillingaforritum og snjalltækjum. Ítarlegri upplýsingar um þetta má finna í hjálparskjölum Nextcloud.",
    "People" : "Fólk",
    "Filter accounts" : "Sía aðganga",
    "The request will expire on {date} at midnight and will be password protected." : "Beiðnin mun renna út þann {date} á miðnætti og verður varin með lykilorði.",
    "The request will expire on {date} at midnight." : "Beiðnin mun renna út þann {date} á miðnætti.",
    "The request will be password protected." : "Beiðnin verður varin með lykilorði.",
    "When should the request expire?" : "Hvenær á beiðnin að renna út?",
    "Set a submission expiration date" : "Setja gildistíma innsendingar",
    "Expiration date" : "Gildir til",
    "Select a date" : "Veldu dagsetningu",
    "What password should be used for the request?" : "Hvaða lykilorð á að nota fyrir beiðnina?",
    "Set a password" : "Setja lykilorð",
    "Password" : "Lykilorð",
    "Enter a valid password" : "Settu inn gilt lykilorð",
    "Generate a new password" : "Útbúa nýtt lykilorð",
    "Your administrator has enforced a password protection." : "Kerfisstjórinn þinn hefur krafist verndunar með lykilorði.",
    "Link copied" : "Tengill afritaður",
    "Email already added" : "Tölvupóstfangi þegar bætt við",
    "Invalid email address" : "Ógilt tölvupóstfang",
    "_The following email address is not valid: {emails}_::_The following email addresses are not valid: {emails}_" : ["Eftirfarandi tölvupóstfang er ógilt: {emails}","Eftirfarandi tölvupóstföng eru ógild: {emails}"],
    "_{count} email address already added_::_{count} email addresses already added_" : ["{count} tölvupóstfangi þegar bætt við","{count} tölvupóstföngum þegar bætt við"],
    "_{count} email address added_::_{count} email addresses added_" : ["{count} tölvupóstfangi bætt við","{count} tölvupóstföngum bætt við"],
    "Share link" : "Tengill á sameign",
    "Copy" : "Afrita",
    "Send link via email" : "Senda tengil með tölvupósti",
    "Enter an email address or paste a list" : "Settu inn tölvupóstfang eða límdu inn lista",
    "Remove email" : "Fjarlægja tölvupóstfang",
    "Select a destination" : "Veldu áfangastað",
    "Select" : "Velja",
    "What are you requesting?" : "Hvað ertu að biðja um?",
    "Request subject" : "Viðfangsefni beiðnar",
    "Birthday party photos, History assignment…" : "Myndir úr afmæli, söguverkefni…",
    "Where should these files go?" : "Hvert ættu þessar skrár að fara?",
    "Upload destination" : "Áfangastaður innsendinga",
    "Revert to default" : "Endurstilla á sjálfgefið",
    "Add a note" : "Bæta við minnispunkti",
    "Note for recipient" : "Minnispunktur til viðtakanda",
    "Add a note to help people understand what you are requesting." : "Bættu við minnispunkti svo fólk viti að um hvað þú sért að biðja.",
    "Close" : "Loka",
    "_Send email and close_::_Send {count} emails and close_" : ["Senda tölvupóst og loka","Senda {count} tölvupósta og loka"],
    "File request created" : "Beiðni um skrá útbúin",
    "Error creating the share: {errorMessage}" : "Villa kom upp við að búa til sameignina: {errorMessage}",
    "Error creating the share" : "Villa við að búa til sameignina",
    "Error sending emails: {errorMessage}" : "Villa við að senda tölvupósta: {errorMessage}",
    "Error sending emails" : "Villa við að senda tölvupósta",
    "Create a file request" : "Útbúa beiðni um skrá",
    "File request" : "Beiðni um skrá",
    "Previous step" : "Fyrra skref",
    "Cancel" : "Hætta við",
    "Cancel the file request creation" : "Hætta við gerð beiðnar um skrá",
    "Close without sending emails" : "Loka án þess að senda tölvupósta",
    "Continue" : "Halda áfram",
    "Error while toggling options" : "Villa við að víxla valkostum",
    "Choose a default folder for accepted shares" : "Veldu sjáfgefna möppu fyrir samþykktar sameignir",
    "Invalid path selected" : "Ógild slóð valin",
    "Unknown error" : "Óþekkt villa",
    "Set default folder for accepted shares" : "Stilltu sjáfgefna möppu fyrir samþykktar sameignir",
    "Reset" : "Endurstilla",
    "Reset folder to system default" : "Frumstilla möppu á sjálfgefna í kerfinu",
    "group" : "hópur",
    "conversation" : "samtal",
    "remote" : "fjartengt",
    "remote group" : "fjartengdur hópur",
    "guest" : "gestanotandi",
    "by {initiator}" : "af {initiator}",
    "Shared with the group {user} by {owner}" : "Deilt með hópnum {user} af {owner}",
    "Shared with the conversation {user} by {owner}" : "Deilt með þér í samtali við {user} af {owner}",
    "Shared with {user} by {owner}" : "Deilt með {user} af {owner}",
    "Open Sharing Details" : "Opna nánari upplýsingar um deilingu",
    "Added by {initiator}" : "Bætt við af {initiator}",
    "Via “{folder}”" : "Í gegnum “{folder}”",
    "Unshare" : "Hætta deilingu",
    "Cannot copy, please copy the link manually" : "Mistókst að afrita, afritaðu tengilinn handvirkt",
    "Copy internal link" : "Afrita innri tengil",
    "Internal link" : "Innri tengill",
    "{shareWith} by {initiator}" : "{shareWith} af {initiator}",
    "Shared via link by {initiator}" : "Deilt með tengli af {initiator}",
    "File request ({label})" : "Beiðni um skrá ({label})",
    "Mail share ({label})" : "Deilt með tölvupósti ({label})",
    "Share link ({label})" : "Tengill á sameign ({label})",
    "Mail share" : "Deiling með tölvupósti",
    "Share link ({index})" : "Tengill á sameign ({index})",
    "Create public link" : "Búa til opinberan tengil",
    "Actions for \"{title}\"" : "Aðgerðir fyrir \"{title}\"",
    "Error, please enter proper password and/or expiration date" : "Villa, settu inn alvöru lykilorð og/eða gildisdagsetningu",
    "Link share created" : "Sameign í gegnum tengil útbúin",
    "Error while creating the share" : "Villa kom upp við að búa til sameignina",
    "Please enter the following required information before creating the share" : "Settu inn eftirfarandi nauðsynlegar upplýsingar áður en þú býrð til sameignina",
    "Password protection (enforced)" : "Verndun með lykilorði (nauðsynleg)",
    "Password protection" : "Verndun með lykilorði",
    "Enter a password" : "Settu inn lykilorð",
    "Enable link expiration (enforced)" : "Virkja gildistíma tengils (nauðsynlegt)",
    "Enable link expiration" : "Virkja gildistíma tengils",
    "Enter expiration date (enforced)" : "Settu inn gildistíma (nauðsynlegt)",
    "Enter expiration date" : "Settu inn gildistíma",
    "Create share" : "Búa til sameign",
    "Customize link" : "Sérsníða tengil",
    "Generate QR code" : "Útbúa QR-kóða",
    "Add another link" : "Bæta við öðrum tengli",
    "Create a new share link" : "Búa til nýjan tengil á sameign",
    "View only" : "Einungis skoða",
    "Can edit" : "Getur breytt",
    "Custom permissions" : "Sérsniðnar heimildir",
    "Resharing is not allowed" : "Endurdeiling er ekki leyfð",
    "Name or email …" : "Nafn eða tölvupóstfang …",
    "Name, email, or Federated Cloud ID …" : "Nafn, tölvupóstfang eða skýjasambandsauðkenni (Federated Cloud ID) …",
    "Searching …" : "Leita …",
    "No elements found." : "Engin stök fundust.",
    "Search everywhere" : "Leita allsstaðar",
    "Guest" : "Gestur",
    "Group" : "Hópur",
    "Email" : "Tölvupóstur",
    "Team" : "Teymi",
    "Talk conversation" : "Samtal í Talk-spjalli",
    "Deck board" : "Deck-borð",
    "ScienceMesh" : "ScienceMesh",
    "on {server}" : "á {server}",
    "Note from" : "Minnispunktur frá",
    "Note:" : "Athugaðu:",
    "File drop" : "Slepping skráa",
    "Upload files to {foldername}." : "Senda skrár inn í {foldername}.",
    "By uploading files, you agree to the terms of service." : "Með því að senda inn skrár, samþykkir þú þjónustuskilmálana.",
    "View terms of service" : "Skoða þjónustuskilmála",
    "Terms of service" : "Þjónustuskilmálar",
    "Share with email {email}" : "Deila í tölvupósti með {email}",
    "Share with group" : "Deila með hópi",
    "Share in conversation" : "Deila í samtali",
    "Share with {user} on remote server {server}" : "Deila með {user} á fjartengda þjóninum {server}",
    "Share with remote group" : "Deila með fjartengdum hópi",
    "Share with guest" : "Deila með gesti",
    "Update share" : "Uppfæra sameign",
    "Save share" : "Vista sameign",
    "Read" : "Lesa",
    "Create" : "Búa til",
    "Edit" : "Breyta",
    "Share" : "Deila",
    "Delete" : "Eyða",
    "Replace current password" : "Skipta út fyrirliggjandi lykilorði",
    "Failed to generate a new token" : "Mistókst að búa til nýtt teikn",
    "Allow upload and editing" : "Leyfa innsendingu og breytingar",
    "Allow editing" : "Leyfa breytingar",
    "Upload only" : "Einungis innsending",
    "Advanced settings" : "Ítarlegri valkostir",
    "Share label" : "Merking á sameign",
    "Generating…" : "Útbý…",
    "Generate new token" : "Búa til nýtt teikn",
    "Set password" : "Stilltu lykilorð",
    "Password expires {passwordExpirationTime}" : "Lykilorð rennur út {passwordExpirationTime}",
    "Password expired" : "Lykilorð er útrunnið",
    "Video verification" : "Sannvottun í myndskeiði",
    "Expiration date (enforced)" : "Gildistími (nauðsynlegur)",
    "Set expiration date" : "Setja gildistíma",
    "Hide download" : "Fela niðurhal",
    "Allow download and sync" : "Leyfa niðurhal og samstillingu",
    "Note to recipient" : "Minnispunktur til viðtakanda",
    "Enter a note for the share recipient" : "Settu inn minnispunkt til viðtakanda sameignar",
    "Show files in grid view" : "Birta skrár í reitasýn",
    "Delete share" : "Eyða sameign",
    "Others with access" : "Aðrir með aðgang",
    "No other accounts with access found" : "Engir aðrir notendur með aðgang fundust",
    "Toggle list of others with access to this directory" : "Víxla af/á lista yfir aðra með aðgang að þessari möppu",
    "Toggle list of others with access to this file" : "Víxla af/á lista yfir aðra með aðgang að þessari skrá",
    "Unable to fetch inherited shares" : "Mistókst að sækja erfðar sameignir",
    "Link shares" : "Sameignartenglar",
    "Shares" : "Sameignir",
    "Unable to load the shares list" : "Mistókst aði hlaða inn lista yfir sameignir",
    "Expires {relativetime}" : "Rennur út {relativetime}",
    "this share just expired." : "Þessi sameign var að renna út.",
    "Shared with you by {owner}" : "Deilt með þér af {owner}",
    "Internal shares" : "Innri sameignir",
    "Internal shares explanation" : "Útskýring á innri sameignum",
    "External shares" : "Utanaðkomandi sameignir",
    "External shares explanation" : "Útskýring á utanaðkomandi sameignum",
    "Additional shares" : "Viðbótarsameignir",
    "Additional shares explanation" : "Útskýring á viðbótarsameignum",
    "Link to a file" : "Tengill í skrá",
    "_Accept share_::_Accept shares_" : ["Samþykkja sameign","Samþykkja sameignir"],
    "Open in Files" : "Opna í skráaforritinu",
    "_Reject share_::_Reject shares_" : ["Hafna sameign","Hafna sameignum"],
    "_Restore share_::_Restore shares_" : ["Endurheimta sameign","Endurheimta sameignir"],
    "Shared" : "Deilt",
    "Shared by {ownerDisplayName}" : "Deilt af {ownerDisplayName}",
    "Shared multiple times with different people" : "Deilt mörgum sinnum með mismunandi fólki",
    "Shared with others" : "Deilt með öðrum",
    "Create file request" : "Útbúa beiðni um skrá",
    "Upload files to {foldername}" : "Senda skrár inn í {foldername}",
    "Public file share" : "Opinber skráasameign",
    "Publicly shared file." : "Skrá deilt opinberlega.",
    "No file" : "Engin skrá",
    "The file shared with you will show up here" : "Skráin sem deilt er með þér birtist hér",
    "Public share" : "Opinber sameign",
    "Publicly shared files." : "Skrár deilt opinberlega.",
    "No files" : "Engar skrár",
    "Files and folders shared with you will show up here" : "Skrár og möppur sem deilt er með þér birtast hér",
    "Overview of shared files." : "Yfirlit yfir deildar skrár.",
    "No shares" : "Engar sameignir",
    "Files and folders you shared or have been shared with you will show up here" : "Skrár og möppur sem þú hefur deilt eða aðrir deila með þér birtast hér",
    "Shared with you" : "Deilt með þér",
    "List of files that are shared with you." : "Listi yfir skrár sem er deilt með þér.",
    "Nothing shared with you yet" : "Engu deilt með þér ennþá",
    "Files and folders others shared with you will show up here" : "Skrár og möppur sem aðrir hafa deilt með þér birtast hér",
    "List of files that you shared with others." : "Listi yfir skrár sem þú hefur deilt með öðrum.",
    "Nothing shared yet" : "Engu deilt ennþá",
    "Files and folders you shared will show up here" : "Skrár og möppur sem þú hefur deilt birtast hér",
    "Shared by link" : "Deilt með tengli",
    "List of files that are shared by link." : "Listi yfir skrár sem er deilt með tengli.",
    "No shared links" : "Engir sameignartenglar",
    "Files and folders you shared by link will show up here" : "Skrár og möppur sem þú hefur deilt í gegnum tengil birtast hér",
    "File requests" : "Beiðnir um skrár",
    "List of file requests." : "Listi yfir beiðnir um skrár.",
    "No file requests" : "Engar beiðnir um skrár",
    "File requests you have created will show up here" : "Beiðnir um skrár sem þú hefur útbúið munu birtast hér",
    "Deleted shares" : "Eyddar sameignir",
    "List of shares you left." : "Listi yfir sameignir sem þú hefur yfirgefið.",
    "No deleted shares" : "Engar eyddar sameignir",
    "Shares you have left will show up here" : "Sameignir sem þú hefur yfirgefið munu birtast hér",
    "Pending shares" : "Sameignir í bið",
    "List of unapproved shares." : "Listi yfir ósamþykktar sameignir.",
    "No pending shares" : "Engar sameignir í bið",
    "Shares you have received but not approved will show up here" : "Sameignir sem þú hefur fengið en ekki samþykkt munu birtast hér",
    "Error updating the share: {errorMessage}" : "Villa kom upp við að uppfæra sameignina: {errorMessage}",
    "Error updating the share" : "Villa við að uppfæra sameignina",
    "File \"{path}\" has been unshared" : "Skráin \"{path}\" hefur verið tekin úr deilingu",
    "Folder \"{path}\" has been unshared" : "Mappan \"{path}\" hefur verið tekin úr deilingu",
    "Could not update share" : "Gat ekki uppfært sameign",
    "Share saved" : "Sameign vistuð",
    "Share expiry date saved" : "Gildistími sameignar vistaður",
    "Share label saved" : "Merking sameignar vistuð",
    "Share note for recipient saved" : "Minnispunktur til viðtakanda sameignar vistaður",
    "Share password saved" : "Lykilorð sameignar vistað",
    "Share permissions saved" : "Heimildir sameignar vistaðar",
    "Upload files to {folder}" : "Senda skrár inn í {folder}",
    "{ownerDisplayName} shared a folder with you." : "{ownerDisplayName} deildi möppu með þér.",
    "Shared by" : "Deilt af",
    "Shared with" : "Deilt með",
    "Password created successfully" : "Tókst að búa til lykilorð",
    "Error generating password from password policy" : "Villa við að útbúa lykilorð út frá lykilorðastefnu",
    "Shared with you and the group {group} by {owner}" : "Deilt með þér og hópnum {group} af {owner}",
    "Shared with you and {circle} by {owner}" : "Deilt með þér og {circle} af {owner}",
    "Shared with you and the conversation {conversation} by {owner}" : "Deilt með þér og samtalinu {conversation} af {owner}",
    "Shared with you in a conversation by {owner}" : "Deilt með þér í samtali af {owner}",
    "Share not found" : "Sameign fannst ekki",
    "Back to %s" : "Til baka í %s",
    "Add to your Nextcloud" : "Bæta í þitt eigið Nextcloud",
    "Waiting…" : "Bíð…",
    "error" : "villa",
    "finished" : "lokið",
    "This will stop your current uploads." : "Þetta mun stöðva núverandi innsendingar þínar.",
    "Move or copy" : "Færa eða afrita",
    "You can upload into this folder" : "Þú getur sent inn skrár í þessa möppu",
    "Show list view" : "Birta listasýn",
    "Show grid view" : "Birta reitasýn",
    "No compatible server found at {remote}" : "Enginn samhæfður vefþjónn fannst á {remote}",
    "Invalid server URL" : "Ógild URI-slóð vefþjóns",
    "Failed to add the public link to your Nextcloud" : "Mistókst að bæta opinberum tengli í þitt eigið Nextcloud",
    "You are not allowed to edit link shares that you don't own" : "Þú hefur ekki heimild til að breyta tenglum á sameignir sem þú átt ekki.",
    "Download all files" : "Sækja allar skrár",
    "Link copied to clipboard" : "Tengill afritaður á klippispjald",
    "_1 email address already added_::_{count} email addresses already added_" : ["1 tölvupóstfangi þegar bætt við","{count} tölvupóstföngum þegar bætt við"],
    "_1 email address added_::_{count} email addresses added_" : ["1 tölvupóstfangi bætt við","{count} tölvupóstföngum bætt við"],
    "Copy to clipboard" : "Afrita á klippispjald",
    "Copy internal link to clipboard" : "Afrita innri tengil á klippispjald",
    "Only works for people with access to this folder" : "Virkar bara fyrir fólk sem hefur aðgang að þessari möppu",
    "Only works for people with access to this file" : "Virkar bara fyrir fólk sem hefur aðgang að þessari skrá",
    "Copy public link of \"{title}\" to clipboard" : "Afrita opinberan tengil \"{title}\" á klippispjald",
    "Search globally" : "Leita allstaðar",
    "Search for share recipients" : "Leita að viðtakendum sameignar",
    "No recommendations. Start typing." : "Engar tillögur. Byrjaðu að skrifa.",
    "To upload files, you need to provide your name first." : "Til að senda inn skrár þarftu fyrst að gefa upp nafnið þitt.",
    "Enter your name" : "Settu inn nafnið þitt",
    "Submit name" : "Nafn við innsendingu",
    "Share with {userName}" : "Deila með {userName}",
    "Show sharing options" : "Birta valkostir deilingar",
    "Share note" : "Deila minnispunkti",
    "Upload files to %s" : "Senda inn skrár á %s",
    "%s shared a folder with you." : "%s deildi möppu með þér.",
    "Note" : "Minnispunktur",
    "Select or drop files" : "Veldu eða slepptu skrám",
    "Uploading files" : "Sendi inn skrár",
    "Uploaded files:" : "Innsendar skrár:",
    "By uploading files, you agree to the %1$sterms of service%2$s." : "Með því að senda inn skrár, samþykkir þú %1$sþjónustuskilmálana%2$s.",
    "Name" : "Heiti",
    "Share with accounts and teams" : "Deila með notendaaðgöngum og teymum",
    "Email, federated cloud id" : "Tölvupóstfang, skýjasambandsauðkenni (Federated Cloud ID)",
    "Filename must not be empty." : "Skráarheiti má ekki vera tómt."
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
