OC.L10N.register(
    "provisioning_api",
    {
    "Logged in account must be an administrator or have authorization to edit this setting." : "Обліковий запису, з яким ви увійшли, має бути адміністративним або дозволи редагування цих налаштувань.",
    "Could not create non-existing user ID" : "Неможливо створити неіснуючого користувача ID",
    "User already exists" : "Користувач вже існує",
    "Group %1$s does not exist" : "Група %1$s не існує",
    "Insufficient privileges for group %1$s" : "Недостатні дозволи для групи %1$s",
    "No group specified (required for sub-admins)" : "Жодної групи не зазначено (потрібно для другорядних адміністраторів)",
    "Sub-admin group does not exist" : "Група другорядних адміністраторів не існує",
    "Cannot create sub-admins for admin group" : "Неможливо створити другорядних адміністраторів для групи адміністраторів",
    "No permissions to promote sub-admins" : "Відсутні дозволи для збільшення повноважень другорядних адміністраторів",
    "Invalid password value" : "Недійсне значення паролю",
    "An email address is required, to send a password link to the user." : "Для надсилання посилання на пароль користувачеві необхідна адреса електронної пошти.",
    "Required email address was not provided" : "Не зазначено обов'язкової ел. адреси",
    "User creation failed" : "Не вдалося створити користувача",
    "Invalid quota value: %1$s" : "Недійсне значення квоти: %1$s",
    "Invalid quota value. %1$s is exceeding the maximum quota" : "Недійсне значення квоти: %1$s перебільшує максимальну квоту",
    "Unlimited quota is forbidden on this instance" : "Необмежену квоту заборонено на цьому примірнику",
    "Setting the password is not supported by the users backend" : "Встановлення паролю не підтримується бекендом користувача",
    "Invalid language" : "Недійсний вибір мови",
    "Invalid locale" : "Недійсний вибір локалі",
    "Invalid first day of week" : "Недійсний перший день тижня",
    "Cannot remove yourself from the admin group" : "Неможливо вилучити себе із групи адміністраторів",
    "Cannot remove yourself from this group as you are a sub-admin" : "Неможливо вилучити себе із цієї групи, оскільки ви є другорядним адміністратором",
    "Not viable to remove user from the last group you are sub-admin of" : "Неможливо вилучити користувача з останньої групи, в якій ви є другорядним адміністратором",
    "User does not exist" : "Користувач не існує",
    "Group does not exist" : "Група не існує",
    "User is not a sub-admin of this group" : "Користувач не є другорядним адміністратором цієї групи",
    "Email address not available" : "Ел. адреса недоступна",
    "Sending email failed" : "Не вдалося надіслати ел. лист",
    "Email confirmation" : "Підтвердження електронною поштою",
    "To enable the email address %s please click the button below." : "Щоб увімкнути адресу електронної пошти %s, натисніть кнопку нижче.",
    "Confirm" : "Підтвердити",
    "Email was already removed from account and cannot be confirmed anymore." : "Електронну адресу вже видалено з облікового запису, і її більше неможливо підтвердити.",
    "Could not verify mail because the token is expired." : "Не вдалося перевірити пошту, оскільки термін дії токена минув.",
    "Could not verify mail because the token is invalid." : "Не вдалося перевірити пошту, оскільки токен не дійсний.",
    "An unexpected error occurred. Please contact your admin." : "Сталася неочікувана помилка. Будь ласка, зверніться до свого адміністратора.",
    "Email confirmation successful" : "Підтвердження електронною поштою успішно",
    "Provisioning API" : "API надання",
    "This application enables a set of APIs that external systems can use to manage accounts, groups and apps." : "Цей застосунок надає доступ до набору API, які можуть використовувати стоонні системи для керування обліковими записами, групами та застосунками.",
    "This application enables a set of APIs that external systems can use to create, edit, delete and query account\n\t\tattributes, query, set and remove groups, set quota and query total storage used in Nextcloud. Group admin accounts\n\t\tcan also query Nextcloud and perform the same functions as an admin for groups they manage. The API also enables\n\t\tan admin to query for active Nextcloud applications, application info, and to enable or disable an app remotely.\n\t\tOnce the app is enabled, HTTP requests can be used via a Basic Auth header to perform any of the functions\n\t\tlisted above. More information is available in the Provisioning API documentation, including example calls\n\t\tand server responses." : "Цей застосунок підтримує набір API, які зовнішні системи можуть використовувати для створення, редагування, видалення та запитів користувача атрибути, запит, встановлення та видалення груп, встановлення квоти та запит загального обсягу пам’яті, що використовується в Nextcloud. Адміністратори групи користувачів також можуть надсилати запити Nextcloud і виконувати ті самі функції, що й адміністратори, для груп, якими вони керують. API також дозволяє адміністраторам надсилати запити до активних застосунків Nextcloud, отримувати інформацію про застосунок та віддалено вмикати чи вимикати застосунок. Після увімкнення застосунку HTTP-запити можна використовувати через заголовок Basic Auth для виконання будь-яких функцій, які перераховано вище. Додаткову інформацію можна знайти в документації Provisioning API включно з прикладами викликів та відповідей сервера."
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
