<?php
/**
 * SPDX-FileCopyrightText: 2016 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */
return array (
  'williamfelipesantiago.santiago74' => true,
  'princessthatguywhowantssomething' => true,
  'peppergeorgefriedmancompaccounts' => true,
  'passf.e.rg.u.sma.n.i.van.o.v.ich' => true,
  'masterchubby_diago_girl123456789' => true,
  'edik.grigorev.90edik.grigorev.90' => true,
  'aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa' => true,
  '33333333333333333333333333333333' => true,
  '26067af27bb314ffbe8ba0528b907e31' => true,
);