OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Personal activity feed for %s",
    "Your feed URL is invalid" : "Your feed URL is invalid",
    "Activity feed for %1$s" : "Activity feed for %1$s",
    "Activity feed" : "Activity feed",
    "Your settings have been updated." : "Your settings have been updated.",
    "Settings have been updated." : "Settings have been updated.",
    "remote user" : "remote user",
    "Recent activity" : "Recent activity",
    "No activities" : "No activities",
    "More activities" : "More activities",
    "Daily activity summary for %s" : "Daily activity summary for %s",
    "_and %n more…_::_and %n more…_" : ["and %n more…","and %n more…"],
    "All activities" : "All activities",
    "By others" : "By others",
    "By you" : "By you",
    "Activity at %s" : "Activity at %s",
    "Hello %s" : "Hello %s",
    "Hello %s," : "Hello %s,",
    "There was some activity at %s" : "There was some activity at %s",
    "_and %n more _::_and %n more _" : ["and %n more","and %n more"],
    "Mail" : "Mail",
    "Push" : "Push",
    "Activity" : "Activity",
    "Notifications" : "Notifications",
    "This application enables people to view a log of activities about them, their files or other data." : "This application enables people to view a log of activities about them, their files or other data.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation.",
    "Send email" : "Send email",
    "Send push notification" : "Send push notification",
    "Activity notification configuration" : "Activity notification configuration",
    "Today" : "Today",
    "Yesterday" : "Yesterday",
    "You need to set up your email address before you can receive notification emails." : "You need to set up your email address before you can receive notification emails.",
    "Send activity emails" : "Send activity emails",
    "As soon as possible" : "As soon as possible",
    "Hourly" : "Hourly",
    "Daily" : "Daily",
    "Weekly" : "Weekly",
    "You commented" : "You commented",
    "Message deleted by author" : "Message deleted by author",
    "Open {filename}" : "Open {filename}",
    "in {path}" : "in {path}",
    "Home" : "Home",
    "Could not load activities" : "Could not load activities",
    "Loading activities" : "Loading activities",
    "This stream will show events like additions, changes & shares" : "This stream will show events like additions, changes & shares",
    "No activity yet" : "No activity yet",
    "Loading more activities" : "Loading more activities",
    "No more activities." : "No more activities.",
    "Could not enable RSS link" : "Could not enable RSS link",
    "RSS link copied to clipboard" : "RSS link copied to clipboard",
    "Could not copy the RSS link, please copy manually:" : "Could not copy the RSS link, please copy manually:",
    "Activity settings" : "Activity settings",
    "Enable RSS feed" : "Enable RSS feed",
    "RSS feed" : "RSS feed",
    "Copy RSS feed link" : "Copy RSS feed link",
    "Personal notification settings" : "Personal notification settings",
    "Unable to load the activity list" : "Unable to load the activity list",
    "Choose for which activities you want to get an email or push notification." : "Choose for which activities you want to get an email or push notification.",
    "Choose for which activities you want to get a push notification." : "Choose for which activities you want to get a push notification.",
    "Notification" : "Notification",
    "Enable notification emails" : "Enable notification emails",
    "Daily activity summary" : "Daily activity summary",
    "Send daily activity summary in the morning" : "Send daily activity summary in the morning",
    "Default settings" : "Default settings",
    "Configure the default notification settings for new accounts." : "Configure the default notification settings for new accounts.",
    "Unable to save the settings" : "Unable to save the settings",
    "No more events to load" : "No more events to load"
},
"nplurals=2; plural=(n != 1);");
