OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "Ugyldig ID for sammenknyttet sky",
    "Server to server sharing is not enabled on this server" : "Server til server deling er ikke aktivert på denne serveren",
    "Couldn't establish a federated share." : "Kunne ikke etablere en sammenknyttet ressurs",
    "Couldn't establish a federated share, maybe the password was wrong." : "Kunne ikke etablere en sammenknyttet ressurs, kanskje passordet var feil.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Sammenknyttet ressurs forespurt, du vil motta en invitasjon. Sjekk varslene dine.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Kunne ikke opprette en sammenknyttet deling, det ser ut til at serveren som skal forenes med er for gammel (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Det er ikke tillatt å sende sammenknyttede gruppedelinger fra denne serveren.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Deling av %1$s feilet, fordi dette elementet er allerede delt med kontoen %2$s",
    "Not allowed to create a federated share to the same account" : "Ikke tillatt å opprette en sammenknyttet deling til samme konto",
    "Federated shares require read permissions" : "Sammenknyttede delinger krever lesetillatelser",
    "File is already shared with %s" : "Filen er allerede delt med %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Deling av %1$s feilet, kunne ikke finne %2$s, kanskje serveren for øyeblikket ikke kan nås eller bruker et selvsignert sertifikat.",
    "Could not find share" : "Kunne ikke finne ressurs",
    "Federated sharing" : "Sammenknyttet deling",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Du har mottatt {share} som en ekstern deling fra {user} (på vegne av {behalf})",
    "You received {share} as a remote share from {user}" : "Du mottok {share} som en fjerndeling fra {user}",
    "Accept" : "Aksepter",
    "Decline" : "Avslå",
    "Federated Cloud Sharing" : "Sammenknyttet skydeling",
    "Sharing" : "Deling",
    "Federated file sharing" : "Sammenknyttet fildeling",
    "Provide federated file sharing across servers" : "Gi sammenknyttet fildeling på tvers av servere",
    "Unable to update federated files sharing config" : "Kan ikke oppdatere sammenknyttet fildelingskonfigurasjon",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Juster hvordan personer kan dele mellom servere. Dette inkluderer også delinger mellom personer på denne serveren hvis de bruker sammenknyttet deling.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Tillat personer på denne serveren å sende delinger til andre servere (dette alternativet gir også WebDAV-tilgang til delte fellesressurser)",
    "Allow people on this server to receive shares from other servers" : "Tillat personer på denne serveren å motta delinger fra andre servere",
    "Allow people on this server to send shares to groups on other servers" : "Tillat personer på denne serveren å sende delinger til grupper på andre servere",
    "Allow people on this server to receive group shares from other servers" : "Tillat personer på denne serveren å motta gruppedelinger fra andre servere",
    "Search global and public address book for people" : "Søk i global og offentlig adressebok etter personer",
    "Allow people to publish their data to a global and public address book" : "Tillat brukere å offentliggjøre deres data til en verdensomspennende og offentlig adressebok",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Del med meg gjennom min #Nextcloud ID for sammenknyttet sky, se {url}.",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Del med meg gjennom min #Nextcloud-ID for sammenknyttet sky",
    "Share with me via Nextcloud" : "Del med meg via Nextcloud",
    "Copy" : "Kopi",
    "Copied!" : "Kopiert!",
    "Federated Cloud" : "Sammenknyttet sky",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Du kan dele med alle som bruker en Nextcloud-server eller andre Open Cloud Mesh (OCM)-kompatible servere og tjenester! Bare legg inn deres ID for sammenknyttet sky i delingsdialogen. Det ser ut som person@cloud.example.com.",
    "Share it so your friends can share files with you:" : "Del den slik at venner kan dele filer med deg:",
    "Facebook" : "Facebook",
    "X (formerly Twitter)" : "X (tidligere Twitter)",
    "Mastodon" : "Mastodont",
    "Add to your website" : "Legg på nettsiden din",
    "HTML Code:" : "HTML-kode:",
    "Cancel" : "Avbryt",
    "Add remote share" : "Legg til ekstern ressurs",
    "Remote share" : "Ekstern ressurs",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Ønsker du å legge til ekstern ressurs {name} fra {owner}@{remote}?",
    "Remote share password" : "Passord for ekstern ressurs",
    "Cloud ID copied to the clipboard" : "Sky-ID kopiert til utklippstavlen",
    "Copy to clipboard" : "Kopiert til utklippstavlen"
},
"nplurals=2; plural=(n != 1);");
