OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "Nevažeći ID udruženog oblaka",
    "Server to server sharing is not enabled on this server" : "Dijeljenje između poslužitelja nije omogućeno na ovom poslužitelju",
    "Couldn't establish a federated share." : "Nije moguće uspostaviti udruženo dijeljenje.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Nije moguće uspostaviti udruženo dijeljenje, možda je pogrešna zaporka.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Poslan je zahtjev za udruženo dijeljenje i primit ćete poziv. Provjerite svoje obavijesti.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Nije moguće uspostaviti udruženo dijeljenje, čini se da je poslužitelj s kojim se udružuje prestar (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Nije dopušteno slanje udruženih grupnih dijeljenja s ovog poslužitelja.",
    "Federated shares require read permissions" : "Udružena dijeljenja zahtjevaju dopuštenja za čitanje",
    "File is already shared with %s" : "Datoteka je već dijeljena s %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Dijeljenje %1$s nije uspjelo, nije bilo moguće pronaći %2$s, možda je poslužitelj trenutno nedostupan ili koristi vjerodajnicu koju je sam potpisao.",
    "Could not find share" : "Nije moguće pronaći dijeljenje",
    "Federated sharing" : "Udruženo dijeljenje",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Primili ste {share} kao udaljeno dijeljenje od {user} (u ime {behalf})",
    "You received {share} as a remote share from {user}" : "Primili ste {share} kao udaljeno dijeljenje od {user}",
    "Accept" : "Prihvati",
    "Decline" : "Odbij",
    "Federated Cloud Sharing" : "Dijeljenje putem udruženog oblaka",
    "Sharing" : "Dijeljenje",
    "Federated file sharing" : "Udruženo dijeljenje datoteka",
    "Provide federated file sharing across servers" : "Omogućite udruženo dijeljenje datoteka između poslužitelja",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Dijeli sa mnom putem mog #ID-ja udruženog oblaka Nextclouda",
    "Share with me via Nextcloud" : "Dijelite sa mnom putem Nextclouda",
    "Copy" : "Kopirajte",
    "Copied!" : "Kopirano!",
    "Federated Cloud" : "Udruženi oblak",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Možete dijeliti sa svima koji upotrebljavaju poslužitelj Nextcloud ili druge poslužitelje i usluge kompatibilne s Open Cloud Mesh (OCM)! Samo unesite njihov Federated Cloud ID u dijaloški okvir za dijeljenje. Primjerice: osoba@cloud.example.com",
    "Share it so your friends can share files with you:" : "Dijelite ga kako bi vaši prijatelji mogli dijeliti datoteke s vama:",
    "Mastodon" : "Mastodon",
    "Add to your website" : "Dodajte na svoje web-mjesto",
    "HTML Code:" : "HTML kod:",
    "Cancel" : "Odustani",
    "Add remote share" : "Dodaj udaljeno dijeljenje",
    "Remote share" : "Udaljeno dijeljenje",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Želite li dodati udaljeni udjel {name} od {owner} u {remote}?",
    "Remote share password" : "Zaporka za udaljeno dijeljenje",
    "Copy to clipboard" : "Kopiraj u međuspremnik"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
