OC.L10N.register(
    "serverinfo",
    {
    "Copied!" : "Хуулсан!",
    "Not supported!" : "Дэмжигдэхгүй",
    "Press ⌘-C to copy." : "Хуулахын тулд ⌘-C дарна уу.",
    "Press Ctrl-C to copy." : "Хуулахын тулд Ctrl-C дарна уу.",
    "System" : "сисмем",
    "Monitoring" : "Хяналт",
    "Size:" : "Хэмжээ:",
    "Files:" : "Файлууд:",
    "Active users" : "Идэвхтэй хэрэглэгчид",
    "Shares" : "Түгээлтүүд",
    "Users:" : "Хэрэглэгчид:",
    "PHP" : "PHP",
    "Version:" : "Хувилбар:",
    "Database" : "Өгөгдлийн сан",
    "Type:" : "Төрөл:",
    "Copy" : "Хуулах"
},
"nplurals=2; plural=(n != 1);");
