OC.L10N.register(
    "recommendations",
    {
    "Recommended files" : "Berkas yang direkomendasikan",
    "Shows recommended files" : "Tampilkan berkas yang direkomendasikan",
    "Show recommendations" : "Tampilkan rekomendasi",
    "Recently edited" : "Baru saja diedit"
},
"nplurals=1; plural=0;");
