OC.L10N.register(
    "files_sharing",
    {
    "File shares" : "Обмен файлами",
    "Downloaded via public link" : "Скачано по общедоступной ссылке",
    "Downloaded by {email}" : "Скачано {email}",
    "{file} downloaded via public link" : "«{file}» скачан по общедоступной ссылке",
    "{email} downloaded {file}" : "{email} скачал(а) «{file}»",
    "Shared with group {group}" : "Предоставлен доступ группе «{group}»",
    "Removed share for group {group}" : "Закрыт доступ группе «{group}»",
    "{actor} shared with group {group}" : "{actor} предоставил(а) доступ группе «{group}»",
    "{actor} removed share for group {group}" : "{actor} закрыл(а) доступ группе «{group}»",
    "Share for group {group} expired" : "Срок действия общего доступа для группы «{group}» истек",
    "You shared {file} with group {group}" : "Вы предоставили группе «{group}» доступ к «{file}»",
    "You removed group {group} from {file}" : "Вы закрыли группе «{group}» доступ к «{file}»",
    "{actor} shared {file} with group {group}" : "{actor} предоставил(а) группе «{group}» доступ к «{file}»",
    "{actor} removed group {group} from {file}" : "{actor} закрыл(а) группе «{group}» доступ к «{file}»",
    "Share for file {file} with group {group} expired" : "Срок действия общего доступа к «{file}» для группы «{group}» истек",
    "Shared as public link" : "Предоставлен доступ общедоступной ссылкой",
    "Removed public link" : "Общедоступная ссылка удалена",
    "Public link expired" : "Истёк срок действия общедоступной ссылки",
    "{actor} shared as public link" : "{actor} открыл(а) общий доступ созданием общедоступной ссылки",
    "{actor} removed public link" : "{actor} удалил(а) общедоступную ссылку",
    "Public link of {actor} expired" : "Истёк срок действия общедоступной ссылки пользователя {actor}",
    "You shared {file} as public link" : "Вы предоставили общий доступ к «{file}» созданием общедоступной ссылки",
    "You removed public link for {file}" : "Вы удалили общедоступную ссылку на «{file}»",
    "Public link expired for {file}" : "Истёк срок действия общедоступной ссылки на «{file}»",
    "{actor} shared {file} as public link" : "{actor} предоставил(а) общий доступ к «{file}» созданием общедоступной ссылки",
    "{actor} removed public link for {file}" : "{actor} удалил(а) общедоступную ссылку на «{file}»",
    "Public link of {actor} for {file} expired" : "Истёк срок действия общедоступной ссылки на «{file}», созданной {actor}.",
    "{user} accepted the remote share" : "{user} принял(а) общий ресурс с другого сервера",
    "{user} declined the remote share" : "{user} отклонил(а) общий ресурс с другого сервера",
    "You received a new remote share {file} from {user}" : "Вы получили от {user} новый общий ресурс «{file}», расположенный на другом сервере",
    "{user} accepted the remote share of {file}" : "{user} принял(а) доступ к ресурсу «{file}», расположенному на другом сервере",
    "{user} declined the remote share of {file}" : "{user} отклонил(а) доступ к ресурсу «{file}», расположенному на другом сервере",
    "{user} unshared {file} from you" : "{user} закрыл(а) вам доступ к «{file}»",
    "Shared with {user}" : "Открыт общий доступ пользователю {user}",
    "Removed share for {user}" : "Закрыт общий доступ пользователю {user}",
    "You removed yourself" : "Вы закрыли себе доступ ",
    "{actor} removed themselves" : "{actor} закрыл(а) себе доступ",
    "{actor} shared with {user}" : "{actor} поделился(ась) с пользователем {user}",
    "{actor} removed share for {user}" : "{actor} закрыл(а) общий доступ пользователю {user}",
    "Shared by {actor}" : "Общий доступ предоставлен пользователем {actor}",
    "{actor} removed share" : "{actor} закрыл(а) общий доступ",
    "Share for {user} expired" : "Срок действия общего доступа для пользователя {user} истек",
    "Share expired" : "Срок действия общего доступа истек",
    "You shared {file} with {user}" : "Вы предоставили пользователю {user} общий доступ к «{file}»",
    "You removed {user} from {file}" : "Вы закрыли пользователю {user} общий доступ к «{file}»",
    "You removed yourself from {file}" : "Вы закрыли себе доступ к «{file}»",
    "{actor} removed themselves from {file}" : "{actor} закрыл(а) себе доступ к «{file}»",
    "{actor} shared {file} with {user}" : "{actor} предоставил(а) пользователю {user} общий доступ к «{file}»",
    "{actor} removed {user} from {file}" : "{actor} закрыл(а) пользователю {user} общий доступ к «{file}»",
    "{actor} shared {file} with you" : "{actor} предоставил(а) вам общий доступ к «{file}»",
    "{actor} removed you from the share named {file}" : "{actor} закрыл(а) вам общий доступ к общим именам «{file}»",
    "Share for file {file} with {user} expired" : "Срок действия общего доступа к «{file}» для пользователя {user} истек",
    "Share for file {file} expired" : "Срок действия общего доступа к «{file}» истек",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "<strong>Скачаны</strong> файлы или папки, доступ к которым был предоставлен по электронной почте или общедоступной ссылке",
    "Files have been <strong>uploaded</strong> to a folder shared by mail or by public link" : "Файлы были <strong>загружены </strong>в папку, расшаренную по почте или по публичной ссылке",
    "A file or folder was shared from <strong>another server</strong>" : "Общий доступ к файлу или каталогу предоставлен <strong>с другого сервера</strong>",
    "Sharing" : "Общий доступ",
    "A file or folder has been <strong>shared</strong>" : "Файл или каталог <strong>опубликован</strong>",
    "Shared link" : "Общая ссылка",
    "Wrong share ID, share does not exist" : "Неправильный идентификатор ресурса, ресурс не существует",
    "Could not delete share" : "Не удалось удалить общий ресурс",
    "Please specify a file or folder path" : "Укажите путь к файлу или каталогу",
    "Wrong path, file/folder does not exist" : "Неверный путь, файл или каталог не существует",
    "Could not create share" : "Не удалось создать общий ресурс",
    "Please specify a valid account to share with" : "Пожалуйста, укажите действительную учетную запись, к которой вы хотите предоставить доступ",
    "Group sharing is disabled by the administrator" : "Возможность делиться с группами отключена администратором",
    "Please specify a valid group" : "Укажите верную группу",
    "Public link sharing is disabled by the administrator" : "Возможность предоставления общего доступа созданием общедоступных ссылок отключена администратором",
    "Please specify a valid email address" : "Пожалуйста, укажите действительный адрес электронной почты",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Не удалось отправить пароль для доступа к «%s»: приложение Nextcloud Talk отключено.",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "Не удалось предоставить общий доступ к  «%1$s», поскольку механизм удалённого обмена не разрешает публикации типа %2$s",
    "Please specify a valid federated account ID" : "Пожалуйста, укажите действительный идентификатор федеративной учетной записи",
    "Please specify a valid federated group ID" : "Укажите действительный идентификатор федеративной группы",
    "You cannot share to a Team if the app is not enabled" : "Вы не сможете поделиться информацией с командой, если приложение не включено",
    "Please specify a valid team" : "Пожалуйста, укажите действующую команду",
    "Sharing %s failed because the back end does not support room shares" : "Не удалось предоставить общий доступ к  «%s» поскольку механизм обмена не поддерживает общий доступ такого типа",
    "Sharing %s failed because the back end does not support ScienceMesh shares" : "Не удалось предоставить общий доступ к  «%s» поскольку механизм обмена не поддерживает общие ресурсы типа ScienceMesh",
    "Unknown share type" : "Общий доступ неизвестного типа",
    "Not a directory" : "Это не каталог",
    "Could not lock node" : "Не удалось заблокировать узел",
    "Public upload is only possible for publicly shared folders" : "Общедоступная выгрузка возможна только в общедоступные папки",
    "Share must at least have READ or CREATE permissions" : "Общий ресурс должен, по крайней мере, иметь разрешения READ или CREATE",
    "Share must have READ permission if UPDATE or DELETE permission is set" : "Общий ресурс должен иметь разрешение READ, если установлено разрешение UPDATE или DELETE",
    "Public upload disabled by the administrator" : "Выгрузка в общедоступную папку запрещена администратором",
    "Could not lock path" : "Не удалось заблокировать путь",
    "no sharing rights on this item" : "нет прав на распространение этого элемента",
    "You are not allowed to edit incoming shares" : "Вам не разрешается редактировать входящие общие материалы",
    "Wrong or no update parameter given" : "Параметр для изменения неправилен или не задан",
    "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled." : "Не удалось отправить пароль для доступа, так как приложение Nextcloud Talk отключено.",
    "Custom share link tokens have been disabled by the administrator" : "Пользовательские токены ссылок общего доступа были отключены администратором",
    "Tokens must contain at least 1 character and may only contain letters, numbers, or a hyphen" : "Токены должны содержать не менее 1 символа и могут содержать только буквы, цифры или дефис",
    "Invalid date. Format must be YYYY-MM-DD" : "Неверная дата. Формат должен быть ГГГГ-ММ-ДД",
    "No sharing rights on this item" : "Нет прав на распространение этого элемента",
    "Invalid share attributes provided: \"%s\"" : "Предоставлены недопустимые атрибуты общего доступа: \"%s\"",
    "You are not allowed to send mail notifications" : "Вам не разрешено отправлять уведомления по почте",
    "No mail notification configured for this share type" : "Для этого типа общего доступа не настроено почтовое уведомление",
    "Wrong password" : "Неверный пароль",
    "Error while sending mail notification" : "Ошибка при отправке почтового уведомления",
    "Failed to generate a unique token" : "Не удалось сгенерировать уникальный токен",
    "This share does not exist or is no longer available" : "Этот общий ресурс отсутствует или недоступен",
    "shared by %s" : "доступ предоставлен пользователем %s",
    "Download" : "Скачать",
    "Add to your %s" : "Добавить в свой %s",
    "Direct link" : "Прямая ссылка",
    "Share API is disabled" : "API общего доступа отключён",
    "File sharing" : "Обмен файлами",
    "Share will expire tomorrow" : "Завтра истекает срок публикации",
    "Your share of {node} will expire tomorrow" : "Завтра истекает срок публикации вашего общего ресурса {node}",
    "You received {share} as a share by {user}" : "Вы получили доступ к {share} от {user}",
    "You received {share} to group {group} as a share by {user}" : "Вы получили от {user} доступ к ресурсу {share}, предназначенный группе {group}",
    "Accept" : "Принять",
    "Decline" : "Отклонить",
    "Remember to upload the files to %s" : "Не забудьте загрузить файлы на %s",
    "We would like to kindly remind you that you have not yet uploaded any files to the shared folder." : "Напоминаем вам, что вы еще не загрузили ни одного файла в общую папку.",
    "Open \"%s\"" : "Открыть \"%s\"",
    "This application enables people to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable people can then share files and folders with other accounts and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other people outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation." : "Это приложение позволяет пользователям обмениваться файлами в Nextcloud. Если оно включено, администратор может выбирать, какие группы могут обмениваться файлами. Соответствующие пользователи могут обмениваться файлами и папками с другими учетными записями и группами в Nextcloud. Кроме того, если администратор активирует функцию \"Поделиться ссылкой\", можно использовать внешнюю ссылку для обмена файлами с другими пользователями за пределами Nextcloud. Администраторы также могут устанавливать пароли, даты истечения срока действия и разрешать общий доступ с сервера на сервер с помощью общих ссылок, а также с мобильных устройств.\nПри отключении этой функции удаляются общие файлы и папки на сервере для всех получателей общего доступа, а также на клиентах синхронизации и в мобильных приложениях. Дополнительная информация доступна в документации Nextcloud.",
    "People" : "Люди",
    "Filter accounts" : "Фильтровать аккаунты",
    "The request will expire on {date} at midnight and will be password protected." : "Срок действия запроса истекает {date} в полночь, и он будет защищен паролем.",
    "The request will expire on {date} at midnight." : "Срок действия запроса истекает {date} в полночь.",
    "The request will be password protected." : "Запрос будет защищен паролем.",
    "When should the request expire?" : "Когда истекает срок действия запроса?",
    "Set a submission expiration date" : "Установите дату истечения срока действия заявки",
    "Expiration date" : "Срок действия",
    "Select a date" : "Выберите дату",
    "Your administrator has enforced a {count} days expiration policy." : "Ваш администратор ввел в действие {count} политику истечения срока действия дней.",
    "What password should be used for the request?" : "Какой пароль следует использовать для запроса?",
    "Set a password" : "Задать пароль",
    "Password" : "Пароль",
    "Enter a valid password" : "Введите действительный пароль",
    "Generate a new password" : "Сгенерируйте новый пароль",
    "Your administrator has enforced a password protection." : "Ваш администратор ввел в действие защиту паролем.",
    "Automatically copying failed, please copy the share link manually" : "Не удалось выполнить автоматическое копирование, пожалуйста, скопируйте ссылку для обмена вручную",
    "Link copied" : "Ссылка скопирована",
    "Email already added" : "Адрес электронной почты уже добавлен",
    "Invalid email address" : "Неверный адрес электронной почты",
    "_The following email address is not valid: {emails}_::_The following email addresses are not valid: {emails}_" : ["Следующий адрес электронной почты недействителен: {emails}","Следующие адреса электронной почты недействительны: {emails}","Следующие адреса электронной почты недействительны: {emails}","Следующие адреса электронной почты недействительны: {emails}"],
    "_{count} email address already added_::_{count} email addresses already added_" : [" {count} e-mail адрес уже добавлен"," {count} e-mail адреса уже добавлено"," {count} e-mail адресов уже добавлены","{count} e-mail адресов уже добавлены"],
    "_{count} email address added_::_{count} email addresses added_" : ["Добавлен {count} адрес электронной почты","Добавлено {count} адреса электронной почты","Добавлено {count} адресов электронной почты","Добавлено {count} адресов электронной почты"],
    "You can now share the link below to allow people to upload files to your directory." : "Теперь вы можете поделиться приведенной ниже ссылкой, чтобы люди могли загружать файлы в ваш каталог.",
    "Share link" : "Общий доступ по ссылке",
    "Copy" : "Копировать",
    "Send link via email" : "Отправить ссылку по электронной почте",
    "Enter an email address or paste a list" : "Введите адрес электронной почты или вставьте список",
    "Remove email" : "Удалить электронную почту",
    "Select a destination" : "Выберите пункт назначения",
    "Select" : "Выбрать",
    "What are you requesting?" : "О чем вы просите?",
    "Request subject" : "Тема запроса",
    "Birthday party photos, History assignment…" : "Фотографии с дня рождения, задание по истории…",
    "Where should these files go?" : "Куда должны быть отправлены эти файлы?",
    "Upload destination" : "Пункт назначения загрузки",
    "Revert to default" : "Вернуться к значению по умолчанию",
    "The uploaded files are visible only to you unless you choose to share them." : "Загруженные файлы видны только вам, если вы не решите поделиться ими.",
    "Add a note" : "Добавить заметку",
    "Note for recipient" : "Записка для получателя",
    "Add a note to help people understand what you are requesting." : "Добавьте примечание, чтобы помочь людям понять, о чем вы просите.",
    "You can add links, date or any other information that will help the recipient understand what you are requesting." : "Вы можете добавить ссылки, дату или любую другую информацию, которая поможет получателю понять, что вы запрашиваете.",
    "Close" : "Закрыть",
    "_Send email and close_::_Send {count} emails and close_" : ["Отправить письмо и закрыть","Отправить {count} письма и закрыть","Отправить {count} писем и закрыть","Отправить {count} писем и закрыть"],
    "Please select a folder, you cannot share the root directory." : "Пожалуйста, выберите папку, вы не можете предоставить общий доступ к корневому каталогу.",
    "File request created" : "Создан запрос на файл",
    "_File request created and email sent_::_File request created and {count} emails sent_" : ["Создан запрос файла и отправлено письмо","Создан запрос файла и отправлено {count} письма","Создан запрос файла и отправлено {count} писем","Создан запрос файла и отправлено {count} писем"],
    "Error creating the share: {errorMessage}" : "Не удалось создать общий ресурс: {errorMessage}",
    "Error creating the share" : "Ошибка создания общего доступа",
    "Error sending emails: {errorMessage}" : "Ошибка при отправке электронных писем: {errorMessage}",
    "Error sending emails" : "Ошибка при отправке электронных писем",
    "Create a file request" : "Создать запрос на файл",
    "Collect files from others even if they do not have an account." : "Собирайте файлы у других пользователей, даже если у них нет учетной записи.",
    "To ensure you can receive files, verify you have enough storage available." : "Чтобы убедиться, что вы можете получать файлы, убедитесь, что у вас достаточно свободного места для хранения.",
    "File request" : "Запрос файла",
    "Previous step" : "Предыдущий шаг",
    "Cancel" : "Отменить",
    "Cancel the file request creation" : "Отменить создание запроса на файл",
    "Close without sending emails" : "Закрыть без отправки электронных писем",
    "Continue" : "Продолжить",
    "Error while toggling options" : "Ошибка изменения параметров",
    "Accept shares from other accounts and groups by default" : "По умолчанию принимать общий доступ от других учетных записей и групп.",
    "Choose a default folder for accepted shares" : "Выберите папку для принятых опубликованных ресурсов",
    "Invalid path selected" : "Выбран некорректный путь",
    "Unknown error" : "Неизвестная ошибка",
    "Set default folder for accepted shares" : "Задать папку для принятых опубликованных ресурсов",
    "Reset" : "Сброс",
    "Reset folder to system default" : "Сбросить папку к значениям по умолчанию",
    "Share expiration: {date}" : "Срок действия общего ресурса: {date}",
    "Share Expiration" : "Срок действия общего ресурса",
    "group" : "группа",
    "conversation" : "беседа",
    "remote" : "на другом сервере",
    "remote group" : "группа на другом сервере",
    "guest" : "Гость",
    "by {initiator}" : "{initiator}",
    "Shared with the group {user} by {owner}" : "{owner} предоставил(а) доступ группе {user}",
    "Shared with the conversation {user} by {owner}" : "Пользователь {owner} предоставил(а) {user} доступ во время беседы",
    "Shared with {user} by {owner}" : "{owner} предоставил(а) доступ {user} ",
    "Open Sharing Details" : "Подробные сведения об общем ресурсе",
    "Added by {initiator}" : "Добавлено пользователем {initiator}",
    "Via “{folder}”" : "Через «{folder}»",
    "Unshare" : "Закрыть доступ",
    "Cannot copy, please copy the link manually" : "Не удалось скопировать, выполните копирование вручную",
    "Copy internal link" : "Копировать внутреннюю ссылку",
    "Internal link" : "Внутренняя ссылка",
    "{shareWith} by {initiator}" : "{shareWith} предоставлено {initiator}",
    "Shared via link by {initiator}" : "{initiator} предоставил(а) доступ по ссылке",
    "File request ({label})" : "Запрос файла ({label})",
    "Mail share ({label})" : "Отправка почты ({label})",
    "Share link ({label})" : "Ссылка общего доступа ({label})",
    "Mail share" : "Общий доступ к почте",
    "Share link ({index})" : "Ссылка общего доступа ({index})",
    "Create public link" : "Создать общедоступную ссылку",
    "Actions for \"{title}\"" : "Действия над «{title}»",
    "Error, please enter proper password and/or expiration date" : "Введите действительный пароль и/или дату истечения",
    "Link share created" : "Ссылка создана",
    "Error while creating the share" : "Не удалось создать общий ресурс",
    "Please enter the following required information before creating the share" : "Для создания общего ресурса требуется указать следующие данные",
    "Password protection (enforced)" : "Защита паролем (требуется системной)",
    "Password protection" : "Защита паролем",
    "Enter a password" : "Введите пароль",
    "Enable link expiration (enforced)" : "Включить истечение срока действия ссылки (принудительно)",
    "Enable link expiration" : "Включить истечение срока действия ссылки",
    "Enter expiration date (enforced)" : "Введите дату истечения срока действия (принудительно)",
    "Enter expiration date" : "Введите дату истечения срока действия",
    "Create share" : "Создать общий ресурс",
    "Customize link" : "Индивидуальная ссылка",
    "Generate QR code" : "Сгенерировать QR-код",
    "Add another link" : "Добавить другую ссылку",
    "Create a new share link" : "Создать ссылку доступа",
    "Quick share options, the current selected is \"{selectedOption}\"" : "Параметры быстрого обмена, выбранный в данный момент \"{selectedOption}\"",
    "View only" : "Для просмотра",
    "Can edit" : "Можно редактировать",
    "Custom permissions" : "Пользовательские права доступа",
    "Resharing is not allowed" : "Повторное открытие доступа запрещено",
    "Name or email …" : "Имя или адрес эл.почты…",
    "Name, email, or Federated Cloud ID …" : "Имя или ID межсерверного обмена…",
    "Searching …" : "Поиск…",
    "No elements found." : "Ничего не найдено.",
    "Search everywhere" : "Искать везде",
    "Guest" : "Гость",
    "Group" : "Группа",
    "Email" : "Электронная почта",
    "Team" : "Команда",
    "Talk conversation" : "Название обсуждения",
    "Deck board" : "Доска",
    "ScienceMesh" : "ScienceMesh",
    "on {server}" : "на {server}",
    "Enter external recipients" : "Введите внешних получателей",
    "Search for internal recipients" : "Поиск внутренних получателей",
    "Note from" : "Примечание от",
    "Note:" : "Примечание:",
    "File drop" : "Приём файлов",
    "Upload files to {foldername}." : "Загрузка файлов в {foldername}.",
    "By uploading files, you agree to the terms of service." : "Загружая файлы, вы соглашаетесь с условиями обслуживания.",
    "Successfully uploaded files" : "Файлы успешно загружены",
    "View terms of service" : "Ознакомиться с условиями предоставления услуг",
    "Terms of service" : "Условия использования",
    "Share with email {email}" : "Поделитесь с помощью электронной почты",
    "Share with group" : "Поделиться с группой",
    "Share in conversation" : "Поделиться в чате",
    "Share with {user} on remote server {server}" : "Поделиться с {user} на удаленном сервере {server}",
    "Share with remote group" : "Поделиться с удалённой группой",
    "Share with guest" : "Поделиться с гостем",
    "Update share" : "Обновить общий ресурс",
    "Save share" : "Сохранить общий ресурс",
    "Read" : "Прочитать",
    "Create" : "Создать",
    "Edit" : "Редактировать",
    "Share" : "Поделиться",
    "Delete" : "Удалить",
    "Password field cannot be empty" : "Поле пароля не может быть пустым",
    "Replace current password" : "Заменить текущий пароль",
    "Failed to generate a new token" : "Не удалось сгенерировать новый токен",
    "Allow upload and editing" : "Разрешить приём и редактирование",
    "Allow editing" : "Разрешить редактирование",
    "Upload only" : "Только загружать",
    "Advanced settings" : "Расширенные параметры",
    "Share label" : "Метка общего доступа",
    "Share link token" : "Токен ссылки на общий ресурс",
    "Set the public share link token to something easy to remember or generate a new token. It is not recommended to use a guessable token for shares which contain sensitive information." : "Установите простой для запоминания токен ссылки на общий ресурс или сгенерируйте новый. Не рекомендуется использовать легко угадываемые токены для общих ресурсов с конфиденциальной информацией.",
    "Generating…" : "Создание…",
    "Generate new token" : "Создать новый токен",
    "Set password" : "Задать пароль",
    "Password expires {passwordExpirationTime}" : "Срок действия пароля истекает {passwordExpirationTime}",
    "Password expired" : "Срок действия пароля истёк",
    "Video verification" : "Подтверждение по видесвязи",
    "Expiration date (enforced)" : "Срок действия (требуется системой)",
    "Set expiration date" : "Установить срок действия",
    "Hide download" : "Скрыть загрузку",
    "Allow download and sync" : "Разрешить загрузку и синхронизацию",
    "Note to recipient" : "Примечание для получателя",
    "Enter a note for the share recipient" : "Введите примечание для получателя",
    "Show files in grid view" : "Показать файлы в виде сетки",
    "Delete share" : "Удалить общий ресурс",
    "Others with access" : "Другие пользователи, имеющие доступ",
    "No other accounts with access found" : "Других учетных записей с доступом не найдено",
    "Toggle list of others with access to this directory" : "Свернуть или развернуть список пользователей, имеющих доступ к этой папке",
    "Toggle list of others with access to this file" : "Свернуть или развернуть список пользователей, имеющих доступ к этому файлу",
    "Unable to fetch inherited shares" : "Невозможно получить список унаследованных общих ресурсов ",
    "Link shares" : "Общие ссылки",
    "Shares" : "Опубликованные ресурсы",
    "Unable to load the shares list" : "Невозможно загрузить список общих ресурсов",
    "Expires {relativetime}" : "Истекает {relativetime}",
    "this share just expired." : "срок действия этого общего ресурса только что истёк.",
    "Shared with you by {owner}" : "{owner} предоставил(а) Вам доступ",
    "Internal shares" : "Внутренние ссылки",
    "Internal shares explanation" : "Пояснение к внутренним общим ресурсам",
    "External shares" : "Внешние ссылки",
    "External shares explanation" : "Пояснение к внешним общим ресурсам",
    "Additional shares" : "Дополнительные ссылки",
    "Additional shares explanation" : "Пояснение к дополнительным общим ресурсам",
    "Link to a file" : "Ссылка на файл",
    "_Accept share_::_Accept shares_" : ["Принять общий ресурс","Принять общие ресурсы","Принять общие ресурсы","Принять общие ресурсы"],
    "Open in Files" : "Открыть в Файлах",
    "_Reject share_::_Reject shares_" : ["Отклонить общий ресурс","Отклонить общие ресурсы","Отклонить общие ресурсы","Отклонить общие ресурсы"],
    "_Restore share_::_Restore shares_" : ["Восстановить общий ресурс","Восстановить общие ресурсы","Восстановить общие ресурсы","Восстановить общие ресурсы"],
    "Shared" : "Опубликованное",
    "Shared by {ownerDisplayName}" : "Доступно пользователю {ownerDisplayName}",
    "Shared multiple times with different people" : "Делиться несколько раз с разными людьми",
    "Shared with others" : "Доступные для других",
    "Create file request" : "Запрос на создание файла",
    "Upload files to {foldername}" : "Загружать файлы в {foldername}",
    "Public file share" : "Общий доступ к файлам",
    "Publicly shared file." : "Общедоступный файл.",
    "No file" : "Нет файла",
    "The file shared with you will show up here" : "Файл, которым вы поделились, появится здесь",
    "Public share" : "Общедоступные ссылки",
    "Publicly shared files." : "Общедоступные файлы.",
    "No files" : "Нет файлов",
    "Files and folders shared with you will show up here" : "Здесь будут отображаться файлы и папки, которыми с вами поделились.",
    "Overview of shared files." : "Предпросмотр общих файлов.",
    "No shares" : "Нет ресурсов общего доступа",
    "Files and folders you shared or have been shared with you will show up here" : "Файлы и папки, которыми вы поделились или к которым Вам был предоставлен доступ, будут отображаться здесь",
    "Shared with you" : "Предоставленные вам",
    "List of files that are shared with you." : "Список файлов, к которым Вам был предоставлен доступ.",
    "Nothing shared with you yet" : "С вами пока ничем не поделились",
    "Files and folders others shared with you will show up here" : "Файлы и каталоги, к которым вам предоставят общий доступ, будут отображаться здесь",
    "List of files that you shared with others." : "Список файлов, которыми Вы поделились.",
    "Nothing shared yet" : "Пока ничего не опубликовано",
    "Files and folders you shared will show up here" : "Здесь появятся файлы и каталоги, к которым вы предоставили общий доступ",
    "Shared by link" : "Доступные по ссылке",
    "List of files that are shared by link." : "Список файлов, к которым был предоставлен доступ по ссылке.",
    "No shared links" : "Нет общедоступных ссылок",
    "Files and folders you shared by link will show up here" : "Здесь появятся файлы и каталоги, ссылкой на которые вы поделитесь",
    "File requests" : "Запросы файлов",
    "List of file requests." : "Список запросов к файлам.",
    "No file requests" : "Никаких запросов файлов",
    "File requests you have created will show up here" : "Здесь будут отображаться созданные вами запросы на файлы",
    "Deleted shares" : "Удалённые общие ресурсы",
    "List of shares you left." : "Список ресурсов общего доступа от которых Вы отказались.",
    "No deleted shares" : "Удалённые ресурсы отсуствуют",
    "Shares you have left will show up here" : "Здесь будут показаны общие ресурсы от которых Вы отказались",
    "Pending shares" : "Ожидающие подтверждения",
    "List of unapproved shares." : "Список ресурсов общего доступа, которые вы еще не приняли",
    "No pending shares" : "Ожидающие общие ресурсы отсуствуют",
    "Shares you have received but not approved will show up here" : "Здесь появятся ресурсы общего доступа, которые Вам предоставлены, но еще не подтверждены с Вашей стороны",
    "Error deleting the share: {errorMessage}" : "Ошибка при удалении общего ресурса: {errorMessage}",
    "Error deleting the share" : "Ошибка прекращения общего доступа",
    "Error updating the share: {errorMessage}" : "Не удалось изменить общий ресурс: {errorMessage}",
    "Error updating the share" : "Ошибка изменения параметров общего доступа",
    "File \"{path}\" has been unshared" : "Закрыт общий доступ к файлу «{path}»",
    "Folder \"{path}\" has been unshared" : "Закрыт общий доступ к папке «{path}»",
    "Could not update share" : "Не удалось обновить общий ресурс",
    "Share saved" : "Общий доступ сохранен",
    "Share expiry date saved" : "Дата истечения срока общего доступа сохранена",
    "Share hide-download state saved" : "Скрытая загрузка ссылки общего доступа сохранено",
    "Share label saved" : "Метка общего доступа сохранена",
    "Share note for recipient saved" : "Примечание к общему ресурсу для получателя сохранено",
    "Share password saved" : "Пароль общего доступа сохранен",
    "Share permissions saved" : "Разрешения общего доступа сохранены",
    "To upload files to {folder}, you need to provide your name first." : "Чтобы загрузить файлы в {folder}, сначала укажите своё имя.",
    "Upload files to {folder}" : "Загрузка файлов в {folder}",
    "Please confirm your name to upload files to {folder}" : "Пожалуйста, подтвердите своё имя для загрузки файлов в {folder}",
    "{ownerDisplayName} shared a folder with you." : "{ownerDisplayName} поделился с вами папкой.",
    "Names must not be empty." : "Имя не может быть пустым.",
    "Names must not start with a dot." : "Имя не должно начинаться с точки.",
    "\"{char}\" is not allowed inside a name." : "Символ «{char}» не допускается в имени.",
    "\"{segment}\" is a reserved name and not allowed." : "«{segment}» — зарезервированное имя и не может быть использовано.",
    "\"{extension}\" is not an allowed name." : "«{extension}» — недопустимое имя.",
    "Names must not end with \"{extension}\"." : "Имя не должно оканчиваться на «{extension}».",
    "Invalid name." : "Недопустимое имя.",
    "Shared by" : "Поделился",
    "Shared with" : "Общий доступ",
    "Password created successfully" : "Пароль создан",
    "Error generating password from password policy" : "Не удалось создать пароль на основе политики",
    "Shared with you and the group {group} by {owner}" : "{owner} предоставил(а) доступ Вам и группе {group}",
    "Shared with you and {circle} by {owner}" : "{owner} предоставил(а) доступ Вам и участникам круга «{circle}»",
    "Shared with you and the conversation {conversation} by {owner}" : "{owner} предоставил(а) доступ Вам и участникам беседы «{conversation}»",
    "Shared with you in a conversation by {owner}" : "Пользователь {owner} предоставил(а) Вам доступ во время беседы",
    "Share not found" : "Ресурс с общим доступом не найден",
    "Back to %s" : "Вернуться к %s",
    "Add to your Nextcloud" : "Добавить в свой Nextcloud",
    "Waiting…" : "Ожидание…",
    "error" : "ошибка",
    "finished" : "завершено",
    "This will stop your current uploads." : "Это остановит ваши текущие загрузки.",
    "Move or copy" : "Переместить или копировать",
    "You can upload into this folder" : "Вы можете загружать в этот каталог",
    "Show list view" : "Просмотр списком",
    "Show grid view" : "Просмотр сеткой",
    "No compatible server found at {remote}" : "Не найден совместимый сервер на {remote}",
    "Invalid server URL" : "Неверный URL сервера",
    "Failed to add the public link to your Nextcloud" : "Не удалось создать общедоступную ссылку",
    "You are not allowed to edit link shares that you don't own" : "Вам не разрешается редактировать ссылки, которыми вы не владеете",
    "Download all files" : "Скачать все файлы",
    "Link copied to clipboard" : "Ссылка скопирована в буфер обмена",
    "_1 email address already added_::_{count} email addresses already added_" : ["Уже добавлен 1 адрес электронной почты","Уже добавлено {count} адреса электронной почты","Уже добавлено {count} адресов электронной почты","Уже добавлено {count} адресов электронной почты"],
    "_1 email address added_::_{count} email addresses added_" : ["Добавлен 1 адрес электронной почты","Добавлено {count} адреса электронной почты","Добавлено {count} адресов электронной почты","Добавлено {count} адресов электронной почты"],
    "Copy to clipboard" : "Копировать в буфер обмена",
    "Copy internal link to clipboard" : "Скопировать внутреннюю ссылку в буфер обмена",
    "Only works for people with access to this folder" : "Работает только для людей, имеющих доступ к этой папке",
    "Only works for people with access to this file" : "Работает только для людей, имеющих доступ к этому файлу",
    "Copy public link of \"{title}\" to clipboard" : "Скопировать общедоступную ссылку для доступа к «{title}» в буфер обмена",
    "Search globally" : "Искать глобально",
    "Search for share recipients" : "Найти больше получателей общего ресурса",
    "No recommendations. Start typing." : "Рекомендации отсутствуют, начните вводить символы",
    "To upload files, you need to provide your name first." : "Чтобы загрузить файлы, вам необходимо сначала указать свое имя.",
    "Enter your name" : "Введите своё имя",
    "Submit name" : "Отправить имя",
    "Share with {userName}" : "Поделиться с {userName}",
    "Show sharing options" : "Показать опции доступа",
    "Share note" : "Комментарий к общему ресурсу",
    "Upload files to %s" : "Загрузка файлов в %s",
    "%s shared a folder with you." : "%s поделился с вами папкой.",
    "Note" : "Примечание",
    "Select or drop files" : "Выберите или перетащите файлы",
    "Uploading files" : "Загрузка файлов",
    "Uploaded files:" : "Отправленные файлы:",
    "By uploading files, you agree to the %1$sterms of service%2$s." : "Передачей файлов на сервер, вы принимаете %1$sусловия обслуживания%2$s.",
    "Name" : "Имя",
    "Use this method to share files with individuals or teams within your organization. If the recipient already has access to the share but cannot locate it, you can send them the internal share link for easy access." : "Используйте этот метод для обмена файлами с отдельными лицами или группами в вашей организации. Если получатель уже имеет доступ к ресурсу, но не может его найти, вы можете отправить ему внутреннюю ссылку на ресурс для легкого доступа.",
    "Use this method to share files with individuals or organizations outside your organization. Files and folders can be shared via public share links and email addresses. You can also share to other Nextcloud accounts hosted on different instances using their federated cloud ID." : "Используйте этот метод для обмена файлами с отдельными лицами или организациями за пределами вашей организации. Файлы и папки можно делить через публичные ссылки и адреса электронной почты. Вы также можете делиться с другими учетными записями Nextcloud, размещенными на разных экземплярах, используя их идентификатор федеративного облака.",
    "Shares that are not part of the internal or external shares. This can be shares from apps or other sources." : "Ссылки, которые не являются частью внутренних или внешних ссылок. Это могут быть ссылки из приложений или других источников.",
    "Share with accounts, teams, federated cloud id" : "Поделиться с учетными записями, командами, идентификатором федеративного облака",
    "Share with accounts and teams" : "Поделиться с аккаунтами и командами",
    "Federated cloud ID" : "Федеративный облачный ID",
    "Email, federated cloud id" : "Электронная почта, идентификатор федеративного облака",
    "Filename must not be empty." : "Имя файла не должно быть пустым."
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
