OC.L10N.register(
    "sharebymail",
    {
    "Shared with {email}" : "Jaettu käyttäjälle {email}",
    "Shared with {email} by {actor}" : "Jaettu käyttäjälle {email} käyttäjän {actor} toimesta",
    "Unshared from {email}" : "Jako käyttäjälle {email} lopetettu",
    "Unshared from {email} by {actor}" : "Jako käyttäjälle {email} lopetettiin käyttäjän {actor} toimesta",
    "Password for mail share sent to {email}" : "Salasana sähköpostijakoon lähetettiin osoitteeseen {email}",
    "Password for mail share sent to you" : "Salasana sähköpostijakoon lähetettiin sinulle",
    "You shared {file} with {email} by mail" : "Jaoit tiedoston {file} sähköpostitse osoitteeseen {email}",
    "{actor} shared {file} with {email} by mail" : "{actor} jakoi tiedoston {file} sähköpostitse osoitteeseen {email}",
    "You unshared {file} from {email} by mail" : "Lopetit kohteen {file} jaon käyttäjältä {email} sähköpostitse",
    "Password to access {file} was sent to {email}" : "Salasana kohteen {file} käyttämiseksi lähetettiin osoitteeseen {email}",
    "Password to access {file} was sent to you" : "Salasana tiedoston {file} käyttämiseksi lähetettiin sinulle",
    "Share by mail" : "Jaa sähköpostitse",
    "We cannot send you the auto-generated password. Please set a valid email address in your personal settings and try again." : "Automaattisesti muodostettua salasanaa ei voi lähettää sinulle. Aseta kelvollinen sähköpostiosoite henkilökohtaisiin asetuksiisi ja yritä uudelleen.",
    "Failed to send share by email. Got an invalid email address" : "Jaon lähettäminen sähköpostitse epäonnistui. Virheellinen sähköpostiosoite",
    "Failed to send share by email" : "Jaon lähettäminen sähköpostitse epäonnistui",
    "Note:" : "Huomioi:",
    "%1$s via %2$s" : "%1$s palvelun %2$s kautta",
    "It is protected with the following password:" : "Se on suojattu seuraavalla salasanalla:",
    "This password will expire at %s" : "Tämä salasana vanhenee %s",
    "This is the password:" : "Tämä on salasana:",
    "You can choose a different password at any time in the share dialog." : "Voit valita muun salasanan koska tahansa jakovalikossa.",
    "Could not find share" : "Jakoa ei löytynyt",
    "Send password by mail" : "Lähetä salasana sähköpostitse",
    "Reply to initiator" : "Vastaa aloitteentekijälle"
},
"nplurals=2; plural=(n != 1);");
