OC.L10N.register(
    "notifications",
    {
    "User not found" : "کاربر یافت نشد",
    "Hello %s" : "سلام %s",
    "Hello %s," : "سلام %s",
    "_New notification for %s_::_%n new notifications for %s_" : ["New notification for %s","%n new notifications for %s"],
    "_You have a new notification for %s_::_You have %n new notifications for %s_" : ["You have a new notification for %s","You have %n new notifications for %s"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "You can change the frequency of these emails or disable them in the settings: %s",
    "Admin notifications" : "اعلان های مدیر",
    "Notifications" : "آگاهی‌ها",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "این برنامه دارای یک پس زمینه و مقدمه برای API اعلان موجود در نکست کلود است.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "این برنامه دارای یک پس زمینه و مقدمه برای API اعلان موجود در نکست کلود است.\n\t\tAPI توسط برنامه های دیگر برای اطلاع رسانی به کاربران در UI وب و همگام سازی مشتری در مورد چیزهای مختلف استفاده می شود. برخی از نمونه ها عبارتند از:\n\n📬 اشتراک فدرال فدرال: شما یک اشتراک از راه دور جدید دریافت کردید\n\n📑 توضیح: کاربر دیگری در اظهارنظر درباره پرونده از شما یاد کرده است\n\n🚢 به روز رسانی اطلاع رسانی: به روز رسانی در دسترس برای یک برنامه یا نکست کلود خود\n\n📣 مرکز اعلامیه: اعلامیه توسط یک مدیر ارسال شده است",
    "Failed to perform action" : "انجام عملی انجام نشد",
    "Failed to dismiss notification" : "رد اخطار انجام نشد",
    "Dismiss" : "پنهان کن",
    "Contact Nextcloud GmbH" : "Contact Nextcloud GmbH",
    "in {path}" : "در { مسیر }",
    "Push notifications might be unreliable" : "Push notifications might be unreliable",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server. For enterprise users, a more scalable gateway is available. Contact Nextcloud GmbH for more information." : "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server. For enterprise users, a more scalable gateway is available. Contact Nextcloud GmbH for more information.",
    "Requesting browser permissions to show notifications" : "Requesting browser permissions to show notifications",
    "No notifications" : "بدون اعلان",
    "Failed to dismiss all notifications" : "رد همه اعلان ها انجام نشد",
    "Dismiss all notifications" : "رد همه اعلان ها",
    "Never" : "هرگز",
    "1 hour" : "۱ ساعت",
    "3 hours" : "۳ ساعت",
    "1 day" : "1 روز",
    "1 week" : "1 week",
    "Your settings have been updated." : "تنظیمات شما به روز رسانی شد",
    "An error occurred while updating your settings." : "An error occurred while updating your settings.",
    "Notifications defaults" : "Notifications defaults",
    "Configure the default notification settings for new users" : "Configure the default notification settings for new users",
    "Send email reminders about unhandled notifications after:" : "ارسال ایمیل یادآوری راجع به سایر اعلان ها پس از :",
    "Play sound when a new notification arrives" : "پخش صدا هنگام دریافت اعلان جدید",
    "Play sound when a call started (requires Nextcloud Talk)" : "پخش صدا به محض برقراری تماس (درصورت استفاده از Nextcloud Talk)",
    "None" : "هیچ‌کدام",
    "You need to set up your email address before you can receive notification emails." : "قبل از دریافت ایمیل های هشدار می بایست ادرس ایمیل خود را تنظیم کنید",
    "seconds ago" : "ثانیه‌هایی پیش"
},
"nplurals=2; plural=(n > 1);");
