OC.L10N.register(
    "files_external",
    {
    "Grant access" : "Hozzáférés megadása",
    "Error configuring OAuth2" : "OAuth2 beállítási hiba",
    "Generate keys" : "Kulcsok előállítása",
    "Error generating key pair" : "Hiba történt a kulcspár előállítása során",
    "You are not logged in" : "Nincs bejelentkezve.",
    "Permission denied" : "Jogosultság megtagadva",
    "Forbidden to manage local mounts" : "A helyi csatolt kötetek kezelése tiltott",
    "Storage with ID \"%d\" not found" : "A(z) „%d” azonosítójú tároló nem található",
    "Invalid backend or authentication mechanism class" : "Érvénytelen háttérszolgáltatási vagy hitelesítési mechanizmus osztály",
    "Invalid mount point" : "Érvénytelen csatolási pont",
    "Objectstore forbidden" : "Az objektumtár tiltott",
    "Invalid storage backend \"%s\"" : "Érvénytelen háttértár-kezelő: „%s”",
    "Not permitted to use backend \"%s\"" : "A(z) „%s” háttérprogram használata nem engedélyezett",
    "Not permitted to use authentication mechanism \"%s\"" : "A(z) „%s” hitelesítési mechanizmus használata nem engedélyezett",
    "Unsatisfied backend parameters" : "Elégtelen paraméterek a háttérprogramhoz",
    "Unsatisfied authentication mechanism parameters" : "Elégtelen paraméterek a hitelesítési mechanizmushoz",
    "Insufficient data: %s" : "Elégtelen adatok: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not editable by non-admins" : "A(z) „%d” azonosítójú tárolót csak rendszergazdák szerkeszthetik",
    "Access key" : "Hozzáférési kulcs",
    "Secret key" : "Titkos kulcs",
    "Builtin" : "Beépített",
    "None" : "Egyik sem",
    "OAuth2" : "OAuth2",
    "Client ID" : "Kliensazonosító",
    "Client secret" : "Kliens titka",
    "OpenStack v2" : "OpenStack v2",
    "Login" : "Bejelentkezés",
    "Password" : "Jelszó",
    "Tenant name" : "Ügyfél neve",
    "Identity endpoint URL" : "Személyazonosság végpont URL-je",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Domain",
    "Rackspace" : "Rackspace",
    "API key" : "API kulcs",
    "Global credentials" : "Globális hitelesítő adatok",
    "Log-in credentials, save in database" : "Bejelentkezési hitelesítő adatok, mentés adatbázisban",
    "Login and password" : "Bejelentkezés és jelszó",
    "Log-in credentials, save in session" : "Bejelentkezési hitelesítő adatok, mentés a munkamenetben",
    "Global credentials, manually entered" : "Globális hitelesítő adatok, kézileg megadva",
    "Manually entered, store in database" : "Kézileg megadva, tárolás adatbázisban",
    "RSA public key" : "RSA nyilvános kulcs",
    "Public key" : "Nyilvános kulcs",
    "RSA private key" : "RSA titkos kulcs",
    "Private key" : "Titkos kulcs",
    "Kerberos default realm, defaults to \"WORKGROUP\"" : "Az alapértelmezett Kerberos tartomány, alapértelmezetten „WORKGROUP”",
    "Kerberos ticket Apache mode" : "Kerberos jegy Apache módja",
    "Kerberos ticket" : "Kerberos jegy",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Gépnév",
    "Port" : "Port",
    "Region" : "Régió",
    "Storage Class" : "Tároló osztály",
    "Enable SSL" : "SSL engedélyezése",
    "Enable Path Style" : "Útvonal stílus engedélyezés",
    "Legacy (v2) authentication" : "Örökölt (v2) hitelesítés",
    "Enable multipart copy" : "Többrészes másolás engedélyezése",
    "SSE-C encryption key" : "SSE-C titkosítási kulcsa",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Távoli almappa",
    "Secure https://" : "Biztonságos https://",
    "FTP" : "FTP",
    "Host" : "Kiszolgáló",
    "Secure ftps://" : "Biztonságos ftps://",
    "Local" : "Helyi",
    "Location" : "Hely",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Gyökér",
    "SFTP with secret key login" : "SFTP titkos kulcsos belépéssel",
    "SMB/CIFS" : "SMB/CIFS",
    "Share" : "Megosztás",
    "Show hidden files" : "Rejtett fájlok megjelenítése",
    "Case sensitive file system" : "Kis- és nagybetűket megkülönböztető fájlrendszer",
    "Disabling it will allow to use a case insensitive file system, but comes with a performance penalty" : "A letiltása lehetővé teszi a kis- és nagybetűket nem megkülönböztető fájlrendszerek használatát, de ez teljesítményvesztést okoz",
    "Verify ACL access when listing files" : "ACL hozzáférés ellenőrzése a fájlok listázásakor",
    "Check the ACL's of each file or folder inside a directory to filter out items where the account has no read permissions, comes with a performance penalty" : "Egy könyvtárban szereplő összes fájl vagy mappa ACL-jének ellenőrzése azon elemek kiszűréséhez, melyeken a fióknak nincs olvasási engedélye; teljesítménycsökkenéssel jár",
    "Timeout" : "Időtúllépés",
    "SMB/CIFS using OC login" : "SMB / CIFS OC bejelentkezéssel",
    "Login as share" : "Bejelentkezés megosztásként",
    "OpenStack Object Storage" : "OpenStack objektumtároló",
    "Service name" : "Szolgáltatás neve",
    "Request timeout (seconds)" : "Kérés időtúllépése (másodpercben)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "A PHP cURL támogatása nincs engedélyezve vagy telepítve.  A(z) %s csatolása nem lehetséges. Kérje meg a rendszergazdát, hogy telepítse.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "A PHP FTP támogatása nincs engedélyezve vagy telepítve. A(z)%s csatolása nem lehetséges. Kérje meg a rendszergazdát, hogy telepítse.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "A(z) „%1$s” nincs telepítve. A(z) %2$s csatolása nem lehetséges. Kérje meg a rendszergazdát, hogy telepítse.",
    "External storage" : "Külső tároló",
    "External storage support" : "Külső tároló támogatás",
    "Adds basic external storage support" : "Külső tároló támogatás hozzáadása",
    "This application enables administrators to configure connections to external storage providers, such as FTP servers, S3 or SWIFT object stores, other Nextcloud servers, WebDAV servers, and more. Administration can choose which types of storage to enable and can mount these storage locations for an account, a group, or the entire system. Users will see a new folder appear in their root Nextcloud directory, which they can access and use like any other Nextcloud folder. External storage also allows people to share files stored in these external locations. In these cases, the credentials for the owner of the file are used when the recipient requests the file from external storage, thereby ensuring that the recipient can access the shared file.\n\nExternal storage can be configured using the GUI or at the command line. This second option provides the administration with more flexibility for configuring bulk external storage mounts and setting mount priorities. More information is available in the external storage GUI documentation and the external storage Configuration File documentation." : "Ez az alkalmazás lehetővé teszi a rendszergazdák számára, hogy beállítsák a kapcsolatokat a külső tárhely-szolgáltatókkal, például FTP-kiszolgálókkal, S3 vagy SWIFT objektumtárolókkal, más Nextcloud-kiszolgálókkal, WebDAV-kiszolgálókkal és egyebekkel. A rendszergazdák kiválaszthatják, hogy milyen típusú tárolókat engedélyeznek, és csatolhatják ezeket a tárhelyeket egy fiók, egy csoport vagy az egész rendszer számára. A felhasználók látni fogják, hogy egy új mappa jelenik meg a Nextcloud gyökérkönyvtárában, amelyet minden más Nextcloud mappához hasonlóan elérhetnek és használhatnak. A külső tárhely lehetővé teszi az emberek számára a külső helyeken tárolt fájlok megosztását is. Ezekben az esetekben a fájl tulajdonosának hitelesítő adatait akkor használják, amikor a címzett a fájlt külső tárhelyről kéri, ezáltal biztosítva, hogy a címzett hozzáférjen a megosztott fájlhoz.\n\nA külső tároló grafikus felületen vagy a parancssorban konfigurálható. Ez a második lehetőség a rendszergazdák számára nagyobb rugalmasságot biztosít a tömeges külső tárolók konfigurálásához, és a csatolási prioritások beállításához. További információ a külső tároló GUI dokumentációjában, és a külső tároló konfigurációs fájljának dokumentációjában található.",
    "Confirm" : "Megerősítés",
    "Storage credentials" : "Tároló hitelesítő adatai",
    "To access the storage, you need to provide the authentication credentials." : "A tároló eléréséhez meg kell adnia a hitelesítő adatokat.",
    "Enter the storage login" : "Adja meg a tároló bejelentkezését",
    "Enter the storage password" : "Adja meg a tároló jelszavát",
    "Unable to update this external storage config. {statusMessage}" : "A külső tároló beállításainak frissítése nem sikerült. {statusMessage}",
    "New configuration successfully saved" : "Az új konfiguráció sikeresen elmentve",
    "Enter missing credentials" : "Adja meg a hiányzó hitelesítési adatokat",
    "Credentials successfully set" : "Hitelesítő adatok sikeresen beállítva",
    "Error while setting credentials: {error}" : "Hiba a hitelesítő adatok beállításakor: {error}",
    "Checking storage …" : "Tároló ellenőrzése…",
    "There was an error with this external storage." : "Hiba történt ezzel a külső tárolóval.",
    "We were unable to check the external storage {basename}" : "Nem sikerült a(z) {basename} külső tároló ellenőrzése",
    "Examine this faulty external storage configuration" : "Vizsgálja meg a külső tároló hibás konfigurációját",
    "Open in Files" : "Megnyitás a Fájlokban",
    "There was an error with this external storage. Do you want to review this mount point config in the settings page?" : "Hiba történt ezzel a külső tárolóval. Átnézi a konfigurációját a beállítások oldalon?",
    "External mount error" : "Külső csatolási hiba",
    "List of external storage." : "Külső tárolók felsorolása.",
    "There is no external storage configured. You can configure them in your Personal settings." : "Nincs külső tároló konfigurálva. Beállíthatja őket a Személyes beállításokban.",
    "There is no external storage configured and you don't have the permission to configure them." : "Nincs külső tároló konfigurálva, és nincs jogosultsága beállítani őket.",
    "No external storage" : "Nincs külső tároló",
    "Storage type" : "Tároló típusa",
    "Unknown" : "Ismeretlen",
    "Scope" : "Hatókör",
    "Personal" : "Személyes",
    "System" : "Rendszer",
    "Type to select account or group." : "Gépeljen a fiók vagy a csoport kiválasztásához.",
    "(Group)" : "(Csoport)",
    "Compatibility with Mac NFD encoding (slow)" : "Kompatibilitás a Mac NFD kódolással (lassú)",
    "Enable encryption" : "Titkosítás engedélyezése",
    "Enable previews" : "Előnézet engedélyezése",
    "Enable sharing" : "Megosztás engedélyezése",
    "Check for changes" : "Változások keresése",
    "Never" : "Soha",
    "Once every direct access" : "Minden közvetlen elérésnél",
    "Read only" : "Csak olvasható",
    "Disconnect" : "Kapcsolat bontása",
    "Unknown backend: {backendName}" : "Ismeretlen háttérszolgáltatás: {backendName}",
    "Admin defined" : "Rendszergazda által definiálva",
    "Automatic status checking is disabled due to the large number of configured storages, click to check status" : "Az automatikus állapotellenőrzés a beállított tárolók nagy száma miatt ki van kapcsolva, kattintson az állapot ellenőrzéséhez",
    "Are you sure you want to disconnect this external storage? It will make the storage unavailable in Nextcloud and will lead to a deletion of these files and folders on any sync client that is currently connected but will not delete any files and folders on the external storage itself." : "Biztos, hogy bontja a kapcsolatot ezzel a külső tárolóval? A tároló nem lesz elérhető a Nextcloudban, és a szinkronizálási kliensek is törölni fogják azokat a fájlokat, amelyek jelenleg kapcsolatban vannak, viszont magáról a külső tárolóról nem fogja törölni a fájlokat és mappákat.",
    "Delete storage?" : "Tároló törlése?",
    "Click to recheck the configuration" : "Kattintson ide a konfiguráció újraellenőrzéséhez",
    "Saved" : "Mentve",
    "Saving …" : "Mentés…",
    "Save" : "Mentés",
    "Failed to save global credentials" : "A globális hitelesítő adatok mentése sikertelen",
    "Failed to save global credentials: {message}" : "A globális hitelesítő adatok mentése sikertelen: {message}",
    "No external storage configured or you don't have the permission to configure them" : "Nincsenek külső tárolók beállítva, vagy nincs hozzáférése a beállításaikhoz",
    "Open documentation" : "Dokumentáció megnyitása",
    "External storage enables you to mount external storage services and devices as secondary Nextcloud storage devices. You may also allow people to mount their own external storage services." : "A külső tárhely lehetővé teszi külső tárolási szolgáltatások és eszközök másodlagos Nextcloud-tárolóeszközként történő csatlakoztatását. Lehetővé teheti az emberek számára, hogy saját külső tárolószolgáltatásukat is csatlakoztassák.",
    "Folder name" : "Mappa neve",
    "Authentication" : "Hitelesítés",
    "Configuration" : "Beállítások",
    "Available for" : "Számukra érhető el:",
    "Add storage" : "Tároló hozzáadása",
    "All people" : "Mindenki",
    "Advanced settings" : "Speciális beállítások",
    "Allow people to mount external storage" : "Külső tárolók csatolásának engedélyezése az emberek számára",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "A globális hitelesítő adatokkal azonos külső hitelesítő adatokkal rendelkező külső tárhelyek hitelesíthetők.",
    "Error configuring OAuth1" : "OAuth1 beállítási hiba",
    "Please provide a valid app key and secret." : "Adjon meg egy érvényes alkalmazáskulcsot és titkot.",
    "OAuth1" : "OAuth1",
    "App key" : "Alkalmazáskulcs",
    "App secret" : "Alkalmazás titka"
},
"nplurals=2; plural=(n != 1);");
