OC.L10N.register(
    "dav",
    {
    "Calendar" : "Agenda",
    "Tasks" : "Taken",
    "Personal" : "Persoonlijk",
    "{actor} created calendar {calendar}" : "{actor} creëerde agenda {calendar}",
    "You created calendar {calendar}" : "Jij creëerde agenda {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} verwijderde agenda {calendar}",
    "You deleted calendar {calendar}" : "Je verwijderde agenda {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} werkte agenda {calendar} bij",
    "You updated calendar {calendar}" : "Je werkte agenda {calendar} bij",
    "{actor} restored calendar {calendar}" : "{actor} herstelde agenda {calendar}",
    "You restored calendar {calendar}" : "Jij herstelde agenda {calendar}",
    "You shared calendar {calendar} as public link" : "Je deelde de agenda {calendar} als openbare link",
    "You removed public link for calendar {calendar}" : "Je verwijderde de openbare link voor de agenda {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} deelde agenda {calendar} met je",
    "You shared calendar {calendar} with {user}" : "Je deelde agenda {calendar} met {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} deelde agenda {calendar} met {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} is gestop de agenda {calendar} met je te delen",
    "You unshared calendar {calendar} from {user}" : "Je stopte met delen agenda {calendar} van {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} stopte met delen agenda {calendar} van {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} stopte het delen van agenda {calendar} van zichzelf",
    "You shared calendar {calendar} with group {group}" : "Je deelde agenda {calendar} met groep {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} deelde agenda {calendar} met groep {group}",
    "You unshared calendar {calendar} from group {group}" : "Je stopte het delen van agenda {calendar} van groep {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} stopte het delen van agenda {calendar} met groep {group}",
    "Untitled event" : "Afspraken zonder naam",
    "{actor} created event {event} in calendar {calendar}" : "{actor} creëerde afspraak {event} in agenda {calendar}",
    "You created event {event} in calendar {calendar}" : "Je creëerde afspraak {event} in agenda {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} verwijderde afspraak {event} uit agenda {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Je verwijderde afspraak {event} uit agenda {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} heeft afspraak {event} in agenda {calendar} bijgewerkt",
    "You updated event {event} in calendar {calendar}" : "Je hebt afspraak {event} in agenda {calendar} bijgewerkt",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} heeft de gebeurtenis {event}verplaatst van de agenda {sourceCalendar} naar de agenda {targetCalendar}.",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Je hebt evenement {event} verplaatst van agenda {sourceCalendar} naar agenda {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} herstelde afspraak {event} in agenda {calendar}",
    "You restored event {event} of calendar {calendar}" : "Je herstelde afspraak {event} in agenda {calendar}",
    "Busy" : "Bezig",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} voegde de taak {todo} to aan de lijst {calendar}",
    "You created to-do {todo} in list {calendar}" : "Je voegde de taak {todo} toe aan de lijst {calendar}",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} verwijderde de taak {todo} van de lijst {calendar}",
    "You deleted to-do {todo} from list {calendar}" : "Jij verwijderde de taak {todo} van de lijst {calendar}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} paste de taak {todo} in de lijst {calendar} aan",
    "You updated to-do {todo} in list {calendar}" : "Jij paste de taak {todo} in de lijst {calendar} aan",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} voltooide de taak {todo} in de lijst {calendar}",
    "You solved to-do {todo} in list {calendar}" : "Jij voltooide de taak {todo} in de lijst {calendar}",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} heropende taak {todo} in lijst {calendar}",
    "You reopened to-do {todo} in list {calendar}" : "Je heropende taak {todo} in lijst {calendar}",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} heeft de taak {todo} van lijst {sourceCalendar} naar lijst {targetCalendar} verplaatst",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Je verplaatste taak {todo} van lijst {sourceCalendar} naar lijst {targetCalendar}",
    "Calendar, contacts and tasks" : "Agenda, contactpersonen en taken",
    "A <strong>calendar</strong> was modified" : "Een <strong>agenda</strong> is aangepast",
    "A calendar <strong>event</strong> was modified" : "Een agenda <strong>gebeurtenis</strong> is aangepast",
    "A calendar <strong>to-do</strong> was modified" : "Een agenda <strong>to-do</strong> was aangepast",
    "Contact birthdays" : "Verjaardagen",
    "Death of %s" : "Sterfdatum van %s",
    "Untitled calendar" : "Naamloze kalender",
    "Calendar:" : "Agenda",
    "Date:" : "Datum",
    "Where:" : "Waar:",
    "Description:" : "Omschrijving:",
    "_%n year_::_%n years_" : ["%n jaar","%n jaar"],
    "_%n month_::_%n months_" : ["%n maand","%n maanden"],
    "_%n day_::_%n days_" : ["%n dag","%n dagen"],
    "_%n hour_::_%n hours_" : ["%n uur","%n uur"],
    "_%n minute_::_%n minutes_" : ["%n minuut","%n minuten"],
    "%s (in %s)" : "%s (in %s)",
    "%s (%s ago)" : "%s (%s geleden)",
    "Calendar: %s" : "Agenda: %s",
    "Date: %s" : "Datum: %s",
    "Description: %s" : "Beschrijving: %s",
    "Where: %s" : "Waar: %s",
    "%1$s via %2$s" : "%1$s via %2$s",
    "In the past on %1$s for the entire day" : "In het verleden op %1$s gedurende de hele dag",
    "_In a minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["Over één minuut op %1$s gedurende de hele dag","Over %n minuten op %1$s gedurende de hele dag"],
    "_In a hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["Over een uur op %1$s gedurende de hele dag","Over %n uur op %1$s gedurende de hele dag"],
    "_In a day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["Over een dag op %1$s gedurende de hele dag","Over %n dagen op %1$s gedurende de hele dag"],
    "_In a week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["Over een week op %1$s gedurende de hele dag","Over %n weken op %1$s gedurende de hele dag"],
    "_In a month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["Over een maand op %1$s gedurende de hele dag","Over %n maanden op %1$s gedurende de hele dag"],
    "_In a year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["Over een jaar op %1$s gedurende de hele dag","Over %n jaar op %1$s gedurende de hele dag"],
    "In the past on %1$s between %2$s - %3$s" : "In het verleden op %1$s van %2$s tot %3$s",
    "_In a minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["Over één minuut op %1$s van %2$s tot %3$s","Over %n minuten op %1$s van %2$s tot %3$s"],
    "_In a hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["Over een uur op %1$s van %2$s tot%3$s","Over %n uur op %1$s van %2$s tot %3$s"],
    "_In a day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["Over één dag op %1$s van %2$s tot %3$s","Over %n dagen op %1$s van %2$s tot %3$s"],
    "_In a week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["Over een week op %1$s van %2$s tot %3$s","Over %n weken op %1$s van %2$s tot %3$s"],
    "_In a month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["Over een maand op %1$s van %2$s tot %3$s","Over %n maanden op %1$s van %2$s tot %3$s"],
    "_In a year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["Over een jaar op %1$s van %2$s tot %3$s","Over %n jaar op %1$s van %2$s tot %3$s"],
    "Every Day for the entire day" : "Elke dag gedurende de hele dag",
    "Every Day for the entire day until %1$s" : "Elke dag gedurende de hele dag tot %1$s",
    "Every Day between %1$s - %2$s" : "Elke dag van %1$s tot %2$s",
    "Every Day between %1$s - %2$s until %3$s" : "Elke dag van %1$s tot %2$s, tot %3$s ",
    "Every %1$d Days for the entire day" : "Elke %1$d dagen gedurende de hele dag",
    "Every %1$d Days for the entire day until %2$s" : "Elke %1$d dagen gedurende de hele dag tot %2$s",
    "Every %1$d Days between %2$s - %3$s" : "Elke %1$d dagen van %2$s tot %3$s",
    "Every %1$d Days between %2$s - %3$s until %4$s" : "Elke %1$d dagen van %2$s tot %3$s, tot %4$s ",
    "Every Week on %1$s for the entire day" : "Elke week op %1$s gedurende de hele dag",
    "Every Week on %1$s for the entire day until %2$s" : "Elke week op %1$s gedurende de hele dag tot %2$s",
    "Every Week on %1$s between %2$s - %3$s" : "Elke week op %1$s van %2$s tot %3$s",
    "Every Week on %1$s between %2$s - %3$s until %4$s" : "Elke week op %1$s van %2$s tot %3$s, tot %4$s ",
    "Every %1$d Weeks on %2$s for the entire day" : "Elke %1$d weken op %2$s gedurende de hele dag",
    "Every %1$d Weeks on %2$s for the entire day until %3$s" : "Elke %1$d weken op %2$s gedurende de hele dag tot %3$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s" : "Elke %1$d weken op %2$s van %3$s tot %4$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s until %5$s" : "Elke %1$d weken op %2$s van %3$s tot %4$s, tot %5$s",
    "Every Month on the %1$s for the entire day" : "Elke %1$s van de maand gedurende de hele dag",
    "Every Month on the %1$s for the entire day until %2$s" : "Elke %1$s van de maand gedurende de hele dag tot %2$s",
    "Every Month on the %1$s between %2$s - %3$s" : "Elke %1$s van de maand van %2$s tot %3$s",
    "Every Month on the %1$s between %2$s - %3$s until %4$s" : "Elke %1$s van de maand van %2$s tot %3$s, tot %4$s ",
    "Every %1$d Months on the %2$s for the entire day" : "Op de %2$s elke %1$d maanden gedurende de hele dag",
    "Every %1$d Months on the %2$s for the entire day until %3$s" : "Op de %2$s elke %1$d maanden gedurende de hele dag tot %3$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s" : "Op de %2$s elke %1$d maanden van %3$s tot %4$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s until %5$s" : "Op de %2$s elke %1$d maanden van %3$s tot %4$s tot %5$s",
    "Every Year in %1$s on the %2$s for the entire day" : "Elk jaar in %1$s op de %2$s gedurende de hele dag",
    "Every Year in %1$s on the %2$s for the entire day until %3$s" : "Elk jaar in %1$s op de %2$s gedurende de hele dag tot %3$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s" : "Elk jaar in %1$s op de %2$s van %3$s tot %4$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s until %5$s" : "Elk jaar in %1$s op de %2$s van %3$s tot %4$s, tot %5$s",
    "Every %1$d Years in %2$s on the %3$s for the entire day" : "Elke %1$d jaar in %2$s op de %3$s gedurende de hele dag",
    "Every %1$d Years in %2$s on the %3$s for the entire day until %4$s" : "Elke %1$d jaar in %2$s op de %3$s gedurende de hele dag tot%4$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s" : "Elke %1$d jaar in %2$s op de %3$s van %4$s tot %5$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "Elke %1$d jaar in %2$s op de %3$s van %4$s tot %5$s, tot %6$s ",
    "On specific dates for the entire day until %1$s" : "Op specifieke dagen gedurende de hele dag tot %1$s",
    "On specific dates between %1$s - %2$s until %3$s" : "Op specifieke dagen van %1$s tot %2$s, tot %3$s",
    "In the past on %1$s" : "In het verleden op %1$s",
    "_In a minute on %1$s_::_In %n minutes on %1$s_" : ["Over een minuut om %1$s","Over %n minuten om %1$s"],
    "_In a hour on %1$s_::_In %n hours on %1$s_" : ["Over een uur om %1$s","Over %n uur om %1$s"],
    "_In a day on %1$s_::_In %n days on %1$s_" : ["Over een dag op %1$s","Over %n dagen op %1$s"],
    "_In a week on %1$s_::_In %n weeks on %1$s_" : ["Over een week op %1$s","Over %n weken op %1$s"],
    "_In a month on %1$s_::_In %n months on %1$s_" : ["Over een maand op %1$s","Over %n maanden op %1$s"],
    "_In a year on %1$s_::_In %n years on %1$s_" : ["Over een jaar op %1$s","Over %n jaar op %1$s"],
    "Cancelled: %1$s" : "Geannuleerd: %1$s",
    "\"%1$s\" has been canceled" : "\"%1$s\" is geannuleerd",
    "Re: %1$s" : "Re: %1$s",
    "%1$s has accepted your invitation" : "%1$s heeft uw uitnodiging aanvaard",
    "%1$s has tentatively accepted your invitation" : "%1$s heeft je uitnodiging voorlopig geaccepteerd",
    "%1$s has declined your invitation" : "%1$s heeft je uitnodiging afgewezen",
    "%1$s has responded to your invitation" : "%1$s heeft op je uitnodiging gereageerd",
    "Invitation updated: %1$s" : "Uitnodiging bijgewerkt: %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s heeft de afspraak \"%2$s\" aangepast",
    "Invitation: %1$s" : "Uitnodiging: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s heeft je uitgenodigd voor \"%2$s\"",
    "Organizer:" : "Organisator:",
    "Attendees:" : "Deelnemers:",
    "Title:" : "Titel:",
    "When:" : "Wanneer:",
    "Location:" : "Locatie:",
    "Link:" : "Link:",
    "Occurring:" : "Elke:",
    "Accept" : "Accepteren",
    "Decline" : "Afwijzen",
    "More options …" : "Meer opties …",
    "More options at %s" : "Meer opties op %s",
    "Monday" : "maandag",
    "Tuesday" : "dinsdag",
    "Wednesday" : "woensdag",
    "Thursday" : "donderdag",
    "Friday" : "vrijdag",
    "Saturday" : "zaterdag",
    "Sunday" : "zondag",
    "January" : "Januari",
    "February" : "Februari",
    "March" : "Maart",
    "April" : "April",
    "May" : "Mei",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "Augustus",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "December",
    "First" : "Eerste",
    "Second" : "Tweede",
    "Third" : "Derde",
    "Fourth" : "Vierde",
    "Fifth" : "Vijfde",
    "Last" : "Laatste",
    "Second Last" : "Voorlaatste",
    "Contacts" : "Contactpersonen",
    "{actor} created address book {addressbook}" : "{actor} creëerde adresboek {addressbook}",
    "You created address book {addressbook}" : "Je creëerde adresboek  {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} verwijdede adresboek {addressbook}",
    "You deleted address book {addressbook}" : "Je verwijderde adresboek  {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} wijzigde adresboek {addressbook}",
    "You updated address book {addressbook}" : "Je wijzigde adresboek {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} deelde adresboek {addressbook} met jou",
    "You shared address book {addressbook} with {user}" : "Jij deelde adresboek {addressbook} met {user}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} deelde adresboek {addressbook} met {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} stopte met delen adresboek {addressbook} van jou",
    "You unshared address book {addressbook} from {user}" : "Je stopte met delen adresboek {addressbook} van {user}",
    "{actor} unshared address book {addressbook} from {user}" : " stopte met delen adresboek {addressbook} van {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} stopte het delen van het adresboek {addressbook} van zichzelf",
    "You shared address book {addressbook} with group {group}" : "Je deelde adresboek {addressbook} met groep {group}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} deelde adresboek {addressbook} met groep {group}",
    "You unshared address book {addressbook} from group {group}" : "Je stopte het delen van adresboek {addressbook} van groep {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} stopte het delen van adresboek {addressbook} van groep {group}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} creëerde contact {card} in adresboek {addressbook}",
    "You created contact {card} in address book {addressbook}" : "Je creëerde contact {card} in adresboek {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} verwijderde contact {card} uit adresboek {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Je verwijderde contact {card} uit adresboek {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} wijzigde contact {card} in adresboek {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Je wijzigde contact {card} in adresboek {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "Een <strong>contactpersoon</strong> of <strong>adresboek</strong> is gewijzigd",
    "Accounts" : "Accounts",
    "System address book which holds all accounts" : "Systeem-adresboek met daarin alle accounts",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "Verwachte bestandsgrootte van %1$s maar gelezen (van Nextcloud-client) en geschreven (naar Nextcloud-opslag) %2$s. Dit kan een netwerkprobleem zijn aan de verzendende kant of een probleem met het schrijven naar de opslag aan de serverkant.",
    "Could not rename part file to final file, canceled by hook" : "Kon bestandsdeel niet hernoemen naar definitief bestand, geannuleerd door hook",
    "Could not rename part file to final file" : "Kon bestandsdeel niet hernoemen naar definitief bestand",
    "Failed to check file size: %1$s" : "Kon bestandsomvang niet controleren: %1$s",
    "Encryption not ready: %1$s" : "Versleuteling niet gereed: %1$s",
    "Failed to open file: %1$s" : "Kon het bestand %1$s niet openen",
    "Failed to unlink: %1$s" : "Kon link niet verwijderen: %1$s",
    "Failed to write file contents: %1$s" : "Kon bestandsinhoud niet wegschrijven: %1$s",
    "File not found: %1$s" : "Bestand niet gevonden: %1$s",
    "System is in maintenance mode." : "Systeem in onderhoudsmodus.",
    "Upgrade needed" : "Upgrade vereist",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Je %s moet worden geconfigureerd voor gebruik van HTTPS om CalDAV en CardDAV met iOS/macOS te kunnen gebruiken.",
    "Configures a CalDAV account" : "Configureert een CalDAV account",
    "Configures a CardDAV account" : "Configureert een CardDAV account",
    "Events" : "Evenementen",
    "Untitled task" : "Taak zonder titel",
    "Completed on %s" : "Voltooid op %s",
    "Due on %s by %s" : "Verwacht op %s door %s",
    "Due on %s" : "Verwacht op %s",
    "Welcome to Nextcloud Calendar!\n\nThis is a sample event - explore the flexibility of planning with Nextcloud Calendar by making any edits you want!\n\nWith Nextcloud Calendar, you can:\n- Create, edit, and manage events effortlessly.\n- Create multiple calendars and share them with teammates, friends, or family.\n- Check availability and display your busy times to others.\n- Seamlessly integrate with apps and devices via CalDAV.\n- Customize your experience: schedule recurring events, adjust notifications and other settings." : "Welkom bij Nextcloud Calendar!\n\nDit is een voorbeeldafspraak - ontdek de flexibiliteit van plannen met Nextcloud Calendar door elke aanpassing te maken die je maar wilt!\n\nMet Nextcloud Calendar kun je:\n- Moeiteloos afspraken maken, bewerken en beheren.\n- Meerdere kalenders maken en delen met teamgenoten, vrienden of familie.\n- Beschikbaarheid controleren en aan anderen laten zien wanneer je al bezet bent.\n- Naadloos integreren met apps en apparaten via CalDAV.\n- Je ervaring aanpassen: terugkerende afspraken plannen, meldingen en andere instellingen aanpassen.",
    "Example event - open me!" : "Voorbeeldafspraak - open me!",
    "System Address Book" : "Systeem-adresboek",
    "The system address book contains contact information for all users in your instance." : "Het systeem-adresboek bevat contactgegevens van alle gebruikers op jouw server.",
    "Enable System Address Book" : "Systeem-adresboek inschakelen",
    "WebDAV endpoint" : "WebDAV eindpunt",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Je webserver is nog niet goed ingesteld voor bestandssynchronisatie, omdat de WebDAV interface niet goed lijkt te werken.",
    "Contacts and groups" : "Contactpersonen en groepen",
    "WebDAV" : "WebDAV",
    "Out of office replacement (optional)" : "Vervanger bij afwezigheid (optioneel)",
    "Name of the replacement" : "Naam van de vervanger",
    "No results." : "Geen resultaten.",
    "Start typing." : "Start met typen.",
    "Short absence status" : "Korte afwezigheidsstatus",
    "Long absence Message" : "Lang afwezigheidsbericht",
    "Save" : "Opslaan",
    "Disable absence" : "Afwezigheid uitschakelen",
    "Failed to load availability" : "Kon beschikbaarheid niet laden",
    "Saved availability" : "Beschikbaarheid opgeslagen",
    "Failed to save availability" : "Opslaan beschikbaarheid mislukt",
    "Time zone:" : "Tijdzone:",
    "to" : "aan",
    "Delete slot" : "Verwijder slot",
    "No working hours set" : "Geen werkuren ingesteld",
    "Add slot" : "Voeg slot toe",
    "Weekdays" : "Weekdagen",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Stel de gebruikersstatus automatisch in op \"Niet storen\" buiten de beschikbaarheid om alle meldingen te dempen.",
    "Cancel" : "Annuleren",
    "Import" : "Import",
    "Error while saving settings" : "Probleem tijdens het opslaan van instellingen",
    "Reset to default" : "Herstellen naar standaard",
    "Availability" : "Beschikbaarheid",
    "Absence" : "Afwezigheid",
    "Configure your next absence period." : "Configureer uw volgende afwezigheidsperiode.",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installeer ook de {calendarappstoreopen}Agenda app{linkclose}, of {calendardocopen}verbind je desktop & mobiel voor synchronisatie ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Zorg ervoor dat je de {emailopen}de e-mailserver{linkclose} correct instelt.",
    "Calendar server" : "Agendaserver",
    "Send invitations to attendees" : "Verzend uitnodigingen naar deelnemers",
    "Automatically generate a birthday calendar" : "Genereer verjaardagskalender automatisch",
    "Birthday calendars will be generated by a background job." : "Verjaardagkalenders zullen worden gegenereerd in een achtergrond taak.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Hierdoor zullen ze niet meteen beschikbaar zijn na het inschakelen maar zullen na een tijdje verschijnen.",
    "Send notifications for events" : "Versturen meldingen voor afspraken",
    "Notifications are sent via background jobs, so these must occur often enough." : "Meldingen worden via achtergrondtaken verstuurd, dus die moeten vaak genoeg plaatsvinden.",
    "Enable notifications for events via push" : "Inschakelen push-melding voor afspraken",
    "There was an error updating your attendance status." : "Er trad een fout op bij het bijwerken van je deelnamestatus.",
    "Please contact the organizer directly." : "Neem rechtstreeks contact op met de organisator.",
    "Are you accepting the invitation?" : "Neem je de uitnodiging aan?",
    "Tentative" : "Onder voorbehoud",
    "Your attendance was updated successfully." : "Je deelname is succesvol bijgewerkt."
},
"nplurals=2; plural=(n != 1);");
