OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Adatvédelem",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Az adatvédelmi központ megmutatja, hogy az adatait hol tárolják és ki férhet hozzájuk, vagy mert megosztotta velük vagy mert rendszergazdák.",
    "Error loading additional administrator." : "Hiba a további rendszergazda betöltése során.",
    "Error adding new administrator." : "Hiba az új rendszergazda hozzáadása során.",
    "Error deleting new administrator." : "Hiba az új rendszergazda törlése során.",
    "Administrators" : "Rendszergazdák",
    "The following accounts are designated administrators and may potentially have access to your data through system storage or backups. However, they do not have easy access to your data via the web interface or client applications." : "A következő fiókok kijelölt rendszergazdák, és a rendszertárolókon vagy biztonsági mentéseken esetlegesen hozzáférhetnek az Ön adataihoz. A webes felületen vagy az ügyfélalkalmazásokon azonban nem férnek hozzá könnyen az Ön adataihoz.",
    "Loading administrators …" : "Rendszergazdák betöltése…",
    "Remove external {propertyName} admin" : "Külső {propertyName} rendszergazda eltávolítása",
    "Add external admin" : "Külső rendszergazda hozzáadása",
    "Cancel" : "Mégse",
    "Add" : "Hozzáadás",
    "Name of external admin" : "Külső rendszergazda neve",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key. It means that administrators can access your files, but not read their content." : "A saját tárolója mesterkulcsot használó {linkopen}kiszolgálóoldali titkosítással ↗{linkclose} védett. Ez azt jelenti, hogy a rendszergazdák elérhetik a fájljait, de nem tudják olvasni a tartalmukat.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key based on their configuration." : "A konfiguráció alapján a külső tárolókon lévő adatait mesterkulcsot használó {linkopen}kiszolgáló oldali titkosítás ↗{linkclose} védheti.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual user key. It means that administrators can access your files, but not read their content." : "A saját tárolója egyéni felhasználói kulcsot használó {linkopen}kiszolgálóoldali titkosítással ↗{linkclose} védett. Ez azt jelenti, hogy a rendszergazdák elérhetik a fájljait, de nem tudják olvasni a tartalmukat.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual key based on their configuration." : "A konfiguráció alapján a külső tárolókon lévő adatait egyéni kulcsot használó {linkopen}kiszolgáló oldali titkosítás ↗{linkclose} védheti.",
    "Additionally, this server is protected with full-disk-encryption." : "Továbbá a kiszolgáló teljes lemeztitkosítással védett.",
    "This server is protected with full-disk-encryption." : "Ez a kiszolgáló teljes lemeztitkosítással védett.",
    "Your files are not protected by encryption." : "A fájljai nincsenek titkosítással védve.",
    "Error saving new state of full-disk-encryption" : "Hiba a teljes lemeztitkosítás új állapotának mentése során",
    "Encryption" : "Titkosítás",
    "Edit encryption" : "Titkosítás szerkesztése",
    "Edit" : "Szerkesztés",
    "This server is using full-disk-encryption." : "Ez a kiszolgáló teljes lemeztitkosítást használ.",
    "Privacy policy" : "Adatvédelmi irányelvek",
    "Read the privacy policy ↗" : "Az adatvédelmi irányelvek elolvasása ↗",
    "Error loading information about shares." : "Hiba a megosztások információinak betöltése során.",
    "People you've shared with" : "Emberek, akikkel adatokat osztott meg",
    "Loading people you've shared with …" : "Emberek betöltése, akikkel adatokat osztott meg…",
    "You do not have any shares with individual users." : "Nincs semmilyen megosztása egyéni felhasználókkal.",
    "Who has access to your data?" : "Ki fér hozzá az adataihoz?",
    "Error saving new location of the server" : "Hiba a kiszolgáló új helyének mentése során",
    "Where is your data?" : "Hol vannak az adatai?",
    "Your data is located in:" : "Az adatai itt találhatók:",
    "An admin has not selected the location of the server yet." : "Még egy rendszergazda sem választotta ki a kiszolgáló helyét.",
    "Change data location" : "Adatok helyének módosítása",
    "Region" : "Régió",
    "Please select a region" : "Régió kiválasztása",
    "User Data Manifesto 2.0" : "User Data Manifesto 2.0",
    "Defining basic rights for people to control their own data in the internet age." : "Leírja a felhasználók saját adataik kezelésére vonatkozó alapvető jogait az internet korában.",
    "Control" : "Irányítás",
    "over user data access" : "a felhasználói adatok elérése felett",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "A felhasználó által kifejezetten és önként feltöltött adatoknak a felhasználó ellenőrzése alatt kell állniuk. A felhasználóknak képesnek kell lenniük arra, hogy eldöntsék, kinek biztosítanak közvetlen hozzáférést az adataikhoz, és azt milyen engedélyekkel és licencekkel teszik.",
    "Knowledge" : "Ismeret",
    "of how the data is stored" : "az adattárolás módjáról",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Amikor az adatokat egy meghatározott szolgáltatóhoz töltik fel, a felhasználókat tájékoztatni kell arról, hogy az adott szolgáltató hol tárolja az adatokat, mennyi ideig, melyik joghatóságban működik, és hogy mely törvényeket kell alkalmazni.",
    "Freedom" : "Szabadság",
    "to choose a platform" : "a platformválasztáshoz",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "A felhasználóknak bármikor ki kell tudni nyerniük az adataikat a szolgáltatásból, anélkül hogy szállítói kötöttségeket tapasztalnának. Ezt csak a nyílt szabványú formátumok és protokollok tudják garantálni.",
    "Learn more ↗" : "Tudjon meg többet ↗",
    "Your {serverName} account" : "Az Ön {serverName}-fiókja",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Az adatai Önt mutatják be, és könnyen vissza lehet élni velük. Mi a Nextcloudnál hiszünk abban, hogy Önnek joga van dönteni arról, hogy mi történjen ezekkel az adatokkal. A Nextcloud megvédi a „User Data Manifesto” kiáltványban megfogalmazott jogait.",
    "Somaliland" : "Szomáliföld",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Egyesült Arab Emírségek",
    "Afghanistan" : "Afganisztán",
    "Antigua and Barbuda" : "Antigua és Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albánia",
    "Armenia" : "Örményország",
    "Angola" : "Angola",
    "Antarctica" : "Antarktisz",
    "Argentina" : "Argentína",
    "American Samoa" : "Amerikai Szamoa",
    "Austria" : "Ausztria",
    "Australia" : "Ausztrália",
    "Aruba" : "Aruba",
    "Åland Islands" : "Åland-szigetek",
    "Azerbaijan" : "Azerbajdzsán",
    "Bosnia and Herzegovina" : "Bosznia-Hercegovina",
    "Barbados" : "Barbadosz",
    "Bangladesh" : "Banglades",
    "Belgium" : "Belgium",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgária",
    "Bahrain" : "Bahrein",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint-Barthélemy",
    "Bermuda" : "Bermuda",
    "Brunei" : "Brunei Szultanátus",
    "Bolivia" : "Bolívia",
    "Bonaire, Sint Eustatius and Saba" : "Karibi Hollandia",
    "Brazil" : "Brazília",
    "Bahamas" : "Bahamák",
    "Bhutan" : "Bhután",
    "Bouvet Island" : "Bouvet-sziget",
    "Botswana" : "Botswana",
    "Belarus" : "Fehéroroszország",
    "Belize" : "Beliz",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Kókusz (Keeling)-szigetek",
    "Democratic Republic of the Congo" : "Kongói Demokratikus Köztársaság",
    "Central African Republic" : "Közép-afrikai Köztársaság",
    "Congo" : "Kongó",
    "Switzerland" : "Svájc",
    "Cote d'Ivoire" : "Elefántcsontpart",
    "Cook Islands" : "Cook-szigetek",
    "Chile" : "Chile",
    "Cameroon" : "Kamerun",
    "China" : "Kína",
    "Colombia" : "Kolumbia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Kuba",
    "Cabo Verde" : "Zöld-foki Köztársaság",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Karácsony-szigetek",
    "Cyprus" : "Ciprus",
    "Czech" : "Csehország",
    "Germany" : "Németország",
    "Djibouti" : "Dzsibuti",
    "Denmark" : "Dánia",
    "Dominican Republic" : "Dominikai Köztársaság",
    "Algeria" : "Algíria",
    "Ecuador" : "Ecuador",
    "Estonia" : "Észtország",
    "Egypt" : "Egyiptom",
    "West Sahara" : "Nyugat-Szahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Spanyolország",
    "Ethiopia" : "Etiópia",
    "Finland" : "Finnország",
    "Fiji" : "Fidzsi-szigetek",
    "Falkland Islands" : "Falkland-szigetek",
    "Micronesia" : "Mikronézia",
    "Faroe Islands" : "Feröer-szigetek",
    "France" : "Franciaország",
    "Gabon" : "Gabon",
    "United Kingdom" : "Egyesült Királyság",
    "Grenada" : "Grenada",
    "Georgia" : "Grúzia",
    "French Guiana" : "Francia Guyana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghána",
    "Gibraltar" : "Gibraltár",
    "Greenland" : "Grönland",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Egyenlítői-Guinea",
    "Greece" : "Görögország",
    "South Georgia and the South Sandwich Islands" : "Dél-Georgia és Déli-Sandwich-szigetek",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Bissau-Guinea",
    "Guyana" : "Guyana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Heard-sziget és McDonald-szigetek",
    "Honduras" : "Honduras",
    "Croatia" : "Horvátország",
    "Haiti" : "Haiti",
    "Hungary" : "Magyarország",
    "Indonesia" : "Indonézia",
    "Ireland" : "Írország",
    "Israel" : "Izrael",
    "Isle of Man" : "Man-sziget",
    "India" : "India",
    "British Indian Ocean Territory" : "Brit tengerentúli területek",
    "Iraq" : "Irak",
    "Iran" : "Irán",
    "Iceland" : "Izland",
    "Italy" : "Olaszország",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordánia",
    "Japan" : "Japán",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kirgizisztán",
    "Cambodia" : "Kambodzsa",
    "Kiribati" : "Kiribati",
    "Comores" : "Comore-szigetek",
    "Saint Kitts and Nevis" : "Saint Kitts és Nevis",
    "North Korea" : "Észak-Korea",
    "South Korea" : "Dél-Korea",
    "Kuwait" : "Kuvait",
    "Cayman Islands" : "Kajmán-szigetek",
    "Kazakhstan" : "Kazahsztán",
    "Laos" : "Laosz",
    "Lebanon" : "Libanon",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Srí Lanka",
    "Liberia" : "Libéria",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Litvánia",
    "Luxembourg" : "Luxemburg",
    "Latvia" : "Lettország",
    "Libya" : "Líbia",
    "Morocco" : "Marokkó",
    "Monaco" : "Monaco",
    "Moldova" : "Moldova",
    "Montenegro" : "Montenegró",
    "Saint Martin" : "Szent Márton-sziget (francia rész)",
    "Madagascar" : "Madagaszkár",
    "Marshall Islands" : "Marshall-szigetek",
    "Macedonia" : "Észak-Macedónia",
    "Mali" : "Mali",
    "Myanmar" : "Mianmar",
    "Mongolia" : "Mongólia",
    "Macao" : "Makaó",
    "Northern Mariana Islands" : "Északi-Mariana-szigetek",
    "Mauritania" : "Mauritánia",
    "Montserrat" : "Montserrat",
    "Malta" : "Málta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Maldív-szigetek",
    "Malawi" : "Malawi",
    "Mexico" : "Mexikó",
    "Malaysia" : "Malajzia",
    "Mozambique" : "Mozambik",
    "Namibia" : "Namíbia",
    "New Caledonia" : "Új-Kaledónia",
    "Niger" : "Niger",
    "Norfolk Island" : "Norfolk-sziget",
    "Nigeria" : "Nigéria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Hollandia",
    "Norway" : "Norvégia",
    "Nepal" : "Nepál",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Új-Zéland",
    "Oman" : "Omán",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Francia Polinézia",
    "Papua New Guinea" : "Pápua Új-Guinea",
    "Philippines" : "Fülöp-szigetek",
    "Pakistan" : "Pakisztán",
    "Poland" : "Lengyelország",
    "Saint Pierre and Miquelon" : "Saint-Pierre és Miquelon",
    "Pitcairn" : "Pitcairn-szigetek",
    "Puerto Rico" : "Puerto Rico",
    "Palestine" : "Palesztína",
    "Portugal" : "Portugália",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Katar",
    "Réunion" : "Réunion",
    "Romania" : "Románia",
    "Serbia" : "Szerbia",
    "Russia" : "Oroszország",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Szaúd-Arábia",
    "Solomon Islands" : "Salamon-szigetek",
    "Seychelles" : "Seychelles",
    "Sudan" : "Szudán",
    "Sweden" : "Svédország",
    "Singapore" : "Szingapúr",
    "Saint Helena, Ascension and Tristan da Cunha" : "Szent Ilona, Ascension és Tristan da Cunha",
    "Slovenia" : "Szlovénia",
    "Svalbard and Jan Mayen" : "Svalbard-szigetek és Jan Mayen-sziget",
    "Slovakia" : "Szlovákia",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Szenegál",
    "Somalia" : "Szomália",
    "Suriname" : "Suriname",
    "South Sudan" : "Dél-Szudán",
    "Sao Tome and Principe" : "São Tomé és Príncipe",
    "El Salvador" : "El Salvador",
    "Sint Maarten" : "Szent Márton-sziget (holland rész)",
    "Syria" : "Szíria",
    "Swaziland" : "Szváziföld",
    "Turks and Caicos Islands" : "Turks- és Caicos-szigetek",
    "Chad" : "Csád",
    "Fr. S. Antarctic Lands" : "Francia déli és antarktiszi területek",
    "Togo" : "Togo",
    "Thailand" : "Thaiföld",
    "Tajikistan" : "Tádzsikisztán",
    "Tokelau" : "Tokelau-szigetek",
    "Timor-Leste" : "Kelet-Timor",
    "Turkmenistan" : "Türkmenisztán",
    "Tunisia" : "Tunézia",
    "Tonga" : "Tonga",
    "Turkey" : "Törökország",
    "Trinidad and Tobago" : "Trinidad és Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan" : "Tajvan",
    "Tanzania" : "Tanzánia",
    "Ukraine" : "Ukrajna",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Amerikai Egyesült Államok lakatlan külbirtokai",
    "United States" : "Egyesült Államok",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Üzbegisztán",
    "Holy See" : "Apostoli Szentszék",
    "Saint Vincent and the Grenadines" : "Saint Vincent és a Grenadine-szigetek",
    "Venezuela" : "Venezuela",
    "Virgin Islands (British)" : "Virgin-szigetek (brit)",
    "Virgin Islands (U.S.)" : "Virgin-szigetek (U.S.)",
    "Vietnam" : "Vietnám",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis és Futuna",
    "Samoa" : "Szamoa",
    "Yemen" : "Jemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Dél-afrikai Köztársaság",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe"
},
"nplurals=2; plural=(n != 1);");
