<?php

/**
 * SPDX-FileCopyrightText: 2016 ownCloud, Inc.
 * SPDX-License-Identifier: AGPL-3.0-only
 */

namespace OCA\Activity\Extension;

class Files_Sharing {
	public const TYPE_SHARED = 'shared';
	public const TYPE_PUBLIC_UPLOAD = 'public_links_upload';
}
