OC.L10N.register(
    "files",
    {
    "Added to favorites" : "تمت إضافته إلى المفضلة",
    "Removed from favorites" : "تمت إزالته مِن المفضلة",
    "You added {file} to your favorites" : "أنت اضفت {file} إلى مفضلتك",
    "You removed {file} from your favorites" : "تم ازالت {file} من مفضلتك",
    "Favorites" : "المفضلة ",
    "File changes" : "تغيير في ملف",
    "Created by {user}" : "انشاء جديد من قبل {user}",
    "Changed by {user}" : "تغيير من قبل {user}",
    "Deleted by {user}" : "حذف من قبل {user}",
    "Restored by {user}" : "استعادة من قبل {user}",
    "Renamed by {user}" : "اعادة تسمية من قبل {user}",
    "Moved by {user}" : "نقل من قبل {user}",
    "\"remote account\"" : "\"حساب بعيد\"",
    "You created {file}" : "أنشأتَ {file}",
    "You created an encrypted file in {file}" : "انشأت ملف مشفر في {file}",
    "{user} created {file}" : "{user} قام بإنشاء ملف {file}",
    "{user} created an encrypted file in {file}" : "{user} قام بإنشاء ملف مشفر {file}",
    "{file} was created in a public folder" : "{file} تم إنشاءه في مجلد عام",
    "You changed {file}" : "أنت قمت بتغيير {file}",
    "You changed an encrypted file in {file}" : "أنت قمت بتغيير ملف مشفر {file}",
    "{user} changed {file}" : "{user} قام بتغيير {file}",
    "{user} changed an encrypted file in {file}" : "{user} قام بتغيير ملف مشفر {file}",
    "You deleted {file}" : "أنت حذفت ملف {file}",
    "You deleted an encrypted file in {file}" : "أنت حذفت ملف مشفر {file}",
    "{user} deleted {file}" : "{user} قام بحذف {file}",
    "{user} deleted an encrypted file in {file}" : "{user} قام بحذف ملف مشفر {file}",
    "You restored {file}" : "أنت قمت باستعادة {file}",
    "{user} restored {file}" : "{user} استعادة ملف {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "لقد أعدت تسمية {oldfile} (مخفي) إلى {newfile} (مخفي)",
    "You renamed {oldfile} (hidden) to {newfile}" : "لقد أعدت تسمية {oldfile} (مخفي) إلى {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "لقد أعدت تسمية {oldfile} إلى {newfile} (مخفي)",
    "You renamed {oldfile} to {newfile}" : "أنت أعدت تسمية {oldfile} إلى {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "أعاد {user} تسمية {oldfile} (مخفي) إلى {newfile} (مخفي)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "أعاد {user} تسمية {oldfile} (مخفي) إلى {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "أعاد {user} تسمية {oldfile} إلى {newfile} (مخفي)",
    "{user} renamed {oldfile} to {newfile}" : "{user} اعادة تسمية {oldfile} إلى {newfile}",
    "You moved {oldfile} to {newfile}" : "أنت نقلت {oldfile} إلى {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} نقل {oldfile} إلى {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "ملف اضيف إلى او تم ازالته من <strong> مفضلتك </strong>",
    "Files" : "الملفات",
    "A file or folder has been <strong>changed</strong>" : "تم  <strong> تغيير</strong> ملف أو مجلد",
    "A favorite file or folder has been <strong>changed</strong>" : "ملف في المفضلة تم <strong>تم تغييره</strong>",
    "Failed to authorize" : "فشل في التخويل",
    "Invalid folder path" : "مسار المجلد غير صحيح",
    "Folder not found" : "المجلد غير موجود",
    "The file cannot be found" : "تعذّر العثور على الملف",
    "The destination path does not exist: %1$s" : "مسار المَقصِد غير موجود: %1$s",
    "You do not have permission to create a file at the specified location" : "ليس لديك صلاحية لإنشاء ملف في الموقع المحدد",
    "The file could not be converted." : "لايمكن تحويل الملف.",
    "Could not get relative path to converted file" : "تعذّر الحصول على المسار النسبي للملف المُتحوِّل",
    "Favorite files" : "الملفات المُفضَّلة",
    "No favorites" : "لا يوجد مفضلات ",
    "More favorites" : "مزيد من المُفضَّلة",
    "Accept" : "قبول",
    "Reject" : "رفض",
    "Incoming ownership transfer from {user}" : "تم تحويل ملكية الملف إليك من قبل {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "هل تريد الموافقة {path}?\n\nملاحظة: عملية موافقة على النقل قد تستغرق إلى 1 ساعة.",
    "Ownership transfer denied" : "تمّ رفض نقل الملكية",
    "Your ownership transfer of {path} was denied by {user}." : "تمّ رفض نقل ملكية الملفات في {path} من قِبَل المستخدِم {user}.",
    "Ownership transfer failed" : "فشل نقل ملكية الملفات",
    "Your ownership transfer of {path} to {user} failed." : "فشلت عمليتك لنقل الـ {path} إلى {user}",
    "The ownership transfer of {path} from {user} failed." : "فشل عملية النقل لـ {path} من قبل {user}",
    "Ownership transfer done" : "تم نقل ملكية الملفات بنجاح",
    "Your ownership transfer of {path} to {user} has completed." : "عمليتك لنقل الـ {path} إلى {user} تمت بنجاح.",
    "The ownership transfer of {path} from {user} has completed." : "نقل ملكية الملفات لـ {path} من قبل {user} تمت بنجاح.",
    "in %s" : "في %s",
    "Transferred from %1$s on %2$s" : "تم النقل من %1$s في%2$s",
    "Files compatibility" : "توافقية الملفات",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "السماح بتقييد أسماء الملفات لضمان إمكانية مزامنة الملفات مع جميع العملاء. بشكل افتراضي، يُسمح بجميع أسماء الملفات الصالحة على POSIX (مثل Linux أو macOS).",
    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "بعد تمكين أسماء الملفات المتوافقة مع نظام التشغيل Windows، لا يمكن تعديل الملفات الموجودة بعد الآن ولكن يمكن إعادة تسميتها بأسماء جديدة صالحة بواسطة مالكها.",
    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "من الممكن أيضًا ترحيل الملفات تلقائيًا بعد تمكين هذا الإعداد، يرجى الرجوع إلى الوثائق المتعلقة بأمر occ.",
    "Enforce Windows compatibility" : "فرض التوافق مع ويندوز",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "سيؤدي هذا إلى حظر أسماء الملفات غير الصالحة على أنظمة Windows؛ مثل استخدام الأسماء المحجوزة أو الأحرف الخاصة. لكن هذا لن يفرض توافق حساسية الحالة.",
    "File Management" : "إدارة الملفات",
    "Home" : "الرئيسية",
    "Target folder does not exist any more" : "المجلد المراد غير موجود بعد الان",
    "Reload current directory" : "إعادة تحميل المجلد الحالي",
    "Go to the \"{dir}\" directory" : "إنتقل إلى المجلد \"{dir}\"",
    "Current directory path" : "مسار المجلد الحالي",
    "Your have used your space quota and cannot upload files anymore" : "لقد استنفذت حصتك التخزينية و لم يعد بإمكانك رفع أي ملفات الآن",
    "You do not have permission to upload or create files here." : "أنت ليس لديك إذنٌ برفع أو إنشاء الملفات هنا.",
    "Drag and drop files here to upload" : "إسحب وأفلت الملفات هنا لرفعها",
    "Favorite" : "المفضلة",
    "Back" : "عودة",
    "Toggle selection for file \"{displayName}\"" : "تبديل الاختيار للملف \"{displayName}\"",
    "Toggle selection for folder \"{displayName}\"" : "تبديل الاختيار للمجلد \"{displayName}\"",
    "File is loading" : "يتم تحميل الملف...",
    "Folder is loading" : "يتم تحميل المجلد...",
    "Filename" : "اسم الملف",
    "Folder name" : "اسم المجلد",
    "This node is unavailable" : "هذه العُقْدَة node غير متوفرة ",
    "Another entry with the same name already exists." : "توجد سلفاً إدخالية أخرى بنفس هذا الاسم.",
    "Invalid filename." : "اسم ملف غير صحيح.",
    "Renamed \"{oldName}\" to \"{newName}\"" : "تمت إعادة تسمية \"{oldName}\" إلى \"{newName}\"",
    "Rename file" : "إعادة تسمية الملف",
    "Folder" : "مجلد",
    "Unknown file type" : "نوع ملف غير معروف",
    "Pending" : "قيد الانتظار",
    "Unknown date" : "تاريخ غير معروف",
    "Clear filter" : "إزالة التصفية",
    "Modified" : "التعديل",
    "Search everywhere" : "البحث الشامل",
    "Type" : "النوع",
    "Active filters" : "فلاتر نشطة",
    "Remove filter" : "إزالة عامل التصفية ",
    "Total rows summary" : "ملخص مجموع الأسطر",
    "Toggle selection for all files and folders" : "تبديل الاختيار لكل الملفات و المجلدات",
    "Name" : "الاسم",
    "File type" : "نوع الملف",
    "Size" : "الحجم",
    "Actions" : "الإجراءات",
    "(selected)" : "(تم اختياره)",
    "List of files and folders." : "قائمة الملفات والمجلدات",
    "You have used your space quota and cannot upload files anymore." : "لقد قمت باستنفاذ كامل حصتك التخزينية و لايمكنك تحميل المزيد من الملفات.",
    "Column headers with buttons are sortable." : "ترويسات الأعمدة ذات الأزرار قابلة للترتيب.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "لم يتم عرض هذه القائمة بالكامل لأسباب تتعلق بالأداء. سيتم عرض الملفات تباعاً أثناء التنقل عبر القائمة.",
    "File not found" : "تعذر العثور على الملف",
    "_{count} selected_::_{count} selected_" : ["{count} تمّ تحديده","{count} تمّ تحديده","{count} تمّ تحديده","{count} تمّ تحديده","{count} تمّ تحديده","{count} تمّ تحديده"],
    "{usedQuotaByte} used" : "{usedQuotaByte} مستخدمة",
    "{used} of {quota} used" : "{used} من {quota} مستخدم",
    "{relative}% used" : "{relative}% مستخدمة",
    "Could not refresh storage stats" : "تعذر تحديث حالة التخزين",
    "Your storage is full, files can not be updated or synced anymore!" : "مساحتك التخزينية ممتلئة, لا يمكن تحديث ملفاتك أو مزامنتها بعد الآن !",
    "Storage information" : "معلومات التخزين",
    "Storage quota" : "حصة التخزين",
    "New folder" : "مجلد جديد",
    "Create new folder" : "إنشاء مجلد جديد",
    "This name is already in use." : "هذا الاسم سبق استعماله.",
    "Create" : "إنشاء",
    "Fill template fields" : "قُم بملء حقول القالب",
    "Submitting fields …" : "إرسال الحقول ...",
    "Submit" : "إرسال ",
    "Choose a file or folder to transfer" : "اختر ملف او مجلد لنقل الملكية",
    "Transfer" : "نقل ملكية",
    "Transfer {path} to {userid}" : "نقل ملكية {path} إلى {userid}",
    "Invalid path selected" : "المسار او الملف غير صحيح",
    "Unknown error" : "خطأ غير معروف",
    "Ownership transfer request sent" : "طلب نقل الملكية أرسل بنجاح",
    "Cannot transfer ownership of a file or folder you do not own" : "لايمكنك نقل ملكية ملف أو مجلد لا تملكه",
    "Transfer ownership of a file or folder" : "تحويل ملكية ملف أو مجلد",
    "Choose file or folder to transfer" : "اختر ملف او مجلد لنقل الملكية",
    "Change" : "تغير",
    "New owner" : "مالك جديد",
    "Keep {old}" : "إحتَفِظ بـ {old}",
    "Keep without extension" : "إحتَفِظ بدون امتداد",
    "Use {new}" : "إستَعمِل {new}",
    "Remove extension" : "أزِل الامتداد",
    "Change file extension" : "تغيير امتداد الملف",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "تغيير امتداد اسم الملف من \"{old}\" إلى \"{new}\" يمكن أن يتسبب في جعله غير قابل للعرض.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "إزالة الامتداد \"{old}\" من اسم الملف يمكن أن يتسبب في تغيير طريقة تناول و عرض الملف أو يجعله غير قابل للعرض.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "إضافة الامتداد \"{new}\" لاسم الملف يمكن أن يتسبب في تغيير طريقة تناول و عرض الملف أو أن يجعله غير قابل للعرض.",
    "Do not show this dialog again." : "لا تُظهِر هذه النافذة مرة أخرى",
    "Select file or folder to link to" : "اختر ملف أو مجلد للربط معه",
    "Choose {file}" : "إختر {file}",
    "Share" : "مشاركة",
    "Shared by link" : "شاركته باستخدام رابط مشاركة",
    "Shared" : "مشاركة",
    "Switch to list view" : "التبديل إلى عرض القائمة",
    "Switch to grid view" : "تبديل إلى العرض الشبكي",
    "The file could not be found" : "تعذّر إيجاد الملف",
    "Upload was cancelled by user" : "عملية الرفع تمّ إلغاؤها من المستخدم",
    "Not enough free space" : "لا يوجد مساحة تخزينية كافية",
    "Operation is blocked by access control" : "العمليات حظرت الوصول لهذه الخدمة",
    "Error during upload: {message}" : "حدث خطأ أثناء الرفع: {message}",
    "Error during upload, status code {status}" : "حدث خطأ أثناء الرفع. رمز الحالة {status}",
    "Unknown error during upload" : "خطأ غير محدد حدث أثناء الرفع",
    "Loading current folder" : "تحميل المجلد الحالي",
    "Retry" : "أعِدِ المحاولة",
    "No files in here" : "لا توجد ملفات هنا ",
    "Upload some content or sync with your devices!" : "ارفع بعض المحتوى أو قم بالمزامنة مع أجهزتك!",
    "Go back" : "العودة",
    "Views" : "مشاهدات",
    "Files settings" : "إعدادات الملفات",
    "Your files" : "ملفاتك",
    "Open in files" : "فتح في تطبيق الملفات",
    "File cannot be accessed" : "الملف لم يمكن الوصول إليه",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "إمّا أن الملف غير موجود أو أنك لا تمتلك الصلاحية لعرضه. أُطلُب من المُرسل أن يتشاركه معك.",
    "Clipboard is not available" : "الحافظة غير متاحة",
    "General" : "عامٌّ",
    "All files" : "كل الملفات",
    "Personal files" : "ملفات شخصية",
    "Sort favorites first" : "فرز المفضلة أولا",
    "Sort folders before files" : "فرز المجلدات قبل الملفات",
    "Appearance" : "المظهر",
    "Show hidden files" : "عرض الملفات المخفية",
    "Show file type column" : "عرض عمود نوع الملف",
    "Crop image previews" : "اقتصاص صورة العروض",
    "Additional settings" : "الإعدادات المتقدمة",
    "WebDAV" : "WebDAV",
    "WebDAV URL" : "عنوان URL لـ WebDAV",
    "Copy" : "نسخ",
    "Warnings" : "تحذيرات",
    "Keyboard shortcuts" : "اختصارات لوحة المفاتيح",
    "File actions" : "إجراءات الملفات",
    "Rename" : "إعادة التسمية",
    "Delete" : "حذف ",
    "Manage tags" : "إدارة الوسوم",
    "Selection" : "اختيار",
    "Select all files" : "تحديد كل الملفات",
    "Deselect all" : "إلغاء تحديد الكل",
    "Navigation" : "التنقل",
    "View" : "عرض",
    "Toggle grid view" : "تفعيل/تعطيل وضع القائمة",
    "Show those shortcuts" : "أعرُض تلك الاختصارات",
    "You" : "أنت",
    "Shared multiple times with different people" : "تمّت مشاركته عدة مرات مع أشخاص متعددين",
    "Unable to change the favorite state of the file" : "تعذّر تغيير حالة المُفضَّلة للملف",
    "Error while loading the file data" : "خطأ اثناء تحميل بيانات الملف",
    "Owner" : "المالك",
    "Remove from favorites" : "إزالة من المفضلة",
    "Add to favorites" : "إضافة إلى المفضلة",
    "Tags" : "الوسوم",
    "Blank" : "فارغ",
    "Unable to create new file from template" : "تعذر إنشاء الملف الجديد من القالب",
    "Pick a template for {name}" : "اختر قالبا لـ {name}",
    "Create a new file with the selected template" : "إنشاء ملف جديد بإستخدام القالب المحدد",
    "Creating file" : "إنشاء ملف",
    "Save as {displayName}" : "حفظ باسم {displayName}",
    "Save as …" : "حفظ باسم ...",
    "Converting files …" : "تحويل الملفات ...",
    "Failed to convert files: {message}" : "تعذّر تحويل الملفات: {message}",
    "All files failed to be converted" : "تعذّر تحويل كل الملفات",
    "One file could not be converted: {message}" : "تعذّر تحويل الملف : {message}",
    "_One file could not be converted_::_%n files could not be converted_" : ["%n ملف لايمكن تحويله","ملف واحد لايمكن تحويله","%n ملف لايمكن تحويله","%n ملفات لايمكن تحويلها","%n ملف لايمكن تحويله","%n ملف لايمكن تحويله"],
    "_One file successfully converted_::_%n files successfully converted_" : ["%n ملف تمّ تحويله بنجاحٍ","ملف واحد تمّ تحويله بنجاحٍ","%n ملف تمّ تحويله بنجاحٍ","%n ملفات تمّ تحويلها بنجاحٍ","%n ملف تمّ تحويله بنجاحٍ","%n ملف تمّ تحويله بنجاحٍ"],
    "Files successfully converted" : "ملفات تمّ تحويلها بنجاحٍ",
    "Failed to convert files" : "تعذّر تحويل الملفات",
    "Converting file …" : "تحويل الملف ...",
    "File successfully converted" : "تمّ تحويل الملفات بنجاحٍ",
    "Failed to convert file: {message}" : "تعذّر تحويل الملف: {message}",
    "Failed to convert file" : "تعذّر تحويل ملف",
    "Leave this share" : "مغادرة هذه المشاركة",
    "Leave these shares" : "مغادرة هاتين المشاركتين",
    "Disconnect storage" : "قطع اتصال التخزين",
    "Disconnect storages" : "فصل وحدات تخزين",
    "Delete permanently" : "حذف بشكل دائم",
    "Delete and unshare" : "حذف وإلغاء المشاركة",
    "Delete file" : "حذف الملف",
    "Delete files" : "حذف الملفات",
    "Delete folder" : "حذف مجلد",
    "Delete folders" : "حذف مجلدين",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["أنت على وشك أن تحذف نهائياً  {count} عنصراً","أنت على وشك أن تحذف نهائياً {count} عنصراً","أنت على وشك أن تحذف نهائياً  {count} عنصراً","أنت على وشك أن تحذف نهائياً {count} عناصر","أنت على وشك أن تحذف نهائياً {count} عناصر","أنت على وشك حذف {count} عنصر بشكل نهائي "],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["أنت على وشك أن تحذف {count} عنصراً","أنت على وشك أن تحذف {count} عنصراً","أنت على وشك أن تحذف {count} عنصراً","أنت على وشك أن تحذف {count} عناصر","أنت على وشك أن تحذف {count} عناصر","أنت على وشك أن تحذف {count} عنصراً"],
    "Confirm deletion" : "تأكيد الحذف",
    "Cancel" : "إلغاء",
    "Download" : "تنزيل",
    "Moving \"{source}\" to \"{destination}\" …" : "نقل \"{source}\" إلى \"{destination}\" …",
    "Copying \"{source}\" to \"{destination}\" …" : "نسخ \"{source}\" إلى \"{destination}\" …",
    "Destination is not a folder" : "الوجهة ليست مجلد",
    "This file/folder is already in that directory" : "هذا الملف/المجلد موجود سلفاً في ذلك المجلد",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "لا يمكنك نقل ملف/مجلد إلى نفسه أو إلى مجلد فرعي منه",
    "(copy)" : "(نسخ)",
    "(copy %n)" : "(نسخ %n)",
    "A file or folder with that name already exists in this folder" : "ملف أو مجلد بنفس ذاك الاسم موجود سلفاً في هذا المجلد",
    "The files are locked" : "الملفات مقفلة",
    "The file does not exist anymore" : "الملف لم يعد موجوداً",
    "Choose destination" : "تحديد الوجهة",
    "Copy to {target}" : "نسخ إلى {target}",
    "Move to {target}" : "نقل إلى {target}",
    "Move" : "نقل",
    "Move or copy operation failed" : "عملية النسخ أو النقل فشلت",
    "Move or copy" : "نقل أو نسخ",
    "Open folder {displayName}" : "فتح المجلد {displayName}",
    "Open in Files" : "فتح في \"الملفات\"",
    "Open locally" : "الفتح محلّيّاً",
    "Failed to redirect to client" : "فشل في التحويل الى العميل",
    "Open file locally" : "فتح الملف محلّيّاً",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "يجب أن يفتح الملف الآن على جهازك. إذا لم يحدث ذلك، فيرجى التأكد من تثبيت تطبيق سطح المكتب.",
    "Retry and close" : "أعِد المحاولة ثم أغلِق",
    "Open online" : "إفتَح مُتَّصِلاً بالإنترنت",
    "Details" : "التفاصيل",
    "View in folder" : "عرض في المجلد",
    "Today" : "اليوم",
    "Last 7 days" : "آخر 7 أيام",
    "Last 30 days" : "آخر 30 يوماً",
    "This year ({year})" : "هذا العام ({year})",
    "Last year ({year})" : "العام الماضي ({year})",
    "Documents" : "المستندات",
    "Spreadsheets" : "الجداول الالكترونية",
    "Presentations" : "العروض",
    "PDFs" : "ملفات PDF",
    "Folders" : "المجلدات",
    "Audio" : "صوت",
    "Images" : "الصِّوَر",
    "Videos" : "مقاطع فيديو",
    "Created new folder \"{name}\"" : "تمّ إنشاء مجلد جديد باسم \"{name}\"",
    "Unable to initialize the templates directory" : "تعذر تهيئة دليل القوالب",
    "Create templates folder" : "إنشاء مجلد للقوالب",
    "Templates" : "القوالب",
    "New template folder" : "مجلد القوالب الجديد",
    "In folder" : "في المجلد",
    "Search in folder: {folder}" : "البحث في المجلد:  {folder}",
    "One of the dropped files could not be processed" : "أحد الملفات المُفلَتة لا يمكن معالجته",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "مُستعرِضُك لا يدعم واجهة تطبيق نظام الملفات Filesystem API. لذا، لن يُمكن رفع المجلدات",
    "No files to upload" : "لا توجد ملفات لرفعها",
    "Unable to create the directory {directory}" : "تعذّر إنشاء الدليل {directory}",
    "Some files could not be uploaded" : "بعض الملفات لم يمكن رفعها",
    "Files uploaded successfully" : "تمّ رفع الملفات بنجاح",
    "No files to process" : "لا توجد ملفات لمعالجتها",
    "Some files could not be copied" : "بعض الملفات لا يمكن نسخها",
    "Some files could not be moved" : "تعذر نقل بعض الملفات",
    "Files copied successfully" : "تمّ نسخ الملفات بنجاح",
    "Files moved successfully" : "تمّ نقل الملفات بنجاح",
    "Conflicts resolution skipped" : "تمّ تخطّي حلّ التعارضات",
    "Upload cancelled" : "تمّ إلغاء الرفع",
    "Could not rename \"{oldName}\", it does not exist any more" : "تعذر إعادة تسمية \"{oldName}\"، لم يعد موجودًا",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "الاسم \"{newName}\" مستعمل سلفاً في المجلد\"{dir}\". إختر اسماً آخر رجاءً.",
    "Could not rename \"{oldName}\"" : "تعذرت إعادة تسمية \"{oldName}\"",
    "This operation is forbidden" : "هذه العملية ممنوعة ",
    "Storage is temporarily not available" : "وحدة التخزين غير متوفرة",
    "Unexpected error: {error}" : "خطأ غير متوقع: {error}",
    "_%n file_::_%n files_" : ["لا يوجد ملفات %n","%n ملف","ملفان","%n ملفات","%n ملف","%n ملفات"],
    "_%n folder_::_%n folders_" : ["لا توجد مجلدات","مجلد واحد","مجلدان","%n مجلدات","%n مجلد","%n مجلدات"],
    "Filename must not be empty." : "يجب ألّا يكون اسم الملف فارغاً.",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\" غير مسموح به في اسم الملف.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" هو اسم محجوز و لا يجوز استعماله كاسم لملف.",
    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" غير مسموح به كنوع لملف.",
    "Filenames must not end with \"{extension}\"." : "أسماء الملفات يجب ألّا تنتهي بـ \"{extension}\".",
    "List of favorite files and folders." : "قائمة بالملفات و المجلدات المُفضّلة.",
    "No favorites yet" : "ليس لديك ملفات مفضلة",
    "Files and folders you mark as favorite will show up here" : "الملفات والمجلدات التي حددتها كمفضلة سوف تظهر هنا ",
    "List of your files and folders." : "قائمة بملفاتك و مجلداتك",
    "List of your files and folders that are not shared." : "قائمة بالملفات و المجلدات التي لم تتم مشاركتها.",
    "No personal files found" : "لا توجد أي ملفات شخصية",
    "Files that are not shared will show up here." : "الملفات التي لم تتم مشاركتها يتم عرضها هنا",
    "Recent" : "آخر الملفات",
    "List of recently modified files and folders." : "قائمة بالملفات والمجلدات التي تمّ تعديلها مؤخراً.",
    "No recently modified files" : "لا توجد أي ملفات تمّ تعديلها مؤخراً",
    "Files and folders you recently modified will show up here." : "الملفات و المجلدات التي تمّ تعديلها مؤخراً ستظهر هنا.",
    "Search" : "بحث",
    "No entries found in this folder" : "لا يوجد مدخلات في هذا المجلد ",
    "Select all" : "تحديد الكل ",
    "Upload too large" : "حجم الرفع أعلى من المسموح",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "حجم الملفات التي تريد رفعها أعلى من المسموح على الخادم.",
    "File could not be found" : "لم يتم العثور على الملف",
    "Show list view" : "اظهر معاينات الروابط",
    "Show grid view" : "عرض شبكي",
    "Close" : "إغلاق",
    "Could not create folder \"{dir}\"" : "لا يمكن إنشاء المجلد \"{dir}\"",
    "This will stop your current uploads." : "هذا سيقوم بوقف رفع الملفات الحالية.",
    "Upload cancelled." : "تم إلغاء عملية رفع الملفات.",
    "Processing files …" : "معالجة الملفات…",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "تعذر رفع الملف {filename} إما لأنه مجلد أو لان حجم الملف 0 بايت",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "لا يوجد مساحة تخزين كافية، إنك بصدد رفع {size1} ولكن المساحة المتبقية المتوفرة تبلُغ {size2}",
    "Target folder \"{dir}\" does not exist any more" : "المجلد المطلوب \"{dir}\" غير موجود بعد الان",
    "An unknown error has occurred" : "حدث خطأ غير معروف",
    "File could not be uploaded" : "لا يمكن تحميل الملف ",
    "Uploading …" : "الرفع جارٍ...",
    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
    "Uploading … ({currentNumber}/{total})" : "يتم التحديث… ({currentNumber}/{total})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} من {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "رفع هذا النوع الملفات غير مدعوم",
    "Error when assembling chunks, status code {status}" : "خطأ عند تجميع القطع، حالة الخطأ {status}",
    "Choose target folder" : "اختر مكان المجلد",
    "Set reminder" : "ضبط التذكير",
    "Edit locally" : "تحرير الملف محلياً",
    "Open" : "فتح",
    "Could not load info for file \"{file}\"" : "فشل تحميل معلومات الملف \"{file}\"",
    "Please select tag(s) to add to the selection" : "يرجى تحديد علامة (علامات) لإضافتها إلى التحديد",
    "Apply tag(s) to selection" : "تطبيق وسم على التحديد",
    "Select directory \"{dirName}\"" : "حدِّد الدليل \"{dirName}\"",
    "Select file \"{fileName}\"" : "حدِّد الملف \"{fileName}\"",
    "Unable to determine date" : "تعذر تحديد التاريخ",
    "This directory is unavailable, please check the logs or contact the administrator" : "هذا المجلد غير متوفر، الرجاء مراجعة سجل الحركات أو الاتصال بمشرف النظام",
    "Could not move \"{file}\", target exists" : "فشل نقل  \"{file}\", الملف موجود بالفعل هناك",
    "Could not move \"{file}\"" : "فشل نقل \"{file}\"",
    "copy" : "نسخ",
    "Could not copy \"{file}\", target exists" : "فشل نسخ \"{file}\"، المستهدف موجود",
    "Could not copy \"{file}\"" : "فشل نسخ \"{file}\"",
    "Copied {origin} inside {destination}" : "تم نسخ {origin} داخل {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "تم نسخ {origin} و {nbfiles} ملفات اخرى داخل {destination}",
    "{newName} already exists" : "{newName} موجود مسبقاً",
    "Could not create file \"{file}\"" : "لا يمكن إنشاء الملف\"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "فشل إنشاء الملف \"{file}\" فهو موجود بالفعل",
    "Could not create folder \"{dir}\" because it already exists" : "فشل إنشاء المجلد \"{dir}\" فهو موجود بالفعل",
    "Could not fetch file details \"{file}\"" : "لم يتم الوصول إلى معلومات \"{file}\"",
    "Error deleting file \"{fileName}\"." : "خطأ أثناء حذف الملف \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "لاتوجد نتائج بحث في مجلدات اخرى ل {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "ادخل حرفين على الاقل للبحث في المجلدات",
    "{dirs} and {files}" : "{dirs} و {files}",
    "_including %n hidden_::_including %n hidden_" : ["يشمل %n مخفي","يشمل %n مخفي","يشمل %n مخفي","يشمل %n مخفي","يشمل %n مخفي","يشمل %n مخفي"],
    "You do not have permission to upload or create files here" : "لا يوجد تخويل برفع أو إنشاء ملفات هنا",
    "_Uploading %n file_::_Uploading %n files_" : ["لا يوجد ملفات %n لتحميلها","تحميل 1 ملف %n","تحميل 2 ملف %n","يتم تحميل عدد قليل من ملفات %n","يتم تحميل عدد كبير من ملفات %n","يتم رفع الملفات %n"],
    "New" : "جديد",
    "New file/folder menu" : "قائمة مجلد/ملف جديد",
    "Select file range" : "حدد نطاق الملف",
    "{used}%" : "{used}%",
    "{used} used" : "{used} مستخدم",
    "\"{name}\" is an invalid file name." : "\"{name}\" اسم ملف غير صالح للاستخدام .",
    "File name cannot be empty." : "اسم الملف لا يجوز أن يكون فارغا",
    "\"/\" is not allowed inside a file name." : "\"/\" غير مسموح في تسمية الملف",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" أنه نوع ملف غير مسموح",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "سعة تخزين {owner} المالك ممتلئة ، ولا يمكن تحديث الملفات أو مزامنتها بعد الآن!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "مجلد المجموعة \"{mountPoint}\" ممتلئ ، لا يمكن تحديث الملفات أو مزامنتها بعد الآن!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "وحدة التخزين الخارجية \"{mountPoint}\" ممتلئة ، لا يمكن تحديث الملفات أو مزامنتها بعد الآن!",
    "Your storage is full, files cannot be updated or synced anymore!" : "سعتك التخزينية ممتلئة ، لا يمكن تحديث الملفات أو مزامنتها بعد الآن!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "تخزين {owner} شبه ممتلئ ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "مجلد مجموعة \"{mountPoint}\" شبه ممتلئ ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "التخزين الخارجي \"{mountPoint}\" شبه ممتلئ ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "مساحة التخزين الخاصة بك شبه ممتلئة ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["تطابق \"{filter}\"","تطابق  \"{filter}\" ","تطابقان \"{filter}\"","تطابقات \"{filter}\"","تطابقات \"{filter}\"","تطابق \"{filter}\""],
    "Direct link was copied (only works for people who have access to this file/folder)" : "تم نسخ الرابط المباشر (يعمل فقط للأشخاص الذين لديهم حق الوصول إلى هذا الملف/المجلد)",
    "Path" : "المسار",
    "_%n byte_::_%n bytes_" : ["بايت","بايت","بايت","بايت","بايت","%n بايت"],
    "Favored" : "مُفضّلة",
    "Favor" : "تفضيل",
    "Copy direct link (only works for people who have access to this file/folder)" : "نسخ الرابط المباشر (يعمل فقط للأشخاص الذين لديهم حق الوصول إلى هذا الملف/المجلد)",
    "Upload file" : "رفع ملف",
    "Not favored" : "غير مُفضّلة",
    "An error occurred while trying to update the tags" : "حدث خطأ اثناء محاولة تحديث الوسوم",
    "Upload (max. %s)" : "الرفع ( حد اقصى. %s ) ",
    "\"{displayName}\" action executed successfully" : "\"{displayName}\" الأمر نُفّذ بنجاح",
    "\"{displayName}\" action failed" : "\"{displayName}\" الأمر أخفق عند التنفيذ",
    "\"{displayName}\" failed on some elements" : "\"{displayName}\" فشل في بعض العناصر",
    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" حزمة الأوامر تم تنفيذها بنجاح",
    "Submitting fields…" : "إرسال الحقول...",
    "Filter filenames…" : "تصفية باسم الملف...",
    "WebDAV URL copied to clipboard" : "تم نسخ WebDAV URL إلى الحافظة",
    "Enable the grid view" : "تمكين العرض الشبكي",
    "Enable folder tree" : "تمكين شجرة المجلدات",
    "Copy to clipboard" : "نسخ الرابط",
    "Use this address to access your Files via WebDAV" : "استخدم هذا العنوان للوصول للملفات عبر WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "إذا كنت قد فعّلت خاصية \"التحقق ثنائي العوامل من الهوية 2FA\"، يجب عليك تجديد كلمة مرور التطبيق بالضغط هنا.",
    "Deletion cancelled" : "تمّ إلغاء الحذف",
    "Move cancelled" : "تمّ إلغاء النقل",
    "Cancelled move or copy of \"{filename}\"." : "تمّ إلغاء عملية حذف أو نقل الملف \"{filename}\".",
    "Cancelled move or copy operation" : ".عملية النسخ أو النقل تمّ إلغاؤها",
    "Open details" : "فتح التفاصيل",
    "Photos and images" : "الصور ",
    "New folder creation cancelled" : "تمّ إلغاء عملية إنشاء مجلد جديد",
    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} مجلد","{folderCount} مجلد","{folderCount} مجلد","{folderCount} مجلدات","{folderCount} مجلد","{folderCount} مجلد"],
    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} ملف","{fileCount} ملف","{fileCount} ملف","{fileCount} ملفات","{fileCount} ملف","{fileCount} ملف"],
    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 ملف و {folderCount} مجلد","1 ملف و {folderCount} مجلد","1 ملف و {folderCount} مجلد","1 ملف و{folderCount} مجلدات","1 ملف و {folderCount} مجلد","1 ملف و {folderCount} مجلد"],
    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} ملف و 1 مجلد","{fileCount} ملف و 1 مجلد","{fileCount} ملف و 1 مجلد","{fileCount} ملفات و 1 مجلد ","{fileCount} ملف و 1 مجلد","{fileCount} ملف و 1 مجلد"],
    "{fileCount} files and {folderCount} folders" : "{fileCount} ملف و {folderCount} مجلد",
    "All folders" : "كل المجلدات",
    "Personal Files" : "ملفات شخصية",
    "Text file" : "ملف نصي",
    "New text file.txt" : "ملف نصي جديد fille.txt",
    "renamed file" : "ملف معاد تسميته",
    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "بعد تمكين أسماء الملفات المتوافقة مع نظام التشغيل Windows، لا يمكن تعديل الملفات الموجودة بعد الآن ولكن يمكن إعادة تسميتها إلى أسماء جديدة صالحة بواسطة مالكها.",
    "Filter file names …" : "تصفية بأسماء الملفات...",
    "Prevent warning dialogs from open or reenable them." : "منع نوافذ التحذير من الفتح أو إعادة تمكينها.",
    "Show a warning dialog when changing a file extension." : "أظهِر نافذة التحذير عندما يتم تغيير امتداد الملف.",
    "Speed up your Files experience with these quick shortcuts." : "سرِّع تعاملك مع الملفات بهذه الاختصارات السريعة.",
    "Open the actions menu for a file" : "إفتَح قائمة الإجراءات للملف",
    "Rename a file" : "تغيير اسم ملف",
    "Delete a file" : "حذف ملف",
    "Favorite or remove a file from favorites" : "تفضيل أو إلغاء تفضيل ملف",
    "Manage tags for a file" : "إدارة الوسوم لملف",
    "Deselect all files" : "إلغاء تحديد كل الملفات",
    "Select or deselect a file" : "اختيار أو إلغاء اختيار ملف",
    "Select a range of files" : "تحديد نطاق من الملفات",
    "Navigate to the parent folder" : "إنتقِل إلى المجلد الأب",
    "Navigate to the file above" : "إنتقِل إلى الملف أعلاه",
    "Navigate to the file below" : "إنتقِل إلى الملف أسفله",
    "Navigate to the file on the left (in grid mode)" : "إنتقِل إلى الملف أيسره (في الشبكة)",
    "Navigate to the file on the right (in grid mode)" : "إنتقِل إلى الملف أيمنه (في الشبكة)",
    "Toggle the grid view" : "بدِّل وضعية الشبكة",
    "Open the sidebar for a file" : "إفتَح الشريط الجانبي للملف"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
