OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Tiedostomuistutukset",
    "Reminder for {name}" : "Muistutus kohteesta {name}",
    "View file" : "Näytä tiedosto",
    "View folder" : "Näytä kansio",
    "Set file reminders" : "Aseta tiedostomuistutuksia",
    "Set reminder for \"{fileName}\"" : "Muistutus asetettu tiedostolle \"{fileName}\"",
    "Clear reminder" : "Tyhjennä muistutus",
    "Please choose a valid date & time" : "Valitse kelvollinen päivä ja aika",
    "Reminder set for \"{fileName}\"" : "Muistutus asetettu tiedostolle \"{fileName}\"",
    "Failed to set reminder" : "Muistutuksen asettaminen epäonnistui",
    "Failed to clear reminder" : "Muistutuksen tyhjentäminen epäonnistui",
    "We will remind you of this file" : "Muistutamme sinua tästä tiedostosta",
    "Cancel" : "Peruuta",
    "Set reminder" : "Aseta muistutus",
    "Reminder set" : "Muistutus asetettu",
    "Later today" : "Myöhemmin tänään",
    "Set reminder for later today" : "Aseta muistutus myöhemmälle ajankohdalle tälle päivälle",
    "Tomorrow" : "Huomenna",
    "Set reminder for tomorrow" : "Aseta muistutus huomiselle",
    "This weekend" : "Tämä viikonloppu",
    "Set reminder for this weekend" : "Aseta muistutus tälle viikonlopulle",
    "Next week" : "Seuraava viikko",
    "Set reminder for next week" : "Aseta muistutus seuraavalle viikolle",
    "Set reminder at custom date & time" : "Aseta muistutus mukautetulle päivälle ja ajankohdalle",
    "Set custom reminder" : "Aseta mukautettu muistutus"
},
"nplurals=2; plural=(n != 1);");
