<?php
namespace Aws\Pipes\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon EventBridge Pipes** service.
 */
class PipesException extends AwsException {}
