OC.L10N.register(
    "settings",
    {
    "Private" : "Privat",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Kun synlig for personer, der matches via telefonnummerintegration via Snak på mobil",
    "Local" : "Lokal",
    "Only visible to people on this instance and guests" : "Kun synlig for personer i denne instans og gæster",
    "Federated" : "Sammenkoblet",
    "Only synchronize to trusted servers" : "Synkroniser kun til betroede servere",
    "Published" : "Udgivet",
    "Synchronize to trusted servers and the global and public address book" : "Synkroniser til betroede servere og den globale og offentlige adressebog",
    "Verify" : "Bekræft",
    "Verifying …" : "Bekræfter...",
    "Unable to change password" : "Kunne ikke ændre kodeord",
    "Very weak password" : "Meget svagt kodeord",
    "Weak password" : "Svagt kodeord",
    "So-so password" : "Jævnt kodeord",
    "Good password" : "Godt kodeord",
    "Strong password" : "Stærkt kodeord",
    "Groups" : "Grupper",
    "Group list is empty" : "Tom gruppeliste",
    "Unable to retrieve the group list" : "Kan ikke hente gruppelisten",
    "{actor} added you to group {group}" : "{actor} tilføjede dig til gruppe {group}",
    "You added {user} to group {group}" : "Tilføjede {user} til gruppen {group}",
    "{actor} added {user} to group {group}" : "{actor} tilføjede {user} til gruppe {group}",
    "An administrator added you to group {group}" : "En administrator tilføjede dig til gruppen {group}",
    "An administrator added {user} to group {group}" : "En administrator tilføjede {user} til gruppen {group}",
    "{actor} removed you from group {group}" : "{actor} fjernede dig fra gruppen {group}",
    "You removed {user} from group {group}" : "Fjernede {user}  fra gruppen {group}",
    "{actor} removed {user} from group {group}" : "{actor} fjernede {user}fra gruppen {group}",
    "An administrator removed you from group {group}" : "En administrator fjernede dig fra gruppen {group}",
    "An administrator removed {user} from group {group}" : "En administrator fjernede {user} fra gruppen {group}",
    "Your <strong>group memberships</strong> were modified" : "Dine <strong>gruppemedlemsskaber</strong> blev ændret",
    "{actor} changed your password" : "{actor} ændrede din adgangskode",
    "You changed your password" : "Du ændrede din kode",
    "Your password was reset by an administrator" : "Din adgangskode er blevet resat af en administrator",
    "Your password was reset" : "Din adgangskode blev nulstillet",
    "{actor} changed your email address" : "{actor} skiftede din e-mail adresse",
    "You changed your email address" : "Du har ændret din email adresse",
    "Your email address was changed by an administrator" : "Din email adresse er blevet ændret af en administrator",
    "You created an app password for a session named \"{token}\"" : "Du oprette en app adgangskode for en session med navnet \"{token}\"",
    "An administrator created an app password for a session named \"{token}\"" : "En administrator oprettede en app adgangskode for en session med navnet \"{token}\"",
    "You deleted app password \"{token}\"" : "Du har slettet app-adgangskoden \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Du omdøbte app-adgangskoden \"{token}\" til \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "Du har givet filsystemadgang til app-adgangskoden \"{token}\"",
    "You revoked filesystem access from app password \"{token}\"" : "Du tilbagekaldte filsystemadgang fra app-adgangskoden \"{token}\"",
    "Security" : "Sikkerhed",
    "You successfully logged in using two-factor authentication (%1$s)" : "Du loggede in ved at bruge two-factor authentication (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Et login forsøg mislykkedes med tofaktors godkendelse (%1$s)",
    "Remote wipe was started on %1$s" : "Fjernsletning blev startet på %1$s",
    "Remote wipe has finished on %1$s" : "Fjernsletning er afsluttet på %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Din <strong>adgangskode</strong> eller <strong>e-mail</strong> blev ændret",
    "Settings" : "Indstillinger",
    "Could not remove app." : "Kunne ikke fjerne app.",
    "Could not update app." : "Kunne ikke opdatere app.",
    "Wrong password" : "Forkert kodeord",
    "Unable to change personal password" : "Kunne ikke ændre personlig adgangskode",
    "Saved" : "Gemt",
    "No Login supplied" : "Intet login angivet",
    "Unable to change password. Password too long." : "Kunne ikke ændre adgangskode. Adgangskode for lang.",
    "Authentication error" : "Autentificerings fejl",
    "Please provide an admin recovery password; otherwise, all account data will be lost." : "Angiv venligst en adgangskode til administratorgendannelse; ellers vil alle kontodata gå tabt.",
    "Wrong admin recovery password. Please check the password and try again." : "Forkert admin gendannelseskode. Se venligst koden efter og prøv igen.",
    "Backend does not support password change, but the encryption of the account key was updated." : "Backend understøtter ikke adgangskodeændringer, men krypteringen af kontonøglen blev opdateret.",
    "Administrator documentation" : "Administratordokumentation",
    "User documentation" : "Brugerdokumentation",
    "Nextcloud help overview" : "Nextcloud hjælpe overblik",
    "Invalid SMTP password." : "Ikke gyldig SMTP adgangskode",
    "Email setting test" : "Test email-indstillinger",
    "Well done, %s!" : "Godt gået, %s!",
    "If you received this email, the email configuration seems to be correct." : "Hvis du har modtaget denne email, så er email konfigureret rigtigt.",
    "Email could not be sent. Check your mail server log" : "Email kunne ikke sendes. Tjek din mail server log",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Der opstod et problem under afsendelse af e-mailen. Gennemse venligst dine indstillinger. (Fejl: %s)",
    "You need to set your account email before being able to send test emails. Go to %s for that." : "Du skal angive din konto e-mail inden du kan sende send test e-mails. Gå til %s for at gøre dette.",
    "Recently active" : "Nyligt aktiv",
    "Disabled accounts" : "Deaktiverede konti",
    "Invalid account" : "Ugyldig konto",
    "Invalid mail address" : "Ugyldig mailadresse",
    "Settings saved" : "Indstillinger gemt",
    "Unable to change full name" : "Ikke i stand til at ændre dit fulde navn",
    "Unable to change email address" : "Kan ikke ændre emailadressen",
    "Unable to set invalid phone number" : "Kan ikke indstille ugyldigt telefonnummer",
    "Unable to set invalid website" : "Kan ikke indstille ugyldigt websted",
    "Some account data was invalid" : "Nogle kontodata var ugyldige",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "For at verificerer din Twitter konto, post den følgende tweet på Twitter (Sørg for at poste det uden linjeskift)",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "For at bekræfte din hjemmeside, opbevare følgende indhold i din web-roden '.well-known/CloudIdVerificationCode.txt' \n(vær sikker på, at den fulde tekst er på en linje):",
    "%1$s changed your password on %2$s." : "%1$s ændrede din adgangskode på %2$s.",
    "Your password on %s was changed." : "Din adgangskode på %s blev ændret.",
    "Your password on %s was reset by an administrator." : "Din adgangskode på %s er blevet nulstillet af en administrator.",
    "Your password on %s was reset." : "Din adgangskode på %s blev nulstillet.",
    "Password for %1$s changed on %2$s" : "Adgangskode for %1$s er ændret på %2$s",
    "Password changed for %s" : "Adgangskode ændret for %s",
    "If you did not request this, please contact an administrator." : "Kontakt en administrator, hvis du ikke har bedt om dette.",
    "Your email address on %s was changed." : "Din email på %s blev ændret.",
    "Your email address on %s was changed by an administrator." : "Din email adresse på %s er blevet ændret af en administrator",
    "Email address for %1$s changed on %2$s" : "Email adresse for %1$s ændret på %2$s",
    "Email address changed for %s" : "Email adresse ændret for %s",
    "The new email address is %s" : "Den nye email adresse er %s",
    "Your %s account was created" : "Din %s-konto blev oprettet",
    "Welcome aboard" : "Velkommen ombord",
    "Welcome aboard %s" : "velkommen ombord %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Velkommen til din %s konto, du kan tilføje, beskytte og dele dine data.",
    "Your Login is: %s" : "Dit login er: %s",
    "Set your password" : "Angiv din adgangskode password",
    "Go to %s" : "Gå til %s",
    "Install Client" : "Installer client",
    "Logged in account must be a sub admin" : "Logget på konto skal være en subadmin",
    "Apps" : "Apps",
    "Personal" : "Personligt",
    "Administration" : "Administration",
    "Users" : "Brugere",
    "Additional settings" : "Yderligere indstillinger",
    "Assistant" : "Assistent",
    "Administration privileges" : "Administrationsrettigheder",
    "Groupware" : "Groupware",
    "Overview" : "Overblik",
    "Basic settings" : "Grundlæggende Indstillinger",
    "Sharing" : "Deling",
    "Availability" : "Tilgængelighed",
    "Calendar" : "Kalender",
    "Personal info" : "Personlige oplysninger",
    "Mobile & desktop" : "Mobil & desktop",
    "Artificial Intelligence" : "Kunstig Intelligens",
    "Email server" : "E-mailserver",
    "Mail Providers" : "Mailudbydere",
    "Mail provider enables sending emails directly through the user's personal email account. At present, this functionality is limited to calendar invitations. It requires Nextcloud Mail 4.1 and an email account in Nextcloud Mail that matches the user's email address in Nextcloud." : "Mailudbydere gør det muligt at sende e-mails direkte gennem brugerens personlige e-mail konto. For nuværende er denne funktion begrænset til kalenderinvitationer. Det kræver Nextcloud Mail 4.1 og en e-mail konto i Nextcloud Mail som matcher brugerens e-mail adresse i Nextcloud.",
    "Send emails using" : "Send e-mails ved anvendelse af",
    "User's email account" : "Brugers e-mailkonto",
    "System email account" : "System e-mailkonto",
    "Security & setup checks" : "Sikkerheds- & opsætningskontroller",
    "Background jobs" : "Baggrundsjobs",
    "Unlimited" : "Ubegrænset",
    "Verifying" : "Bekræfter",
    "Allowed admin IP ranges" : "Tilladt admin IP områder",
    "Admin IP filtering isn't applied." : "Admin IP filtrering er ikke anvendt.",
    "Configuration key \"%1$s\" expects an array (%2$s found). Admin IP range validation will not be applied." : "Konfigurationsnøgle \"%1$s\" forventer et array (%2$s fundet). Admin IP områdevalidering vil ikke blive anvendt.",
    "Configuration key \"%1$s\" contains invalid IP range(s): \"%2$s\"" : "Konfigurationsnøgle \"%1$s\" indeholder ugyldig(e) IP område(r): \"%2$s\"",
    "Admin IP filtering is correctly configured." : "Admin IP filtrering er korrekt konfigureret.",
    "App directories owner" : "App mappe ejer",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:\n%s" : "Nogle app mapper ejes af andre brugere end webserver brugeren. Dette kan være tilfældet hvis apps er blevet installeret manuelt. Kontroller rettighederne for det følgende app mapper:\n%s",
    "App directories have the correct owner \"%s\"" : "App mapper har korrekt ejer \"%s\"",
    "Brute-force Throttle" : "Brute-force drosling",
    "Your remote address could not be determined." : "Din fjern-adresse kunne ikke bestemmes.",
    "Your remote address was identified as \"%s\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly." : "Din fjern-adresse blev bestemt som \"%s\" og bliver brute-force droslet på nuværende tidspunkt, hvilket nedsætter hastigheden af forskellige forespørgsler. Hvis fjern-adressen ikke er din adresse, så kan dette være en indikation af at en proxy ikke er konfigureret korrekt.",
    "Your remote address \"%s\" is not brute-force throttled." : "Din fjern-adresse \"%s\" er ikke brute-force droslet.",
    "Old administration imported certificates" : "Gamle administrations importerede certifikater",
    "A background job is pending that checks for administration imported SSL certificates. Please check back later." : "Et baggrundsjob afventer, som kontrollerer for administrations importerede SSL certifikater. Vend venligst tilbage senere.",
    "There are some administration imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Der er nogle administrations importerede SSL certifikater tilstede, som ikke anvendes mere i Nextcloud 21. De kan importeres via kommandolinjen via \"occ security:certificates:import\" kommandoen. Deres stier indeni datamappen vises nedenfor.",
    "Code integrity" : "Kodeintegritet",
    "Integrity checker has been disabled. Integrity cannot be verified." : "Integritetskontrol er blevet deaktiveret. Integriteten kan ikke verificeres.",
    "No altered files" : "Ingen ændrede filer",
    "Some files have not passed the integrity check. {link1} {link2}" : "Nogle filer har ikke bestået integritetskontrollen. {link1} {link2}",
    "Cron errors" : "Cronfejl",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:\n%s" : "Det var ikke muligt at udføre cron jobbet via CLI. De følgende tekniske fejl er opstået:\n%s",
    "The last cron job ran without errors." : "Det seneste cronjob kørte uden fejl.",
    "Cron last run" : "Cron senest kørt",
    "Last background job execution ran %s. Something seems wrong. {link}." : "Senest kørsel af baggrundsjob udført %s. Noget ser ud til at være galt. {link}.",
    "Last background job execution ran %s." : "Seneste baggrundsjobudførsel kørt %s.",
    "Data directory protected" : "Datamappe beskyttet",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Din datamappe og filer er sandsynligvis tilgængelige fra internettet. .htaccess-filen virker ikke. Det anbefales kraftigt, at du konfigurerer din webserver, så databiblioteket ikke længere er tilgængeligt, eller flytter databiblioteket uden for webserverens dokumentrod.",
    "Could not check that the data directory is protected. Please check manually that your server does not allow access to the data directory." : "Kunne ikke kontrollere at datamappen er beskyttet. kontroller venligst manuelt at din server ikke tillader adgang til datamappen.",
    "Database missing columns" : "Database mangler kolonner",
    "Missing optional column \"%s\" in table \"%s\"." : "Manglende valgfri kolonne \"%s\" i tabel \"%s\".",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Databasen mangler nogle valgfrie kolonner. Da tilføjelse af koloner i store tabeller kan tage noget tid, blev de ikke blevet tilføjet automatisk da de er valgfrie. Kør \"occ db:add-missing-columns\" for manuelt at tilføje de manglende kolonner mens instansen fortsætter. Når kolonnerne er tliføjet vil nogle funktioner muligvis forbedre respons tiden eller brugbarheden.",
    "Database missing indices" : "Database mangler indekser",
    "Missing indices:" : "Manglende indekser:",
    "\"%s\" in table \"%s\"" : "\"%s\" i tabel \"%s\"",
    "Detected some missing optional indices. Occasionally new indices are added (by Nextcloud or installed applications) to improve database performance. Adding indices can sometimes take awhile and temporarily hurt performance so this is not done automatically during upgrades. Once the indices are added, queries to those tables should be faster. Use the command `occ db:add-missing-indices` to add them." : "Registrerede nogle manglende valgfrie indekser. Lejlighedsvis tilføjes nye indekser (af Nextcloud eller installerede applikationer) for at forbedre databasens ydeevne. Tilføjelse af indeks kan nogle gange tage et stykke tid og midlertidigt degradere ydeevnen, derfor gøres dette ikke automatisk under opgraderinger. Når indekserne er tilføjet, bør forespørgsler til disse tabeller være hurtigere. Brug kommandoen `occ db:add-missing-indexes` for at tilføje dem.",
    "Database missing primary keys" : "Database manglende primære nøgler",
    "Missing primary key on table \"%s\"." : "Manglende primær nøgle i tabel \"%s\".",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Databasen mangler nogle primære nøgler. På grund af det faktum, at tilføjelse af primærnøgler på store borde kunne tage noget tid, blev de ikke tilføjet automatisk. Ved at køre \"occ db:add-missing-primary-keys\" kunne de manglende primærnøgler tilføjes manuelt, mens instansen bliver ved med at køre.",
    "Database pending bigint migrations" : "bigint migration er ikke udført på databasen",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline." : "Nogle kolonner i databasen mangler en konvertering til til big int. På grund af at ændring af kolonnetyper på store tabeller, kan tage noget tid, så er de ikke blevet ændret automatisk. Ved at køre \"occ db:convert-filecache-bigint\", så kan disse afventende ændringer køres manuelt. Denne handling skal udføres i mens applikationen er offline.",
    "Debug mode" : "Fejlsøgningstilstand",
    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Denne instans kører i fejlretningstilstand. Aktiver kun dette for lokal udvikling og ikke i produktionsmiljøer.",
    "Debug mode is disabled." : "Fejlsøgningstilstand er deaktiveret.",
    "Default phone region" : "Standard telefonregion",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective ISO 3166-1 code of the region to your config file." : "Din installation har ikke en standard telefonregion. Dette er krævet for at kunne validere telefonnumre under profilindstillingerne uden en landekode. For at tillade numbe uden en landekode, så tilføje venligst \"default_phone_region\" med den respektive ISO 3166-1 kode for regionen i din config file.",
    "Email test" : "E-mail test",
    "Mail delivery is disabled by instance config \"%s\"." : "Maillevering er deaktiveret af instanskonfigurationen \"%s\".",
    "Email test was successfully sent" : "E-mailtesten blev sendt",
    "You have not set or verified your email server configuration, yet. Please head over to the \"Basic settings\" in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "Du har endnu ikke sat eller verificeret din e-mailserver konfiguration. Gå venligst til \"Grundindstillinger\" for at angive den. Anvend derefter knappen \"Send e-mail\" nedenunder formularen for at verificere dine indstillinger.",
    "Transactional File Locking" : "Transaktionel fillåsning",
    "Transactional File Locking is disabled. This is not a a supported configuraton. It may lead to difficult to isolate problems including file corruption. Please remove the `'filelocking.enabled' => false` configuration entry from your `config.php` to avoid these problems." : "Transaktionel fillåsning er deaktiveret. Dette er ikke en understøttet konfiguration. Det kan føre til vanskelige at isolere problemer, herunder filkorruption. Fjern venligst `'filelocking.enabled' => false` konfigurationslinjen fra din `config.php` for at undgå disse problemer.",
    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available." : "Databasen bruges til transaktionsfillåsning. For at forbedre ydeevnen skal du konfigurere MemCache, hvis den er tilgængelig.",
    "Forwarded for headers" : "Forwardet til headere",
    "Your \"trusted_proxies\" setting is not correctly set, it should be an array." : "Dine \"trusted_proxies\" indstillinger er ikke korrekt angivet. Det skal være et array.",
    "Your \"trusted_proxies\" setting is not correctly set, it should be an array of IP addresses - optionally with range in CIDR notation." : "Dine \"trusted_proxies\" indstillinger er ikke sat korrekt. Det skal være et array med IP adresser - eventuelt med område i CIDR notation.",
    "The reverse proxy header configuration is incorrect. This is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "Konfigurationen af ​​reverse proxy-header er forkert. Dette er et sikkerhedsproblem og kan tillade en hacker at forfalske deres IP-adresse som synlig for Nextcloud.",
    "Your IP address was resolved as %s" : "Din IP adress blev genkendt til %s",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "Konfigurationen af ​​reverse proxy-header er forkert, eller du får adgang til Nextcloud fra en betroet proxy. Hvis ikke, er dette et sikkerhedsproblem og kan tillade en hacker at forfalske deres IP-adresse som synlig for Nextcloud.",
    "HTTPS access and URLs" : "HTTPS adgang og URLs",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "Adgang til siden usikkert via HTTP. Det anbefales kraftigt at konfigurere din server til at kræve HTTPS i stedet for. Uden det vil nogle vigtige webfunktioner som \"kopi til udklipsholder\" eller \"servicemedarbejdere\" ikke fungere!",
    "Accessing site insecurely via HTTP." : "Tilgår websted via usikker HTTP.",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This likely means that your instance is behind a reverse proxy and the Nextcloud `overwrite*` config values are not set correctly." : "Du tilgår din instans via en sikker forbindelse, men din instans genererer usikre URL'er. Dette betyder sandsynligvis, at din instans er bag en reverse proxy, og at Nextcloud `overwrite*` konfigurationsværdierne ikke er indstillet korrekt.",
    "Your instance is generating insecure URLs. If you access your instance over HTTPS, this likely means that your instance is behind a reverse proxy and the Nextcloud `overwrite*` config values are not set correctly." : "Din instans genererer usikre URL'er. Hvis du tilgår din instans via HTTPS, betyder det sandsynligvis, at din instans er bag en reverse proxy, og at Nextcloud `overwrite*` konfigurationsværdierne ikke er indstillet korrekt.",
    "You are accessing your instance over a secure connection, and your instance is generating secure URLs." : "Du tilgår din instans via en sikker forbindelse, og din instans genererer sikre URL'er.",
    "Internet connectivity" : "Internetofrbindelse",
    "Internet connectivity is disabled in configuration file." : "Internetforbindelse er deaktiveret i konfigurationsfil.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Denne server har ingen fungerende internetforbindelse: Flere slutpunkter kunne ikke nås. Det betyder, at nogle af funktionerne som montering af eksternt lager, meddelelser om opdateringer eller installation af tredjepartsapps ikke vil fungere. Fjernadgang til filer og afsendelse af notifikations-e-mails virker muligvis heller ikke. Opret en forbindelse fra denne server til internettet for at nyde alle funktioner.",
    "JavaScript modules support" : "Understøttelse af JavaScript moduler",
    "Unable to run check for JavaScript support. Please remedy or confirm manually if your webserver serves `.mjs` files using the JavaScript MIME type." : "Kan ikke kontrollere for JavaScript understøttelse. Ret eller bekræft venligst manuelt hvis din webserver leverer `.mjs` filer ved anvendelse af JavaScript MIME typen.",
    "Your webserver does not serve `.mjs` files using the JavaScript MIME type. This will break some apps by preventing browsers from executing the JavaScript files. You should configure your webserver to serve `.mjs` files with either the `text/javascript` or `application/javascript` MIME type." : "Din webserver leverer ikke `.mjs` filer ved anvendelse af JavaScript MIME typen. Dette vil ødelægge nogle apps ved at forhindre browsere i at køre JavaScript filerne. Du bør konfigurere din webserver til at levere `.mjs` filer med enten `text/javascript` eller `application/javascript` MIME typen.",
    "JavaScript source map support" : "Understøttelse af JavaScript kildekoblinger",
    "Your webserver is not set up to serve `.js.map` files. Without these files, JavaScript Source Maps won't function properly, making it more challenging to troubleshoot and debug any issues that may arise." : "Din webserver er ikke sat op til at levere `.js.map` filer. Uden disse filer vil JavaScript kildekoblinger ikke fungere korrekt, hvilket gør det mere udfordrende at fejlfinde eventuelle problemer, der måtte opstå.",
    "Old server-side-encryption" : "Gammel server-side kryptering",
    "Disabled" : "Deaktiveret",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Det gamle serverside-krypteringsformat er aktiveret. Vi anbefaler at deaktivere dette.",
    "Logging level" : "Log niveau",
    "The %1$s configuration option must be a valid integer value." : "Indstillingen %1$s skal være en gyldig heltalsværdi.",
    "The logging level is set to debug level. Use debug level only when you have a problem to diagnose, and then reset your log level to a less-verbose level as it outputs a lot of information, and can affect your server performance." : "Logningsniveauet er indstillet til fejlretningsniveau. Brug debug niveau kun, når du har et problem med at diagnosticere, og derefter nulstille din log niveau til et mindre-verbose niveau, da det udskriver en masse oplysninger, og kan påvirke din server ydeevne.",
    "Logging level configured correctly." : "Logningsniveau konfigureret korrekt.",
    "Maintenance window start" : "Vedligeholdelsesvindue starter",
    "Server has no maintenance window start time configured. This means resource intensive daily background jobs will also be executed during your main usage time. We recommend to set it to a time of low usage, so users are less impacted by the load caused from these heavy tasks." : "Serveren har ikke konfigureret noget starttidspunkt for vedligeholdelsesvinduet. Dette betyder, at ressourcekrævende daglige baggrundsjobs også vil blive udført under din primære anvendelsestid. Vi anbefaler at indstille det til et tidspunkt med lavt forbrug, så brugerne bliver mindre påvirket af belastningen, forårsaget af disse tunge opgaver.",
    "Maintenance window to execute heavy background jobs is between {start}:00 UTC and {end}:00 UTC" : "Vedligeholdelsesvinduet til at udføre tunge baggrundsjob er mellem {start}:00 UTC og {end}:00 UTC",
    "Memcache" : "Memcache",
    "Memcached is configured as distributed cache, but the wrong PHP module (\"memcache\") is installed. Please install the PHP module \"memcached\"." : "Memcached er konfigureret som distribueret cache, men det forkerte PHP modul (\"memcache\") er installeret. Installer venligst PHP modulet \"memcached\".",
    "Memcached is configured as distributed cache, but the PHP module \"memcached\" is not installed. Please install the PHP module \"memcached\"." : "Memcached er konfigureret som distribueret cache, men PHP modulet \"memcached\" er ikke installeret. Installer venligst PHP modulet \"memcached\".",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available." : "Der er ikke konfigureret nogen hukommelsescache. For at forbedre ydeevnen skal du konfigurere en memcache, hvis den er tilgængelig.",
    "Failed to write and read a value from local cache." : "Kunne ikke skrive og læse en værdi fra den lokale cache.",
    "Failed to write and read a value from distributed cache." : "Kunne ikke skrive og læse en værdi fra distribueret cache.",
    "Configured" : "Konfigureret",
    "Mimetype migrations available" : "Kunne ikke skrive og læse en værdi fra distribueret cache.",
    "One or more mimetype migrations are available. Occasionally new mimetypes are added to better handle certain file types. Migrating the mimetypes take a long time on larger instances so this is not done automatically during upgrades. Use the command `occ maintenance:repair --include-expensive` to perform the migrations." : "En eller flere mimetype migreringer er tilgængelige. Lejlighedsvis bliver der tilføjet nye mimetyper for bedre at håndtere visse filtyper. Migrering af mimetyperne tager lang tid på større instanser, så dette sker ikke automatisk under opgraderinger. Brug kommandoen `occ maintenance:repair --include-expensive` til at udføre migreringerne.",
    "MySQL row format" : "MySQL rækkeformat",
    "You are not using MySQL" : "Du anvender ikke MySQL",
    "None of your tables use ROW_FORMAT=Compressed" : "Ingen af tabellerne anvender ROW_FORMAT=Compressed",
    "Incorrect row format found in your database. ROW_FORMAT=Dynamic offers the best database performances for Nextcloud. Please update row format on the following list: %s." : "Forkert rækkeformat fundet i din database. ROW_FORMAT=Dynamic tilbyder den bedste databaseydelse til Nextcloud. Opdater venligst rækkeformatet på følgende liste: %s.",
    "MySQL Unicode support" : "MySQL Unicode understøttelse",
    "MySQL is used as database and does support 4-byte characters" : "MySQL bruges som database og understøtter 4-byte karakterer",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL." : "MySQL anvendes som database, men understøtter ikke 4-byte tegn. For at kunne håndtere 4-byte tegn (som fx emojis) uden problemer i f.eks. filnavne eller kommentarer, så anbefales det at aktivere 4-byte understøttelsen i MySQL.",
    "OCS provider resolving" : "OCS udbyder løser",
    "Could not check if your web server properly resolves the OCM and OCS provider URLs." : "Kunne ikke kontrollere, om din webserver opløser OCM og OCS udbyderens URL'er korrekt.",
    "Your web server is not properly set up to resolve %1$s.\nThis is most likely related to a web server configuration that was not updated to deliver this folder directly.\nPlease compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx.\nOn Nginx those are typically the lines starting with \"location ~\" that need an update." : "Din webserver er ikke korrekt konfigureret til at opløse %1$s.\nDette er højst sandsynligt relateret til en webserverkonfiguration, der ikke blev opdateret til at levere denne mappe direkte.\nSammenlign venligst din konfiguration med de afsendte omskrivningsregler i \".htaccess\" for Apache eller den medfølgende i dokumentationen til Nginx.\nPå Nginx er det typisk de linjer, der starter med \"location~\", der skal opdateres.",
    "Overwrite CLI URL" : "Overskriv CLI URL",
    "The \"overwrite.cli.url\" option in your config.php is correctly set to \"%s\"." : "\"overwrite.cli.url\" indstillingen i din config.php er korrekt indstillet til \"%s\".",
    "The \"overwrite.cli.url\" option in your config.php is set to \"%s\" which is a correct URL. Suggested URL is \"%s\"." : "\"overwrite.cli.url\" indstillingen i din config.php er sat til \"%s, hvilket er en korrekt URL. Foreslået URL er \"%s\".",
    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"%s\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "Sørg for at indstille indstillingen \"overwrite.cli.url\" i din config. php-fil til URL, som dine brugere primært bruger til at få adgang til denne Nextcloud. Forslag: \"%s\". Ellers kan der være problemer med URL-generering via cron. (Det er muligt, selv om den foreslåede URL ikke er den URL, som dine brugere primært bruger til at få adgang til denne Nextcloud. Bedst er at dobbelttjekke dette under alle omstændigheder.)",
    "PHP APCu configuration" : "PHP APCu konfiguration",
    "Your APCu cache has been running full, consider increasing the apc.shm_size php setting." : "Din APCu cache er fuld, overvej at øge php indstillingen apc.shm_size.",
    "Your APCu cache is almost full at %s%%, consider increasing the apc.shm_size php setting." : "Din APCu cache er næsten fuld på %s%%, overveje at øge apc.shm_size php indstilling.",
    "PHP default charset" : "PHP standard tegnsæt",
    "PHP configuration option \"default_charset\" should be UTF-8" : "PHP konfigurationsmuligheden \"default_charset\" skal være UTF-8",
    "PHP set_time_limit" : "PHP set_time_limit",
    "The function is available." : "Funktionen er tilgængelig.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP funktionen \"set_time_limit\" er ikke tilgængelig. Dette kan resultere i at scripts stopper halvvejs og din installation fejler. Vi anbefaler at aktivere denne funktion.",
    "Freetype" : "Freetype",
    "Supported" : "Understøttet",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Din PHP version har ikke FreeType-support, hvilket resulterer i brud på profilbilleder og indstillingerne.",
    "PHP getenv" : "PHP getenv",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP lader ikke til at være korrekt opsat til at forespørge miljøvariablerne i systemet. Testen med getenv(\"PATH\") returnerer et tomt svar.",
    "PHP file size upload limit" : "Uploadgrænse sat i PHP konfiguration",
    "The PHP upload_max_filesize is too low. A size of at least %1$s is recommended. Current value: %2$s." : "PHP upload_max_filesize er for lille. En størrelse på minimum %1$s er anbefalet. Aktuel værdi: %2$s.",
    "The PHP post_max_size is too low. A size of at least %1$s is recommended. Current value: %2$s." : "PHP post_max_size er for lille. En størrelse på minimum %1$s er anbefalet. Aktuel værdi: %2$s.",
    "The PHP max_input_time is too low. A time of at least %1$s is recommended. Current value: %2$s." : "PHP max_input_time er for lille. Et tidsrum på minimum %1$s er anbefalet. Aktuel værdi: %2$s.",
    "The PHP max_execution_time is too low. A time of at least %1$s is recommended. Current value: %2$s." : "PHP max_execution_time er for lille. Et tidsrum på minimum %1$s er anbefalet. Aktuel værdi: %2$s.",
    "PHP memory limit" : "PHP hukommelsesgrænse",
    "The PHP memory limit is below the recommended value of %s. Some features or apps - including the Updater - may not function properly." : "PHP hukommelsesgrænsen er under den anbefalede værdi af %s. Nogle funktioner eller apps - herunder Updater - fungerer muligvis ikke korrekt.",
    "PHP modules" : "PHP moduler",
    "increases language translation performance and fixes sorting of non-ASCII characters" : "Øger sprogoversættelsesperformance og retter sortering af ikke-ASCII karakterer",
    "for Argon2 for password hashing" : "til Argon2 for adgangskode hashing",
    "required for SFTP storage and recommended for WebAuthn performance" : "kræves til SFTP opbevaring og anbefales til WebAuthn ydeevne",
    "for picture rotation in server and metadata extraction in the Photos app" : "til billedrotation på server og metadata ekstraktion i Fotos app",
    "This instance is missing some required PHP modules. It is required to install them: %s." : "Instansen mangler nogle krævede PHP moduler. Det kræves at de installeres: %s.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them:\n%s" : "Denne instans mangler nogle anbefalede PHP moduler. For forbedret performance og bedre kompatibilitet anbefales det kraftigt at installere disse:\n%s",
    "PHP opcache" : "PHP opcache",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "PHP OPcache modulet er ikke indlæst. For bedre performance anbefales det at indlæse det i din PHP installation.",
    "OPcache is disabled. For better performance, it is recommended to apply \"opcache.enable=1\" to your PHP configuration." : "OPcache er deaktiveret. For bedre performance, så anbefales det at anvende \"opcache.enable=1\" i din PHP konfiguration.",
    "The shared memory based OPcache is disabled. For better performance, it is recommended to apply \"opcache.file_cache_only=0\" to your PHP configuration and use the file cache as second level cache only." : "Den delte hukommelsesbaserede OPcache er deaktiveret. For bedre ydeevne anbefales det at tilføje \"opcache.file_cache_only=0\" til din PHP konfiguration, og kun bruge filcachen som anden niveau cache.",
    "OPcache is not working as it should, opcache_get_status() returns false, please check configuration." : "OPcache fungerer ikke som den skal. opcache_get_status() returnerer falsk, kontroller venligst konfigurationen.",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply \"opcache.max_accelerated_files\" to your PHP configuration with a value higher than \"%s\"." : "Det maksimale antal opcache nøgler er næsten overskredet. For at sikre, at alle scripts kan holdes i cachen, anbefales det at anvende \"opcache.max_accelered_files\" til din PHP konfiguration med en værdi højere end \"%s\".",
    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply \"opcache.memory_consumption\" to your PHP configuration with a value higher than \"%s\"." : "OPcache-bufferen er næsten fuld. For at sikre, at alle scripts kan beholdes i cachen, anbefales det at tilføje \"opcache.memory_consumption\" til din PHP-konfiguration med en værdi højere end \"%s\".",
    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply \"opcache.interned_strings_buffer\" to your PHP configuration with a value higher than \"%s\"." : "OPcache internet strenge buffer er næsten fuld. For at sikre, at gentagne strenge effektivt kan caches, så anbefales det at tilføje \"opcache.interned_strings_buffer\" til din PHP konfiguration med en værdi højere end \"%s\".",
    "OPcache is configured to remove code comments. With OPcache enabled, \"opcache.save_comments=1\" must be set for Nextcloud to function." : "OPcache er konfigureret til at fjerne kodekommentarer. Med OPcache aktiveret skal \"opcache.save_comments=1\" angives for at Nextcloud kan fungere.",
    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with \"opcache.restrict_api\" or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud har ikke tilladelse til at bruge OPcache API. Med OPcache aktiveret, anbefales det stærkt at inkludere alle Nextcloud mapper med \"opcache.restrict_api\" eller deaktivere denne indstilling for at deaktivere OPcache API begrænsninger, for at forhindre fejl under Nextcloud kerne- eller appopgraderinger.",
    "Checking from CLI, OPcache checks have been skipped." : "Kontrol fra CLI, OPcache tjek er blevet sprunget over.",
    "The PHP OPcache module is not properly configured. %s." : "PHP OPcache modulet er ikke korrekt konfigureret %s.",
    "Correctly configured" : "Korrekt konfigureret",
    "PHP version" : "PHP version",
    "You are currently running PHP %1$s. PHP %2$s is deprecated since Nextcloud %3$s. Nextcloud %4$s may require at least PHP %5$s. Please upgrade to one of the officially supported PHP versions provided by the PHP Group as soon as possible." : "Du kører i øjeblikket PHP %1$s. PHP %2$s er forældet siden Nextcloud %3$s. Nextcloud %4$s kan kræve mindst PHP %5$s. Opgrader til en af de officielt understøttede PHP-versioner, som PHP Group leverer så hurtigt som muligt.",
    "You are currently running PHP %s." : "Din aktuelle PHP version er %s.",
    "PHP \"output_buffering\" option" : "PHP indstillingen \"output_buffering\"",
    "PHP configuration option \"output_buffering\" must be disabled" : "PHP konfigurationsindstillingen \"output_buffering\" skal være deaktiveret",
    "Push service" : "Push service",
    "Valid enterprise license" : "Gyldig enterprise licens",
    "Free push service" : "Gratis push service",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {link}." : "Dette er den ikke-understøttede community build af Nextcloud. I betragtning af størrelsen af ​​denne instans kan ydeevne, pålidelighed og skalerbarhed ikke garanteres. Push-meddelelser er begrænset for at undgå at overbelaste vores gratis service. Lær mere om fordelene ved Nextcloud Enterprise her {link}.",
    "Random generator" : "Tilfældighedsgenerator",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons." : "Ingen passende kilde til tilfældighed fundet af PHP, hvilket frarådes kraftigt af sikkerhedsmæssige årsager.",
    "Secure" : "Sikker",
    "Configuration file access rights" : "Adgangsrettigheder til konfigurationsfil",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Den skrivebeskyttede konfiguration er blevet slået til. Dette forhindrer indstillinger af nogle konfigurationer via webgrænsefladen. I tillæg skal filen gøres skrivbar manuelt for hver opdatering.",
    "Nextcloud configuration file is writable" : "Nextcloud konfigurationsfilen er skrivbar",
    "Scheduling objects table size" : "Planlægning af objekters tabelstørrelse",
    "You have more than %s rows in the scheduling objects table. Please run the expensive repair jobs via occ maintenance:repair --include-expensive." : "Du har mere end %s rækker i tabellen med planlægningsobjekter. Kør venligst de tungere reparationsjob via occ maintenance:repair --include-expensive.",
    "Scheduling objects table size is within acceptable range." : "Tabelstørrelsen for planlægningsobjekter er inden for det acceptable område.",
    "HTTP headers" : "HTTP headere",
    "- The `%1$s` HTTP header is not set to `%2$s`. Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "- The ' %1$s' HTTP- header er ikke indstillet til ' %2$s'. Nogle funktioner virker måske ikke korrekt, da det anbefales at justere denne indstilling i overensstemmelse hermed.",
    "- The `%1$s` HTTP header is not set to `%2$s`. This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "- The ' %1$s' HTTP- header er ikke indstillet til ' %2$s'. Dette er en potentiel sikkerheds- eller fortrolighedsrisiko, da det anbefales at justere denne indstilling i overensstemmelse hermed.",
    "- The `%1$s` HTTP header is not set to `%2$s`, `%3$s`, `%4$s`, `%5$s` or `%6$s`. This can leak referer information. See the {w3c-recommendation}." : "- `%1$s` HTTP header er ikke indstillet til `%2$s`, `%3$s`, `%4$s`, `%5$s` eller `%6$s`. Dette kan lække reference information. Se mere {w3c-recommendation}.",
    "- The `Strict-Transport-Security` HTTP header is not set to at least `%d` seconds (current value: `%d`). For enhanced security, it is recommended to use a long HSTS policy." : "- The 'Strict-Transport-Security' HTTP- header er ikke indstillet til mindst '%d' sekunder (aktuel værdi: '%d'). For øget sikkerhed, anbefales det at bruge en lang HSTS politik.",
    "- The `Strict-Transport-Security` HTTP header is malformed: `%s`. For enhanced security, it is recommended to enable HSTS." : "- The 'Strict-Transport-Security' HTTP- header er misdannet: '%s'. For øget sikkerhed anbefales det at aktivere HSTS.",
    "- The `Strict-Transport-Security` HTTP header is not set (should be at least `%d` seconds). For enhanced security, it is recommended to enable HSTS." : "- The 'Strict-Transport-Security' HTTP- header er ikke indstillet (bør være mindst '%d' sekunder). For øget sikkerhed anbefales det at aktivere HSTS.",
    "Some headers are not set correctly on your instance" : "Nogle overskrifter er ikke indstillet korrekt på din instans",
    "Could not check that your web server serves security headers correctly. Please check manually." : "Kunne ikke kontrollere, at din webserver leverer sikkerhedsheadere korrekt. Kontroller venligst manuelt.",
    "Could not check that your web server serves security headers correctly, unable to query `%s`" : "Kunne ikke kontrollere at din webserver serverer sikkerhedsoverskrifter korrekt, kunne ikke forespørge '%s'",
    "Your server is correctly configured to send security headers." : "Din server er korrekt konfigureret til at sende sikkerhedsheadere.",
    "Database version" : "Databaseversion",
    "MariaDB version 10.3 detected, this version is end-of-life and only supported as part of Ubuntu 20.04. MariaDB >=%1$s and <=%2$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "MariaDB version 10.3 fundet, denne version er end-of-life og kun understøttet som en del af Ubuntu 20.04. MariaDB > = %1$s og < = %2$s foreslås for bedste ydeevne, stabilitet og funktionalitet med denne version af Nextcloud.",
    "MariaDB version \"%1$s\" detected. MariaDB >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "MariaDB version \"%1$s\" fundet. MariaDB >=%2$s og <=%3$s foreslås for bedste ydeevne, stabilitet og funktionalitet med denne version af Nextcloud.",
    "MySQL version \"%1$s\" detected. MySQL >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "MySQL- version \"%1$s\" fundet. MySQL >=%2$s og <=%3$s foreslås for bedste ydeevne, stabilitet og funktionalitet med denne version af Nextcloud.",
    "PostgreSQL version \"%1$s\" detected. PostgreSQL >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "PostgreSQL version \"%1$s\" fundet. PostgreSQL >=%2$s og <=%3$s foreslås for bedste ydeevne, stabilitet og funktionalitet med denne version af Nextcloud.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend. This is particularly recommended when using the desktop client for file synchronisation. To migrate to another database use the command line tool: \"occ db:convert-type\"." : "SQLite bliver i øjeblikket brugt som backend-database. For større installationer anbefaler vi, at du skifter til en anden database-backend. Dette anbefales især, når du bruger desktop-klienten til filsynkronisering. For at migrere til en anden database skal du bruge kommandolinjeværktøjet: \"occ db:convert-type\".",
    "Unknown database platform" : "Ukendt databaseplatform",
    "Architecture" : "Arkitektur",
    "64-bit" : "64-bit",
    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit!" : "Det ser ud til at du kører en 32-bit PHP version. Nextcloud skal bruge 64-bit for at køre ordentligt. Opgrader venligst dit OS og PHP til 64-bit!",
    "Temporary space available" : "Tilgængeligt midlertidig plads",
    "Error while checking the temporary PHP path - it was not properly set to a directory. Returned value: %s" : "Fejl under kontrol af den midlertidige PHP sti - den er ikke korrekt sat til en mappe. Returneret værdi: %s",
    "The PHP function \"disk_free_space\" is disabled, which prevents the check for enough space in the temporary directories." : "PHP funktionen \"disk_free_space\" er deaktiveret, hvilket forhindrer kontrollen af tilstrækkelig plads i de midlertidige mapper.",
    "Error while checking the available disk space of temporary PHP path or no free disk space returned. Temporary path: %s" : "Fejl under kontrol af den tilgængelige diskplads på midlertidig PHP sti eller ingen ledig diskplads returneret. Midlertidig sti: %s",
    "- %.1f GiB available in %s (PHP temporary directory)" : "- %.1f GiB tilgængelig i %s (PHP midlertidig mappe)",
    "- %.1f GiB available in %s (Nextcloud temporary directory)" : "- %.1f GiB tilgængelig i %s (Nextcloud midlertidig mappe)",
    "Temporary directory is correctly configured:\n%s" : "Midlertidig mappe er korrekt konfigureret:\n%s",
    "This instance uses an S3 based object store as primary storage, and has enough space in the temporary directory.\n%s" : "Denne instans bruger et S3-baseret objektlager som primært lager og har nok plads i den midlertidige mappe.\n%s",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GiB of free space available in the temp directory of PHP. To improve this please change the temporary directory in the php.ini or make more space available in that path. \nChecking the available space in the temporary path resulted in %.1f GiB instead of the recommended 50 GiB. Path: %s" : "Denne instans bruger et S3-baseret objektlager som primært lager. De uploadede filer gemmes midlertidigt på serveren, og det anbefales derfor at have 50 GiB ledig plads til rådighed i temp-mappen i PHP. For at forbedre dette bedes du ændre den midlertidige mappe i php.ini eller gøre mere plads tilgængelig i den sti.\nKontrol af den tilgængelige plads i den midlertidige sti resulterede i %.1f GB i stedet for den anbefalede 50 GiB. Sti: %s",
    "Database transaction isolation level" : "Databasetransaktion isolationsniveau",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Din database kører ikke med \"READ COMMITTED\" transaktions isoleringsniveau. Dette kan føre til problemer når multiple transaktioner udføres parallelt.",
    "Was not able to get transaction isolation level: %s" : "Var ikke i stand til at få transaktion isolation niveau: %s",
    ".well-known URLs" : ".well-known URL'er",
    "`check_for_working_wellknown_setup` is set to false in your configuration, so this check was skipped." : "`check_for_working_wellknown_setup` er sat til falsk i din konfiguration, så denne kontrol blev sprunget over.",
    "Could not check that your web server serves `.well-known` correctly. Please check manually." : "Kunne ikke kontrollere, at din webserver leverer `.well-known` korrekt. Kontroller venligst manuelt.",
    "Your web server is not properly set up to resolve `.well-known` URLs, failed on:\n`%s`" : "Din webserver er ikke korrekt indstillet til at løse '.well-known' URL'er, mislykkedes den:\n'%s'",
    "Your server is correctly configured to serve `.well-known` URLs." : "Din server er korrekt konfigureret til at levere `.well-known` URL'er.",
    "Font file loading" : "Fontfil indlæses",
    "Could not check for {extension} loading support. Please check manually if your webserver serves `.{extension}` files." : "Kunne ikke tjekke for {extension} indlæsningsunderstøttelse. Kontroller manuelt om din webserver tjener '. {extension}' filer.",
    "Your web server is not properly set up to deliver .{extension} files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustment to also deliver .{extension} files. Compare your Nginx configuration to the recommended configuration in our documentation." : "Din webserver er ikke korrekt indstillet til at levere. {extension} filer. Dette er typisk et problem med Nginx konfiguration. For Nextcloud 15 det har brug for en justering for også at levere. {extension} filer. Sammenlign din Nginx-konfiguration med den anbefalede konfiguration i vores dokumentation.",
    "Profile information" : "Profil information",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Profilbillede, fulde navn, e-mail, telefonnummer, adresse, hjemmeside, X (Twitter), organisation, rolle, overskrift, biografi og om din profil er aktiveret",
    "Nextcloud settings" : "Nextcloud indstillinger",
    "Unified task processing" : "Samlet opgavebehandling",
    "AI tasks can be implemented by different apps. Here you can set which app should be used for which task." : "AI opgaver kan implementeres af forskellige apps. Her kan du indstille hvilken app der skal bruges til hvilken opgave.",
    "Enable" : "Aktiver",
    "None of your currently installed apps provide Task processing functionality" : "Ingen af ​​dine aktuelt installerede apps giver opgavebehandlings funktionalitet",
    "Machine translation" : "Maskinoversættelse",
    "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "Maskinoversættelse kan implementeres af forskellige apps. Her kan du definere fortrinsretten for ​​de maskinoversættelsesapps, du har installeret i øjeblikket.",
    "Image generation" : "Billedgenerering",
    "Image generation can be implemented by different apps. Here you can set which app should be used." : "Billedgenerering kan implementeres af forskellige apps. Her kan du angive hvilken app der skal anvendes.",
    "None of your currently installed apps provide image generation functionality" : "Ingen af ​​dine aktuelt installerede apps giver billedgenereringsfunktionalitet",
    "Text processing" : "Tekstbehandling",
    "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Tekstbehandlingsopgaver kan implementeres af forskellige apps. Her kan du indstille hvilken app der skal bruges til hvilken opgave.",
    "Task:" : "Opgave:",
    "None of your currently installed apps provide text processing functionality using the Text Processing API." : "Ingen af ​​dine aktuelt installerede apps giver tekstbehandlingsfunktionalitet ved hjælp af tekstbehandlings API'et.",
    "Here you can decide which group can access certain sections of the administration settings." : "Her kan du bestemme, hvilken gruppe der kan få adgang til visse sektioner af administrationsindstillingerne.",
    "Unable to modify setting" : "Indstillingen kunne ikke ændres",
    "None" : "Ingen",
    "Changed disclaimer text" : "Ændret ansvarsfraskrivelsestekst",
    "Deleted disclaimer text" : "Slettet ansvarsfraskrivelsestekst",
    "Could not set disclaimer text" : "Ansvarsfraskrivelsesteksten kunne ikke indstilles",
    "Allow apps to use the Share API" : "Tillad apps til at bruge Share API",
    "Allow resharing" : "Tillad videredeling",
    "Allow sharing with groups" : "Tillad deling med grupper",
    "Restrict users to only share with users in their groups" : "Begræns brugere til kun at dele med brugere i deres egen gruppe",
    "Ignore the following groups when checking group membership" : "Ignorer følgende grupper når der kontrolleres for gruppe medlemsskab",
    "Allow users to share via link and emails" : "Tillad brugere at dele via link og e-mails",
    "Allow public uploads" : "Tillad offentlig upload",
    "Always ask for a password" : "Spørg altid efter adgangskode",
    "Enforce password protection" : "Gennemtving beskyttelse med adgangskode",
    "Exclude groups from password requirements" : "Ekskluder grupper fra adgangskodekrav",
    "Exclude groups from creating link shares" : "Ekskluder grupper fra at oprette linkdelinger",
    "Allow users to set custom share link tokens" : "Tillad brugere at angive brugerdefinerede delings link tokens",
    "Shares with custom tokens will continue to be accessible after this setting has been disabled" : "Delinger med tilpassede tokens vil fortsat være tilgængelige, efter at denne indstilling er blevet deaktiveret",
    "Shares with guessable tokens may be accessed easily" : "Delinger med tokens der er lette at gætte, kan nemt tilgås",
    "Limit sharing based on groups" : "Begræns deling baseret på grupper",
    "Allow sharing for everyone (default)" : "Tillad deling for alle (standard)",
    "Exclude some groups from sharing" : "Ekskluder nogle grupper fra deling",
    "Limit sharing to some groups" : "Begræns deling til nogle grupper",
    "Groups allowed to share" : "Grupper der har lov til at dele",
    "Groups excluded from sharing" : "Grupper der er ekskluderet fra deling",
    "Not allowed groups will still be able to receive shares, but not to initiate them." : "Ikke tilladte grupper vil stadig kunne modtage delinger, men ikke starte dem.",
    "Set default expiration date for internal shares" : "Indstil standardudløbsdato for interne delinger",
    "Enforce expiration date" : "Påtving udløbsdato",
    "Default expiration time of new shares in days" : "Standardudløbstid for nye delinger i dage",
    "Expire shares after x days" : "Lad delinger udløber efter x dage",
    "Set default expiration date for shares to other servers" : "Indstil standardudløbsdato for delinger til andre servere",
    "Enforce expiration date for remote shares" : "Håndhæv udløbsdatoen for fjerndelinger",
    "Default expiration time of remote shares in days" : "Standardudløbstid for fjerndelinger i dage",
    "Expire remote shares after x days" : "Lad fjerndeling udløbe efter x dage",
    "Set default expiration date for shares via link or mail" : "Indstil standardudløbsdato for delinger via link eller mail",
    "Default expiration time of shares in days" : "Standard udløbstid for delinger i dage",
    "Privacy settings for sharing" : "Privatlivsindstillinger for deling",
    "Allow account name autocompletion in share dialog and allow access to the system address book" : "Tillad autofuldførelse af kontonavn i deledialogen og tillad adgang til systemets adressebog",
    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Hvis autofuldførelse \"samme gruppe\" og \"telefonnummerintegration\" er aktiveret, så er et match i en af dem, nok til at vise brugeren.",
    "Restrict account name autocompletion and system address book access to users within the same groups" : "Begræns autofuldførelse af kontonavn og systemadressebogsadgang til brugere inden for de samme grupper",
    "Restrict account name autocompletion to users based on phone number integration" : "Begræns autofuldførelse af kontonavn til brugere baseret på telefonnummerintegration",
    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Tillad autofuldførelse, når du indtaster det fulde navn eller e-mailadresse (ignorerer manglende telefonbogsmatch og at man er i samme gruppe)",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Vis ansvarsfraskrivelsestekst på den offentlige link uploadside (vises kun, når fillisten er skjult)",
    "Disclaimer text" : "Ansvarsfraskrivelsestekst",
    "This text will be shown on the public link upload page when the file list is hidden." : "Denne tekst vil blive vist på den offentlige link uploadside, når fillisten er skjult.",
    "Default share permissions" : "Standard delingsrettigheder",
    "Two-Factor Authentication" : "To-faktor godkendelse",
    "Two-factor authentication can be enforced for all accounts and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "To-faktor godkendelse kan håndhæves for alle konti og specifikke grupper. Hvis de ikke har en to-faktor udbyder konfigureret, vil de ikke være i stand til at logge på systemet.",
    "Enforce two-factor authentication" : "Gennemtving to-faktor-godkendelse",
    "Limit to groups" : "Begræns til grupper",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Gennemtvingelse af to-faktor-godkendelse kan kun indstilles for visse grupper.",
    "Two-factor authentication is enforced for all members of the following groups." : "To-faktor-godkendelse gennemtvinges for alle medlemmer af følgende grupper.",
    "Enforced groups" : "Gennemtvungne grupper",
    "Two-factor authentication is not enforced for members of the following groups." : "To-faktor-godkendelse gennemtvinges ikke for medlemmer af følgende grupper.",
    "Excluded groups" : "Ekskluderede grupper",
    "When groups are selected/excluded, they use the following logic to determine if an account has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If an account is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Når grupper er valgt/ekskluderet, så anvender de følgende logik til at bestemme, om en konto har 2FA håndhævet: Hvis ingen grupper er valgt, så er 2FA aktiveret for alle, undtagen medlemmer af de ekskluderede grupper. Hvis grupper er valgt, så er 2FA aktiveret for alle medlemmer af disse. Hvis en konto er både i en valgt og ekskluderet gruppe, så har den valgte forrang, og 2FA håndhæves.",
    "Save changes" : "Gem ændringer",
    "Default" : "Standard",
    "Registered Deploy daemons list" : "Liste over registrerede udgivelses daemoner",
    "No Deploy daemons configured" : "Ingen udgivelses daemoner konfigureret",
    "Register a custom one or setup from available templates" : "Registrer en brugerdefineret en eller opsæt fra tilgængelige skabeloner",
    "Show details for {appName} app" : "Vis detaljer for {appName} app",
    "Update to {update}" : "Opdater til {update}",
    "Remove" : "Fjern",
    "Featured" : "Fremhævet",
    "This app is supported via your current Nextcloud subscription." : "Denne app understøttes via dit nuværende Nextcloud-abonnement.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Udvalgte apps er udviklet af og inden for fællesskabet. De tilbyder central funktionalitet og er klar til produktionsbrug.",
    "Community rating: {score}/5" : "Fællesskabsbedømmelse: {score}/5",
    "Disable all" : "Deaktiver alt",
    "Download and enable all" : "Download og aktiver alle",
    "All apps are up-to-date." : "Alle apps er opdateret",
    "Icon" : "Ikon",
    "Name" : "Navn",
    "Version" : "Version",
    "Level" : "Niveau",
    "Actions" : "Handlinger",
    "Results from other categories" : "Resultater fra andre kategorier",
    "No apps found for your version" : "Ingen apps fundet for din version",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n app har en tilgængelig opdatering","%n apps har en tilgængelig opdatering"],
    "_Update_::_Update all_" : ["Opdatér","Opdater alle"],
    "Failed to load groups" : "Kunne ikke indlæse grupper",
    "Failed to create group" : "Kunne ikke oprette gruppe",
    "Creating group…" : "Opretter gruppe...",
    "Create group" : "Opret gruppe",
    "Group name" : "Gruppenavn",
    "Please enter a valid group name" : "Indtast venligst et gyldigt gruppenavn",
    "Search groups…" : "Søg grupper…",
    "List of groups. This list is not fully populated for performance reasons. The groups will be loaded as you navigate or search through the list." : "Liste over grupper. Denne liste er ikke fuldt befolket af præstationsgrunde. Grupperne vil blive indlæst som du navigere eller søge gennem listen.",
    "Loading groups…" : "Indlæser grupper…",
    "Could not load app discover section" : "App opdagelsessektionen kunne ikke indlæses",
    "Could not render element" : "Elementet kunne ikke gengives",
    "Nothing to show" : "Intet indhold",
    "Could not load section content from app store." : "Kunne ikke hente det valgte indhold fra app store.",
    "Loading" : "Loader",
    "Fetching the latest news…" : "Henter seneste nyt...",
    "Carousel" : "Karrusel",
    "Previous slide" : "Forrige slide",
    "Next slide" : "Næste slide",
    "Choose slide to display" : "Vælg slide til visning",
    "{index} of {total}" : "{index} ud af {total}",
    "Daemon" : "Daemon",
    "Deploy Daemon" : "Implementer Daemon",
    "Type" : "Type",
    "Display Name" : "Vist navn",
    "GPUs support" : "GPUs understøttelse",
    "Compute device" : "Beregningsapparat",
    "Advanced deploy options" : "Avancerede implementeringsmuligheder",
    "Edit ExApp deploy options before installation" : "Rediger ExApp implementeringsindstillinger før installation",
    "Configured ExApp deploy options. Can be set only during installation" : "Konfigurerede ExApp implementeringsmuligheder. Kan kun indstilles under installationen",
    "Learn more" : "Lær mere",
    "Environment variables" : "Miljøvariabler",
    "ExApp container environment variables" : "ExApp container miljøvariabler",
    "No environment variables defined" : "Ingen miljøvariabler defineret",
    "Mounts" : "Monteringer",
    "Define host folder mounts to bind to the ExApp container" : "Definer værtsmappemonteringer for at binde til ExApp beholderen",
    "Must exist on the Deploy daemon host prior to installing the ExApp" : "Skal eksistere på Deploy daemon værten, før installation af ExApp",
    "Host path" : "Host stien",
    "Container path" : "Beholderstien",
    "Read-only" : "Skrivebeskyttet",
    "Remove mount" : "Fjern montering",
    "New mount" : "Ny montering",
    "Enter path to host folder" : "Indtast stien til host mappen",
    "Enter path to container folder" : "Indtast stien til beholdermappen",
    "Toggle read-only mode" : "Skift skrivebeskyttet tilstand",
    "Confirm adding new mount" : "Bekræft tilføjelse af ny montering",
    "Confirm" : "Bekræft",
    "Cancel adding mount" : "Annuller tilføjelse af montering",
    "Cancel" : "Annuller",
    "Add mount" : "Tilføj montering",
    "ExApp container mounts" : "ExApp beholdermonteringer",
    "No mounts defined" : "Der er ikke defineret nogen monteringer",
    "Description" : "Beskrivelse",
    "View in store" : "Se i butik",
    "Visit website" : "Besøg hjemmeside",
    "Usage documentation" : "Anvendelsesdokumentation",
    "Admin documentation" : "Admin-dokumentation",
    "Developer documentation" : "Udvikler-dokumentation",
    "Details" : "Detaljer",
    "All" : "Alle",
    "Limit app usage to groups" : "Begræns appanvendelse til grupper",
    "No results" : "Ingen resultater",
    "Update to {version}" : "Opdateret til {version}",
    "Deploy options" : "Implementeringsmuligheder",
    "Default Deploy daemon is not accessible" : "Standard udrulningsdaemon er ikke tilgængelig",
    "Delete data on remove" : "Slet data ved fjernelse",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Denne app har ikke angivet en minimums understøttet version af Nextcloud. I fremtiden vil dette medføre en fejl.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Denne app har ikke angivet en maksimums understøttet version af Nextcloud. I fremtiden vil dette medføre en fejl.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Dette program kan ikke installeres, da følgende afhængigheder ikke imødekommes:",
    "Latest updated" : "Sidst opdateret",
    "Author" : "Forfatter",
    "Categories" : "Kategorier",
    "Resources" : "Ressourcer",
    "Documentation" : "Dokumentation",
    "Interact" : "Interager",
    "Report a bug" : "Rapporter en fejl",
    "Request feature" : "Foreslå feature",
    "Ask questions or discuss" : "Stil spørgsmål eller diskuter",
    "Rate the app" : "Bedøm appen",
    "Rate" : "Bedøm",
    "Changelog" : "Ændringslog",
    "Google Chrome for Android" : "Google Chrome til Android",
    "{productName} iOS app" : "{productName} iOS app",
    "{productName} Android app" : "{productName} Android app",
    "{productName} Talk for iOS" : "{productName} Snak til iOS",
    "{productName} Talk for Android" : "{productName} Snak til Android",
    "Sync client" : "Synkronisér klient",
    "This session" : "Sessionen",
    "{client} - {version} ({system})" : "{client} - {version} ({system})",
    "{client} - {version}" : "{client} - {version}",
    "Device name" : "Enheds navn",
    "Cancel renaming" : "Annuller omdøbning",
    "Save new name" : "Gem nyt navn",
    "Marked for remote wipe" : "Markeret til fjernsletning",
    "Device settings" : "Enhedsindstillinger",
    "Allow filesystem access" : "Tillad filsystem adgang",
    "Rename" : "Omdøb",
    "Revoke" : "Tilbagekald",
    "Wipe device" : "Slet enhed",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Tilbagekaldelse af denne token kan muligvis forhindre sletning af din enhed, hvis sletningen endnu ikke er startet.",
    "Device" : "Enhed",
    "Last activity" : "Sidste aktivitet",
    "Devices & sessions" : "Enheder og sessioner",
    "Web, desktop and mobile clients currently logged in to your account." : "Web, stationære og mobile klienter, der er logget ind på din konto.",
    "Error while creating device token" : "Fejl ved oprettelse af enhedsnøgle",
    "App name" : "App navn",
    "Create new app password" : "Opret nyt app kodeord",
    "App password copied!" : "App adgangskode kopieret!",
    "Copy app password" : "Kopier app adgangskode",
    "Login name copied!" : "Log på navn kopieret!",
    "Copy login name" : "Kopier log på navn",
    "Could not copy app password. Please copy it manually." : "Kunne ikke kopiere app-adgangskoden. Kopier den venligst manuelt.",
    "Could not copy login name. Please copy it manually." : "Kunne ikke kopiere log på navn. Kopier det venligst manuelt.",
    "New app password" : "Ny app adgangskode",
    "Use the credentials below to configure your app or device. For security reasons this password will only be shown once." : "Anvend legitimationsoplysninger nedenfor for at konfigurere din app eller dit apparat. Af sikkerhedsgrunde, så vil denne adgangskode kun blive vist en gang.",
    "Login" : "Login",
    "Password" : "Kodeord",
    "Show QR code for mobile apps" : "Vis QR-kode til mobilapps",
    "Use system cron service to call the cron.php file every 5 minutes." : "Brug systemets cron-tjeneste til at ringe til cron.php-filen hvert 5. minut.",
    "The cron.php needs to be executed by the system account \"{user}\"." : "Cron.php skal udføres af systemkontoen \"{user}\".",
    "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details." : "PHP-modulet POSIX er påkrævet. Se {linkstart}PHP dokumentationen{linkend} for mere information.",
    "Unable to update background job mode" : "Kan ikke opdatere baggrundsjobtilstand",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "For at serveren kan fungere korrekt, så er det vigtigt, at konfigurere baggrundsjobs korrekt. Cron er den anbefalede indstilling. Se venligst dokumentationen for mere information.",
    "Last job execution ran {time}. Something seems wrong." : "Seneste baggrundsjob kørte {time}. Noget ser ud til at være galt.",
    "Last job ran {relativeTime}." : "Sidste job kørte for {relativeTime}.",
    "Background job did not run yet!" : "Baggrundsjobbet har ikke kørt endnu!",
    "AJAX" : "AJAX",
    "Execute one task with each page loaded. Use case: Single account instance." : "Udfør en opgave med hver side indlæst. Anvendelsescase: Enkeltkontoinstans.",
    "Webcron" : "Webcron",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 accounts depending on the usage)." : "cron.php er registreret hos en webcron tjeneste til at kalde cron.php hvert 5. minut over HTTP. Anvendelsescase: Meget små instanser (1-5 konti afhængigt af brugen).",
    "Cron (Recommended)" : "Cron (Anbefalet)",
    "Unable to update profile default setting" : "Kan ikke opdatere profilens standardindstilling",
    "Profile" : "Profil",
    "Enable or disable profile by default for new accounts." : "Aktiver eller deaktiver profil som standard for nye konti.",
    "Password confirmation is required" : "Bekræftelse af adgangskode er påkrævet",
    "Failed to save setting" : "Kunne ikke gemme indstillingerne",
    "{app}'s declarative setting field: {name}" : "{app}'s deklarative indstillingsfelt: {name}",
    "Unable to update server side encryption config" : "Kan ikke opdatere krypteringskonfigurationen på serversiden",
    "Server-side encryption" : "Kryptering på serversiden",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Kryptering på serversiden gør det muligt at kryptere filer, som uploades til denne server. Dette kommer med visse begrænsninger såsom en nedsat performance, så aktiver kun dette, hvis det er nødvendigt.",
    "To encrypt all existing files run this OCC command:" : "For at kryptere alle eksisterende filer skal du køre denne OCC kommando:",
    "Enable server-side encryption" : "Slå kryptering til på serversiden",
    "Disabling server side encryption is only possible using OCC, please refer to the documentation." : "Deaktivering af serversidekryptering er kun muligt ved hjælp af OCC, se venligst dokumentationen.",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Der er ikke indlæst et krypteringsmodul - slå venligst et krypteringsmodul til i app-menuen.",
    "Select default encryption module:" : "Vælg standardmodulet til kryptering:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Du skal migrere dine krypteringsnøgler fra den gamle kryptering (ownCloud <= 8.0) til den nye. Aktiver venligst \"Standardkrypteringsmodulet\" og kør {command}",
    "Cancel encryption" : "Annuller kryptering",
    "Enable encryption" : "Aktiver kryptering",
    "Confirm enabling encryption" : "Bekræft aktivering af kryptering",
    "Please read carefully before activating server-side encryption:" : "Læs venligst omhyggeligt, før du aktiverer server-side kryptering:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Når kryptering er aktiveret, så vil alle filer, der uploades til serveren fra det tidspunkt og frem, blive krypteret i hvile på serveren. Det vil kun være muligt at deaktivere kryptering på et senere tidspunkt, hvis det aktive krypteringsmodul understøtter denne funktion, og alle forudsætninger (f.eks. indstilling af en gendannelsesnøgle) er opfyldte.",
    "By default a master key for the whole instance will be generated. Please check if that level of access is compliant with your needs." : "Som standard vil en hovednøgle for hele instansen blive genereret. Kontroller, om dette adgangsniveau er i overensstemmelse med dine behov.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Kryptering alene garanterer ikke systemets sikkerhed. I dokumentationen er der mere information om hvordan krypteringsappen virker, og kan anvendes.",
    "Be aware that encryption always increases the file size." : "Vær opmærksom på at kryptering altid øger filstørrelsen.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Det er altid godt at lave regelmæssige sikkerhedskopier af dine data, i tilfælde af kryptering skal du sørge for at tage backup af krypteringsnøglerne sammen med dine data.",
    "Refer to the admin documentation on how to manually also encrypt existing files." : "Se administratordokumentationen om, hvordan man manuelt også krypterer eksisterende filer.",
    "This is the final warning: Do you really want to enable encryption?" : "Dette er den sidste advarsel: Sikker på at du vil slå kryptering til?",
    "Please confirm the group removal" : "Bekræft venligst sletning af gruppen",
    "Submit" : "Tilføj",
    "Rename group" : "Omdøb gruppe",
    "Current password" : "Nuværende adgangskode",
    "New password" : "Ny adgangskode",
    "Change password" : "Skift adgangskode",
    "Choose your profile picture" : "Vælg dit profil billede",
    "Please select a valid png or jpg file" : "Vælg en gyldig PNG eller JPG fil",
    "Error setting profile picture" : "Fejl; profil billede ikke gyldigt",
    "Error cropping profile picture" : "Fejl, kunne ikke beskære profil billede",
    "Error saving profile picture" : "Fejl; kunne ikke gemme profil billede",
    "Error removing profile picture" : "Fejl; kunne ikke slette profil billede",
    "Your profile picture" : "Dit profil billede",
    "Upload profile picture" : "Upload profil billede",
    "Choose profile picture from Files" : "Vælg profil billede fra Filer",
    "Remove profile picture" : "Fjern profil billede",
    "The file must be a PNG or JPG" : "Fil format: PNG eller JPG",
    "Picture provided by original account" : "Billede leveret af den oprindelige konto",
    "Set as profile picture" : "Indstil som profil billede",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Bemærk; det tager op til 24 timer for dit profil billede, at blive opdateret alle steder.",
    "Your biography. Markdown is supported." : "Din biografi. Markdown understøttes.",
    "Unable to update date of birth" : "Kunne ikke opdatere fødselsdato",
    "Enter your date of birth" : "Indtast din fødselsdato",
    "You are using {s}{usage}{/s}" : "Du anvender {s}{usage}{/s}",
    "You are using {s}{usage}{/s} of {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})" : "Du anvender {s}{usage}{/s} af {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})",
    "You are a member of the following groups:" : "Du er medlem af følgende grupper:",
    "Your full name" : "Dit fulde navn",
    "Email options" : "E-mail indstillinger",
    "Options for additional email address {index}" : "Muligheder for yderligere email {index}",
    "Remove primary email" : "Fjern primær e-mail",
    "Delete email" : "Slet e-mail",
    "This address is not confirmed" : "Denne adresse er ikke bekræftet",
    "Unset as primary email" : "Deaktiveret som primær e-mail",
    "Set as primary email" : "Indstil som primær e-mail",
    "Additional email address {index}" : "Yderligere e-mailadresse {index}",
    "Unable to delete primary email address" : "Den primære e-mailadresse kunne ikke slettes",
    "Unable to update primary email address" : "Den primære e-mailadresse kunne ikke opdateres",
    "Unable to add additional email address" : "Kan ikke tilføje yderligere e-mailadresse",
    "Unable to update additional email address" : "Kan ikke opdatere yderligere e-mailadresse",
    "Unable to delete additional email address" : "Kan ikke slette yderligere e-mailadresse",
    "Primary email for password reset and notifications" : "Primær e-mail til nulstilling af adgangskode og meddelelser",
    "No email address set" : "Der er ikke angivet e-mailadresse",
    "Your handle" : "Dit kendetegn",
    "Derived from your locale ({weekDayName})" : "Afledt af systemindstillinger ({weekDayName})",
    "Unable to update first day of week" : "Kunne ikke opdatere indstillingerne for første ugedag",
    "Day to use as the first day of week" : "Første dag i ugen",
    "Your headline" : "Din overskrift",
    "Unable to update language" : "Kunne ikke opdatere sproget",
    "Languages" : "Sprog",
    "Help translate" : "Hjælp med oversættelsen",
    "No language set" : "Intet sprog indstillet",
    "Unable to update locale" : "Kunne ikke opdatere lokalitet",
    "Locales" : "Lokaliteter",
    "Week starts on {firstDayOfWeek}" : "Første ugedag: {firstDayOfWeek}",
    "No locale set" : "Ingen lokalitet indstillet",
    "Your city" : "Din by",
    "Your organisation" : "Din organisation",
    "Your phone number" : "Dit telefon nummer",
    "Edit your Profile visibility" : "Rediger din profils synlighed",
    "Unable to update profile enabled state" : "Kan ikke opdatere profilaktiveret tilstand",
    "Enable profile" : "Aktivér profil",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Den mere restriktive indstilling af enten synlighed eller omfang respekteres på din profil. For eksempel, hvis synlighed er indstillet til \"Vis til alle\", og omfanget er indstillet til \"Privat\", så respekteres \"Privat\".",
    "Unable to update visibility of {displayId}" : "Kan ikke opdatere synligheden af {displayId}",
    "she/her" : "hun/hende",
    "he/him" : "han/ham",
    "they/them" : "de/dem",
    "Your role" : "Din rolle",
    "Your X (formerly Twitter) handle" : "Dit X (tidligere Twitter) brugernavn",
    "Your website" : "Vores hjemmeside",
    "Invalid value" : "Ugyldig værdi",
    "Unable to update {property}" : "Kunne ikke opdaterer {property}",
    "No {property} set" : "Ingen {property} indstillet",
    "Change scope level of {property}, current scope is {scope}" : "Skift omfangsniveau for {property}, nuværende omfang er {scope}",
    "Unable to update federation scope of the primary {property}" : "Kan ikke opdatere sammenkoblings scope for den primære {property}",
    "Unable to update federation scope of additional {property}" : "Kan ikke opdatere sammenkoblings scope for yderligere {property}",
    "Add additional email" : "Tilføj yderligere e-mail",
    "Add" : "Tilføj",
    "Create" : "Opret",
    "Change" : "Ændr",
    "Delete" : "Slet",
    "Reshare" : "Videredel",
    "Default language" : "Standardsprog",
    "Common languages" : "Hyppigt anvendte sprog",
    "Other languages" : "Andre sprog",
    "Password change is disabled because the master key is disabled" : "Adgangskodeændring er deaktiveret, fordi hovednøglen er deaktiveret",
    "No accounts" : "Ingen konti",
    "Loading accounts …" : "Indlæser kontoerne...",
    "List of accounts. This list is not fully rendered for performance reasons. The accounts will be rendered as you navigate through the list." : "Brugerkonti. Hele listen er ikke hentet, af hensyn til størrelsen. Listen vil blive hentet løbende som du kører igennem listen.",
    "Manager" : "Administrer",
    "Set line manager" : "Sæt linjeleder",
    "Account name will be autogenerated" : "Brugernavnet vil blive genereret automatisk",
    "Account name (required)" : "Brugernavn (påkrævet)",
    "Failed to search groups" : "Fejl under søgning af grupper",
    "New account" : "Ny konto",
    "Display name" : "Vist navn",
    "Either password or email is required" : "Adgangskode eller e-mail er påkrævet",
    "Password (required)" : "Adgangskode (påkrævet)",
    "Email (required)" : "E-mail (påkrævet)",
    "Email" : "E-mail",
    "Member of the following groups (required)" : "Medlem af følgende grupper (påkrævet)",
    "Member of the following groups" : "Medlem af følgende grupper",
    "Set account groups" : "Indstil bruger grupper",
    "Admin of the following groups" : "Administrator for følgende grupper",
    "Set account as admin for …" : "Sæt konto som administrator for ...",
    "Quota" : "Kvote",
    "Set account quota" : "Sæt konto kvote",
    "Language" : "Sprog",
    "Set default language" : "Vælg standard sprog",
    "Add new account" : "Tilføj ny konto",
    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} konto …","{userCount} konti …"],
    "_{userCount} account_::_{userCount} accounts_" : ["{userCount} konto","{userCount} konti"],
    "Total rows summary" : "Samlet rækkeantal",
    "Scroll to load more rows" : "Rul for at indlæse flere rækker",
    "Password or insufficient permissions message" : "Besked om adgangskode eller manglende rettigheder",
    "Avatar" : "Avatar",
    "Account name" : "Kontonavn",
    "Group admin for" : "Gruppeadministrator for",
    "Account backend" : "Konto backend",
    "Storage location" : "Placering af lageret",
    "First login" : "Første log på",
    "Last login" : "Seneste login",
    "Account actions" : "Kontohandlinger",
    "{size} used" : "{size} brugt",
    "Delete account" : "Slet konto",
    "Disconnect all devices and delete local data" : "Afbryd forbindelsen til alle indloggede enheder og slet lokale data",
    "Disable account" : "Deaktivér konto",
    "Enable account" : "Aktivér konto",
    "Resend welcome email" : "Send velkomstemail igen",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "I tilfælde af en tabt enhed eller at en forlader organisationen, så kan dette fjernslette Nextcloud-dataene fra alle enheder, der er knyttet til {userid}. Virker kun, hvis enhederne er forbundet til internettet.",
    "Remote wipe of devices" : "Fjernsletning af enheder",
    "Wipe {userid}'s devices" : "Slet {userid}'s enheder",
    "Wiped {userid}'s devices" : "Slettede {userid}'s enheder",
    "Failed to load groups with details" : "Kunne ikke indlæse grupper med detaljer",
    "Failed to load sub admin groups with details" : "Kunne ikke indlæse underadministratorgrupper med detaljer",
    "Failed to update line manager" : "Kunne ikke opdatere linjeleder",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Slet {userid}s konto fuldstændigt, inklusiv alle deres personlige filer, appdata osv.",
    "Account deletion" : "Sletning af konto",
    "Delete {userid}'s account" : "Slet {userid}s konto",
    "Display name was successfully changed" : "Vist navn er ændret",
    "Password can't be empty" : "Adgangskode kan ikke være tom",
    "Password was successfully changed" : "Adgangskode er ændret",
    "Email can't be empty" : "E-mail kan ikke være tom",
    "Email was successfully changed" : "E-mail adresse er ændret",
    "Welcome mail sent!" : "Velkomst-email sendt!",
    "Loading account …" : "Indlæser konto ...",
    "Change display name" : "Redigér vist navn",
    "Set new password" : "Angiv ny adgangskode",
    "You do not have permissions to see the details of this account" : "Du har ikke tilladelse til at se denne brugers detaljer",
    "Set new email address" : "Angiv ny e-mail adresse",
    "Add account to group" : "Føj bruger til gruppe",
    "Set account as admin for" : "Sæt konto som administrator for ...",
    "Select account quota" : "Sæt konto kvote",
    "Set the language" : "Indstil sproget",
    "Toggle account actions menu" : "Skift kontohandlingsmenu",
    "Done" : "Færdig",
    "Edit" : "Redigér",
    "Account management settings" : "Kontoadministrationsindstillinger",
    "Visibility" : "Synlighed",
    "Show language" : "Vis sprog",
    "Show account backend" : "Vis backend konto",
    "Show storage path" : "Vis lagersti",
    "Show first login" : "Vis første login",
    "Show last login" : "Vis seneste login",
    "Sorting" : "Sortering",
    "The system config enforces sorting the groups by name. This also disables showing the member count." : "Systemkonfigurationen gennemtvinger sortering af grupperne efter navn. Dette deaktiverer også visning af medlemsantallet.",
    "Group list sorting" : "Gruppeliste sortering",
    "Sorting only applies to the currently loaded groups for performance reasons. Groups will be loaded as you navigate or search through the list." : "Sortering gælder kun for de aktuelt indlæste grupper af hensyn til ydeevne. Grupper vil blive indlæst som du navigere eller søge gennem listen.",
    "By member count" : "Efter medlemstal",
    "By name" : "Efter navn",
    "Send email" : "Send e-mail",
    "Send welcome email to new accounts" : "Send velkomstmail til nye konti",
    "Defaults" : "Standarder",
    "Default quota" : "Standard kvote",
    "Select default quota" : "Vælg standardkvote",
    "Server error while trying to complete WebAuthn device registration" : "Serverfejl under forsøg på at fuldføre WebAuthn-enhedsregistrering",
    "Passwordless authentication requires a secure connection." : "Adgangskodefri godkendelse kræver en sikker forbindelse.",
    "Add WebAuthn device" : "Tilføj WebAuthn-enhed",
    "Please authorize your WebAuthn device." : "Godkend venligst din WebAuthn-enhed.",
    "Adding your device …" : "Tilføjer din enhed...",
    "Unnamed device" : "Unavngiven enhed",
    "Passwordless Authentication" : "Adgangskodeløs godkendelse",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Konfigurer din konto til adgangskodefri godkendelse efter FIDO2-standarden.",
    "No devices configured." : "Ingen enheder konfigureret.",
    "The following devices are configured for your account:" : "Følgende enheder er konfigureret til din konto:",
    "Your browser does not support WebAuthn." : "Din browser understøtter ikke WebAuthn.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Som administrator kan du finjustere delingsadfærden. Se venligst dokumentationen for mere information.",
    "You need to enable the File sharing App." : "Du skal aktivere fildelingsappen.",
    "App Store" : "App Store",
    "Loading app list" : "Send velkomstmail til nye konti",
    "Loading categories" : "Indlæser kategorier",
    "Developer documentation ↗" : "Udviklerdokumentation ↗",
    "Version {version}, {license}-licensed" : "Version {version}, {license}-licenseret",
    "Version {version}" : "Version {version}",
    "All accounts" : "Alle konti",
    "Admins" : "Administratorer",
    "Account group: {group}" : "Konto gruppe: {group}",
    "Account management" : "Kontostyring",
    "Sending…" : "Sender...",
    "Email sent" : "E-mail afsendt",
    "For performance reasons, when you enable encryption on a Nextcloud server only new and changed files are encrypted." : "Af hensyn til performancemæssige, så er det kun nye og ændrede filer, der krypteres, når du aktiverer kryptering på en Nextcloud server.",
    "Location" : "Sted",
    "Profile picture" : "Profilbillede",
    "About" : "Om",
    "Date of birth" : "Fødselsdato",
    "Full name" : "Fulde navn",
    "Additional email" : "Yderligere e-mail",
    "Fediverse (e.g. Mastodon)" : "Fediverse (fx Mastodon)",
    "Headline" : "Overskrift",
    "Organisation" : "Organisation",
    "Phone number" : "Telefon nummer",
    "Pronouns" : "Pronominer",
    "Role" : "Rolle",
    "X (formerly Twitter)" : "X (tidligere Twitter)",
    "Website" : "Hjemmeside",
    "Profile visibility" : "Profilsynlighed",
    "Locale" : "Lokalitet",
    "First day of week" : "Første dag i ugen",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Ikke tilgængelig, da denne egenskab er påkrævet for kernefunktionalitet, herunder fildeling og kalenderinvitationer",
    "Not available as federation has been disabled for your account, contact your system administration if you have any questions" : "Ikke tilgængelig som sammenkobling er blevet deaktiveret for din konto, kontakt din systemadministration hvis du har spørgsmål",
    "Not available as publishing account specific data to the lookup server is not allowed, contact your system administration if you have any questions" : "Ikke tilgængelig, da udgivelse af kontospecifikke data til opslagsserveren ikke er tilladt. Kontakt din systemadministration, hvis du har spørgsmål",
    "Discover" : "Opdag",
    "Your apps" : "Dine apps",
    "Active apps" : "Aktive apps",
    "Disabled apps" : "Deaktiverede apps",
    "Updates" : "Opdateringer",
    "App bundles" : "App bundles",
    "Featured apps" : "Udvalgte apps",
    "Supported apps" : "Understøttede apps",
    "Show to everyone" : "Vis til alle",
    "Show to logged in accounts only" : "Vis kun til påloggede konti",
    "Hide" : "Skjul",
    "Manually installed apps cannot be updated" : "Manuelt installerede apps kan ikke opdateres",
    "{progress}% Deploying …" : "{progress}% Udruller …",
    "{progress}% Initializing …" : "{progress}% Initialiserer …",
    "Health checking" : "Sundhedskontrol",
    "Deploy and Enable" : "Udrul og aktiver",
    "Download and enable" : "Download og aktiver",
    "Disable" : "Deaktiver",
    "Allow untested app" : "Tillad ikke-testet app",
    "The app will be downloaded from the App Store" : "Appen vil blive downloadet fra App Store",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Denne app er ikke markeret som kompatibel med din Nextcloud version. Hvis du fortsætter, vil du stadig være i stand til at installere appen. Bemærk, at appen muligvis ikke fungerer som forventet.",
    "Unknown" : "Ukendt",
    "Never" : "Aldrig",
    "Could not register device: Network error" : "Kunne ikke registrere apparat: Netværksfejl",
    "Could not register device: Probably already registered" : "Kunne ikke registrere apparat: Sandsynligvis allerede registreret",
    "Could not register device" : "Kunne ikke registrere apparat",
    "An error occurred during the request. Unable to proceed." : "Der opstod en fejl under anmodningen. Kan ikke fortsætte.",
    "The app has been enabled but needs to be updated." : "Appen er blevet aktiveret, men skal opdateres.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Fejl: Denne app kan ikke aktiveres, fordi den gør serveren ustabil",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Appen er blevet aktiveret, men skal opdateres. Du vil blive omdirigeret til opdateringssiden om 5 sekunder.",
    "Do you really want to wipe your data from this device?" : "Vil du virkelig slette dine data fra denne enhed?",
    "Confirm wipe" : "Bekræft sletning",
    "Could not delete the app token" : "Kunne ikke slette app token",
    "Error while wiping the device with the token" : "Fejl under sletning af enheden med token",
    "Error while updating device token name" : "Fejl under opdatering af enhedstokennavn",
    "Error while updating device token scope" : "Fejl under opdatering af enhedstokenomfang",
    "Could not set group sorting" : "Kunne ikke indstille gruppesortering",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Der har været for mange forespørgsmåler fra dit netværk. Forsøg igen senere eller kontakt din administrator hvis dette er en fejl.",
    "Error" : "Fejl",
    "Account documentation" : "Konto dokumentation",
    "Administration documentation" : "Administrations dokumentation",
    "Forum" : "Forum",
    "Nextcloud help & privacy resources" : "Nextcloud hjælpe- og privatlivsressourcer",
    "General documentation" : "Overordnet dokumentation",
    "Legal notice" : "Juridisk notits",
    "Privacy policy" : "Fortrolighedspolitik",
    "None/STARTTLS" : "Ingen/STARTTLS",
    "SSL" : "SSL",
    "Open documentation" : "Åbn dokumentation",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Det er vigtigt at konfigurere denne server til at kunne sende e-mails, f.eks. for nulstilling af adgangskode og meddelelser.",
    "Send mode" : "Tilstand for afsendelse",
    "Encryption" : "Kryptering",
    "Sendmail mode" : "Sendemail-tilstand",
    "From address" : "Fra adresse",
    "Server address" : "Serveradresse",
    "Port" : "Port",
    "Authentication" : "Godkendelse",
    "Authentication required" : "Godkendelse påkrævet",
    "Credentials" : "Legitimationsoplysninger",
    "SMTP Login" : "SMTP Log på",
    "SMTP Password" : "SMTP Kodeord",
    "Save" : "Gem",
    "Test and verify email settings" : "Afprøv og bekræft indstillinger",
    "Security & setup warnings" : "Advarsler om sikkerhed og opsætning",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Det er vigtigt for sikkerheden og ydeevnen af din instans, at alt er konfigureret korrekt. For at hjælpe dig med det, så laver vi foretager vi nogle automatiske kontroller. Se venligst den linkede dokumentation for mere information.",
    "All checks passed." : "Alle tjek blev bestået.",
    "There are some errors regarding your setup." : "Der er nogle fejl vedrørende din opsætning.",
    "There are some warnings regarding your setup." : "Der er nogle advarsler vedrørende din opsætning.",
    "Checking for system and security issues." : "Tjek for system- og sikkerhedsproblemer.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Dobbelttjek venligst <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installations vejledninger ↗</a>, og tjek for eventuelle fejl eller advarsler i <a href=\"%2$s\">loggen</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Tjek sikkerheden på din Nextcloud via <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">vores sikkerhedsscanning ↗</a>.",
    "Reasons to use Nextcloud in your organization" : "Grunde til at bruge Nextcloud i din organisation",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Udviklet af {communityopen}Nextcloud fællesskabet{linkclose}, {githubopen}kildekoden{linkclose} er udgivet med {licenseopen}AGPL{linkclose} licensen.",
    "Like our Facebook page" : "Følg os på Facebook",
    "Follow us on X" : "Følg os på X",
    "Follow us on Mastodon" : "Følg os på Mastodon",
    "Check out our blog" : "Besøg vores blog",
    "Subscribe to our newsletter" : "Abonner på vores nyhedsbrev",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Denne fællesskabsudgivelse af Nextcloud er ikke understøttet, og øjeblikkelige meddelelser er ikke tilgængelige.",
    "Use a second factor besides your password to increase security for your account." : "Brug to-faktor godkendelse for at øge sikkerheden for din konto.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Hvis du bruger tredjepartsapplikationer til at oprette forbindelse til Nextcloud, så skal du sørge for at oprette og konfigurere en app-adgangskode for hver applikation, før du aktiverer to-faktor-godkendelse.",
    "Logged in account must be a subadmin" : "På-logget konto skal være en subadmin",
    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "For at tillade at denne kontrol køres så skal du sikre dig at din webserver kan forbinde til sig selv. Derfor skal den kunne opløse og forbinde til mindst en af dets `trusted_domains` eller `overwrite.cli.url`. Denne fejl kan være resultatet af en server-side DNS mismatch eller udadgående firewall regel.",
    "File locking" : "Fillåsning",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems." : "Transaktionel fillåsning er deaktiveret. Dette kan føre til problemer med ræskonditioner. Aktiver \"filelocking.enabled\" i config.php for at undgå disse problemer.",
    "The PHP memory limit is below the recommended value of %s." : "PHP hukommelsesgræsen er under den anbefalede værdi på %s.",
    "for WebAuthn passwordless login" : "til WebAuthn adgangskodeløst login",
    "for WebAuthn passwordless login, and SFTP storage" : "til WebAuthn adgangskodeløst login, og SFTP lagring",
    "- The `%1$s` HTTP header does not contain `%2$s`. This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "- HTTP- headeren ' %1$s' indeholder ikke ' %2$s'. Dette er en potentiel sikkerheds- eller fortrolighedsrisiko, da det anbefales at justere denne indstilling i overensstemmelse hermed.",
    "PostgreSQL version \"%s\" detected. PostgreSQL >=12 and <=16 is suggested for best performance, stability and functionality with this version of Nextcloud." : "PostgreSQL- version \"%s\" fundet. PostgreSQL > = 12 og < = 16 er foreslået for bedste ydeevne, stabilitet og funktionalitet med denne version af Nextcloud.",
    "Set default expiration date for shares" : "Indstil standardudløbsdato for delinger",
    "Your biography" : "Din biografi",
    "You are using <strong>{usage}</strong>" : "Forbrug: <strong>{usage}</strong>",
    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Forbrug: <strong>{usage}</strong> af <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
    "Failed to load subadmin groups with details" : "Kunne ikke indlæse subadmin grupper med detaljer"
},
"nplurals=2; plural=(n != 1);");
