OC.L10N.register(
    "nextcloud_announcements",
    {
    "Nextcloud announcements" : "Thông báo Nextcloud",
    "Nextcloud announcement" : "Thông báo Nextcloud",
    "Read more" : "Đọc thêm",
    "Disable announcements" : "Tắt thông báo",
    "(These announcements are only shown to administrators)" : "(Các thông báo này chỉ được hiện cho các quản trị viên)",
    "Nextcloud announcements brings the latest news of Nextcloud into your notifications" : "Thông báo Nextcloud mang tin tức mới nhất của Nextcloud vào thông báo của bạn"
},
"nplurals=1; plural=0;");
