OC.L10N.register(
    "settings",
    {
    "Private" : "Súkromný",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Viditeľné iba pre ľudí s integráciou telefónneho čísla prostredníctvom aplikácie Talk /Rozhovor/ pre mobil",
    "Local" : "Lokálny",
    "Only visible to people on this instance and guests" : "Viditeľné iba pre ľudí na tejto inštancii a hostí",
    "Federated" : "Združený",
    "Only synchronize to trusted servers" : "Synchronizovať iba s dôveryhodnými servermi",
    "Published" : "Publikované",
    "Synchronize to trusted servers and the global and public address book" : "Synchronizovať s dôveryhodnými servermi a globálnym a verejným adresárom",
    "Verify" : "Overiť",
    "Verifying …" : "Overovanie ...",
    "Unable to change password" : "Zmena hesla sa nepodarila",
    "Very weak password" : "Veľmi slabé heslo",
    "Weak password" : "Slabé heslo",
    "So-so password" : "Priemerné heslo",
    "Good password" : "Dobré heslo",
    "Strong password" : "Silné heslo",
    "Groups" : "Skupiny",
    "Group list is empty" : "Zoznam skupín je prázdny",
    "Unable to retrieve the group list" : "Nie je možné načítať zoznam skupín",
    "{actor} added you to group {group}" : "používateľ {actor} vás pridal do skupiny {group}",
    "You added {user} to group {group}" : "Pridali ste používateľa {user} do skupiny {group}",
    "{actor} added {user} to group {group}" : "{actor} pridal(a) používateľa {user} do skupiny {group}",
    "An administrator added you to group {group}" : "Správca vás pridal do skupiny {group}",
    "An administrator added {user} to group {group}" : "Správca pridal používateľa {user} do skupiny {group}",
    "{actor} removed you from group {group}" : "{actor} vás odobral(a) zo skupiny {group}",
    "You removed {user} from group {group}" : "Odobrali ste používateľa {user} zo skupiny {group}",
    "{actor} removed {user} from group {group}" : "{actor} odobral(a) používateľa {user} ze skupiny {group}",
    "An administrator removed you from group {group}" : "Správca vás odobral ze skupiny {group}",
    "An administrator removed {user} from group {group}" : "Správca odobral používateľa {user} zo skupiny {group}",
    "Your <strong>group memberships</strong> were modified" : "Bolo upravené vaše <strong>členstvo v skupinách</strong>",
    "{actor} changed your password" : "{actor} zmenil Vaše heslo",
    "You changed your password" : "Zmenili ste si heslo",
    "Your password was reset by an administrator" : "Vaše heslo bolo resetované administrátorom",
    "Your password was reset" : "Vaše heslo bolo znova nastavené",
    "{actor} changed your email address" : "{actor} zmenil Vašu emailovú adresu",
    "You changed your email address" : "Zmenili ste si emailovú adresu",
    "Your email address was changed by an administrator" : "Vaša emailová adresa bola zmenená administrátorom",
    "You created an app password for a session named \"{token}\"" : "Vytvorili ste heslo aplikácie pre reláciu s názvom \"{token}\"",
    "An administrator created an app password for a session named \"{token}\"" : "Administrátor vytvoril heslo aplikácie pre reláciu s názvom \"{token}\"",
    "You deleted app password \"{token}\"" : "Odstránili ste heslo pre aplikáciu \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Premenovali ste heslo aplikácie \"{token}\" na \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "Povolili ste prístup k súborovému systému aplikácii, používajúcej heslo \"{token}\"",
    "You revoked filesystem access from app password \"{token}\"" : "Zrušili ste prístup k súborovému systému pre aplikáciu, používajúcej heslo \"{token}\"",
    "Security" : "Zabezpečenie",
    "You successfully logged in using two-factor authentication (%1$s)" : "Úspešne ste sa prihlásili pomocou dvoj-faktorovej autentizácie (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Pokus o prihlásenie s použitím dvoj-faktorovej autentizácie zlyhal (%1$s)",
    "Remote wipe was started on %1$s" : "Vymazanie na diaľku sa začalo na %1$s",
    "Remote wipe has finished on %1$s" : "Vymazanie na diaľku sa skončilo na %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Vaše <strong>heslo</strong> alebo <strong>email</strong> bolo zmenené",
    "Settings" : "Nastavenia",
    "Could not remove app." : "Aplikáciu nie je možné zmazať.",
    "Could not update app." : "Nepodarilo sa aktualizovať aplikáciu.",
    "Wrong password" : "Nesprávne heslo",
    "Unable to change personal password" : "Nepodarilo sa zmeniť osobné heslo",
    "Saved" : "Uložené",
    "No Login supplied" : "Žiadne prihlasovacie údaje neboli poskytnuté",
    "Unable to change password. Password too long." : "Nepodarilo sa zmeniť heslo. Heslo je veľmi dlhé.",
    "Authentication error" : "Chyba autentifikácie",
    "Please provide an admin recovery password; otherwise, all account data will be lost." : "Zadajte administrátorské heslo pre obnovu, inak budú všetky údaje o účte stratené.",
    "Wrong admin recovery password. Please check the password and try again." : "Chybné administrátorské heslo pre obnovu. Skontrolujte správnosť hesla a skúste to znovu.",
    "Backend does not support password change, but the encryption of the account key was updated." : "Backend nepodporuje zmenu hesla, ale kľúč k účtu bol aktualizovaný.",
    "Administrator documentation" : "Príručka administrátora",
    "User documentation" : "Príručka používateľa",
    "Nextcloud help overview" : "Nextcloud - prehľad pomoci",
    "Invalid SMTP password." : "Nesprávne heslo pre SMTP.",
    "Email setting test" : "Test nastavení emailu",
    "Well done, %s!" : "Dobrá práca, %s!",
    "If you received this email, the email configuration seems to be correct." : "Ak ste prijali tento email, emailová konfigurácia sa zdá byť správna.",
    "Email could not be sent. Check your mail server log" : "Nepodarilo sa odoslať email. Skontrolujte log vášho mail servera",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Vyskytol sa problém pri odosielaní emailu. Prosím, znovu skontrolujte svoje nastavenia. (Chyba: %s)",
    "You need to set your account email before being able to send test emails. Go to %s for that." : "Musíte nastaviť svoj email k účtu, než budete môcť odoslať testovacie emaily. Ak tak chcete urobiť, prejdite na %s.",
    "Recently active" : "Naposledy aktívny",
    "Disabled accounts" : "Zakázané účty",
    "Invalid account" : "Neplatný účet",
    "Invalid mail address" : "Neplatná emailová adresa",
    "Settings saved" : "Nastavenia uložené",
    "Unable to change full name" : "Nemožno zmeniť meno a priezvisko",
    "Unable to change email address" : "Nemožno zmeniť emailovú adresu",
    "Unable to set invalid phone number" : "Nie je možné nastaviť neplatné telefónne číslo",
    "Unable to set invalid website" : "Nie je možné nastaviť neplatnú webstránku",
    "Some account data was invalid" : "Niektoré dáta účtu boli neplatné",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Ak chcete overiť svoj Twitter účet, napíšte nasledujúci tweet (uistite sa, že ho zasielate bez zalomenia riadkov):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Pre verifikáciu vašich webových stránok uložte nasledujúci obsah v koreňovom adresári webovej stránky v umiestnení '.well-known/CloudIdVerificationCode.txt' (uistite sa, že bol text vložený ako jediný riadok)",
    "%1$s changed your password on %2$s." : "%1$s zmenil Vaše heslo na %2$s.",
    "Your password on %s was changed." : "Vaše heslo na %s bolo zmenené.",
    "Your password on %s was reset by an administrator." : "Vaše heslo na %s bolo resetované administrátorom.",
    "Your password on %s was reset." : "Vaše heslo na %s bolo znova nastavené.",
    "Password for %1$s changed on %2$s" : "Heslo pre %1$s bolo zmenené na %2$s",
    "Password changed for %s" : "Heslo zmenené pre %s",
    "If you did not request this, please contact an administrator." : "Ak ste to nevyžadovali, prosím kontaktujte administrátora.",
    "Your email address on %s was changed." : "Vaša emailová adresa na %s bola zmenená.",
    "Your email address on %s was changed by an administrator." : "Vaša emailová adresa na %s bola zmenená administrátorom.",
    "Email address for %1$s changed on %2$s" : "Emailová adresa pre %1$s zmenená na %2$s",
    "Email address changed for %s" : "Emailová adresa zmenená pre %s",
    "The new email address is %s" : "Nová emailová adresa je %s",
    "Your %s account was created" : "Váš účet %s bol vytvorený",
    "Welcome aboard" : "Vitajte na palube",
    "Welcome aboard %s" : "Vitajte na palube %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Vitajte vo vašom %s účte, môžete pridávať, chrániť a zdieľať svoje dáta.",
    "Your Login is: %s" : "Váše prihlasovacie meno je: %s",
    "Set your password" : "Nastavte si heslo",
    "Go to %s" : "Prejsť na %s",
    "Install Client" : "Inštalácia klienta",
    "Apps" : "Apky",
    "Personal" : "Osobné",
    "Administration" : "Administrácia",
    "Users" : "Používatelia",
    "Additional settings" : "Ďalšie nastavenia",
    "Assistant" : "Asistent",
    "Administration privileges" : "Oprávnenia správcu",
    "Groupware" : "Groupware",
    "Overview" : "Prehľad",
    "Basic settings" : "Základné nastavenia",
    "Sharing" : "Zdieľanie",
    "Availability" : "Dostupnosť",
    "Calendar" : "Kalendár",
    "Personal info" : "Osobné informácie",
    "Mobile & desktop" : "Mobil a počítač",
    "Artificial Intelligence" : "Umelá inteligencia",
    "Email server" : "Poštový server",
    "Mail Providers" : "Poskytovatelia e-mailu",
    "Mail provider enables sending emails directly through the user's personal email account. At present, this functionality is limited to calendar invitations. It requires Nextcloud Mail 4.1 and an email account in Nextcloud Mail that matches the user's email address in Nextcloud." : "Poskytovateľ e-mailu umožňuje odosielať e-maily priamo prostredníctvom osobného e-mailového konta používateľa. V súčasnosti je táto funkcia obmedzená na pozvánky do kalendára. Vyžaduje si aplikáciu Nextcloud Mail 4.1 a e-mailové konto v službe Nextcloud Mail, ktoré sa zhoduje s e-mailovou adresou používateľa v službe Nextcloud.",
    "Send emails using" : "Odosielať e-maily pomocou",
    "User's email account" : "Uživateľský e-mail účet",
    "System email account" : "Systémový e-mail účet",
    "Security & setup checks" : "Bezpečnosť a kontrola nastavení",
    "Background jobs" : "Úlohy na pozadí",
    "Unlimited" : "Nelimitované",
    "Verifying" : "Overovanie",
    "Allowed admin IP ranges" : "Povolené rozsahy IP adries pre administráciu",
    "Admin IP filtering isn't applied." : "Filtrovanie IP adries pre administráciu sa nepoužije.",
    "Configuration key \"%1$s\" expects an array (%2$s found). Admin IP range validation will not be applied." : "Konfiguračný kľúč \"%1$s\" očakáva pole (nájdené %2$s). Overenie IP rozsahu pre administráciu sa nepoužije.",
    "Configuration key \"%1$s\" contains invalid IP range(s): \"%2$s\"" : "Konfiguračný kľúč \"%1$s\" obsahuje naplatný IP rozsah(y): \"%2$s\"",
    "Admin IP filtering is correctly configured." : "Filtrovanie IP pre adminstráciu je správne nakonfigurované.",
    "App directories owner" : "Vlastník adresárov Aplikácie",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:\n%s" : "Niektoré aplikačné adresáre majú iného vlastníka ako web server. Toto môže nastať ak aplikácie boli inštalované manuálne. Skontrolujte práva nasledovných adresárov nasledovných aplikácií:\n%s",
    "App directories have the correct owner \"%s\"" : "Adresáre Aplikácie majú správneho vlastníka \"%s\"",
    "Brute-force Throttle" : "Potlačenie Brute-force útoku",
    "Your remote address could not be determined." : "Váša vzdialená adresa sa nedala určiť.",
    "Your remote address was identified as \"%s\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly." : "Váš vzdialený adresár bol identifikovaný ako \"%s\" a momentálne súčasťou potlačovania útoku hrubou silou, čo spomaľuje výkon rôznych požiadaviek. Ak vzdialená adresa nie je vaša adresa, môže to naznačovať, že proxy nie je správne nakonfigurovaná.",
    "Your remote address \"%s\" is not brute-force throttled." : "Váš vzdialený adresár \"%s\" nie je obmedzený pre útok hrubou silou.",
    "Old administration imported certificates" : "Importované certifikáty starej administrácie",
    "A background job is pending that checks for administration imported SSL certificates. Please check back later." : "Úloha na pozadí čaká na kontrolu administrácie importovaných SSL certifikátov. Skúste to znova neskôr.",
    "There are some administration imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Našlo sa niekoľko administratívnych importovaných SSL certifikátov, ktoré sa už v NextCloud 21 nepoužívajú. Môžu byť importované z príkazového riadku pomocou \"occ security:certificates:import\". Ich cesty vo vnútri dátového adresára sú uvedené nižšie.",
    "Code integrity" : "Integrita kódu",
    "Integrity checker has been disabled. Integrity cannot be verified." : "Kontrola integrity bola zakázaná. Integrita nemôže byť overená.",
    "No altered files" : "Žiadne zmenené súbory",
    "Some files have not passed the integrity check. {link1} {link2}" : "Niektoré súbory neprešli kontrolou integrity. {link1} {link2}",
    "Cron errors" : "Chyby Cron-u",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:\n%s" : "Nebolo možné spustiť úlohu na pozadí pomocou CLI. Nasledujúce technické chyby sa môžu objaviť:\n%s",
    "The last cron job ran without errors." : "Posledný cron job prebehol bez chýb.",
    "Cron last run" : "Cron naposledy spustený",
    "Last background job execution ran %s. Something seems wrong. {link}." : "Posledné vykonanie úlohy na pozadí prebehlo %s. Niečo nefunguje. {link}.",
    "Last background job execution ran %s." : "Posledné spustenie úloh na pozadí prebehlo %s.",
    "Data directory protected" : "Adresár s dátami je chránený.",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Váš dátový adresár a súbory sú pravdepodobne prístupné z internetu. Súbor .htaccess nefunguje. Dôrazne odporúčame nakonfigurovať webový server tak, aby k dátovému adresáru už nebol prístupný, alebo presunúť dátový adresár mimo koreňa dokumentov webového servera.",
    "Could not check that the data directory is protected. Please check manually that your server does not allow access to the data directory." : "Nepodarilo sa overiť, či je adresár s dátami chránený. Prosím, manuálne skontrolujte, či váš server umožňuje prístup k adresáru s dátami.",
    "Database missing columns" : "Chýbajúce stĺpce databázy",
    "Missing optional column \"%s\" in table \"%s\"." : "Chýba voliteľný stĺpec \"%s\" v tabuľke \"%s\".",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "V databáze chýbajú niektoré voliteľné stĺpce. Vzhľadom na skutočnosť, že pridanie stĺpcov na veľké tabuľky by mohlo nejaký čas trvať, neboli pridané automaticky, keď môžu byť voliteľné. Spustením príkazu „occ db:add-missing-columns“ sa tieto chýbajúce stĺpce môžu pridať ručne, zatiaľ čo inštancia zostáva v prevádzke. Po pridaní stĺpcov môžu niektoré funkcie zlepšiť odozvu alebo použiteľnosť.",
    "Database missing indices" : "Chýbajúce indexy databázy",
    "Missing indices:" : "Chýbajúce indexy:",
    "\"%s\" in table \"%s\"" : "\"%s\" v tabuľke \"%s\"",
    "Detected some missing optional indices. Occasionally new indices are added (by Nextcloud or installed applications) to improve database performance. Adding indices can sometimes take awhile and temporarily hurt performance so this is not done automatically during upgrades. Once the indices are added, queries to those tables should be faster. Use the command `occ db:add-missing-indices` to add them." : "Zistilo sa niekoľko chýbajúcich voliteľných indexov. Príležitostne sa pridávajú nové indexy (prostredníctvom Nextcloud alebo nainštalovaných aplikácií), aby sa zlepšil výkon databázy. Pridávanie indexov môže niekedy chvíľu trvať a dočasne poškodiť výkon, takže sa to počas aktualizácií nerobí automaticky. Po pridaní indexov by mali byť dopyty do týchto tabuliek rýchlejšie. Na ich pridanie použite príkaz `occ db:add-missing-indices`.",
    "Database missing primary keys" : "Chýbajúce primárne kľúče v databáze.",
    "Missing primary key on table \"%s\"." : "Chýbajúci primárny kľúč na tabuľke \"%s\".",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "V databáze chýbajú niektoré primárne kľúče. Vzhľadom na to, že pridávanie primárnych kľúčov do veľkých tabuliek by mohlo chvíľu trvať, neboli pridané automaticky. Spustením príkazu „occ db:add-missing-primary-keys“ je možné tieto chýbajúce primárne kľúče pridať ručne, zatiaľ čo inštancia beží.",
    "Database pending bigint migrations" : "Databáza čaká na migráciu typu bigint.",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline." : "Niektorým stĺpcom v databáze chýba konverzia na bigint. Vzhľadom na to, že zmena typov stĺpcov na veľkých tabuľkách by mohla chvíľu trvať, neboli zmenené automaticky. Spustením príkazu „occ db: convert-filecache-bigint“ budú zmeny aplikované manuálne. Túto operáciu je potrebné vykonať v čase, keď je inštancia offline.",
    "Debug mode" : "Režim ladenia",
    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Táto inštancia beží v režime ladenia. Toto povolte iba pre lokálny vývoj a nie v produkčnom prostredí.",
    "Debug mode is disabled." : "Režim ladenia je vypnutý.",
    "Default phone region" : "Predvolený telefónny región",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective ISO 3166-1 code of the region to your config file." : "Vaša inštalácia nemá nastavenú žiadnu predvolenú oblasť predvoľby telefónu. Toto je potrebné na overenie telefónnych čísel v nastaveniach profilu bez kódu krajiny. Ak chcete povoliť čísla bez kódu krajiny, pridajte do svojho konfiguračného súboru „default_phone_region“ s príslušným ISO 3166-1 kódom regiónu.",
    "Email test" : "Test Emailu",
    "Mail delivery is disabled by instance config \"%s\"." : "Doručovanie pošty je zakázané konfiguráciou inštancie \"%s\".",
    "Email test was successfully sent" : "Testovací Email bol úspešne odoslaný.",
    "You have not set or verified your email server configuration, yet. Please head over to the \"Basic settings\" in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "Zatiaľ ste nenastavili ani neoverili konfiguráciu e-mailového servera. Ak ju chcete nastaviť, prejdite na základné nastavenia. Potom pomocou tlačidla „Odoslať e-mail“ pod formulárom overte svoje nastavenia.",
    "Transactional File Locking" : "Transakčné Uzamykanie Súborov",
    "Transactional File Locking is disabled. This is not a a supported configuraton. It may lead to difficult to isolate problems including file corruption. Please remove the `'filelocking.enabled' => false` configuration entry from your `config.php` to avoid these problems." : "Transakčné Uzamykanie Súborov je vypnuté. Toto nie je podporovaná konfigurácia. Môže to viesť k ťažko izolovateľným problémom vrátane poškodenia súborov. Ak chcete predísť týmto problémom, odstráňte konfiguračnú položku `'filelocking.enabled' => false` z vášho súboru `config.php`.",
    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available." : "Na transakčné uzamykanie súborov sa používa databáza. Pre zvýšenie výkonu, ak je to možné,  prosím, nakonfigurujte memcache.",
    "Forwarded for headers" : "Preposlané kvôli hlavičkám",
    "Your \"trusted_proxies\" setting is not correctly set, it should be an array." : "Vaše \"trusted_proxies\" nastavenie nie je správne, malo by to byť pole.",
    "Your \"trusted_proxies\" setting is not correctly set, it should be an array of IP addresses - optionally with range in CIDR notation." : "Vaše nastavenie \"trusted_proxy\" nie je správne, malo by to byť pole IP adries - voliteľne s rozsahom v notácii CIDR.",
    "The reverse proxy header configuration is incorrect. This is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "Nastavenie hlavičky reverzného proxy servera je nesprávne. Toto je bezpečnostný problém a môže umožniť útočníkovi falšovať svoju IP adresu, ktorá je viditeľná pre Nextcloud.",
    "Your IP address was resolved as %s" : "Vaša IP adresa bola rozpoznaná ako %s",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "Nastavenie hlavičky reverzného proxy je nesprávne alebo pristupujete k Nextcloudu z dôveryhodného proxy. Ak nie, ide o bezpečnostný problém a útočníkovi umožňuje falšovať svoju IP adresu, ktorá je viditeľná pre Nextcloud.",
    "HTTPS access and URLs" : "Prístup HTTPS a URL adresy",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "Prístup na stránku nie je nezabezpečený cez HTTP. Dôrazne sa odporúča nastaviť server tak, aby namiesto toho vyžadoval HTTPS. Bez neho niektoré dôležité webové funkcie ako \"kopírovanie do schránky\" alebo \"procesy služieb\" nebudú fungovať!",
    "Accessing site insecurely via HTTP." : "Prístup na stránku nezabezpečeným spôsobom cez HTTP.",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This likely means that your instance is behind a reverse proxy and the Nextcloud `overwrite*` config values are not set correctly." : "K svojej inštancii pristupujete cez zabezpečené pripojenie, no vaša inštancia generuje nezabezpečené adresy URL. Pravdepodobne to znamená, že vaša inštancia je za reverzným proxy serverom a hodnoty konfigurácie Nextcloud `overwrite*` nie sú správne nastavené.",
    "Your instance is generating insecure URLs. If you access your instance over HTTPS, this likely means that your instance is behind a reverse proxy and the Nextcloud `overwrite*` config values are not set correctly." : "Vaša inštancia generuje nezabezpečené adresy URL. Ak pristupujete k svojej inštancii cez HTTPS, pravdepodobne to znamená, že vaša inštancia je za reverzným proxy serverom a hodnoty konfigurácie Nextcloud `overwrite*` nie sú správne nastavené.",
    "You are accessing your instance over a secure connection, and your instance is generating secure URLs." : "Prístup k vašej inštancii prebieha cez zabezpečené pripojenie a vaša inštancia generuje zabezpečené URL adresy.",
    "Internet connectivity" : "Internetové pripojenie",
    "Internet connectivity is disabled in configuration file." : "Internetové pripojenie je zakázané v konfiguračnom súbore.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Tento server nemá funkčné internetové pripojenie: Nie je možné dosiahnuť viacero koncových bodov. To znamená, že niektoré funkcie, ako je pripojenie externého úložiska, upozornenia na aktualizácie alebo inštalácia aplikácií tretích strán, nebudú fungovať. Tiež nemusí fungovať vzdialený prístup k súborom a odosielanie e -mailov s upozorneniami. Ak chcete využívať všetky funkcie, vytvorte z tohto servera pripojenie na internet.",
    "JavaScript modules support" : "Podpora JavaScript modulov",
    "Unable to run check for JavaScript support. Please remedy or confirm manually if your webserver serves `.mjs` files using the JavaScript MIME type." : "Nie je možné spustiť kontrolu podpory JavaScriptu. Manuálne skontrolujte že váš webový server poskytuje súbory `.mjs` pomocou typu JavaScript MIME.",
    "Your webserver does not serve `.mjs` files using the JavaScript MIME type. This will break some apps by preventing browsers from executing the JavaScript files. You should configure your webserver to serve `.mjs` files with either the `text/javascript` or `application/javascript` MIME type." : "Váš webový server neobsluhuje súbory `.mjs` pomocou MIME typu JavaScript. Týmto sa niektoré aplikácie pokazia, pretože prehliadače nebudú môcť vykonávať JavaScriptové súbory. Mali by ste nakonfigurovať váš webový server tak, aby obsluhoval súbory `.mjs` s MIME typom `text/javascript` alebo `application/javascript`.",
    "JavaScript source map support" : "Podpora pre mapy zdrojov JavaScript ",
    "Your webserver is not set up to serve `.js.map` files. Without these files, JavaScript Source Maps won't function properly, making it more challenging to troubleshoot and debug any issues that may arise." : "Váš webový server nie je nastavený na poskytovanie súborov `.js.map`. Bez týchto súborov nebude JavaScript Source Maps správne fungovať, čo zťažuje riešenie a ladenie akýchkoľvek problémov, ktoré sa môžu vyskytnúť.",
    "Old server-side-encryption" : "Staré šifrovanie na strane servera",
    "Disabled" : "Vypnuté",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Starý formát šifrovania na strane servera je povolený. Odporúčame vám to zakázať.",
    "Logging level" : "Úroveň protokolovania",
    "The %1$s configuration option must be a valid integer value." : "Voľba %1$s v nastaveniach musí byť platné číslo.",
    "The logging level is set to debug level. Use debug level only when you have a problem to diagnose, and then reset your log level to a less-verbose level as it outputs a lot of information, and can affect your server performance." : "Úroveň protokolovania je nastavená na úroveň ladenia. Úroveň ladenia použite len vtedy, keď máte problém s diagnostikou, a potom resetujte úroveň svojho protokolu na menej podrobnú úroveň, pretože poskytuje množstvo informácií a môže ovplyvniť výkon vášho servera.",
    "Logging level configured correctly." : "Úroveň protokolovania bol správne nastavený.",
    "Maintenance window start" : "Okno pre údržbu",
    "Server has no maintenance window start time configured. This means resource intensive daily background jobs will also be executed during your main usage time. We recommend to set it to a time of low usage, so users are less impacted by the load caused from these heavy tasks." : "Server nemá nastavený časový úsek údržby. To znamená, že náročné denné úlohy na pozadí budú vykonávané aj počas hlavného užívacieho času. Odporúčame nastaviť čas na obdobie s nízkym využitím, aby boli užívatelia menej ovplyvnení záťažou spôsobenou týmito náročnými úlohami.",
    "Maintenance window to execute heavy background jobs is between {start}:00 UTC and {end}:00 UTC" : "Údržbové okno na vykonávanie náročných úloh na pozadí je medzi {start}:00 UTC a {end}:00 UTC.",
    "Memcache" : "Memcache",
    "Memcached is configured as distributed cache, but the wrong PHP module (\"memcache\") is installed. Please install the PHP module \"memcached\"." : "Memcached je nakonfigurovaný ako distribuovaná cache, ale je nainštalovaný nesprávny PHP modul (\"memcache\"). Prosím nainštalujte PHP modul \"memcached\".",
    "Memcached is configured as distributed cache, but the PHP module \"memcached\" is not installed. Please install the PHP module \"memcached\"." : "Memcached je nakonfigurovaný ako distribuovaná cache, ale PHP modul \"memcached\" nie je nainštalovaný. Prosím nainštalujte PHP modul \"memcached\".",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available." : "Žiadna pamäťová cache nebola nakonfigurovaná. Ak je k dispozícii, prosím nakonfigurujte memcache, aby ste zvýšili výkon.",
    "Failed to write and read a value from local cache." : "Nepodarilo sa prečítať a zapísať hodnotu z lokálnej vyrovnávacej pamäte.",
    "Failed to write and read a value from distributed cache." : "Nepodarilo sa prečítať a zapísať hodnotu z distribuovanej vyrovnávacej pamäte.",
    "Configured" : "Nastavené",
    "Mimetype migrations available" : "Je dostupná migrácia Mimetype ",
    "One or more mimetype migrations are available. Occasionally new mimetypes are added to better handle certain file types. Migrating the mimetypes take a long time on larger instances so this is not done automatically during upgrades. Use the command `occ maintenance:repair --include-expensive` to perform the migrations." : "K dispozícii je jedna alebo viacero migrácií mimetypov. Príležitostne sa pridávajú nové typy mime, aby sa lepšie spracovali určité typy súborov. Migrácia mimetypov trvá dlho na väčších inštanciách, takže sa nevykonáva automaticky počas aktualizácií. Na vykonanie migrácií použite príkaz `occ maintenance:repair --include-expensive`.",
    "MySQL row format" : "MySQL row formát",
    "You are not using MySQL" : "Nepoužívate MySQL",
    "None of your tables use ROW_FORMAT=Compressed" : "Žiadna vaša tabuľka nepoužíva ROW_FORMAT=Compressed",
    "Incorrect row format found in your database. ROW_FORMAT=Dynamic offers the best database performances for Nextcloud. Please update row format on the following list: %s." : "V databáze sa našiel nesprávny formát riadkov. ROW_FORMAT=Dynamic ponúka najlepší výkon databázy pre Nextcloud. Aktualizujte formát riadkov v nasledujúcom zozname: %s.",
    "MySQL Unicode support" : "Podpora Unicode v MySQL",
    "MySQL is used as database and does support 4-byte characters" : "MySQL sa používa ako databáza a podporuje 4-bajtové znaky.",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL." : "MySQL sa používa ako databáza, ale nepodporuje 4-bajtové znaky. Ak chcete byť schopní spracovať 4-bajtové znaky (ako sú emotikony) bez problémov v názvoch súborov alebo komentároch, odporúča sa povoliť podporu 4-bajtov v MySQL.",
    "OCS provider resolving" : "Riešenie poskytovateľa OCS",
    "Could not check if your web server properly resolves the OCM and OCS provider URLs." : "Nepodarilo sa skontrolovať, či váš webový server správne rozpoznáva adresy URL poskytovateľov OCM a OCS.",
    "Your web server is not properly set up to resolve %1$s.\nThis is most likely related to a web server configuration that was not updated to deliver this folder directly.\nPlease compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx.\nOn Nginx those are typically the lines starting with \"location ~\" that need an update." : "Váš web server nie je správne nastavený, aby preložil %1$s.\nTo pravdepodobne súvisí s nastavením webového servera, ktoré nebolo aktualizované pre priame doručovanie tohto adresára.\nPorovnajte prosím svoje nastavenia voči dodávaným rewrite pravidlám v \".htaccess\" pre Apache alebo tým, ktoré uvádzame v dokumentácii pre Nginx.\nV Nginx je typicky potrebné aktualizovať riadky začínajúce na \"location ~\".",
    "Overwrite CLI URL" : "Prepísať CLI URL",
    "The \"overwrite.cli.url\" option in your config.php is correctly set to \"%s\"." : "\"Možnosť \"overwrite.cli.url\" vo vašom config.php je správne nastavená na \"%s\".\"",
    "The \"overwrite.cli.url\" option in your config.php is set to \"%s\" which is a correct URL. Suggested URL is \"%s\"." : "\"Možnosť \"overwrite.cli.url\" vo vašom config.php je nastavená na \"%s\", čo je správna URL. Navrhovaná URL je \"%s\".\"",
    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"%s\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "Uistite sa, že ste v súbore config.php nastavili možnosť „overwrite.cli.url“ na adresu URL, ktorú vaši užívatelia používajú na prístup k tomuto Nextcloudu. Návrh: \"%s\". V opačnom prípade môžu nastať problémy s generovaním URL cez cron. (Je však možné, že navrhovaná adresa URL nie je adresa URL, ktorú vaši používatelia používajú na prístup k tomuto Nextcloudu. Najlepšie je v každom prípade to ešte raz skontrolovať.)",
    "PHP APCu configuration" : "Konfigurácia PHP APCu",
    "Your APCu cache has been running full, consider increasing the apc.shm_size php setting." : "Vaša vyrovnávacia pamäť APCu je plná, zvážte zvýšenie nastavenia apc.shm_size php.",
    "Your APCu cache is almost full at %s%%, consider increasing the apc.shm_size php setting." : " Vaša vyrovnávacia pamäť APCu je skoro plná na %s %%:\", zvážte zvýšenie nastavenia apc.shm_size php.",
    "PHP default charset" : "Predvolená znaková sada pre PHP ",
    "PHP configuration option \"default_charset\" should be UTF-8" : "PHP premenná \"default_charset\" by mala byť UTF-8",
    "PHP set_time_limit" : "PHP set_time_limit",
    "The function is available." : "Funkcia je k dispozícii.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "Funkcia PHP \"set_time_limit\" nie je k dispozícii. To by mohlo viesť k zastaveniu skriptov v polovici vykonávania, čím by došlo k prerušeniu inštalácie. Dôrazne odporúčame povoliť túto funkciu.",
    "Freetype" : "Freetype",
    "Supported" : "Podporované",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Vaše PHP nemá podporu FreeType, čo bude mať za následok poškodenie profilových obrázkov a rozhrania nastavení.",
    "PHP getenv" : "PHP getenv",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Zdá sa že PHP nie je nastavené korektne na získanie premenných prostredia. Test s getenv(\"PATH\") vráti prázdnu odpoveď.",
    "PHP file size upload limit" : "Limit veľkosti súboru PHP pre nahratie",
    "The PHP upload_max_filesize is too low. A size of at least %1$s is recommended. Current value: %2$s." : "PHP upload_max_filesize je príliš nízke. Odporúčaná veľkosť je %1$s. Súčasná hodnota: %2$s.",
    "The PHP post_max_size is too low. A size of at least %1$s is recommended. Current value: %2$s." : "PHP post_max_size je príliš nízke. Odporúčaná veľkosť je %1$s. Súčasná hodnota: %2$s.",
    "The PHP max_input_time is too low. A time of at least %1$s is recommended. Current value: %2$s." : "PHP upload_input_time je príliš nízke. Odporúčaná veľkosť je %1$s. Súčasná hodnota: %2$s.",
    "The PHP max_execution_time is too low. A time of at least %1$s is recommended. Current value: %2$s." : "PHP max_execution_time je príliš nízke. Odporúčaná veľkosť je %1$s. Súčasná hodnota: %2$s.",
    "PHP memory limit" : "Limit pamäte pre PHP",
    "The PHP memory limit is below the recommended value of %s. Some features or apps - including the Updater - may not function properly." : "Limit pamäte PHP je pod odporúčanou hodnotou %s. Niektoré funkcie alebo aplikácie – vrátane nástroja Updater – nemusia fungovať správne.",
    "PHP modules" : "PHP moduly",
    "increases language translation performance and fixes sorting of non-ASCII characters" : "zvyšuje výkon prekladu jazyka a opravuje triedenie ne-ASCII znakov",
    "for Argon2 for password hashing" : "pre Argon2 na hašovanie hesiel",
    "required for SFTP storage and recommended for WebAuthn performance" : "vyžadované pre úložisko SFTP a odporúčané pre výkon WebAuthn",
    "for picture rotation in server and metadata extraction in the Photos app" : "pre rotáciu obrázka na serveri a extrakciu metadát v aplikácii Fotky",
    "This instance is missing some required PHP modules. It is required to install them: %s." : "Táto inštancia nemá niektoré potrebné PHP moduly. Je potrebné ich nainštalovať: %s.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them:\n%s" : "V tejto inštancii chýbajú niektoré odporúčané moduly PHP. Ak chcete zlepšiť výkon a kompatibilitu, dôrazne odporúčame, aby ste ich nainštalovali:\n%s",
    "PHP opcache" : "PHP opcache",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "Modul OPcache PHP nie je načítaný. Pre lepší výkon sa odporúča načítať ho do vašej inštalácie PHP.",
    "OPcache is disabled. For better performance, it is recommended to apply \"opcache.enable=1\" to your PHP configuration." : "OPcache je vypnutá. Pre lepší výkon sa odporúča vložiť do konfigurácie PHP \"opcache.enable=1\".",
    "The shared memory based OPcache is disabled. For better performance, it is recommended to apply \"opcache.file_cache_only=0\" to your PHP configuration and use the file cache as second level cache only." : "Sdieľanie pamäte OPcache je zakázané. Pre lepšiu výkonnosť sa odporúča nastaviť \"opcache.file_cache_only=0\" vo vašej konfigurácii PHP a používať súborovú vyrovnávaciu pamäť iba ako vyrovnávaciu pamäť druhej úrovne.",
    "OPcache is not working as it should, opcache_get_status() returns false, please check configuration." : "OPcache nefunguje tak, ako by malo, opcache_get_status() vracia false, prosím skontrolujte konfiguráciu.",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply \"opcache.max_accelerated_files\" to your PHP configuration with a value higher than \"%s\"." : "Maximálny počet kľúčov OPcache je takmer prekročený. Aby ste sa uistili, že všetky skripty môžu byť uložené vo vyrovnávacej pamäti, odporúča sa použiť \"opcache.max_accelerated_files\" na vašu konfiguráciu PHP s hodnotou vyššou ako \"%s\".",
    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply \"opcache.memory_consumption\" to your PHP configuration with a value higher than \"%s\"." : "Vyrovnávacia pamäť OPcache je takmer plná. Aby ste sa uistili, že všetky skripty môžu byť uložené vo vyrovnávacej pamäti, odporúča sa použiť \"opcache.memory_consumption\" na vašu konfiguráciu PHP s hodnotou vyššou ako \"%s\".",
    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply \"opcache.interned_strings_buffer\" to your PHP configuration with a value higher than \"%s\"." : "Vyrovnávacia pamäť interných reťazcov OPcache je takmer plná. Aby ste sa uistili, že opakujúce sa reťazce možno efektívne ukladať do vyrovnávacej pamäte, odporúča sa použiť na konfiguráciu PHP \"opcache.interned_strings_buffer\" s hodnotou vyššou ako \"%s\".",
    "OPcache is configured to remove code comments. With OPcache enabled, \"opcache.save_comments=1\" must be set for Nextcloud to function." : "OPcache je nakonfigurovaná na odstraňovanie komentárov v kóde. Ak je povolená OPcache, musí byť nastavený \"opcache.save_comments=1\", aby Nextcloud fungoval.",
    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with \"opcache.restrict_api\" or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud nemá povolené používať OPcache API. Keď je OPcache povolená, dôrazne sa odporúča zahrnúť všetky adresáre Nextcloud s \"opcache.restrict_api\" alebo zrušiť toto nastavenie, aby ste deaktivovali obmedzenia API OPcache a aby ste predišli chybám počas aktualizácie jadra alebo aplikácií Nextcloud.",
    "Checking from CLI, OPcache checks have been skipped." : "Kontrola z CLI, kontroly OPcache boli preskočené.",
    "The PHP OPcache module is not properly configured. %s." : "Modul PHP OPcache nie je správne nakonfigurovaný. %s.",
    "Correctly configured" : "Správne nakonfigurované",
    "PHP version" : "Verzia PHP",
    "You are currently running PHP %1$s. PHP %2$s is deprecated since Nextcloud %3$s. Nextcloud %4$s may require at least PHP %5$s. Please upgrade to one of the officially supported PHP versions provided by the PHP Group as soon as possible." : "Momentálne používate PHP %1$s. PHP %2$s je pre Nextcloud zastarané od verzie %3$s. Nextcloud %4$s môže vyžadovať aspoň PHP %5$s. Čo najskôr aktualizujte na jednu z oficiálne podporovaných verzií PHP poskytovaných skupinou PHP.",
    "You are currently running PHP %s." : "Momentálne používate PHP %s.",
    "PHP \"output_buffering\" option" : "možnosť PHP \"output_buffering\"",
    "PHP configuration option \"output_buffering\" must be disabled" : "PHP premenná \"output_buffering\" musí byť zakázaná",
    "Push service" : "Služba Push",
    "Valid enterprise license" : "Platná enterprise licencia",
    "Free push service" : "Bezplatná služba push",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {link}." : "Toto je nepodporovaná komunitná verzia Nextcloud. Vzhľadom na veľkosť tejto inštancie nemožno zaručiť výkon, spoľahlivosť a škálovateľnosť. Push notifikácie boli deaktivované, aby sa predišlo preťaženiu našej bezplatnej služby. Získajte viac informácií o výhodách Nextcloud Enterprise na {link}.",
    "Random generator" : "Generátor náhodných čísel",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons." : "Žiadny vhodný zdroj náhodnosti nebol nájdený PHP, čo je vysoko odporúčané z bezpečnostných dôvodov.",
    "Secure" : "Zabezpečené",
    "Configuration file access rights" : "Prístupové práva k súboru konfigurácie",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Konfigurácia je nastavená len na čítanie. Toto znemožňuje urobiť niektoré nastavenia prostredníctvom webového rozhrania. Okrem toho, súbor musí mať zapisovanie ručne povolené pre každú aktualizáciu.",
    "Nextcloud configuration file is writable" : "Konfiguračný súbor Nextcloud je zapisovateľný",
    "Scheduling objects table size" : "Veľkosť tabuľky plánovania objektov",
    "You have more than %s rows in the scheduling objects table. Please run the expensive repair jobs via occ maintenance:repair --include-expensive." : "V tabuľke objektov plánovania máte viac ako %s riadkov. Spustite dlho-trvajúce opravy cez occ maintenance:repair --include-expensive.",
    "Scheduling objects table size is within acceptable range." : "Veľkosť tabuľky plánovania objektov je povolenom rozsahu.",
    "HTTP headers" : "HTTP hlavičky",
    "- The `%1$s` HTTP header is not set to `%2$s`. Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "Hlavička HTTP `%1$s` nie je nakonfigurovaná na `%2$s`. Niektoré funkcie nemusia pracovať správne a preto odporúčame toto nastavenie upraviť.",
    "- The `%1$s` HTTP header is not set to `%2$s`. This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "Hlavička HTTP `%1$s` nie je nakonfigurovaná na `%2$s`. Toto je potenciálne riziko pre bezpečnosť alebo ochranu osobných údajov a preto odporúčame toto nastavenie upraviť.",
    "- The `%1$s` HTTP header is not set to `%2$s`, `%3$s`, `%4$s`, `%5$s` or `%6$s`. This can leak referer information. See the {w3c-recommendation}." : "- Hlavička `%1$s` HTTP nie je nastavená na `%2$s`, `%3$s`, `%4$s`, `%5$s` alebo `%6$s`. Toto môže spôsobiť únik informácií o referentovi. Pozrite si {w3c-recommendation}.",
    "- The `Strict-Transport-Security` HTTP header is not set to at least `%d` seconds (current value: `%d`). For enhanced security, it is recommended to use a long HSTS policy." : "- HTTP hlavička  `Strict-Transport-Security` nie je nastavená na aspoň `%d` sekúnd (aktuálna hodnota: `%d`). Na zvýšenie bezpečnosti sa odporúča použiť dlhšiu politiku pre HSTS.",
    "- The `Strict-Transport-Security` HTTP header is malformed: `%s`. For enhanced security, it is recommended to enable HSTS." : "- HTTP hlavička `Strict-Transport-Security` má nesprávny tvar: `%s`. Pre zvýšenie bezpečnosti sa odporúča povoliť HSTS.",
    "- The `Strict-Transport-Security` HTTP header is not set (should be at least `%d` seconds). For enhanced security, it is recommended to enable HSTS." : "- HTTP hlavička `Strict-Transport-Security` nie je nastavená (mala by byť aspoň `%d` sekúnd). Pre zvýšenie bezpečnosti sa odporúča povoliť HSTS.",
    "Some headers are not set correctly on your instance" : "Niektoré hlavičky na vašej inštancii nie sú nastavené korektne",
    "Could not check that your web server serves security headers correctly. Please check manually." : "Nepodarilo sa skontrolovať, či váš webový server správne poskytuje bezpečnostné hlavičky. Skontrolujte to prosím manuálne.",
    "Could not check that your web server serves security headers correctly, unable to query `%s`" : "Nepodarilo sa skontrolovať, či váš webový server správne poskytuje bezpečnostné hlavičky, nepodarilo sa požiadať o `%s`",
    "Your server is correctly configured to send security headers." : "Váš server je správne nakonfigurovaný pre poskytovanie bezpečnostných hlavičiek.",
    "Database version" : "Verzia databázy",
    "MariaDB version 10.3 detected, this version is end-of-life and only supported as part of Ubuntu 20.04. MariaDB >=%1$s and <=%2$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "Bola zistená verzia MariaDB 10.3, táto verzia je na konci životnosti a je podporovaná iba ako súčasť Ubuntu 20.04. Odporúča sa MariaDB >=%1$s a <=%2$s pre najlepší výkon, stabilitu a funkčnosť s touto verziou Nextcloud.",
    "MariaDB version \"%1$s\" detected. MariaDB >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "Bola zistená verzia \"%1$s\" MariaDB. Odporúča sa MariaDB >=%2$s a <=%3$s pre najlepší výkon, stabilitu a funkčnosť s touto verziou Nextcloud.",
    "MySQL version \"%1$s\" detected. MySQL >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "Bola zistená verzia \"%1$s\" MySQL. Odporúča sa MySQL >=%2$s a <=%3$s pre najlepší výkon, stabilitu a funkčnosť s touto verziou Nextcloud.",
    "PostgreSQL version \"%1$s\" detected. PostgreSQL >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "Zistená verzia PostgreSQL „%1$s“. PostgreSQL >=%2$s a %3$s<= sa odporúča pre najlepší výkon, stabilitu a funkčnosť s touto verziou Nextcloud.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend. This is particularly recommended when using the desktop client for file synchronisation. To migrate to another database use the command line tool: \"occ db:convert-type\"." : "SQLite sa v súčasnosti používa ako databáza na pozadí. Pre väčšie inštalácie odporúčame prepnúť na inú databázovú platformu. Toto sa odporúča najmä pri používaní desktopového klienta pre synchronizáciu súborov. Pre migráciu na inú databázu použite príkazový riadok: \"occ db:convert-type\".",
    "Unknown database platform" : "Neznáma databázová platforma",
    "Architecture" : "Architektúra",
    "64-bit" : "64-bit",
    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit!" : "Zdá sa, že používate 32-bitovú verziu PHP. Na správne fungovanie Nextcloudu je potrebná 64-bitová verzia. Prosím, aktualizujte váš operačný systém a PHP na 64-bitovú verziu!",
    "Temporary space available" : "Dočasné miesto k dispozícii",
    "Error while checking the temporary PHP path - it was not properly set to a directory. Returned value: %s" : "Chyba pri kontrole dočasnej cesty PHP - nebola správne nastavená na adresár. Vrátená hodnota: %s",
    "The PHP function \"disk_free_space\" is disabled, which prevents the check for enough space in the temporary directories." : "PHP funkcia \"disk_free_space\" je zakázaná, čo bráni kontrole dostatočného miesta v dočasných adresároch.",
    "Error while checking the available disk space of temporary PHP path or no free disk space returned. Temporary path: %s" : "Chyba pri kontrole dostupného miesta na disku cesty dočasných súborov PHP alebo žiadne voľné miesto na disku. Cesta pre dočasné súbory: %s",
    "- %.1f GiB available in %s (PHP temporary directory)" : "- %.1f GiB k dispozícii v %s (adresár dočasných súborov PHP)",
    "- %.1f GiB available in %s (Nextcloud temporary directory)" : "- %.1f GiB k dispozícii v %s (adresár dočasných súborov Nextcloud)",
    "Temporary directory is correctly configured:\n%s" : "Adresár pre dočasné súbory je správne nakonfigurovaný:\n%s",
    "This instance uses an S3 based object store as primary storage, and has enough space in the temporary directory.\n%s" : "Táto inštancia používa úložisko objektov S3 ako primárne úložisko a má dostatok miesta v dočasnom adresári.\n%s",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GiB of free space available in the temp directory of PHP. To improve this please change the temporary directory in the php.ini or make more space available in that path. \nChecking the available space in the temporary path resulted in %.1f GiB instead of the recommended 50 GiB. Path: %s" : "Táto inštancia používa úložisko objektov S3 ako primárne úložisko. Nahrané súbory sú dočasne uložené na serveri a preto sa odporúča mať k dispozícii 50 GiB voľného miesta v dočasnom adresári PHP. Pre zlepšenie tohto nastavenia prosím zmeňte dočasný adresár v súbore php.ini alebo zabezpečte viac voľného miesta v tomto adresári. \nKontrola dostupného miesta v dočasnom priečinku ukázala %.1f GiB namiesto odporúčaných 50 GiB. Cesta: %s",
    "Database transaction isolation level" : "Úroveň izolácie transakcií databáze",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Vaša databáza nebeží s úrovňou izolácie transakcií \"READ COMMITTED\".  Toto môže spôsobovať problémy v prípade ak viacero akcií beží paralelne.",
    "Was not able to get transaction isolation level: %s" : "Nebolo možné získať úroveň izolácie transakcie: %s",
    ".well-known URLs" : ".well-known URLs",
    "`check_for_working_wellknown_setup` is set to false in your configuration, so this check was skipped." : "`check_for_working_wellknown_setup` je nastavené na false vo vašej konfigurácii, preto sa táto kontrola preskočila.",
    "Could not check that your web server serves `.well-known` correctly. Please check manually." : "Nemohol som overiť, či váš webový server správne poskytuje `.well-known`. Prosím, skontrolujte to manuálne.",
    "Your web server is not properly set up to resolve `.well-known` URLs, failed on:\n`%s`" : "Váš webový server nie je správne nastavený na poskytovanie URL adries `.well-known`, zlyhalo na:\n`%s`",
    "Your server is correctly configured to serve `.well-known` URLs." : "Váš server je správne nakonfigurovaný na poskytovanie URL adries `.well-known`.",
    "Font file loading" : "Nahrávanie súboru písma",
    "Could not check for {extension} loading support. Please check manually if your webserver serves `.{extension}` files." : "Nepodarilo sa skontrolovať podporu načítania typu {extension}. Prosím skontrolujte manuálne, či váš webový server obsluhuje súbory typu `.{extension}`.",
    "Your web server is not properly set up to deliver .{extension} files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustment to also deliver .{extension} files. Compare your Nginx configuration to the recommended configuration in our documentation." : "Váš webový server nie je správne nastavený na doručovanie súborov typu {extension}. Toto je zvyčajne problém s konfiguráciou Nginx. Pre Nextcloud 15 potrebuje úpravu, aby poskytoval aj .{extension} súbory. Porovnajte svoju konfiguráciu Nginx s odporúčanou konfiguráciou v našej dokumentácii.",
    "Profile information" : "Informácie o profile",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Profilový obrázok, celé meno, e-mail, telefónne číslo, adresa, webová stránka, Twitter, organizácia, rola, titul, životopis a či je váš profil povolený",
    "Nextcloud settings" : "Nastavenia Nextcloud",
    "Unified task processing" : "Jednotné spracovanie úloh",
    "AI tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Úlohy AI môžu byť implementované rôznymi aplikáciami. Tu môžete nastaviť, ktorá aplikácia sa má použiť pre akú úlohu.",
    "Enable" : "Povoliť",
    "None of your currently installed apps provide Task processing functionality" : "Žiadna z vašich aktuálne nainštalovaných aplikácií neposkytuje funkcie spracovania pre Task",
    "Machine translation" : "Strojový preklad",
    "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "Strojový preklad môže byť implementovaný rôznymi aplikáciami. Tu môžete definovať prednosť aplikácií na strojový preklad, ktoré máte momentálne nainštalované.",
    "Image generation" : "Generovanie obrázkov",
    "Image generation can be implemented by different apps. Here you can set which app should be used." : "Generovanie obrázkov môže byť implementovaný rôznymi aplikáciami. Tu môžete nastaviť, ktorá aplikácia by mala byť použitá.",
    "None of your currently installed apps provide image generation functionality" : "Žiadna z vašich momentálne nainštalovaných aplikácií neposkytuje funkciu generovania obrázkov.",
    "Text processing" : "Spracovanie textu",
    "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Úlohy spracovania textu môžu byť implementované rôznymi aplikáciami. Tu môžete nastaviť, ktorá aplikácia by mala byť použitá pre ktorú úlohu.",
    "Task:" : "Úloha:",
    "None of your currently installed apps provide text processing functionality using the Text Processing API." : "Žiadna z vašich aktuálne nainštalovaných aplikácií neposkytuje funkcie spracovania textu pomocou rozhrania API na spracovanie textu.",
    "Here you can decide which group can access certain sections of the administration settings." : "Tu sa môžete rozhodnúť, ktorá skupina má prístup k niektorým nastaveniam správcu.",
    "Unable to modify setting" : "Nie je možné zmeniť nastavenie",
    "None" : "Žiadny",
    "Changed disclaimer text" : "Zmenený text odmietnutia zodpovednosti",
    "Deleted disclaimer text" : "Text odmietnutia zodpovednosti bol vymazaný",
    "Could not set disclaimer text" : "Nepodarilo sa nastaviť text odmietnutia zodpovednosti",
    "Allow apps to use the Share API" : "Povoliť aplikáciám používať API pre zdieľanie",
    "Allow resharing" : "Povoliť zdieľanie ďalej",
    "Allow sharing with groups" : "Povoliť zdieľanie so skupinami",
    "Restrict users to only share with users in their groups" : "Povoliť užívateľom zdieľanie obsahu len v rámci ich skupiny",
    "Ignore the following groups when checking group membership" : "Ignorovať nasledujúce skupiny pri kontrole členstva v skupine.",
    "Allow users to share via link and emails" : "Povoliť užívateľom zdieľanie obsahu pomocou odkazov",
    "Allow public uploads" : "Povoliť verejné nahrávanie súborov",
    "Always ask for a password" : "Vždy vyžadovať heslo",
    "Enforce password protection" : "Vynútiť ochranu heslom",
    "Exclude groups from password requirements" : "Vylúčiť skupiny z požiadaviek na kvalitu hesla.",
    "Exclude groups from creating link shares" : "Nepovoliť týmto skupinám vytvárať odkazy k zdieľaniu",
    "Allow users to set custom share link tokens" : "Povoliť užívateľom nastaviť vlastné tokeny zdieľania",
    "Shares with custom tokens will continue to be accessible after this setting has been disabled" : "Zdieľania s vlastnými tokenmi budú aj po deaktivácii tohto nastavenia naďalej dostupné",
    "Shares with guessable tokens may be accessed easily" : "Zdieľania s uhádnuteľnými tokenmi sú ľahko prístupné",
    "Limit sharing based on groups" : "Obmedziť zdieľanie na základe skupín",
    "Allow sharing for everyone (default)" : "Povoliť zdieľanie pre všetkých (predvolené)",
    "Exclude some groups from sharing" : "Vylúčiť niektoré skupiny zo zdieľania",
    "Limit sharing to some groups" : "Obmedziť zdieľanie pre niektoré skupiny",
    "Groups allowed to share" : "Skupiny pre ktoré je povolené zdieľanie",
    "Groups excluded from sharing" : "Skupiny vylúčené zo zdieľania",
    "Not allowed groups will still be able to receive shares, but not to initiate them." : "Nepovolené skupiny budú môcť naďalej prijímať zdieľania, ale nebudú ich môcť iniciovať.",
    "Set default expiration date for internal shares" : "Nastaviť predvolený dátum skončenia platnosti pre interné zdieľania",
    "Enforce expiration date" : "Vynútiť dátum expirácie",
    "Default expiration time of new shares in days" : "Predvolený čas vypršania nových zdieľaní v dňoch",
    "Expire shares after x days" : "Expirovať zdieľanie po x dňoch",
    "Set default expiration date for shares to other servers" : "Nastaviť predvolený dátum vypršania platnosti sprístupnení pre iné servery",
    "Enforce expiration date for remote shares" : "Vynútiť dátum vypršania pre vzdialené zdieľania",
    "Default expiration time of remote shares in days" : "Predvolený čas vypršania vzdialených zdieľaní v dňoch",
    "Expire remote shares after x days" : "Vzdialené zdieľania vypršia po x dňoch",
    "Set default expiration date for shares via link or mail" : "Nastavte predvolený dátum vypršania pre zdiľanie cez odkaz alebo e-mail.",
    "Default expiration time of shares in days" : "Predvolený čas vypršania zdieľaní v dňoch",
    "Privacy settings for sharing" : "Nastavenia súkromia pre zdieľanie",
    "Allow account name autocompletion in share dialog and allow access to the system address book" : "Povoliť dopĺňanie mena používateľa v dialógovom okne zdieľania a umožniť prístup do systémového adresára kontaktov",
    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Ak je povolené automatické dopĺňanie „pre rovnakú skupinu“ a „integrácia telefónneho čísla“, na zobrazenie používateľa stačí zhoda v ktorejkoľvek z nich.",
    "Restrict account name autocompletion and system address book access to users within the same groups" : "Obmedziť automatické dopĺňanie názvu účtu a prístup k systémovému adresáru na užívateľov v rámci rovnakých skupín",
    "Restrict account name autocompletion to users based on phone number integration" : "Obmedziť automatické dopĺňanie mien užívateľom založené na integrácii s telefónnym číslom",
    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Pri zadávaní celého mena alebo e-mailovej adresy povoliť automatické dopĺňanie (ignoruje sa chýbajúca zhoda v telefónnom zozname a príslušnosť k rovnakej skupine)",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Zobraziť text upozornenia na stránke pre nahrávanie verejného odkazu (zobraziť len ak je zoznam súborov skrytý)",
    "Disclaimer text" : "Text odmietnutia zodpovednosti",
    "This text will be shown on the public link upload page when the file list is hidden." : "Ak nebude zoznam súborov skrytý, tento text sa zobrazí na stránke pre nahrávanie verejného odkazu.",
    "Default share permissions" : "Prednastavené povolenia pre zdieľanie",
    "Two-Factor Authentication" : "Dvojfázové overovanie",
    "Two-factor authentication can be enforced for all accounts and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Dvojfaktorové overovanie je možné vynútiť pre všetky účty a konkrétne skupiny. Ak nemajú nastaveného poskytovateľa dvojfaktorového overovania, nebudú sa môcť prihlásiť do systému.",
    "Enforce two-factor authentication" : "Vynútiť dvojfázové overovanie",
    "Limit to groups" : "Povoľ len pre skupiny",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Vynútenie dvojfázového overovania je možné nastaviť len pre určité skupiny.",
    "Two-factor authentication is enforced for all members of the following groups." : "Dvojfázové overovanie sa vynúti pre všetkých členov nasledujúcich skupín.",
    "Enforced groups" : "Vynútené skupiny",
    "Two-factor authentication is not enforced for members of the following groups." : "Dvojfázové overovanie sa nevynucuje pre členov nasledujúcich skupín.",
    "Excluded groups" : "Vynechané skupiny",
    "When groups are selected/excluded, they use the following logic to determine if an account has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If an account is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Pokiaľ sú skupiny vybraté/vynechané, je pre zisťovanie či je účtu vynútené dvojfaktorové (2FA) overovanie použitá nasledovná logika: Ak nie sú vybraté žiadne skupiny, je 2FA zapnuté pre všetkých okrem členov vynechaných skupín. Ak sú nejaké skupiny vybraté, je 2FA zapnuté pre všetkých jej členov. Ak je účet členom ako vybratej, tak aj vynechanej skupiny, potom má vybratá skupina prednosť a 2FA je vynútené.",
    "Save changes" : "Uložiť zmeny",
    "Default" : "Predvolené",
    "Registered Deploy daemons list" : "Zoznam registrovaných démonov nasadenia",
    "No Deploy daemons configured" : "Neboli nastavené žiadne Démony nasadeia",
    "Register a custom one or setup from available templates" : "Zaregistrujte si vlastný alebo ho nastavte z dostupných šablón",
    "Show details for {appName} app" : "Zobraziť podrobnosti o aplikácii {appName}",
    "Update to {update}" : "Aktualizovať na {update}",
    "Remove" : "Odstrániť",
    "Featured" : "Doporučená",
    "This app is supported via your current Nextcloud subscription." : "Táto aplikácia je podporovaná prostredníctvom vášho aktuálneho predplatného Nextcloud.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Odporúčané aplikácie sú vyvíjané komunitou Sú prepojené so zbytkom Nextcloud a pripravené na produkčné nasadenie.",
    "Community rating: {score}/5" : "Komunitné hodnotenie: {score}/5",
    "Disable all" : "Zakázať všetko",
    "Download and enable all" : "Stiahnuť a povoliť všetko",
    "All apps are up-to-date." : "Všetky aplikácie sú aktuálne.",
    "Icon" : "Ikona",
    "Name" : "Meno",
    "Version" : "Verzia",
    "Level" : "Úroveň",
    "Actions" : "Akcie",
    "Results from other categories" : "Výsledku z ostatných kategórií",
    "No apps found for your version" : "Aplikácie pre vašu verziu sa nenašli",
    "_%n app has an update available_::_%n apps have an update available_" : ["Pre %n aplikáciu je dostupná aktualizácia","Pre %n aplikácie sú dostupné aktualizácie","Pre %n aplikácií sú dostupné aktualizácie","Pre %n aplikácií sú dostupné aktualizácie"],
    "_Update_::_Update all_" : ["Aktualizovať všetko","Aktualizovať všetko","Aktualizovať všetko","Aktualizovať všetko"],
    "Failed to load groups" : "Nepodarilo sa načítať skupiny",
    "Failed to create group" : "Nepodarilo sa vytvoriť skupinu",
    "Creating group…" : "Vytváram skupinu...",
    "Create group" : "Vytvoriť skupinu",
    "Group name" : "Názov skupiny",
    "Please enter a valid group name" : "Prosím, zadajte platné meno skupiny",
    "Search groups…" : "Prehľadať skupiny...",
    "List of groups. This list is not fully populated for performance reasons. The groups will be loaded as you navigate or search through the list." : "Zoznam skupín. Tento zoznam nie je úplne vykreslený z dôvodov výkonu. Skupiny budú vykreslené, keď budete prechádzať zoznamom.",
    "Loading groups…" : "Načítavanie skupín…",
    "Could not load app discover section" : "Nepodarilo sa načítať sekciu objavovania aplikácií",
    "Could not render element" : "Prvok sa nepodarilo vykresliť",
    "Nothing to show" : "Nič pre zobrazenie",
    "Could not load section content from app store." : "Nepodarilo sa načítať obsah sekcie z obchodu s aplikáciami.",
    "Loading" : "Načítava sa",
    "Fetching the latest news…" : "Načítavajú sa najnovšie správy…",
    "Carousel" : "Karusel",
    "Previous slide" : "Predchádzajúca snímka",
    "Next slide" : "Ďalšia snímka",
    "Choose slide to display" : "Vyberte snímok pre zobrazenie",
    "{index} of {total}" : "{index} z {total}",
    "Daemon" : "Daemon",
    "Deploy Daemon" : "Nasadiť proces služby",
    "Type" : "Typ",
    "Display Name" : "Zobrazované meno",
    "GPUs support" : "Podpora GPU",
    "Compute device" : "Výpočetné zariadenie",
    "Advanced deploy options" : "Pokročilé možnosti nasadenia",
    "Edit ExApp deploy options before installation" : "Editovať možnosti nasadenia ExApp pred inštaláciou",
    "Configured ExApp deploy options. Can be set only during installation" : "Nakonfigurované možnosti nasadenia ExApp. Dá sa nastaviť len počas inštalácie",
    "Learn more" : "Dozvedieť sa viac",
    "Environment variables" : "Premenné prostredia",
    "ExApp container environment variables" : "Premenné prostredia kontajnera AppAPI",
    "No environment variables defined" : "Neboli definované žiadne premenné prostredia",
    "Mounts" : "Prípojné body",
    "Define host folder mounts to bind to the ExApp container" : "Definujte pripojenia hostiteľského adresára, ktoré sa majú naviazať na kontajner ExApp",
    "Must exist on the Deploy daemon host prior to installing the ExApp" : "Musí existovať na hostiteľovi démona Deploy pred inštaláciou ExApp",
    "Host path" : "Cesta k hostiteľovi",
    "Container path" : "Cesta ku kontajneru",
    "Read-only" : "Iba na čítanie",
    "Remove mount" : "Odstrániť prípojný bod",
    "New mount" : "Nový prípojný bod",
    "Enter path to host folder" : "Vložte cestu k hostiteľskému adresáru ",
    "Enter path to container folder" : "Vložte cestu k adresáru kontajnera",
    "Toggle read-only mode" : "Prepnúť režim iba na čítanie",
    "Confirm adding new mount" : "Potvrdiť pridanie nového prípojného bodu",
    "Confirm" : "Potvrdiť",
    "Cancel adding mount" : "Zrušiť pridanie prípojného bodu",
    "Cancel" : "Zrušiť",
    "Add mount" : "Pridať prípojný bod",
    "ExApp container mounts" : "Prípojné body kontajnera ExApp",
    "No mounts defined" : "Nie sú definované žiadne prípojné body",
    "Description" : "Popis",
    "View in store" : "Zobraziť v obchode",
    "Visit website" : "Navštíviť webstránku",
    "Usage documentation" : "Užívateľská dokumentácia",
    "Admin documentation" : "Príručka administrátora",
    "Developer documentation" : "Dokumentácia vývojára",
    "Details" : "Podrobnosti",
    "All" : "Všetko",
    "Limit app usage to groups" : "Obmedziť používanie aplikácií pre skupiny",
    "No results" : "Žiadne výsledky",
    "Update to {version}" : "Aktualizovať na {version}",
    "Deploy options" : "Možnosti nasadenia",
    "Default Deploy daemon is not accessible" : "Východzí proces služby nasadzovania nie je dostupný",
    "Delete data on remove" : "Pri odobraní zmazať dáta",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Pre túto aplikáciu nie je zadaná minimálna verzia Nextcloudu. Toto v budúcnosti spôsobí chybu.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Pre túto aplikáciu nie je zadaná maximálna verzia Nextcloudu. Toto v budúcnosti spôsobí chybu.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Túto aplikáciu nemožno nainštalovať, pretože nie sú splnené nasledovné závislosti:",
    "Latest updated" : "Naposledy aktualizované",
    "Author" : "Autor",
    "Categories" : "Kategórie",
    "Resources" : "Zdroje",
    "Documentation" : "Dokumentácia",
    "Interact" : "Interagovať",
    "Report a bug" : "Nahlásiť chybu",
    "Request feature" : "Požiadavka odporúčania",
    "Ask questions or discuss" : "Pýtajte sa alebo diskutujte",
    "Rate the app" : "Ohodnotiť aplikáciu",
    "Rate" : "Hodnotenie",
    "Changelog" : "Zoznam zmien",
    "Google Chrome for Android" : "Google Chrome pre Android",
    "{productName} iOS app" : "{productName} iOS aplikácia",
    "{productName} Android app" : "{productName} Android aplikácia",
    "{productName} Talk for iOS" : "{productName} Talk /Rozhovor/ pre iOS",
    "{productName} Talk for Android" : "{productName} Talk /Rozhovor/ pre Android",
    "Sync client" : "Klient synchronizácie",
    "This session" : "Táto relácia",
    "{client} - {version} ({system})" : "{client} - {version} ({system})",
    "{client} - {version}" : "{client} - {version}",
    "Device name" : "Názov zariadenia",
    "Cancel renaming" : "Zrušiť premenovanie",
    "Save new name" : "Uložiť nové meno",
    "Marked for remote wipe" : "Označené na vymazanie na diaľku",
    "Device settings" : "Nastavenia zariadenia",
    "Allow filesystem access" : "Povoliť prístup ku súborovému systému",
    "Rename" : "Premenovať",
    "Revoke" : "Odvolať",
    "Wipe device" : "Vymazať obsah zariadenia",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Ostránenie tohto tokenu môže zabrániť vymazaniu vášho zariadenia, ak sa ešte nezačalo mazanie.",
    "Device" : "Zariadenie",
    "Last activity" : "Posledná aktivita",
    "Devices & sessions" : "Zariadenia a relácie",
    "Web, desktop and mobile clients currently logged in to your account." : "Weboví, desktopoví alebo mobilní klienti práve prihlásení k vášmu účtu.",
    "Error while creating device token" : "Chyba pri vytváraní tokenov zariadenia",
    "App name" : "Názov aplikácie",
    "Create new app password" : "Vytvoriť nové heslo aplikácie",
    "App password copied!" : "Heslo aplikácie skopírované!",
    "Copy app password" : "Kopírovať heslo aplikácie",
    "Login name copied!" : "Prihlasovacie meno bolo skopírované!",
    "Copy login name" : "Skopírovať prihlasovacie meno",
    "Could not copy app password. Please copy it manually." : "Nie je možné skopírovať heslo pre aplikáciu. Skopírujte ho ručne.",
    "Could not copy login name. Please copy it manually." : "Nepodarilo sa skopírovať prihlasovacie meno. Prosím, skopírujte ho manuálne.",
    "New app password" : "Nové heslo aplikácie",
    "Use the credentials below to configure your app or device. For security reasons this password will only be shown once." : "Použite nižšie uvedené prihlasovacie údaje na konfiguráciu vášho programu alebo zariadenia. Z bezpečnostných dôvodov sa toto heslo zobrazí len raz.",
    "Login" : "Prihlásenie",
    "Password" : "Heslo",
    "Show QR code for mobile apps" : "Zobraziť QR kód pre mobilné apky",
    "Use system cron service to call the cron.php file every 5 minutes." : "Použiť systémový plánovač (cron) pre spustenie súboru cron.php každých 5 minút.",
    "The cron.php needs to be executed by the system account \"{user}\"." : "Je potrebné, aby cron.php bol spustený systémovým používateľom \"{user}\".",
    "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details." : "Je potrebné mať nainštalované rozšírenie PHP POSIX. Pre viac informácií pozrite {linkstart}dokumentáciu PHP{linkend}.",
    "Unable to update background job mode" : "Nie je možné aktualizovať režim úlohy na pozadí",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "Aby mohol server dobre fungovať je dôležité správne nakonfigurovať úlohy spúšťané na pozadí. Odporúčame použiť 'Cron'. Viac informácií nájdete v dokumentácii.",
    "Last job execution ran {time}. Something seems wrong." : "Úloha naposledy prebehla %s. Zdá sa, že niečo nie je v poriadku.",
    "Last job ran {relativeTime}." : "Posledná úloha bežala {relativeTime}.",
    "Background job did not run yet!" : "Úloha na pozadí ešte nebežala!",
    "AJAX" : "AJAX",
    "Execute one task with each page loaded. Use case: Single account instance." : "S každou načítanou stránkou spustiť jednu úlohu. Prípad použitia: Inštancia jedného účtu.",
    "Webcron" : "Webcron",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 accounts depending on the usage)." : "cron.php je zaregistrovaný v službe webcron, aby každých 5 minút volal cron.php cez HTTP. Prípad použitia: Veľmi malá inštancia (1–5 účtov v závislosti od použitia).",
    "Cron (Recommended)" : "Cron (Odporúčané)",
    "Unable to update profile default setting" : "Nie je možné aktualizovať predvolené nastavenie profilu",
    "Profile" : "Profil",
    "Enable or disable profile by default for new accounts." : "Predvolene povoliť alebo zakázať profil pre nové účty.",
    "Password confirmation is required" : "Vyžaduje sa overenie heslom",
    "Failed to save setting" : "Nepodarilo sa uložiť nastavenie",
    "{app}'s declarative setting field: {name}" : "Pole deklaratívneho nastavenia aplikácie {app}: {name}",
    "Unable to update server side encryption config" : "Nedá sa aktualizovať konfigurácia šifrovania na strane servera",
    "Server-side encryption" : "Šifrovanie na serveri",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Šifrovanie na strane servera umožňuje zašifrovať súbory, ktoré sú na tento server nahrávané. To prináša obmedzenia ako napr. výkonnostné obmedzenie, takže to povoľte len ak je to naozaj potrebné.",
    "To encrypt all existing files run this OCC command:" : "Ak chcete zašifrovať všetky existujúce súbory, spustite tento príkaz OCC:",
    "Enable server-side encryption" : "Povoliť šifrovanie na serveri",
    "Disabling server side encryption is only possible using OCC, please refer to the documentation." : "Zakázanie šifrovania na strane servera je možné iba pomocou OCC, pozrite si dokumentáciu.",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Nebol načítaný žiadny šifrovací modul, povoľte prosím šifrovací modul v menu aplikácií.",
    "Select default encryption module:" : "Vybrať predvolený šifrovací modul:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Musíte zmigrovať svoje šifrovacie kľúče zo starého šifrovania (ownCloud <= 8.0) na nové. Povoľte „Predvolený modul šifrovania“ a spustite príkaz {command}",
    "Cancel encryption" : "Zrušiť šifrovanie",
    "Enable encryption" : "Povoliť šifrovanie",
    "Confirm enabling encryption" : "Potvrďte povolenie šifrovania",
    "Please read carefully before activating server-side encryption:" : "Prečítajte prosím pozorne pred použitím šifrovania na strane servera:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Potom ako sa zapne šifrovanie sú od toho bodu všetky nahrávané súbory šifrované serverom. Vypnutie šifrovania bude možné až vtedy, keď bude šifrovací modul túto možnosť podporovať a po splnení všetkých nutných podmenok (tzn. nastavenie kľúčov pre obnovenie).",
    "By default a master key for the whole instance will be generated. Please check if that level of access is compliant with your needs." : "Štandardne sa vygeneruje hlavný kľúč pre celú inštanciu. Skontrolujte, či je táto úroveň prístupu v súlade s vašimi potrebami.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Samotné šifrovanie negarantuje bezpečnosť systému. Ak sa chcete dozvedieť viac o tom ako funguje aplikácia pre šifrovanie a aké sú podporované prípady použitia, prečítajte si prosím dokumentáciu.",
    "Be aware that encryption always increases the file size." : "Majte na vedomí, že šifrovanie vždy zväčší veľkosť súborov.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Je dobré vytvárať pravidelné zálohy vašich dát, uistite sa, že v prípade šifrovania spolu s vašimi dátami zálohujete aj šifrovacie kľúče.",
    "Refer to the admin documentation on how to manually also encrypt existing files." : "Informácie o tom, ako ručne zašifrovať aj existujúce súbory, nájdete v dokumentácii pre administrátora.",
    "This is the final warning: Do you really want to enable encryption?" : "Toto je posledné varovanie: Vážne si prajete povoliť šifrovanie?",
    "Please confirm the group removal" : "Prosím potvrďte vymazanie skupiny.",
    "Submit" : "Odoslať",
    "Rename group" : "Premenovať skupinu",
    "Current password" : "Aktuálne heslo",
    "New password" : "Nové heslo",
    "Change password" : "Zmeniť heslo",
    "Choose your profile picture" : "Vyberte si váš profilový obrázok",
    "Please select a valid png or jpg file" : "Prosím vyberte platný png alebo jpg súbor",
    "Error setting profile picture" : "Chyba pri nastavovaní profilového obrázku",
    "Error cropping profile picture" : "Chyba pri orezávaní profilového obrázku",
    "Error saving profile picture" : "Chyba pri ukladaní profilového obrázku",
    "Error removing profile picture" : "Chyba pri odstraňovaní profilového obrázku",
    "Your profile picture" : "Váš profilový obrázok",
    "Upload profile picture" : "Nahrať profilový obrázok",
    "Choose profile picture from Files" : "Vyberte profilový obrázok zo Súborov",
    "Remove profile picture" : "Odstrániť profilový obrázok",
    "The file must be a PNG or JPG" : "Súbor musí byť vo formáte PNG alebo JPG",
    "Picture provided by original account" : "Obrázok poskytnutý originálnym účtom",
    "Set as profile picture" : "Nastaviť ako profilový obrázok",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Upozorňujeme, že aktualizácia vášho profilového obrázka môže trvať až 24 hodín.",
    "Your biography. Markdown is supported." : "Váš životopis. Markdown je podporovaný.",
    "Unable to update date of birth" : "Nepodarilo sa aktualizovať dátum narodenia",
    "Enter your date of birth" : "Zadajte váš dátum narodenia",
    "You are using {s}{usage}{/s}" : "Využívate {s}{usage}{/s}",
    "You are using {s}{usage}{/s} of {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})" : "Využívate {s}{usage}{/s} z {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})",
    "You are a member of the following groups:" : "Ste členom nasledovných skupín:",
    "Your full name" : "Vaše celé meno",
    "Email options" : "E-mailové nastavenia",
    "Options for additional email address {index}" : "Možnosti pre ďalšiu emailovú adresu {index}",
    "Remove primary email" : "Odobrať primárny email",
    "Delete email" : "Zmazať email",
    "This address is not confirmed" : "Táto adresa nie je potvrdená",
    "Unset as primary email" : "Zrušiť nastavenie ako primárny e-mail",
    "Set as primary email" : "Nastaviť ako primárny e-mail",
    "Additional email address {index}" : "Ďalšia e-mailová adresa {index}",
    "Unable to delete primary email address" : "Nie je možné zmazať primárnu e-mail adresu",
    "Unable to update primary email address" : "Nie je možné aktualizovať primárnu e-mail adresu",
    "Unable to add additional email address" : "Nie je možné pridať ďalšiu e-mail adresu",
    "Unable to update additional email address" : "Nie je možné aktualizovať ďalšiu e-mail adresu",
    "Unable to delete additional email address" : "Nie je možné odstrániť ďalšiu e-mail adresu",
    "Primary email for password reset and notifications" : "Primárny e-mail na obnovenie hesla a zasielanie upozornení",
    "No email address set" : "Emailová adresa nie je nastavená",
    "Your handle" : "Váš identifikátor (handle)",
    "Derived from your locale ({weekDayName})" : "Odvodené z vášho miestneho nastavenia ({weekDayName})",
    "Unable to update first day of week" : "Nepodarilo sa aktualizovať deň používaný ako prvý deň v týždni",
    "Day to use as the first day of week" : "Deň používaný ako prvý deň v týždni",
    "Your headline" : "Váš titul",
    "Unable to update language" : "Nie je možné aktualizovať jazyk",
    "Languages" : "Jazyky",
    "Help translate" : "Pomôcť s prekladom",
    "No language set" : "Nie je nastavený žiadny jazyk",
    "Unable to update locale" : "Nie je možné aktualizovať regionálne nastavenia",
    "Locales" : "Regionálne nastavenia",
    "Week starts on {firstDayOfWeek}" : "Prvý deň v týždni je {firstDayOfWeek}",
    "No locale set" : "Nie sú konfigurované žiadne regionálne nastavenia",
    "Your city" : "Vaše mesto",
    "Your organisation" : "Vaša organizácia",
    "Edit your Profile visibility" : "Upraviť viditeľnosť vášho profilu",
    "Unable to update profile enabled state" : "Nie je možné aktualizovať stav aktivácie profilu",
    "Enable profile" : "Povoliť profil",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Vo vašom profile sa rešpektuje prísnejšie nastavenie viditeľnosti alebo rozsahu. Ak je napríklad viditeľnosť nastavená na „Zobraziť všetkým“ a rozsah je nastavený na „Súkromné“, „Súkromné“ bude rešpektované.",
    "Unable to update visibility of {displayId}" : "Nie je možné aktualizovať viditeľnosť {displayId}",
    "she/her" : "ona/jej",
    "he/him" : "on/jeho",
    "they/them" : "oni/ich",
    "Your role" : "Vaša rola",
    "Your X (formerly Twitter) handle" : "Ovládanie Vašeho X (predtým Twitter)",
    "Your website" : "Vaša webstránka",
    "Invalid value" : "Chybná hodnota",
    "Unable to update {property}" : "Nie je možné aktualizovať {property}",
    "No {property} set" : "Nie je nastavená žiadna {property}",
    "Change scope level of {property}, current scope is {scope}" : "Zmeniť úroveň rozsahu {property}, aktuálny rozsah je {scope}",
    "Unable to update federation scope of the primary {property}" : "Nie je možné aktualizovať rozsah združenia primárneho {property}",
    "Unable to update federation scope of additional {property}" : "Nie je možné aktualizovať rozsah združenia ďalšieho {property}",
    "Add additional email" : "Pridať ďalší e-mail",
    "Add" : "Pridať",
    "Create" : "Vytvoriť",
    "Change" : "Zmeniť",
    "Delete" : "Vymazať",
    "Reshare" : "Zdieľať ďalej",
    "Default language" : "Predvolený jazyk",
    "Common languages" : "Spoločné jazyky",
    "Other languages" : "Iné jazyky",
    "Password change is disabled because the master key is disabled" : "Zmena hesla je zablokovaná pretože hlavný kľúč je vypnutý",
    "No accounts" : "Žiadne účty",
    "Loading accounts …" : "Nahrávanie účtov ...",
    "List of accounts. This list is not fully rendered for performance reasons. The accounts will be rendered as you navigate through the list." : "Zoznam účtov. Tento zoznam nie je úplne vykreslený z dôvodov výkonu. Účty budú vykreslené, keď budete prechádzať zoznamom.",
    "Manager" : "Manažér",
    "Set line manager" : "Nastaviť líniového manažéra",
    "Account name will be autogenerated" : "Názov účtu bude automaticky generovaný",
    "Account name (required)" : "Názov účtu (povinné)",
    "Failed to search groups" : "Neporarilo sa prehľadať skupiny",
    "New account" : "Nový účet",
    "Display name" : "Zobrazované meno",
    "Either password or email is required" : "Buď je potrebné zadať heslo alebo e-mail",
    "Password (required)" : "Heslo (povinné)",
    "Email (required)" : "E-mail (povinné)",
    "Email" : "Email",
    "Member of the following groups (required)" : "Člen nasledujúcich skupín (povinné)",
    "Member of the following groups" : "Člen nasledujúcich skupín",
    "Set account groups" : "Nastaviť skupiny pre účet",
    "Admin of the following groups" : "Administrátor nasledujúcich skupín",
    "Set account as admin for …" : "Nastaviť účet ako adminstrátora pre ...",
    "Quota" : "Kvóta",
    "Set account quota" : "Nastaviť kvótu pre účet",
    "Language" : "Jazyk",
    "Set default language" : "Nastaviť predvolený jazyk",
    "Add new account" : " Pridať nový účet",
    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} účet ...","{userCount} účty ...","{userCount} účtov ...","{userCount} účtov ..."],
    "_{userCount} account_::_{userCount} accounts_" : ["{userCount} účet","{userCount} účty","{userCount} účtov","{userCount} účtov"],
    "Total rows summary" : "Súčet všetkých riadkov",
    "Scroll to load more rows" : "Posúvajte pre načítanie ďalších riadkov",
    "Password or insufficient permissions message" : "Heslo alebo správa o nedostatočných oprávneniach",
    "Avatar" : "Avatar",
    "Account name" : "Názov účtu",
    "Group admin for" : "Administrátor skupiny pre",
    "Account backend" : "Backend účtu",
    "Storage location" : "Umiestnenie úložiska",
    "First login" : "Prvé prihlásenie",
    "Last login" : "Posledné prihlásenie",
    "Account actions" : "Možnosti účtu",
    "{size} used" : "{size} použité",
    "Delete account" : "Zmazať účet",
    "Disconnect all devices and delete local data" : "Odpojiť všetky zariadenia a vymazať lokálne dáta",
    "Disable account" : "Zakázať účet",
    "Enable account" : "Povoliť účet",
    "Resend welcome email" : "Znova odoslať privítací email",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "V prípade straty zariadenia alebo napr. odchodu z firmy to môže na daľku vymazať údaje Nextcloud zo všetkých zariadení priradených k {userid}. Funguje iba vtedy, ak sú zariadenia pripojené k internetu.",
    "Remote wipe of devices" : "Vymazať obsah zariadení na diaľku",
    "Wipe {userid}'s devices" : "Vymazať obsah zariadení {userid}",
    "Wiped {userid}'s devices" : "Vymazané zariadenia užívateľa {userid}",
    "Failed to load groups with details" : "Nepodarilo sa načítať skupiny s podrobnosťami",
    "Failed to update line manager" : "Nepodarilo sa aktualizovať líniového manažéra",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Úplne odstráiť účet používateľa {userid} vrátane všetkých osobných súborov, údajov aplikácií atď.",
    "Account deletion" : "Zmazanie účtu",
    "Delete {userid}'s account" : "Vymazať účet {userid}",
    "Display name was successfully changed" : "Zobrazované meno ste úspešne zmenili",
    "Password can't be empty" : "Heslo nemôže byť prázdne",
    "Password was successfully changed" : "Heslo bolo úspešne zmenené",
    "Email can't be empty" : "E-mail nemôže byť prázdny",
    "Email was successfully changed" : "Email bol úspešne zmenený",
    "Welcome mail sent!" : "Privítací email odoslaný",
    "Loading account …" : "Nahrávam účet ...",
    "Change display name" : "Zmeniť zobrazované meno",
    "Set new password" : "Vytvoriť nové heslo",
    "You do not have permissions to see the details of this account" : "Nemáte oprávnenie vidieť detaily tohto účtu",
    "Set new email address" : "Nastavte novú e-mailovú adresu",
    "Add account to group" : "Pridať účet do skupiny",
    "Set account as admin for" : "Nastavte účet ako správcu pre",
    "Select account quota" : "Vyberte kvótu účtu",
    "Set the language" : "Nastavte jazyk",
    "Toggle account actions menu" : "Prepnúť ponuku akcií účtu",
    "Done" : "Hotovo",
    "Edit" : "Upraviť",
    "Account management settings" : "Nastavenia správy účtu",
    "Visibility" : "Viditeľnosť",
    "Show language" : "Zobraziť jazyk",
    "Show account backend" : "Zobraziť backend účtu",
    "Show storage path" : "Zobraziť popis umiestnenia úložiska",
    "Show first login" : "Zobraziť prvé prihlásenie",
    "Show last login" : "Zobraziť posledné prihlásenie",
    "Sorting" : "Triedenie",
    "The system config enforces sorting the groups by name. This also disables showing the member count." : "Systémová konfigurácia vynucuje triedenie skupín podľa názvu. Toto tiež zakáže zobrazovanie počtu členov.",
    "Group list sorting" : "Triedenie zoznamu skupín",
    "Sorting only applies to the currently loaded groups for performance reasons. Groups will be loaded as you navigate or search through the list." : "Zoradenie sa z dôvodu výkonu vzťahuje len na aktuálne načítané skupiny. Skupiny sa načítajú pri navigácii alebo vyhľadávaní v zozname.",
    "By member count" : "Podľa počtu členov",
    "By name" : "Podľa názvu",
    "Send email" : "Odoslať email",
    "Send welcome email to new accounts" : "Poslať uvítací e-mail novým účtom",
    "Defaults" : "Predvolené hodnoty",
    "Default quota" : "Predvolená kvóta",
    "Select default quota" : "Vybrať predvolenú kvótu",
    "Server error while trying to complete WebAuthn device registration" : "Chyba servera pri pokuse o dokončenie registrácie zariadenia WebAuthn",
    "Passwordless authentication requires a secure connection." : "Overenie bez hesla vyžaduje zabezpečné pripojenie.",
    "Add WebAuthn device" : "Pridať zariadenie WebAuthn",
    "Please authorize your WebAuthn device." : "Autorizujte svoje zariadenie WebAuthn.",
    "Adding your device …" : "Pridáva sa zariadenie...",
    "Unnamed device" : "Nepomenované zariadenie",
    "Passwordless Authentication" : "Overovanie bez hesla",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Nastavte si účet pre využívanie overovania bez hesla podľa štandardu FIDO2.",
    "No devices configured." : "Nie sú nastavené žiadne zariadenia.",
    "The following devices are configured for your account:" : "Pre váš účet máte nastavené nasledujúce zariadenia:",
    "Your browser does not support WebAuthn." : "Váš prehliadač nepodporuje WebAuthn.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Ako administrátor môžete nastaviť správanie sprístupňovania. Pre viac informácií pozrite dokumentáciu.",
    "You need to enable the File sharing App." : "Musíte povoliť Aplikáciu pre zdieľanie súborov.",
    "App Store" : "Obchod s aplikáciami",
    "Loading app list" : "Načítavam zoznam aplikácií",
    "Loading categories" : "Načítavam kategórie",
    "Developer documentation ↗" : "Dokumentácia vývojára ↗",
    "Version {version}, {license}-licensed" : "Verzia {version}, {license}-licencované",
    "Version {version}" : "Verzia {version}",
    "All accounts" : "Všetky účty",
    "Admins" : "Administrátori",
    "Account group: {group}" : "Skupina účtu: {group}",
    "Account management" : "Správa účtu",
    "Sending…" : "Odosielam...",
    "Email sent" : "Email odoslaný",
    "For performance reasons, when you enable encryption on a Nextcloud server only new and changed files are encrypted." : "Z dôvodu zachovania výkonu, keď povolíte šifrovanie na serveri Nextcloud, budú šifrované iba nové a zmenené súbory.",
    "Location" : "Miesto",
    "Profile picture" : "Avatar",
    "About" : "O vás",
    "Date of birth" : "Dátum narodenia",
    "Full name" : "Meno a priezvisko",
    "Additional email" : "Ďalšie e-maily",
    "Fediverse (e.g. Mastodon)" : "Fediverse (napr. Mastodon)",
    "Headline" : "Titul",
    "Organisation" : "Organizácia",
    "Phone number" : "Telefónne číslo",
    "Pronouns" : "Zámená",
    "Role" : "Rola",
    "X (formerly Twitter)" : "X (predtým Twitter)",
    "Website" : "Webstránka",
    "Profile visibility" : "Viditeľnosť profilu",
    "Locale" : "Regionálne nastavenia",
    "First day of week" : "Prvý deň v týždni",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Nie je k dispozícii, pretože táto vlastnosť je potrebná pre základné funkcie vrátane zdieľania súborov a pozvánok do kalendára",
    "Not available as federation has been disabled for your account, contact your system administration if you have any questions" : "Nie je k dispozícii, pretože federácia bola pre váš účet zakázaná. Ak máte nejaké otázky, kontaktujte správcu systému",
    "Not available as publishing account specific data to the lookup server is not allowed, contact your system administration if you have any questions" : "Nie je k dispozícii, pretože publikovanie údajov špecifických pre účet na vyhľadávacom serveri nie je povolené. Ak máte nejaké otázky, kontaktujte správcu systému.",
    "Discover" : "Objavujte",
    "Your apps" : "Vaše aplikácie",
    "Active apps" : "Aktívne aplikácie",
    "Disabled apps" : "Vypnuté aplikácie",
    "Updates" : "Aktualizácie",
    "App bundles" : "Aplikačné balíky",
    "Featured apps" : "Odporúčané aplikácie",
    "Supported apps" : "Podporované aplikácie",
    "Show to everyone" : "Viditeľné pre všetkých",
    "Show to logged in accounts only" : "Zobraziť len pre prihlásené účty",
    "Hide" : "Skryť",
    "Manually installed apps cannot be updated" : "Manuálne nainštalované aplikácie nemôžu byť aktualizované",
    "{progress}% Deploying …" : "{progress}% Nasadzovanie ...",
    "{progress}% Initializing …" : "{progress}% Inicializuje sa ...",
    "Health checking" : "Kontrola stavu",
    "Deploy and Enable" : "Nasadiť a zapnúť",
    "Download and enable" : "Stiahnuť a povoliť",
    "Disable" : "Zakázať",
    "Allow untested app" : "Povoliť netestovanú aplikáciu",
    "The app will be downloaded from the App Store" : "Aplikácia bude stiahnutá z obchodu",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Táto aplikácia nie je označená ako kompatibilná s vašou verziou Nextcloud. Ak budete pokračovať, aplikáciu budete môcť stále nainštalovať. Aplikácia nemusí fungovať podľa očakávania.",
    "Unknown" : "Neznámy",
    "Never" : "Nikdy",
    "Could not register device: Network error" : "Zariadenie sa nepodarilo zaregistrovať: Chyba siete",
    "Could not register device: Probably already registered" : "Zariadenie sa nepodarilo zaregistrovať: Pravdepodobne je už zaregistrované",
    "Could not register device" : "Zariadenie sa nepodarilo zaregistrovať",
    "An error occurred during the request. Unable to proceed." : "Počas vybavovania požiadavky nastala chyba.  Nie je možné pokračovať.",
    "The app has been enabled but needs to be updated." : "Aplikácia bola zapnutá ale je potrebné ju aktualizovať.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Chyba: aplikáciu nie je možné povoliť, lebo naruší stabilitu servera",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Aplikácia bola povolená, ale vyžaduje sa aktualizácia. Presmerovanie na stránku aktualizácie o 5 sekúnd.",
    "Do you really want to wipe your data from this device?" : "Naozaj chcete vymazať svoje údaje z tohto zariadenia?",
    "Confirm wipe" : "Potvrďte vymazanie",
    "Could not delete the app token" : "Nepodarilo sa vymazať token aplikácie",
    "Error while wiping the device with the token" : "Chyba pri vymazávaní zariadenia s tokenom",
    "Error while updating device token name" : "Chyba pri aktualizácii názvu tokenu zariadenia",
    "Error while updating device token scope" : "Chyba pri aktualizácii rozsahu tokenu zariadenia",
    "Could not set group sorting" : "Nepodarilo sa nastaviť triedenie podľa skupín",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Príliš mnoho požiadaviek z vašej siete. Skúste to znovu neskôr alebo kontaktujte svojho administrátora ak je toto chyba.",
    "Error" : "Chyba",
    "Account documentation" : "Dokumentácia k účtom",
    "Administration documentation" : "Príručka administrátora",
    "Forum" : "Fórum",
    "Nextcloud help & privacy resources" : "Pomocník Nextcloud a zdroje ochrany osobných údajov",
    "General documentation" : "Všeobecná dokumentácia",
    "Legal notice" : "Právne upozornenie",
    "Privacy policy" : "Zásady ochrany osobných údajov",
    "None/STARTTLS" : "Žiadne/STARTTLS",
    "SSL" : "SSL",
    "Open documentation" : "Otvoriť dokumentáciu",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Je dôležité nastaviť odosielanie e-mailov zo servera, aby tak fungovalo napríklad nastavenie hesla a notifikácie.",
    "Send mode" : "Mód odosielania",
    "Encryption" : "Šifrovanie",
    "Sendmail mode" : "Režim sendmail",
    "From address" : "Z adresy",
    "Server address" : "Adresa servera",
    "Port" : "Port",
    "Authentication" : "Autentifikácia",
    "Authentication required" : "Vyžaduje sa overenie",
    "Credentials" : "Prihlasovacie údaje",
    "SMTP Login" : "SMTP Prihlasovacie meno",
    "SMTP Password" : "SMTP heslo",
    "Save" : "Uložiť",
    "Test and verify email settings" : "Otestovať a overiť nastavenia e-mailu",
    "Security & setup warnings" : "Bezpečnosť a nastavenia upozornení",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Kvôli bezpečnosti a výkonu vašej inštalácie je dôležité, aby bolo všetko správne nastavené. Robíme automatickú kontrolu, ktorá vám s touto úlohou pomôže. Pre ďalšie informácie nahliadnite do priloženej dokumentácie.",
    "All checks passed." : "Všetky kontroly prešli úspešne.",
    "There are some errors regarding your setup." : "Vo vašom nastavení sú nejaké chyby.",
    "There are some warnings regarding your setup." : "Tu sú niektoré varovania týkajúce sa vašich nastavení.",
    "Checking for system and security issues." : "Prebieha kontrola systémových a bezpečnostných problémov.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Prosím skontrolujte <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">inštalačnú dokumentáciu</a> a skontrolujte existenciu chýb a upozornení v <a href=\"%2$s\">logu</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Skontrolujte bezpečnosť svojho Nextcloudu pomocou <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">nášho bezpečnostného skenu</a>.",
    "Reasons to use Nextcloud in your organization" : "Dôvody použitia NextCloudu vo vašej organizácii",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Vyvíjané {communityopen}komunitou Nextcloud{linkclose}, {githubopen}zdrojové kódy{linkclose} sú licencované pod licenciou {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Sleduj nás na Facebook-u",
    "Follow us on X" : "Sledujte nás na X",
    "Follow us on Mastodon" : "Sledujte nás na Mastodon",
    "Check out our blog" : "Pozri si náš blog",
    "Subscribe to our newsletter" : "Prihlás sa na odber noviniek emailom",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Toto komunitné vydanie Nextcloud nie je podporované a okamžité upozornenia nie sú k dispozícii.",
    "Use a second factor besides your password to increase security for your account." : "Pre zlepšenie zabezpečenia vášho účtu použite okrem hesla aj druhý faktor.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Ak na pripojenie k NextCloudu používate aplikácie tretích strán, pred povolením dvojstupňového overovania totožnosti, nezabudnite pre každú z nich vytvoriť a nastaviť heslo aplikácie.",
    "Logged in account must be a subadmin" : "Prihlásený účet musí byť sub-správca",
    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Ak chcete povoliť spustenie tejto kontroly, musíte sa uistiť, že váš webový server sa môže pripojiť sám k sebe. Preto musí byť schopný rozpoznať a pripojiť sa aspoň k jednej zo svojich `trusted_domains` alebo `overwrite.cli.url`.  Výsledkom nesprávneho nastavenia môže byť nesúlad DNS na strane servera alebo pravidla brány firewall pre výstup.",
    "File locking" : "Zamykanie súborov",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems." : "Transakčné zamykanie súborov je zakázané, toto by mohlo viesť k problémom pri súbehu úloh. Povolte \"filelocking.enabled\" v config.php, aby ste týmto problémom predišli.",
    "The PHP memory limit is below the recommended value of %s." : "Limit pre pamäť PHP je nižší ako odporúčaná hodnota %s.",
    "for WebAuthn passwordless login" : "pre bezheslového prihlásenia pomocou WebAuthn",
    "for WebAuthn passwordless login, and SFTP storage" : "pre prihlásenie bez hesla WebAuthn a SFTP úložisko",
    "- The `%1$s` HTTP header does not contain `%2$s`. This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "Hlavička HTTP `%1$s` neobsahuje `%2$s`. Toto je potenciálne riziko pre bezpečnosť alebo ochranu osobných údajov a preto odporúčame toto nastavenie upraviť.",
    "PostgreSQL version \"%s\" detected. PostgreSQL >=12 and <=16 is suggested for best performance, stability and functionality with this version of Nextcloud." : "Bola zistená verzia \"%s\" PostgreSQL. Odporúča sa PostgreSQL >=12 a <=16 pre najlepší výkon, stabilitu a funkčnosť s touto verziou Nextcloud.",
    "Set default expiration date for shares" : "Nastaviť predvolený dátum expirácie pre sprístupnenia",
    "Your biography" : "Váš životopis",
    "You are using <strong>{usage}</strong>" : "Využívate <strong>{usage}</strong>",
    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Využívate <strong>{usage}</strong> z <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
    "Failed to load subadmin groups with details" : "Nepodarilo sa načítať skupiny subadministátorov s podrobnosťami"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
