OC.L10N.register(
    "comments",
    {
    "Comments" : "Komentarai",
    "You commented" : "Jūs pakomentavote",
    "{author} commented" : "{author} pakomentavo",
    "You commented on %1$s" : "Pakomentavote %1$s",
    "You commented on {file}" : "Pakomentavote {file}",
    "%1$s commented on %2$s" : "%1$s pakomentavo %2$s",
    "{author} commented on {file}" : "{author} pakomentavo {file}",
    "<strong>Comments</strong> for files" : "Failų <strong>komentarai</strong>",
    "Files" : "Failai",
    "Files app plugin to add comments to files" : "Failų programėlės įskiepis, skirtas prie failų pridėti komentarus",
    "Edit comment" : "Taisyti komentarą",
    "Delete comment" : "Ištrinti komentarą",
    "Cancel edit" : "Atsisakyti taisymo",
    "New comment" : "Naujas komentaras",
    "Post comment" : "Paskelbti komentarą",
    "Unable to load the comments list" : "Nepavyko įkelti komentarų sąrašo",
    "No comments yet, start the conversation!" : "Komentarų kol kas nėra, pradėkite pokalbį!",
    "Retry" : "Bandyti dar kartą",
    "_1 new comment_::_{unread} new comments_" : ["1 neskaitytas komentaras","{unread} neskaityti komentarai","{unread} neskaitytų komentarų","{unread} neskaitytas komentaras"],
    "Comment" : "Komentaras",
    "An error occurred while trying to edit the comment" : "Bandant taisyti komentarą, įvyko klaida",
    "Comment deleted" : "Komentaras ištrintas",
    "An error occurred while trying to delete the comment" : "Bandant ištrinti komentarą, įvyko klaida",
    "An error occurred while trying to create the comment" : "Bandant sukurti komentarą, įvyko klaida"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
