OC.L10N.register(
    "comments",
    {
    "Comments" : "Comments",
    "You commented" : "You commented",
    "{author} commented" : "{author} commented",
    "You commented on %1$s" : "You commented on %1$s",
    "You commented on {file}" : "You commented on {file}",
    "%1$s commented on %2$s" : "%1$s commented on %2$s",
    "{author} commented on {file}" : "{author} commented on {file}",
    "<strong>Comments</strong> for files" : "<strong>Comments</strong> for files",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} mentioned you in a comment on \"{file}\"",
    "Files app plugin to add comments to files" : "Files app plugin to add comments to files",
    "Edit comment" : "Edit comment",
    "Delete comment" : "Delete comment",
    "Cancel edit" : "Cancel edit",
    "Post comment" : "Post comment",
    "@ for mentions, : for emoji, / for smart picker" : "@ for mentions, : for emoji, / for smart picker",
    "Could not reload comments" : "Could not reload comments",
    "Failed to mark comments as read" : "Failed to mark comments as read",
    "Unable to load the comments list" : "Unable to load the comments list",
    "No comments yet, start the conversation!" : "No comments yet, start the conversation!",
    "No more messages" : "No more messages",
    "Retry" : "Retry",
    "_1 new comment_::_{unread} new comments_" : ["1 new comment","{unread} new comments"],
    "Comment" : "Comment",
    "An error occurred while trying to edit the comment" : "An error occurred while trying to edit the comment",
    "Comment deleted" : "Comment deleted",
    "An error occurred while trying to delete the comment" : "An error occurred while trying to delete the comment",
    "An error occurred while trying to create the comment" : "An error occurred while trying to create the comment"
},
"nplurals=2; plural=(n!=1);");
