OC.L10N.register(
    "app_api",
    {
    "Delete" : "Sil",
    "Edit" : "Dəyişiklik et",
    "Name" : "Ad",
    "Host" : "Şəbəkədə ünvan",
    "Enabled" : "İşə salınıb",
    "Confirm" : "Təsdiq edin",
    "Save" : "Saxla",
    "Update to {version}" : "{version} dək yenilə",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Bu proqram yüklənə bilməz ona görə ki, göstərilən asılılıqlar yerinə yetirilməyib:",
    "View in store" : "Dükanda bax",
    "Visit website" : "Sayta keç",
    "Report a bug" : "Səhv haqqında bildir",
    "User documentation" : "İstifadəçi dokumentasiyası",
    "Admin documentation" : "İdarəci dokumentasiyası",
    "Developer documentation" : "Yaradıcı sənədləşməsi",
    "Supported" : "Dəstəklənir",
    "Featured" : "Seçilmiş",
    "Version" : "Versiya",
    "Actions" : "İşlər",
    "Documentation" : "Sənədlər",
    "Details" : "Detallar",
    "Changelog" : "Dəyişikliklər jurnalı",
    "Updates" : "Yenilənmələr",
    "Disable" : "Dayandır"
},
"nplurals=2; plural=(n != 1);");
