OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "Kitambulisho batili cha Cloud ililoshirikishwa",
    "Server to server sharing is not enabled on this server" : "Ushiriki wa Seva hadi seva haujawezeshwa kwenye seva hii",
    "Couldn't establish a federated share." : "Haikuweza kuanzisha ushiriki ulioshirikishwa.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Haikuweza kuanzisha ushiriki ulioshirikishwa, labda nenosiri halikuwa sahihi.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Ombi la Shiriki Lililotumwa limetumwa, utapokea mwaliko. Angalia arifa zako.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Haikuweza kuanzisha ushiriki ulioshirikishwa, inaonekana kama seva ya kushirikiana nayo ni ya zamani sana (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Hairuhusiwi kutuma hisa za vikundi vilivyoshirikishwa kutoka kwa seva hii.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Kushiriki %1$s kumeshindwa, kwa sababu kipengee hiki tayari kimeshirikiwa na akaunti %2$s",
    "Not allowed to create a federated share to the same account" : "Hairuhusiwi kuunda ushiriki ulioshirikishwa kwa akaunti sawa",
    "Federated shares require read permissions" : "Hisa zilizoshirikishwa zinahitaji ruhusa za kusoma",
    "File is already shared with %s" : "Faili tayari imeshirikiwa na %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Kushiriki %1$s kumeshindwa, hakuweza kupata %2$s, labda seva haiwezi kufikiwa kwa sasa au inatumia cheti cha kujiandikisha.",
    "Could not find share" : "Haikuweza kupata kushiriki",
    "Federated sharing" : "Kushiriki kwa shirikisho",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Umepokea {share} kama mgao wa mbali kutoka kwa {user} (kwa niaba ya {behalf}",
    "You received {share} as a remote share from {user}" : "Umepokea {share} kama mgao wa mbali kutoka   {user}",
    "Accept" : "Kubali",
    "Decline" : "Kataa",
    "Federated Cloud Sharing" : "Ushirikiano wa Cloud ulioshirikishwa",
    "Sharing" : "inashirikisha",
    "Federated file sharing" : " Kushiriki faili zilizoshirikiwa",
    "Provide federated file sharing across servers" : "Toa ugavi wa faili ulioshirikishwa kwenye seva",
    "Confirm data upload to lookup server" : "Thibitisha upakiaji wa data kwenye seva ya kuangalia",
    "When enabled, all account properties (e.g. email address) with scope visibility set to \"published\", will be automatically synced and transmitted to an external system and made available in a public, global address book." : "Ikiwezeshwa, sifa zote za akaunti (k.m. anwani ya barua pepe) zenye mwonekano wa upeo uliowekwa kuwa \"zilizochapishwa\", zitasawazishwa kiotomatiki na kutumwa kwa mfumo wa nje na kupatikana katika kitabu cha anwani cha umma, cha kimataifa.",
    "Disable upload" : "Zima upakiaji",
    "Enable data upload" : "Washa upakiaji wa data",
    "Confirm querying lookup server" : "Thibitisha kuuliza seva ya utafutaji",
    "When enabled, the search input when creating shares will be sent to an external system that provides a public and global address book." : "Ikiwezeshwa, ingizo la utafutaji wakati wa kuunda hisa litatumwa kwa mfumo wa nje ambao hutoa kitabu cha anwani cha umma na kimataifa.",
    "This is used to retrieve the federated cloud ID to make federated sharing easier." : "Hii inatumika kupata kitambulisho cha Cloud kilichoshirikishwa ili kurahisisha kushiriki kwa shirikisho.",
    "Moreover, email addresses of users might be sent to that system in order to verify them." : "Zaidi ya hayo, anwani za barua pepe za watumiaji zinaweza kutumwa kwa mfumo huo ili kuzithibitisha.",
    "Disable querying" : "Zima kuuliza",
    "Enable querying" : "Washa kuuliza",
    "Unable to update federated files sharing config" : "Imeshindwa kusasisha usanidi wa kushiriki faili zilizoshirikiwa",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Rekebisha jinsi watu wanaweza kushiriki kati ya seva. Hii inajumuisha kushiriki kati ya watu kwenye seva hii pia ikiwa wanatumia kushiriki kwa shirikisho.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Ruhusu watu kwenye seva hii kutuma hisa kwa seva zingine (chaguo hili pia huruhusu ufikiaji wa WebDAV kwa hisa za umma)",
    "Allow people on this server to receive shares from other servers" : "Ruhusu watu kwenye seva hii kupokea shiriki kutoka kwa seva zingine",
    "Allow people on this server to send shares to groups on other servers" : "Ruhusu watu kwenye seva hii kutuma shiriki kwa vikundi kwenye seva zingine",
    "Allow people on this server to receive group shares from other servers" : "Ruhusu watu kwenye seva hii kupokea shiriki za kikundi kutoka kwa seva zingine",
    "The lookup server is only available for global scale." : "Seva ya utafutaji inapatikana kwa kiwango cha kimataifa pekee.",
    "Search global and public address book for people" : "Tafuta kitabu cha anwani cha kimataifa na hadharani kwa watu",
    "Allow people to publish their data to a global and public address book" : "Ruhusu watu kuchapisha data zao kwenye kitabu cha anwani cha kimataifa na cha umma",
    "Trusted federation" : "Shirikisho linaloaminika",
    "Automatically accept shares from trusted federated accounts and groups by default" : "Kubali kushiriki kiotomatiki kutoka kwa akaunti na vikundi vinavyoaminika vilivyoshirikishwa kwa chaguomsingi",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Shiriki nami kupitia Kitambulisho changu cha #Nextcloud Federated Cloud, ona, {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Shiriki nami kupitia Kitambulisho changu cha #Nextcloud Federated Cloud",
    "Share with me via Nextcloud" : "Shiriki nami kupitia Nextcloud",
    "Copy" : "Nakili",
    "Clipboard not available. Please copy the cloud ID manually." : "Ubao wa kunakili haupatikani. Tafadhali nakili kitambulisho cha cloud wewe mwenyewe.",
    "Copied!" : "Imenakiliwa!",
    "Federated Cloud" : "Shirikisho la Cloud",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Unaweza kushiriki na mtu yeyote anayetumia seva ya Nextcloud au seva na huduma zingine zinazooana na Open Cloud Mesh (OCM)! Weka tu Kitambulisho chao cha Wingu Shirikishi kwenye kidirisha cha kushiriki. Inaonekana kama person@cloud.example.com",
    "Your Federated Cloud ID" : "Kitambulisho chako cha Shirikisho la Cloud",
    "Share it so your friends can share files with you:" : "Ishiriki ili marafiki zako waweze kushiriki faili nawe:",
    "Facebook" : "Facebook",
    "X (formerly Twitter)" : "X (zamani Twitter)",
    "formerly Twitter" : "zamani Twitter",
    "Mastodon" : "Mastodon",
    "Bluesky" : "Angabluu",
    "Add to your website" : "Ongeza kwenye tovuti yako",
    "HTML Code:" : "Msimbo wa HTML:",
    "Cancel" : "Ghaili",
    "Add remote share" : "Ongeza kushiriki kwa mbali",
    "Remote share" : "Kushiriki kwa mbali",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Je, ungependa kuongeza ushiriki wa mbali {name} tangu {owner}@{remote}?",
    "Remote share password" : "Nenosiri la kushiriki kwa mbali",
    "Incoming share could not be processed" : "Ushiriki unaoingia haukuweza kuchakatwa",
    "Cloud ID copied to the clipboard" : "Kitambulisho cha Cloud kimenakiliwa kwenye ubao wa kunakili",
    "Copy to clipboard" : "Nakili kwenye ubao wa kunakili"
},
"nplurals=2; plural=(n != 1);");
