OC.L10N.register(
    "app_api",
    {
    "Cancel" : "ýatyrmak",
    "Delete" : "Pozmak",
    "Default" : "Bellenen",
    "Edit" : "Redaktirläň",
    "Name" : "Ady",
    "Save" : "Saklamak",
    "Remove" : "Aýyrmak",
    "Type" : "Görnüşi",
    "Details" : "Jikme-jiklikler",
    "Disable" : "Öçürmek"
},
"nplurals=2; plural=(n != 1);");
