OC.L10N.register(
    "nextcloud_announcements",
    {
    "Nextcloud announcements" : "Nextcloud 公告",
    "Nextcloud announcement" : "Nextcloud 公告",
    "Read more" : "更多",
    "Disable announcements" : "停用公告",
    "(These announcements are only shown to administrators)" : "（這些公告只顯示給管理員）",
    "Nextcloud announcements brings the latest news of Nextcloud into your notifications" : "Nextcloud 公告將 Nextcloud 的最新消息納入您的通知中"
},
"nplurals=1; plural=0;");
