OC.L10N.register(
    "photos",
    {
    "Photos" : "Fotos",
    "Your memories under your control" : "Tus recuerdos bajo tu control",
    "Videos" : "Videos",
    "Folders" : "Carpetas",
    "Favorites" : "Favoritos",
    "Shared with you" : "Compartido con usted",
    "Tags" : "Etiquetas",
    "Back" : "Atrás",
    "Save" : "Guardar",
    "Shared by" : "Compartido por",
    "Group" : "Grupo",
    "An error occurred" : "Se presentó un error",
    "Favorite" : "Hacer favorito",
    "Open the full size \"{name}\" image" : "Abrir la imagen \"{name}\" en tamaño completo",
    "Go back" : "Regresar",
    "Dates" : "Fechas",
    "Home" : "Inicio",
    "Remove from favorites" : "Eliminar de favoritos",
    "No photos in here" : "No hay fotos aquí",
    "No tags yet" : "Aún no hay etiquetas",
    "Photos with tags will show up here" : "Fotos con etiquetas serán mostradas aquí",
    "Tagged photos" : "Fotos etiquetadas",
    "Details" : "Detalles",
    "Back to {folder}" : "Volver a {folder}",
    "Share this folder" : "Compartir esta carpeta",
    "Add" : "Agregar"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
