OC.L10N.register(
    "logreader",
    {
    "Logging" : "Registravimas",
    "Log Reader" : "Žurnalų skaitytuvė",
    "A log reader for Nextcloud" : "Žurnalo skaitytuvė, skirta Nextcloud",
    "Log reader for Nextcloud" : "Žurnalo skaitytuvė, skirta Nextcloud",
    "Level" : "Lygmuo",
    "App" : "Programėlė",
    "Time" : "Laikas",
    "Ctrl" : "Vald",
    "Download logs" : "Atsisiųsti žurnalus",
    "Relative" : "Santykinis laikas",
    "Message" : "Žinutė",
    "Show details" : "Rodyti išsamiau",
    "Debug" : "Derinimas",
    "Info" : "Informacija",
    "Warning" : "Įspėjimas",
    "Error" : "Klaida",
    "Fatal" : "Lemtinga klaida"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
