<?php
// This file is auto-generated. Do not edit!
return array('spellout-numbering-year'=>array('-x'=>array('rule'=>'mínusz →→'),'x.x'=>array('rule'=>'=0.0='),'integer'=>array(array('rule'=>'=%spellout-numbering='))),'spellout-numbering'=>array('integer'=>array(array('rule'=>'=%spellout-cardinal='))),'spellout-cardinal'=>array('-x'=>array('rule'=>'mínusz →→'),'x.x'=>array('rule'=>'←← egész →→'),'integer'=>array(0=>array('rule'=>'nulla'),1=>array('rule'=>'egy'),2=>array('rule'=>'kettő'),3=>array('rule'=>'három'),4=>array('rule'=>'négy'),5=>array('rule'=>'öt'),6=>array('rule'=>'hat'),7=>array('rule'=>'hét'),8=>array('rule'=>'nyolc'),9=>array('rule'=>'kilenc'),10=>array('rule'=>'tíz'),11=>array('rule'=>'tizen­→→'),20=>array('rule'=>'húsz'),21=>array('rule'=>'huszon­→→'),30=>array('rule'=>'harminc[­→→]'),40=>array('rule'=>'negyven[­→→]'),50=>array('rule'=>'ötven[­→→]'),60=>array('rule'=>'hatvan[­→→]'),70=>array('rule'=>'hetven[­→→]'),80=>array('rule'=>'nyolcvan[­→→]'),90=>array('rule'=>'kilencven[­→→]'),100=>array('rule'=>'száz[­→→]'),200=>array('rule'=>'←%%spellout-cardinal-initial←­száz[­→→]'),1000=>array('rule'=>'ezer[­→→]'),2000=>array('rule'=>'←%%spellout-cardinal-initial←­ezer[­→→]'),1000000=>array('rule'=>'←%%spellout-cardinal-initial←­millió[­→→]'),1000000000=>array('rule'=>'←%%spellout-cardinal-initial←­milliárd[­→→]'),'1000000000000'=>array('rule'=>'←%%spellout-cardinal-initial←­billió[­→→]'),'1000000000000000'=>array('rule'=>'←%%spellout-cardinal-initial←­billiárd[­→→]'),'1000000000000000000'=>array('rule'=>'=#,##0='))),'spellout-cardinal-verbose'=>array('-x'=>array('rule'=>'mínusz →→'),'x.x'=>array('rule'=>'←← egész →→'),'integer'=>array(0=>array('rule'=>'=%spellout-cardinal='),100=>array('rule'=>'←←­száz[­→→]'),1000=>array('rule'=>'←←­ezer[­→→]'),1000000=>array('rule'=>'←←­millió[­→→]'),1000000000=>array('rule'=>'←←­milliárd[­→→]'),'1000000000000'=>array('rule'=>'←←­billió[­→→]'),'1000000000000000'=>array('rule'=>'←←­billiárd[­→→]'),'1000000000000000000'=>array('rule'=>'=#,##0='))),'%spellout-cardinal-initial'=>array('integer'=>array(1=>array('rule'=>'egy'),2=>array('rule'=>'két'),3=>array('rule'=>'=%spellout-cardinal='))),'spellout-ordinal'=>array('-x'=>array('rule'=>'mínusz →→'),'x.x'=>array('rule'=>'=#,##0.#='),'integer'=>array(array('rule'=>'nulla'),array('rule'=>'első'),array('rule'=>'második'),array('rule'=>'=%%spellout-ordinal-larger='))),'%spellout-ordinal-adik'=>array('integer'=>array(array('rule'=>'adik'),array('rule'=>'=%%spellout-ordinal-larger='))),'%spellout-ordinal-odik'=>array('integer'=>array(array('rule'=>'odik'),array('rule'=>'=%%spellout-ordinal-larger='))),'%spellout-ordinal-larger'=>array('integer'=>array(0=>array('rule'=>'edik'),1=>array('rule'=>'egyedik'),2=>array('rule'=>'kettedik'),3=>array('rule'=>'harmadik'),4=>array('rule'=>'negyedik'),5=>array('rule'=>'ötödik'),6=>array('rule'=>'hatodik'),7=>array('rule'=>'hetedik'),8=>array('rule'=>'nyolcadik'),9=>array('rule'=>'kilencedik'),10=>array('rule'=>'tizedik'),11=>array('rule'=>'tizen→→'),20=>array('rule'=>'huszadik'),21=>array('rule'=>'huszon→→'),30=>array('rule'=>'harminc→%%spellout-ordinal-adik→'),40=>array('rule'=>'negyven→→'),50=>array('rule'=>'ötven→→'),60=>array('rule'=>'hatvan→%%spellout-ordinal-adik→'),70=>array('rule'=>'hetven→→'),80=>array('rule'=>'nyolcvan→%%spellout-ordinal-adik→'),90=>array('rule'=>'kilencven→→'),100=>array('rule'=>'száz→%%spellout-ordinal-adik→'),200=>array('rule'=>'←%%spellout-cardinal-initial←száz→%%spellout-ordinal-adik→'),1000=>array('rule'=>'ezr→→'),1001=>array('rule'=>'ezer­→→'),2000=>array('rule'=>'←%%spellout-cardinal-initial←­ezr→→'),2001=>array('rule'=>'←%%spellout-cardinal-initial←­ezer­→→'),1000000=>array('rule'=>'←%%spellout-cardinal-initial←­milliom­→%%spellout-ordinal-odik→'),1000000000=>array('rule'=>'=#,##0=.'))),'spellout-ordinal-verbose'=>array('-x'=>array('rule'=>'mínusz →→'),'x.x'=>array('rule'=>'=#,##0.#='),'integer'=>array(array('rule'=>'nulladik'),array('rule'=>'első'),array('rule'=>'második'),array('rule'=>'=%%spellout-ordinal-verbose-larger='))),'%spellout-ordinal-verbose-adik'=>array('integer'=>array(array('rule'=>'adik'),array('rule'=>'=%%spellout-ordinal-verbose-larger='))),'%spellout-ordinal-verbose-odik'=>array('integer'=>array(array('rule'=>'odik'),array('rule'=>'=%%spellout-ordinal-verbose-larger='))),'%spellout-ordinal-verbose-larger'=>array('integer'=>array(0=>array('rule'=>'=%%spellout-ordinal-larger='),100=>array('rule'=>'←%spellout-cardinal-verbose←száz→%%spellout-ordinal-verbose-adik→'),1000=>array('rule'=>'←%spellout-cardinal-verbose←­ezr→→'),1001=>array('rule'=>'←%spellout-cardinal-verbose←­ezer­→→'),1000000=>array('rule'=>'←%spellout-cardinal-verbose←­milliom­→%%spellout-ordinal-verbose-odik→'),1000000000=>array('rule'=>'=#,##0=.'))),'digits-ordinal'=>array('-x'=>array('rule'=>'−→→'),'integer'=>array(array('rule'=>'=#,##0=.'))));
