OC.L10N.register(
    "app_api",
    {
    "Cancel" : "Anullar",
    "Delete" : "Suprimir",
    "Edit" : "Modificar",
    "Name" : "Nom",
    "Host" : "Òste",
    "Nextcloud URL" : "URL Nextcloud",
    "Enabled" : "Activada",
    "Confirm" : "Confirmar",
    "Save" : "Enregistrar",
    "Register" : "S'inscriure",
    "Update to {version}" : "Metre a jorn cap a {version}",
    "Remove" : "Suprimir",
    "View in store" : "Veire a la botiga",
    "Visit website" : "Veire lo site web",
    "Report a bug" : "Raportar un bug",
    "User documentation" : "Documentacion utilizaire",
    "Admin documentation" : "Documentacion admin",
    "Developer documentation" : "Documentacion desvolopaire",
    "Update to {update}" : "Actualizar en {update}",
    "Version" : "Version",
    "Actions" : "Accions",
    "Type" : "Tipe",
    "Your apps" : "Vòstras aplicacions",
    "Documentation" : "Documentacion",
    "Details" : "Per lo Menut",
    "Changelog" : "Nòta de version",
    "by {author}\n{license}" : "per {author}\n{license}",
    "Active apps" : "Aplicacions activas",
    "Disabled apps" : "Aplicacions desactivadas",
    "Updates" : "Mesas a jorn",
    "Disable" : "Desactivar"
},
"nplurals=2; plural=(n > 1);");
