<?php
namespace Aws\PaymentCryptographyData\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Payment Cryptography Data Plane** service.
 */
class PaymentCryptographyDataException extends AwsException {}
