OC.L10N.register(
    "files_trashbin",
    {
    "restored" : "atkurta",
    "Deleted files" : "Ištrinti failai",
    "Deleted files and folders in the trash bin (may expire during export if you are low on storage space)" : "Ištrinti failai ir aplankai šiukšlinėje (eksportavimo metu gali nebegalioti, jei yra mažai saugyklos vietos)",
    "This application enables people to restore files that were deleted from the system." : "Ši programėlė suteikia žmonėms galimybę atkurti iš sistemos ištrintus failus.",
    "This application enables people to restore files that were deleted from the system. It displays a list of deleted files in the web interface, and has options to restore those deleted files back to the people file directories or remove them permanently from the system. Restoring a file also restores related file versions, if the versions application is enabled. When a file is deleted from a share, it can be restored in the same manner, though it is no longer shared. By default, these files remain in the trash bin for 30 days.\nTo prevent an account from running out of disk space, the Deleted files app will not utilize more than 50% of the currently available free quota for deleted files. If the deleted files exceed this limit, the app deletes the oldest files until it gets below this limit. More information is available in the Deleted Files documentation." : "Ši programėlė įgalina žmones atkurti iš sistemos ištrintus failus. Ji saityno sąsajoje rodo ištrintų failų sąrašą ir teikia parinktis atkurti tuos ištrintus failus atgal į žmonių failų katalogus arba visam laikui pašalinti failus iš sistemos. Atkūrus failą, tuo pačiu yra atkuriamos susijusios failo versijos, jei yra  įjungta versijų programėlė. Kai failas ištrinamas iš viešinio, jis gali būti atkurtas tokiu pačiu būdu, tik jau nebebus bendrinamas. Pagal numatymą, šie failai yra laikomi šiukšlinėje 30 dienų.\nTam, kad paskyroms nepritrūktų vietos, „Ištrinti failai“ nenaudos ištrintiems failams daugiau kaip 50% esamu metu prieinamo laisvo leidžiamo duomenų kiekio. Jei ištrinti failai viršija šią ribą, programėlė atrenka seniausius failus ir juos ištrina, kad nebūtų viršyta numatytoji riba. Daugiau informacijos yra prieinama „Ištrinti failai“ dokumentacijoje.",
    "Restore" : "Atkurti",
    "Empty deleted files" : "Išvalyti ištrintus failus",
    "Cancel" : "Atsisakyti",
    "Original location" : "Pradinė vieta",
    "Deleted by" : "Ištrynė",
    "Deleted" : "Ištrinta",
    "A long time ago" : "Prieš ilgą laiką",
    "Unknown" : "Nežinoma",
    "All files" : "Visi failai",
    "You" : "Jūs",
    "List of files that have been deleted." : "Ištrintų failų sąrašas.",
    "No deleted files" : "Ištrintų failų nėra",
    "Files and folders you have deleted will show up here" : "Čia bus rodomi failai ir aplankai, kuriuos ištrynėte",
    "Deletion cancelled" : "Ištrynimo atsisakyta"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
