OC.L10N.register(
    "provisioning_api",
    {
    "Logged in account must be an administrator or have authorization to edit this setting." : "Aby mohl upravovat toto nastavení, je třeba, aby přihlášený účet byl správcem nebo měl potřebná pověření.",
    "Could not create non-existing user ID" : "Není možné vytvořit neexistující identifikátor uživatele",
    "User already exists" : "Uživatel už existuje",
    "Group %1$s does not exist" : "Skupina %1$s neexistuje",
    "Insufficient privileges for group %1$s" : "Nedostatečná oprávnění pro skupinu %1$s",
    "No group specified (required for sub-admins)" : "Neurčena žádná skupina (vyžadováno pro dílčí správce)",
    "Sub-admin group does not exist" : "Skupina dílčích správců neexistuje",
    "Cannot create sub-admins for admin group" : "Nepodařilo se vytvořit dílčí správce pro skupinu správců",
    "No permissions to promote sub-admins" : "Chybí oprávnění povyšovat dílčí správce",
    "Invalid password value" : "Neplatná hodnota hesla",
    "An email address is required, to send a password link to the user." : "Je vyžadována e-mailová adresa (pro zaslání odkazu na heslo uživateli).",
    "Required email address was not provided" : "Nebyla poskytnuta potřebná e-mailová adresa",
    "User creation failed" : "Vytváření uživatele se nezdařilo",
    "Invalid quota value: %1$s" : "Neplatná hodnota kvóty: %1$s",
    "Invalid quota value. %1$s is exceeding the maximum quota" : "Neplatná hodnota kvóty. %1$s překračuje maximální kvótu",
    "Unlimited quota is forbidden on this instance" : "Neomezená kvóta není na této instanci dovolena",
    "Setting the password is not supported by the users backend" : "Nastavování hesla není touto podpůrnou vrstvou pro uživatelské účty podporována",
    "Invalid language" : "Neplatný jazyk",
    "Invalid locale" : "Neplatná místní a jazyková nastavení",
    "Invalid first day of week" : "Neplatný první den v týdnu",
    "Cannot remove yourself from the admin group" : "Není možné odebrat sama sebe ze skupiny správců",
    "Cannot remove yourself from this group as you are a sub-admin" : "Není možné odebrat sama sebe z této skupiny protože jste dílčím správcem",
    "Not viable to remove user from the last group you are sub-admin of" : "Není uskutečnitelné odebrat uživatele z poslední skupiny, které jste dílčím správcem",
    "User does not exist" : "Uživatel neexistuje",
    "Group does not exist" : "Skupina neexistuje",
    "User is not a sub-admin of this group" : "Uživatel není dílčím správcem této skupiny",
    "Email address not available" : "E-mailová adresa není k dispozici",
    "Sending email failed" : "Odeslání e-mailu se nezdařilo",
    "Email confirmation" : "Potvrzení e-mailu",
    "To enable the email address %s please click the button below." : "Pokud chcete povolit e-mailovou adresu %s, klikněte na tlačítko níže.",
    "Confirm" : "Potvrdit",
    "Email was already removed from account and cannot be confirmed anymore." : "E-mail už byl odebrán z účtu a není už možné ho potvrdit.",
    "Could not verify mail because the token is expired." : "E-mail není možné ověřit, protože platnost tokenu skončila.",
    "Could not verify mail because the token is invalid." : "E-mail není možné ověřit, protože token není platný.",
    "An unexpected error occurred. Please contact your admin." : "Došlo k neočekávané chybě. Obraťte se na svého správce.",
    "Email confirmation successful" : "E-mail úspěšně potvrzen",
    "Provisioning API" : "Provisioning API",
    "This application enables a set of APIs that external systems can use to manage accounts, groups and apps." : "Tato aplikace zapíná sadu PI rozhraní, kterou mohou využívat externí systémy pro správu účtů, skupin a aplikací.",
    "This application enables a set of APIs that external systems can use to create, edit, delete and query account\n\t\tattributes, query, set and remove groups, set quota and query total storage used in Nextcloud. Group admin accounts\n\t\tcan also query Nextcloud and perform the same functions as an admin for groups they manage. The API also enables\n\t\tan admin to query for active Nextcloud applications, application info, and to enable or disable an app remotely.\n\t\tOnce the app is enabled, HTTP requests can be used via a Basic Auth header to perform any of the functions\n\t\tlisted above. More information is available in the Provisioning API documentation, including example calls\n\t\tand server responses." : "Tato aplikace umožňuje nastavit aplikační programová rozhraní (API) pro externí systémy, která je možné použít pro vytváření, upravování, mazání a dotazování se na atributy účtů,\n\t\tdotazovat se na, nastavovat a odebírat skupiny, nastavovat kvóty a dotazovat se na celkové využívání úložiště v Nextcloud. Správci skupin\n\t\tse také mohou Nextcloud dotazovat a provádět stejné funkce jako správci pro skupiny, které spravují. API také umožňuje\n\t\tsprávci dotazovat se na aktivní Nextcloud aplikace, informace o nich a zapínat nebo vypínat aplikace na dálku.\n\t\tJakmile je aplikace zapnutá, HTTP požadavky je možné použít prostřednictvím Basic Auth záhlaví pro provádění jakékoli\n\t\tz výše zmíněných funkcí. Více informací je k dispozici v dokumentaci k Provisioning API, včetně ukázek volání\n\t\ta odpovědí ze serveru."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
