<?php
// This file is auto-generated. Do not edit!
return array('Adlm'=>'Adlm','Aghb'=>'Aghb','Ahom'=>'Ahom','Arab'=>'Arab','Aran'=>'Aran','Armi'=>'Armi','Armn'=>'Armn','Avst'=>'Avst','Bali'=>'Bali','Bamu'=>'Bamu','Bass'=>'Bass','Batk'=>'Batk','Beng'=>'Beng','Bhks'=>'Bhks','Bopo'=>'Bopo','Brah'=>'Brah','Brai'=>'Brai','Bugi'=>'Bugi','Buhd'=>'Buhd','Cakm'=>'Cakm','Cans'=>'Cans','Cari'=>'Cari','Cham'=>'Cham','Cher'=>'Cher','Chrs'=>'Chrs','Copt'=>'Copt','Cpmn'=>'Cpmn','Cprt'=>'Cprt','Cyrl'=>'Cyrl','Deva'=>'Deva','Diak'=>'Diak','Dogr'=>'Dogr','Dsrt'=>'Dsrt','Dupl'=>'Dupl','Egyp'=>'Egyp','Elba'=>'Elba','Elym'=>'Elym','Ethi'=>'Ethi','Geor'=>'Geor','Glag'=>'Glag','Gong'=>'Gong','Gonm'=>'Gonm','Goth'=>'Goth','Gran'=>'Gran','Grek'=>'Grek','Gujr'=>'Gujr','Guru'=>'Guru','Hanb'=>'Hanb','Hang'=>'Hang','Hani'=>'Hani','Hano'=>'Hano','Hans'=>array(''=>'Hans','stand-alone'=>array('Hans')),'Hant'=>array(''=>'Hant','stand-alone'=>array('Hant')),'Hatr'=>'Hatr','Hebr'=>'Hebr','Hira'=>'Hira','Hluw'=>'Hluw','Hmng'=>'Hmng','Hmnp'=>'Hmnp','Hrkt'=>'Hrkt','Hung'=>'Hung','Ital'=>'Ital','Jamo'=>'Jamo','Java'=>'Java','Jpan'=>'Jpan','Kali'=>'Kali','Kana'=>'Kana','Kawi'=>'Kawi','Khar'=>'Khar','Khmr'=>'Khmr','Khoj'=>'Khoj','Kits'=>'Kits','Knda'=>'Knda','Kore'=>'Kore','Kthi'=>'Kthi','Lana'=>'Lana','Laoo'=>'Laoo','Latn'=>'Latn','Lepc'=>'Lepc','Limb'=>'Limb','Lina'=>'Lina','Linb'=>'Linb','Lisu'=>'Lisu','Lyci'=>'Lyci','Lydi'=>'Lydi','Mahj'=>'Mahj','Maka'=>'Maka','Mand'=>'Mand','Mani'=>'Mani','Marc'=>'Marc','Medf'=>'Medf','Mend'=>'Mend','Merc'=>'Merc','Mero'=>'Mero','Mlym'=>'Mlym','Modi'=>'Modi','Mong'=>'Mong','Mroo'=>'Mroo','Mtei'=>'Mtei','Mult'=>'Mult','Mymr'=>'Mymr','Nagm'=>'Nagm','Nand'=>'Nand','Narb'=>'Narb','Nbat'=>'Nbat','Newa'=>'Newa','Nkoo'=>'Nkoo','Nshu'=>'Nshu','Ogam'=>'Ogam','Olck'=>'Olck','Orkh'=>'Orkh','Orya'=>'Orya','Osge'=>'Osge','Osma'=>'Osma','Ougr'=>'Ougr','Palm'=>'Palm','Pauc'=>'Pauc','Perm'=>'Perm','Phag'=>'Phag','Phli'=>'Phli','Phlp'=>'Phlp','Phnx'=>'Phnx','Plrd'=>'Plrd','Prti'=>'Prti','Qaag'=>'Qaag','Rjng'=>'Rjng','Rohg'=>'Rohg','Runr'=>'Runr','Samr'=>'Samr','Sarb'=>'Sarb','Saur'=>'Saur','Sgnw'=>'Sgnw','Shaw'=>'Shaw','Shrd'=>'Shrd','Sidd'=>'Sidd','Sind'=>'Sind','Sinh'=>'Sinh','Sogd'=>'Sogd','Sogo'=>'Sogo','Sora'=>'Sora','Soyo'=>'Soyo','Sund'=>'Sund','Sylo'=>'Sylo','Syrc'=>'Syrc','Tagb'=>'Tagb','Takr'=>'Takr','Tale'=>'Tale','Talu'=>'Talu','Taml'=>'Taml','Tang'=>'Tang','Tavt'=>'Tavt','Telu'=>'Telu','Tfng'=>'Tfng','Tglg'=>'Tglg','Thaa'=>'Thaa','Thai'=>'Thai','Tibt'=>'Tibt','Tirh'=>'Tirh','Tnsa'=>'Tnsa','Toto'=>'Toto','Ugar'=>'Ugar','Vaii'=>'Vaii','Vith'=>'Vith','Wara'=>'Wara','Wcho'=>'Wcho','Xpeo'=>'Xpeo','Xsux'=>'Xsux','Yezi'=>'Yezi','Yiii'=>'Yiii','Zanb'=>'Zanb','Zinh'=>'Zinh','Zmth'=>'Zmth','Zsye'=>'Zsye','Zsym'=>'Zsym','Zxxx'=>'Zxxx','Zyyy'=>'Zyyy','Zzzz'=>'Zzzz');
