<?php return array(
    'root' => array(
        'name' => 'nextcloud/related_resources',
        'pretty_version' => 'dev-stable31',
        'version' => 'dev-stable31',
        'reference' => 'e8707170134d38da0fbf719cf0166134b820d011',
        'type' => 'library',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => false,
    ),
    'versions' => array(
        'nextcloud/related_resources' => array(
            'pretty_version' => 'dev-stable31',
            'version' => 'dev-stable31',
            'reference' => 'e8707170134d38da0fbf719cf0166134b820d011',
            'type' => 'library',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
