OC.L10N.register(
    "files_sharing",
    {
    "File shares" : "Bendrinami failai",
    "Downloaded via public link" : "Atsisiųstas per viešąją nuorodą",
    "Downloaded by {email}" : "Atsisiuntė {email}",
    "{file} downloaded via public link" : "{file} atsisiųstas per viešąją nuorodą",
    "{email} downloaded {file}" : "{email} atsisiuntė {file}",
    "Shared with group {group}" : "Bendrinama su grupe {group}",
    "Removed share for group {group}" : "Nebebendrinama su grupe: {group}",
    "{actor} shared with group {group}" : "{actor} pradėjo bendrinti su grupe {group}",
    "{actor} removed share for group {group}" : "{actor} nustojo bendrinti su {group} grupe",
    "Share for group {group} expired" : "Pasibaigė bendrinimo su grupe {group} galiojimo laikas",
    "You shared {file} with group {group}" : "Jūs pradėjote bendrinti {file} su grupe {group}",
    "You removed group {group} from {file}" : "Pašalinote grupę {group} iš {file}",
    "{actor} shared {file} with group {group}" : "{actor} pradėjo bendrinti {file} su grupe {group}",
    "{actor} removed group {group} from {file}" : "{actor} pašalino grupę {group} iš {file}",
    "Share for file {file} with group {group} expired" : "Failo {file} bendrinimas su grupe {group} baigė galioti",
    "Shared as public link" : "Bendrinama kaip viešoji nuoroda",
    "Removed public link" : "Pašalinta viešoji nuoroda",
    "Public link expired" : "Pasibaigė viešosios nuorodos galiojimo laikas",
    "{actor} shared as public link" : "{actor} pradėjo bendrinti kaip viešąją nuorodą",
    "{actor} removed public link" : "{actor} pašalino viešąją nuorodą",
    "Public link of {actor} expired" : "Pasibaigė {actor}  viešosios nuorodos galiojimo laikas",
    "You shared {file} as public link" : "Jūs pradėjote bendrinti {file} kaip viešąją nuorodą",
    "You removed public link for {file}" : "Jūs pašalinote viešąją {file} nuorodą",
    "Public link expired for {file}" : "Viešoji nuoroda, skirta {file}, nebegalioja",
    "{actor} shared {file} as public link" : "{actor} pradėjo bendrinti {file} kaip viešąją nuorodą",
    "{actor} removed public link for {file}" : "{actor} pašalino viešąją „{file}“ nuorodą",
    "Public link of {actor} for {file} expired" : "Pasibaigė {actor} failo {file} viešosios nuorodos galiojimo laikas",
    "{user} accepted the remote share" : "{user} priėmė nuotolinį viešinį",
    "{user} declined the remote share" : "{user} atmetė nuotolinį viešinį",
    "You received a new remote share {file} from {user}" : "Jūs iš {user} gavote naują nuotolinį viešinį „{file}“",
    "{user} accepted the remote share of {file}" : "{user} priėmė nuotolinį viešinį „{file}“",
    "{user} declined the remote share of {file}" : "{user} atmetė nuotolinį viešinį „{file}“",
    "{user} unshared {file} from you" : "{user} nustojo bendrinti su jumis {file}",
    "Shared with {user}" : "Pradėta bendrinti su {user}",
    "Removed share for {user}" : "Nustota bendrinti su {user}",
    "You removed yourself" : "Jūs pašalinote save",
    "{actor} removed themselves" : "{actor} pašalino save",
    "{actor} shared with {user}" : "{actor} pradėjo bendrinti su {user}",
    "{actor} removed share for {user}" : "{actor} nustojo bendrinti su {user}",
    "Shared by {actor}" : "Bendrina {actor}",
    "{actor} removed share" : "{actor} pašalino viešinį",
    "Share for {user} expired" : "Pasibaigė bendrinimo su  {user} galiojimo laikas",
    "Share expired" : "Viešinys nebegalioja",
    "You shared {file} with {user}" : "Jūs pradėjote bendrinti failą {file} su {user}",
    "You removed {user} from {file}" : "Nebesidalinate {file} su {user}",
    "You removed yourself from {file}" : "Nebesidalinate {file} su savimi",
    "{actor} removed themselves from {file}" : "{actor} nebesidalina {file} su savimi",
    "{actor} shared {file} with {user}" : "{actor} pradėjo bendrinti {file} su {user}",
    "{actor} removed {user} from {file}" : "{actor} nebesidalina {file} su {user}",
    "{actor} shared {file} with you" : "{actor} pradėjo bendrinti su jumis {file}",
    "{actor} removed you from the share named {file}" : "{actor} pašalino jus iš viešinio, pavadinimu „{file}“",
    "Share for file {file} with {user} expired" : "Pasibaigė failo {file} bendrinimo su {user} galiojimo laikas",
    "Share for file {file} expired" : "Failo {file} viešinys nebegalioja",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Buvo <strong>atsisiųstas</strong> el. paštu ar viešąja nuoroda bendrinamas failas ar aplankas",
    "A file or folder was shared from <strong>another server</strong>" : "Failas ar aplankas buvo pradėtas bendrinti iš <strong>kito serverio</strong>",
    "Sharing" : "Bendrinimas",
    "A file or folder has been <strong>shared</strong>" : "Failas ar aplankas <strong>pradėtas bendrinti</strong>",
    "Shared link" : "Bendrinama nuoroda",
    "Wrong share ID, share does not exist" : "Neteisingas viešinio ID, viešinio nėra",
    "Could not delete share" : "Nepavyko ištrinti viešinio",
    "Please specify a file or folder path" : "Nurodykite kelią iki duomenų",
    "Wrong path, file/folder does not exist" : "Neteisingas kelias, failo/aplanko nėra",
    "Could not create share" : "Nepavyko sukurti viešinio",
    "Please specify a valid account to share with" : "Nurodykite tinkamą paskyrą, su kuria bendrinti",
    "Group sharing is disabled by the administrator" : "Administratorius išjungė bendrinimą su grupėmis",
    "Please specify a valid group" : "Nurodykite teisingą grupę",
    "Public link sharing is disabled by the administrator" : "Administratorius išjungė bendrinimą per viešąsias nuorodas",
    "Please specify a valid email address" : "Nurodykite tinkamą el. pašto adresą",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Nepavyko išsiųsti slaptažodžio bendrinimui %s panaudojant Nextcloud Talk, kadangi Nextcloud Talk neįjungtas ",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "Bendrinimas %1$s nepavyko, kadangi sistema nepalaiko bendrinimų šio tipo %2$s",
    "Please specify a valid team" : "Nurodykite tinkamą komandą",
    "Sharing %s failed because the back end does not support room shares" : "Bendrinimas %s nepavyko, kadangi sistema nepalaiko kambario bendrinimo",
    "Unknown share type" : "Nežinomas viešinio tipas",
    "Not a directory" : "Nėra katalogas",
    "Could not lock node" : "Nepavyko užrakinti mazgo",
    "Public upload is only possible for publicly shared folders" : "Duomenų įkėlimas viešam naudojimui galimas tik į viešai dalinamus aplankus",
    "Public upload disabled by the administrator" : "Įkėlimas viešam naudojimui yra išjungtas",
    "Could not lock path" : "Nepavyko užrakinti kelio",
    "Wrong or no update parameter given" : "Neperduoti atnaujinimo parametrai",
    "Wrong password" : "Neteisingas slaptažodis",
    "Failed to generate a unique token" : "Nepavyko sugeneruoti išskirtinio prieigos rakto",
    "This share does not exist or is no longer available" : "Šio viešinio nebėra arba jis daugiau nebeprieinamas",
    "shared by %s" : "bendrina %s",
    "Download" : "Atsisiųsti",
    "Add to your %s" : "Pridėti į jūsų %s",
    "Direct link" : "Tiesioginė nuoroda",
    "Share API is disabled" : "Bendrinimo API yra išjungtas",
    "File sharing" : "Failų pasidalinimas",
    "Share will expire tomorrow" : "Bendrinimo laikas baigiasi rytoj.",
    "Your share of {node} will expire tomorrow" : "Jūsų {node} bendrinimas baigs galioti rytoj",
    "You received {share} as a share by {user}" : "Jūs gavote bendrinimą {share}, kuriuo pasidalino {user}",
    "You received {share} to group {group} as a share by {user}" : "Jūs gavote bendrinimą {share} prie grupės {group}, kuriuo pasidalino {user}",
    "Accept" : "Priimti",
    "Decline" : "Atmesti",
    "Open \"%s\"" : "Atverti „%s“",
    "People" : "Žmonės",
    "Filter accounts" : "Filtruoti paskyras",
    "Expiration date" : "Pabaigos data",
    "Select a date" : "Pasirinkti datą",
    "Set a password" : "Nustatyti slaptažodį",
    "Password" : "Slaptažodis",
    "Generate a new password" : "Generuoti naują slaptažodį",
    "Automatically copying failed, please copy the share link manually" : "Nepavyko automatiškai nukopijuoti, nukopijuokite nuorodą rankiniu būdu",
    "Link copied" : "Nuoroda nukopijuota",
    "Email already added" : "El. paštas jau pridėtas",
    "Invalid email address" : "Neteisingas el. pašto adresas",
    "_{count} email address already added_::_{count} email addresses already added_" : ["Jau pridėtas {count} el. pašto adresas","Jau pridėti {count} el. pašto adresai","Jau pridėta {count} el. pašto adresų","Jau pridėtas {count} el. pašto adresas"],
    "_{count} email address added_::_{count} email addresses added_" : ["Pridėtas {count} el. pašto adresas","Pridėti {count} el. pašto adresai","Pridėta {count} el. pašto adresų","Pridėtas {count} el. pašto adresas"],
    "Share link" : "Viešinio nuoroda",
    "Copy" : "Kopijuoti",
    "Send link via email" : "Siųsti nuorodą el. paštu",
    "Enter an email address or paste a list" : "Įveskite el. pašto adresą arba įdėkite sąrašą",
    "Remove email" : "Šalinti el. paštą",
    "Select" : "Žymėti",
    "Birthday party photos, History assignment…" : "Gimtadienio nuotraukos, istorijos užduotis…",
    "Revert to default" : "Sugrąžinti į numatytąjį",
    "Close" : "Užverti",
    "_Send email and close_::_Send {count} emails and close_" : ["Išsiųsti el. laišką ir užverti","Išsiųsti {count} el. laiškus ir užverti","Išsiųsti {count} el. laiškų ir užverti","Išsiųsti {count} el. laišką ir užverti"],
    "Error creating the share: {errorMessage}" : "Klaida kuriant viešinį: {errorMessage}",
    "Error creating the share" : "Klaida kuriant viešinį",
    "Error sending emails: {errorMessage}" : "Klaida siunčiant el. laiškus: {errorMessage}",
    "Error sending emails" : "Klaida siunčiant el. laiškus",
    "Previous step" : "Ankstesnis žingsnis",
    "Cancel" : "Atsisakyti",
    "Continue" : "Tęsti",
    "Error while toggling options" : "Klaida perjungiant parinktis",
    "Choose a default folder for accepted shares" : "Pasirinkite numatytąjį aplanką priimtiems viešiniams",
    "Invalid path selected" : "Pasirinktas neteisingas kelias",
    "Unknown error" : "Nežinoma klaida",
    "Set default folder for accepted shares" : "Nustatykite numatytąjį priimtų viešinių aplanką",
    "Reset" : "Atstatyti",
    "Reset folder to system default" : "Atstatyti aplanką į sistemos numatytąjį",
    "group" : "grupė",
    "conversation" : "pokalbis",
    "remote" : "nuotolinis",
    "remote group" : "nuotolinė grupė",
    "guest" : "svečias",
    "Shared with the conversation {user} by {owner}" : "Bendrinimas su pokalbiu {user}, kurį aliko {owner}",
    "Shared with {user} by {owner}" : "Bendrinimas su {user}, kurį aliko {owner}",
    "Added by {initiator}" : "Pridėjo {initiator}",
    "Via “{folder}”" : "Per \"{folder}\"",
    "Unshare" : "Nustoti bendrinti",
    "Cannot copy, please copy the link manually" : "Nepavyksta nukopijuoti, nukopijuokite nuorodą rankiniu būdu",
    "Copy internal link" : "Kopijuoti vidinę nuorodą",
    "Internal link" : "Vidinė nuoroda",
    "Shared via link by {initiator}" : "{initiator} bendrina per nuorodą",
    "Share link ({label})" : "Viešinio nuoroda ({label})",
    "Create public link" : "Sukurti viešąją nuorodą",
    "Error, please enter proper password and/or expiration date" : "Įvyko klaida, įveskite teisingą slaptažodį ir/ar galiojimo datą",
    "Error while creating the share" : "Klaida kuriant viešinį",
    "Please enter the following required information before creating the share" : "Prieš sukurdami viešinį, įveskite šią reikiamą informaciją",
    "Password protection (enforced)" : "Apsauga slaptažodžiu (priverstinė)",
    "Password protection" : "Apsauga slaptažodžiu",
    "Enter a password" : "Enter a password",
    "Create share" : "Sukurti viešinį",
    "Customize link" : "Tinkinti nuorodą",
    "Generate QR code" : "Generuoti QR kodą",
    "Add another link" : "Pridėti kitą nuorodą",
    "Create a new share link" : "Sukurti naują viešinio nuorodą",
    "View only" : "Tik peržiūrėti",
    "Can edit" : "Gali taisyti",
    "Custom permissions" : "Tinkinti leidimai",
    "Resharing is not allowed" : "Bendrinimas iš naujo yra neleidžiamas",
    "Name or email …" : "Vardas ar el. paštas…",
    "Name, email, or Federated Cloud ID …" : "Vardas, el. paštas ar federacinės debesijos ID…",
    "Searching …" : "Ieškoma…",
    "No elements found." : "Nerasta jokių elementų.",
    "Guest" : "Svečias",
    "Group" : "Grupė",
    "Email" : "El. paštas",
    "Team" : "Komanda",
    "on {server}" : "serveryje {server}",
    "Note:" : "Pastaba:",
    "File drop" : "Failų įkėlimas",
    "Terms of service" : "Naudojimosi sąlygos",
    "Share with email {email}" : "Bendrinti su el. pašto adresu {email}",
    "Share with group" : "Bendrinti su grupe",
    "Share in conversation" : "Bendrinti pokalbyje",
    "Share with {user} on remote server {server}" : "Bendrinti su {user} nuotoliniame serveryje {server}",
    "Share with remote group" : "Bendrinti su nuotoline grupe",
    "Share with guest" : "Bendrinti su svečiu",
    "Update share" : "Atnaujinti viešinį",
    "Save share" : "Įrašyti viešinį",
    "Read" : "Skaityti",
    "Create" : "Sukurti",
    "Edit" : "Taisyti",
    "Share" : "Bendrinti",
    "Delete" : "Ištrinti",
    "Allow upload and editing" : "Leisti įkelti ir redaguoti",
    "Allow editing" : "Leisti redaguoti",
    "Advanced settings" : "Išplėstiniai nustatymai",
    "Share label" : "Viešinio etiketė",
    "Generating…" : "Generuojama…",
    "Generate new token" : "Generuoti naują prieigos raktą",
    "Set password" : "Nustatyti slaptažodį",
    "Password expires {passwordExpirationTime}" : "Slaptažodis galioja iki {passwordExpirationTime}",
    "Password expired" : "Slaptažodis nebegalioja",
    "Video verification" : "Video patikrinimas",
    "Expiration date (enforced)" : "Galiojimo pabaigos data (nustatyta)",
    "Set expiration date" : "Nustatyti galiojimo pabaigos datą",
    "Hide download" : "Slėpti atsisiuntimą",
    "Note to recipient" : "Pastaba gavėjui",
    "Enter a note for the share recipient" : "Įrašykite pranešimą bendrinimo gavėjui",
    "Delete share" : "Ištrinti viešinį",
    "Others with access" : "Kiti asmenys, turintys prieigą",
    "No other accounts with access found" : "Nerasta jokių kitų paskyrų, turinčių prieigą",
    "Toggle list of others with access to this directory" : "Perjungti sąrašą kitų asmenų, turinčių prieigą prie šio katalogo",
    "Toggle list of others with access to this file" : "Perjungti sąrašą kitų asmenų, turinčių prieigą prie šio failo",
    "Unable to fetch inherited shares" : "Nepavyko gauti paveldėtų viešinių",
    "Shares" : "Viešiniai",
    "Unable to load the shares list" : "Nepavyko įkelti viešinių sąrašo",
    "Expires {relativetime}" : "Galioja iki {relativetime}",
    "this share just expired." : "šis viešinys ką tik nustojo galioti.",
    "Shared with you by {owner}" : "{owner} pasidalino su jumis",
    "Link to a file" : "Nuoroda į failą",
    "Shared" : "Bendrinama",
    "Shared by {ownerDisplayName}" : "Bendrina {ownerDisplayName}",
    "Shared with others" : "Bendrinama su kitais",
    "Public share" : "Viešasis viešinys",
    "Overview of shared files." : "Bendrinamų failų apžvalga.",
    "No shares" : "Nėra jokių viešinių",
    "Shared with you" : "Bendrinama su jumis",
    "List of files that are shared with you." : "Failų, kurie yra bendrinami su jumis, sąrašas.",
    "Nothing shared with you yet" : "Kol kas su jumis nieko nėra bendrinama",
    "Nothing shared yet" : "Kol kas nieko nebendrinama",
    "Shared by link" : "Bendrinama pagal nuorodą",
    "No shared links" : "Nėra bendrinamų nuorodų",
    "Files and folders you shared by link will show up here" : "Čia bus rodomi failai ir aplankai, kuriuos bendrinate per nuorodą",
    "Deleted shares" : "Ištrinti viešiniai",
    "No deleted shares" : "Ištrintų viešinių nėra",
    "Pending shares" : "Laukiantys viešiniai",
    "No pending shares" : "Nėra jokių laukiančių viešinių",
    "Error deleting the share" : "Klaida ištrinant bendrinimą",
    "Error updating the share: {errorMessage}" : "Klaida atnaujinant viešinį: {errorMessage}",
    "Error updating the share" : "Klaida atnaujinant viešinį",
    "File \"{path}\" has been unshared" : "Failas „{path}“ nustotas bendrinti",
    "Folder \"{path}\" has been unshared" : "Aplankas „{path}“ nustotas bendrinti",
    "Could not update share" : "Nepavyko atnaujinti viešinio",
    "Share saved" : "Viešinys įrašytas",
    "Share label saved" : "Viešinio etiketė įrašyta",
    "Share password saved" : "Viešinio slaptažodis įrašytas",
    "Share permissions saved" : "Viešinio leidimai įrašyti",
    "Shared by" : "Bendrina",
    "Shared with" : "Bendrinama su",
    "Password created successfully" : "Slaptažodis sėkmingai sukurtas",
    "Shared with you and the group {group} by {owner}" : "{owner} pradėjo bendrinti su jumis ir grupe {group}",
    "Shared with you and {circle} by {owner}" : "{owner} pradėjo bendrinti su jumis ir {circle}",
    "Shared with you and the conversation {conversation} by {owner}" : "{owner} pasidalino su jumis ir pokalbiu {conversation}",
    "Shared with you in a conversation by {owner}" : "{owner} pasidalino su jumis pokalbyje",
    "Share not found" : "Viešinys nerastas",
    "Back to %s" : "Atgal į %s",
    "Add to your Nextcloud" : "Pridėti į savo Nextcloud",
    "Waiting…" : "Laukiama…",
    "error" : "klaida",
    "finished" : "pabaigta",
    "This will stop your current uploads." : "Tai sustabdys dabartinius įkėlimus.",
    "Move or copy" : "Perkelti ar kopijuoti",
    "You can upload into this folder" : "Galite įkelti į šį aplanką",
    "Show list view" : "Rodyti sąrašo rodinį",
    "Show grid view" : "Rodyti tinklelio rodinį",
    "No compatible server found at {remote}" : "Nerasta jokio suderinamo serverio ties {remote}",
    "Invalid server URL" : "Neteisingas serverio URL adresas",
    "Failed to add the public link to your Nextcloud" : "Nepavyko pridėti viešosios nuorodos į jūsų Nextcloud",
    "Download all files" : "Atsisiųsti visus failus ",
    "Link copied to clipboard" : "Nuoroda nukopijuota į iškarpinę",
    "_1 email address already added_::_{count} email addresses already added_" : ["Jau pridėtas 1 el. pašto adresas","Jau pridėti {count} el. pašto adresai","Jau pridėta {count} el. pašto adresų","Jau pridėtas {count} el. pašto adresas"],
    "_1 email address added_::_{count} email addresses added_" : ["Pridėtas 1 el. pašto adresas","Pridėti {count} el. pašto adresai","Pridėta {count} el. pašto adresų","Pridėtas {count} el. pašto adresas"],
    "Copy to clipboard" : "Kopijuoti į iškarpinę",
    "Copy internal link to clipboard" : "Kopijuoti vidinę nuorodą į iškarpinę",
    "Search globally" : "Ieškoti visuotiniu mastu",
    "Search for share recipients" : "Ieškoti viešinio gavėjų",
    "No recommendations. Start typing." : "Rekomendacijų nėra. Pradėkite rašyti.",
    "Enter your name" : "Įveskite savo vardą",
    "Share with {userName}" : "Bendrinti su {userName}",
    "Show sharing options" : "Rodyti bendrinimo parinktis",
    "Share note" : "Pasidalinimo pastaba",
    "Upload files to %s" : "Įkelkite failus į %s",
    "%s shared a folder with you." : "%s pradėjo bendrinti su jumis aplanką.",
    "Note" : "Pastaba",
    "Select or drop files" : "Pasirinkite arba vilkite failus",
    "Uploading files" : "Įkeliami failai",
    "Uploaded files:" : "Įkelti failai:",
    "By uploading files, you agree to the %1$sterms of service%2$s." : "Įkeldami failus, sutinkate su %1$snaudojimosi sąlygomis%2$s.",
    "Name" : "Pavadinimas",
    "Filename must not be empty." : "Failo pavadinimas negali būti tuščias."
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
