OC.L10N.register(
    "notifications",
    {
    "Hello %s" : "Salam%s",
    "Notifications" : "Duýduryşlar",
    "Dismiss" : "Ýapmak.",
    "No notifications" : "Duýduryş ýok",
    "1 hour" : "1 sagat",
    "None" : "Hiç",
    "seconds ago" : "Sekunt öň"
},
"nplurals=2; plural=(n != 1);");
