OC.L10N.register(
    "recommendations",
    {
    "Recommended files" : "Comhaid molta",
    "Recommendations" : "Moltaí",
    "Shows recommended files" : "Taispeáin comhaid mholta",
    "Shows recommended files for quick access of files and folders with recent activity" : "Taispeáin comhaid molta le haghaidh rochtain thapa ar chomhaid agus fillteáin le gníomhaíocht le déanaí",
    "No recommendations yet" : "Níl aon mholtaí fós",
    "Last updated {timeAgo}" : "Nuashonraithe is déanaí {timeAgo}",
    "Shared with you {timeAgo}" : "Roinnte leat {timeAgo}",
    "Last commented on {timeAgo}" : "Ar deireadh trácht ar {timeAgo}",
    "Path name {path}" : "Ainm conair {path}",
    "Show recommendations" : "Taispeáin moltaí",
    "Recently commented" : "Trácht le déanaí",
    "Recently edited" : "Curtha in eagar le déanaí",
    "Recently shared" : "Roinnte le déanaí"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
