OC.L10N.register(
    "settings",
    {
    "Private" : "Privé",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Alleen zichtbaar voor mensen die via telefoonnummerintegratie gematcht zijn voor Talk op mobiel",
    "Local" : "Lokaal",
    "Only visible to people on this instance and guests" : "Alleen zichtbaar voor gebruikers op deze server en gasten",
    "Federated" : "Gefedereerd",
    "Only synchronize to trusted servers" : "Alleen synchroniseren met vertrouwde servers",
    "Published" : "Gepubliceerd",
    "Synchronize to trusted servers and the global and public address book" : "Synchroniseren met vertrouwde servers en het wereldwijde en openbare adresboek",
    "Verify" : "Verifiëren",
    "Verifying …" : "Verifiëren...",
    "Unable to change password" : "Kan wachtwoord niet wijzigen",
    "Very weak password" : "Zeer zwak wachtwoord",
    "Weak password" : "Zwak wachtwoord",
    "So-so password" : "Matig wachtwoord",
    "Good password" : "Goed wachtwoord",
    "Strong password" : "Sterk wachtwoord",
    "Groups" : "Groepen",
    "Group list is empty" : "Groepenlijst is leeg",
    "Unable to retrieve the group list" : "Kan groepenoverzicht niet ophalen",
    "{actor} added you to group {group}" : "{actor} voegde je toe aan groep {group}",
    "You added {user} to group {group}" : "Je hebt gebruiker {user} aan de groep {group} toegevoegd.",
    "{actor} added {user} to group {group}" : "{actor} voegde {user} toe aan groep {group}",
    "An administrator added you to group {group}" : "Een beheerder heeft je aan de groep {group} toegevoegd.",
    "An administrator added {user} to group {group}" : "Een beheerder heeft gebruiker {user} aan groep {group} toegevoegd.",
    "{actor} removed you from group {group}" : "{actor} verwijderde jou uit groep {group}",
    "You removed {user} from group {group}" : "Je hebt gebruiker {user} uit de groep {group} verwijderd.",
    "{actor} removed {user} from group {group}" : "{actor} verwijderde {user} uit groep {group}",
    "An administrator removed you from group {group}" : "Een beheerder heeft u uit groep {group} verwijderd.",
    "An administrator removed {user} from group {group}" : "Een beheerder verwijderde {user} uit groep {group}",
    "Your <strong>group memberships</strong> were modified" : "Je <strong>groepslidmaatschap</strong> werd gewijzigd",
    "{actor} changed your password" : "{actor} heeft je wachtwoord aangepast",
    "You changed your password" : "Je hebt je wachtwoord aangepast",
    "Your password was reset by an administrator" : "Je wachtwoord is hersteld door een beheerder",
    "Your password was reset" : "Je wachtwoord is opnieuw ingesteld",
    "{actor} changed your email address" : "{actor} wijzigde je e-mailadres",
    "You changed your email address" : "Je wijzigde je e-mailadres",
    "Your email address was changed by an administrator" : "Je e-mailadres is gewijzigd door een beheerder",
    "You created an app password for a session named \"{token}\"" : "Je creëerde een app wachtwoord voor een sessie genaamd \"{token}\"",
    "An administrator created an app password for a session named \"{token}\"" : "Een beheerder maakte een app wachtwoord voor een sessie met de naam \"{token}\"",
    "You deleted app password \"{token}\"" : "Je verwijderde appwachtwoord \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Je hernoemde appwachtwoord \"{token}\" naar \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "Je hebt toegang tot het bestandssysteem verleend aan appwachtwoord \"{token}\"",
    "You revoked filesystem access from app password \"{token}\"" : "Je hebt toegang tot het bestandssysteem ingetrokken voor appwachtwoord \"{token}\"",
    "Security" : "Beveiliging",
    "You successfully logged in using two-factor authentication (%1$s)" : "Je bent succesvol ingelogd via tweestapsverificatie (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Een inlogpoging via tweestapsverificatie is mislukt (%1$s)",
    "Remote wipe was started on %1$s" : "Wissen op afstand gestart op %1$s",
    "Remote wipe has finished on %1$s" : "Wissen op afstand voltooid op %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Je <strong>wachtwoord</strong> of <strong>e-mailadres</strong> is gewijzigd",
    "Settings" : "Instellingen",
    "Could not remove app." : "Kon app niet verwijderen",
    "Could not update app." : "Kon app niet updaten",
    "Wrong password" : "Onjuist wachtwoord",
    "Unable to change personal password" : "Kan persoonlijk wachtwoord niet wijzigen",
    "Saved" : "Opgeslagen",
    "No Login supplied" : "Geen login opgegeven",
    "Unable to change password. Password too long." : "Kan wachtwoord niet wijzigen. Wachtwoord te lang.",
    "Authentication error" : "Authenticatiefout",
    "Please provide an admin recovery password; otherwise, all account data will be lost." : "Voer een beheerdersherstelwachtwoord in, anders zullen alle account gegevens verloren gaan.",
    "Wrong admin recovery password. Please check the password and try again." : "Onjuist beheerdersherstelwachtwoord. Controleer het wachtwoord en probeer het opnieuw.",
    "Backend does not support password change, but the encryption of the account key was updated." : "Backend ondersteunt geen wachtwoordwijzigingen, maar de versleuteling van de accountsleutel is bijgewerkt.",
    "Administrator documentation" : "Beheerdersdocumentatie",
    "User documentation" : "Gebruikersdocumentatie",
    "Nextcloud help overview" : "Nextcloud hulpoverzicht",
    "Invalid SMTP password." : "Ongeldig SMTP-wachtwoord",
    "Email setting test" : "E-mailinstellingen test",
    "Well done, %s!" : "Goed gedaan, %s!",
    "If you received this email, the email configuration seems to be correct." : "Als je deze e-mail hebt ontvangen, dan lijken de e-mailinstellingen correct.",
    "Email could not be sent. Check your mail server log" : "Er kon geen e-mail verstuurd worden. Controleer je server log files",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Er ontstond een probleem bij het versturen van de e-mail. Controleer je instellingen.  (Fout: %s)",
    "You need to set your account email before being able to send test emails. Go to %s for that." : "Je moet je e-mail voor je account instellen voordat je e-mail kan versturen. Ga hiervoor naar %s.",
    "Recently active" : "Recent actief",
    "Disabled accounts" : "Uitgeschakelde accounts",
    "Invalid account" : "Ongeldig account",
    "Invalid mail address" : "Ongeldig e-mailadres",
    "Settings saved" : "Instellingen opgeslagen",
    "Unable to change full name" : "Kan de volledige naam niet wijzigen",
    "Unable to change email address" : "Kan e-mailadres niet wijzigen",
    "Unable to set invalid phone number" : "Kon geen geldig telefoonnummer instellen",
    "Unable to set invalid website" : "Kan geen ongeldig website instellen",
    "Some account data was invalid" : "Sommige accountgegevens ongeldig",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Om je Twitter-account te verifiëren moet je de volgende tweet op Twitter plaatsen (zorg dat je het plaatst zonder regelafbreking):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Om je website te verifiëren voeg de inhoud toe binnen de web-root van je server '.well-known/CloudIdVerificationCode.txt' (zorg dat de tekst op één regel staat):",
    "%1$s changed your password on %2$s." : "%1$swijzigde je wachtwoord op %2$s.",
    "Your password on %s was changed." : "Je wachtwoord op %s is gewijzigd.",
    "Your password on %s was reset by an administrator." : "Je wachtwoord op %s werd hersteld door een beheerder.",
    "Your password on %s was reset." : "Je wachtwoord op %s is opnieuw ingesteld",
    "Password for %1$s changed on %2$s" : "Wachtwoord voor %1$s gewijzigd op %2$s",
    "Password changed for %s" : "Wachtwoord gewijzigd voor %s",
    "If you did not request this, please contact an administrator." : "Als je dat niet aanvroeg, neem dan contact op met een beheerder.",
    "Your email address on %s was changed." : "Je e-mailadres op %sis gewijzigd.",
    "Your email address on %s was changed by an administrator." : "Je e-mailadres op %s is gewijzigd door een beheerder.",
    "Email address for %1$s changed on %2$s" : "E-mailadres voor %1$s gewijzigd op %2$s",
    "Email address changed for %s" : "E-mailadres gewijzigd voor %s",
    "The new email address is %s" : "Het nieuwe e-mailadres is %s",
    "Your %s account was created" : "Je %s account is aangemaakt",
    "Welcome aboard" : "Welkom aan boord",
    "Welcome aboard %s" : "Welkom aan boord %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Welkom bij je %s account; je kunt nu je bestanden toevoegen en veilig delen.",
    "Your Login is: %s" : "Je login is: %s",
    "Set your password" : "Stel je wachtwoord in",
    "Go to %s" : "Ga naar %s",
    "Install Client" : "Installeer Client",
    "Logged in account must be a sub admin" : "Ingelogd account moet een subbeheerder zijn",
    "Apps" : "Apps",
    "Personal" : "Persoonlijk",
    "Administration" : "Beheer",
    "Users" : "Gebruikers",
    "Additional settings" : "Aanvullende instellingen",
    "Assistant" : "Assistent",
    "Administration privileges" : "Beheerdersprivileges",
    "Groupware" : "Groupware",
    "Overview" : "Overzicht",
    "Basic settings" : "Basis-instellingen",
    "Sharing" : "Delen",
    "Availability" : "Beschikbaarheid",
    "Calendar" : "Agenda",
    "Personal info" : "Persoonlijke info",
    "Mobile & desktop" : "Mobiel & desktop",
    "Artificial Intelligence" : "Artificiële Intelligentie",
    "Email server" : "E-mailserver",
    "Mail Providers" : "Mail-providers",
    "Mail provider enables sending emails directly through the user's personal email account. At present, this functionality is limited to calendar invitations. It requires Nextcloud Mail 4.1 and an email account in Nextcloud Mail that matches the user's email address in Nextcloud." : "Mailprovider maakt het mogelijk e-mails rechtstreeks via het persoonlijke e-mailaccount van de gebruiker te verzenden. Momenteel is deze functionaliteit beperkt tot agenda-uitnodigingen. Het vereist Nextcloud Mail 4.1 en een e-mailaccount in Nextcloud Mail dat overeenkomt met het e-mailadres van de gebruiker in Nextcloud.",
    "Send emails using" : "E-mail verzenden met",
    "User's email account" : "E-mailaccount gebruiker",
    "System email account" : "E-mailaccount systeem",
    "Security & setup checks" : "Veiligheids- en instellingencontrole",
    "Background jobs" : "Achtergrondtaken",
    "Unlimited" : "Ongelimiteerd",
    "Verifying" : "Controleer",
    "Allowed admin IP ranges" : "Toegestane beheerder IP-reeksen",
    "Admin IP filtering isn't applied." : "Admin IP-filtering wordt niet toegepast.",
    "Configuration key \"%1$s\" expects an array (%2$s found). Admin IP range validation will not be applied." : "Configuratiesleutel \"%1$s\" verwacht een array (%2$s gevonden). Validatie van beheerder IP-bereik wordt niet toegepast.",
    "Configuration key \"%1$s\" contains invalid IP range(s): \"%2$s\"" : "Configuratiesleutel \"%1$s\" bevat ongeldig(e) IP-bereik(en): \"%2$s\"",
    "Admin IP filtering is correctly configured." : "Beheerder IP-filtering is juist geconfigureerd.",
    "App directories owner" : "Eigenaar app mappen",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:\n%s" : "Sommige app mappen zijn eigendom van een andere gebruiker dan op de webserver . Dat kan het geval zijn als apps handmatig zijn geïnstalleerd. Controleer de machtigingen van de volgende app mappen:\n%s",
    "App directories have the correct owner \"%s\"" : "App mappen hebben de juiste eigenaar \"%s\"",
    "Brute-force Throttle" : "Bruteforce begrenzing",
    "Your remote address could not be determined." : "Je remote adres kon niet bepaald worden",
    "Your remote address was identified as \"%s\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly." : "Je remote adres is geregistreerd als \"%s\" en wordt op dit moment afgeremd ter bescherming van bruteforce aanvallen. Dit verlaagt de performantie van verschillende aanvragen. Als het remote adres niet uw adres is kan dit wijzen op een verkeerd ingestelde proxy. ",
    "Your remote address \"%s\" is not brute-force throttled." : "Je remote adres %s is niet bruteforce begrensd.",
    "Old administration imported certificates" : "Oude administratie geïmporteerde certificaten",
    "A background job is pending that checks for administration imported SSL certificates. Please check back later." : "Er is een achtergrondtaak in behandeling die controleert op het beheer van geïmporteerde SSL-certificaten. Kom later nog eens terug.",
    "There are some administration imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Er zijn enkele door de administratie geïmporteerde SSL-certificaten aanwezig die niet meer worden gebruikt bij Nextcloud 21. Ze kunnen op de opdrachtregel worden geïmporteerd via het commando \"occ security: certificates: import\". Hun paden binnen de datadirectory worden hieronder weergegeven.",
    "Code integrity" : "Integriteit code",
    "Integrity checker has been disabled. Integrity cannot be verified." : "Integriteitscontrole is uitgeschakeld. Integriteit kan niet gecontroleerd worden.",
    "No altered files" : "Geen gewijzigde bestanden",
    "Some files have not passed the integrity check. {link1} {link2}" : "Sommige bestanden zijn niet door de integriteitscontrole gekomen. {link1} {link2}",
    "Cron errors" : "Cron fouten",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:\n%s" : "Het was niet mogelijk om de systeem cron via CLI uit te voeren. De volgende technische problemen traden op:\n%s",
    "The last cron job ran without errors." : "De laatste crontaak liep zonder fouten.",
    "Cron last run" : "Cron laatste run",
    "Last background job execution ran %s. Something seems wrong. {link}." : "Laatste achtegrondtaak liep%s. Er ging iets fout. {link}",
    "Last background job execution ran %s." : "Laatste achtergrondtaak liep %s.",
    "Data directory protected" : "Datamap is beveiligd",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Je datamap en je bestanden zijn waarschijnlijk vanaf het internet bereikbaar.  Het .htaccess-bestand werkt niet. We raden ten zeerste aan aan om je webserver zodanig te configureren, dat de datadirectory niet bereikbaar is vanaf het internet of om je datadirectory te verplaatsen naar een locatie buiten de document-root van de webserver.",
    "Could not check that the data directory is protected. Please check manually that your server does not allow access to the data directory." : "Kon niet vaststellen of de datamap beveiligd is. Bekijk a.u.b. handmatig of de server toegang heeft tot de datamap.",
    "Database missing columns" : "Database mist kolommen",
    "Missing optional column \"%s\" in table \"%s\"." : "Optionele kolom \"%s\" mist in tabel \"%s\".",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "De database mist een paar optionele kolommen. Omdat het toevoegen van kolommen op grote tabellen veel tijd kan kosten, zijn ze niet automatisch gecreëerd, omdat dat optioneel kan. Door het draaien van \"occ db:add-missing-columns\" kunnen deze kolommen handmatig worden toegevoegd terwijl de server blijft draaien.  Als de kolommen zijn toegevoegd, zullen bepaalde functionaliteiten veel sneller of gemakkelijker plaatsvinden.",
    "Database missing indices" : "Database mist indexen",
    "Missing indices:" : "Ontbrekende indexen:",
    "\"%s\" in table \"%s\"" : "\"%s\" in tabel \"%s\"",
    "Detected some missing optional indices. Occasionally new indices are added (by Nextcloud or installed applications) to improve database performance. Adding indices can sometimes take awhile and temporarily hurt performance so this is not done automatically during upgrades. Once the indices are added, queries to those tables should be faster. Use the command `occ db:add-missing-indices` to add them." : "Enkele ontbrekende optionele indices gedetecteerd. Af en toe worden er nieuwe indices toegevoegd (door Nextcloud of geïnstalleerde applicaties) om de databaseprestaties te verbeteren. Het toevoegen van indices kan soms een tijdje duren en de prestaties tijdelijk schaden, dus dit gebeurt niet automatisch tijdens upgrades. Zodra de indices zijn toegevoegd, moeten zoekopdrachten naar die tabellen sneller zijn. Gebruik de opdracht `occ db:add-missing-indices` om ze toe te voegen.",
    "Database missing primary keys" : "Database mist primaire sleutels",
    "Missing primary key on table \"%s\"." : "Ontbrekende primaire sleutel op tabel \"%s\".",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "De database mist enkele primaire sleutels. Omdat het toevoegen van primaire sleutels aan grote tabellen enige tijd kan duren, werden ze niet automatisch toegevoegd. Door \"occ db:add-missing-primary-keys\" uit te voeren, kunnen die ontbrekende primaire sleutels handmatig worden toegevoegd terwijl de server blijft draaien.",
    "Database pending bigint migrations" : "Database in afwachting van bigint-migraties",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline." : "Sommige kolommen in de database missen een conversie naar big int. Omdat het veranderen van kolomtypen op grote tabellen enige tijd kon duren, werden ze niet automatisch gewijzigd. Door \"occ db: convert-filecache-bigint\" uit te voeren, kunnen de hangende wijzigingen handmatig worden toegepast. Deze bewerking moet worden uitgevoerd terwijl de instantie offline is.",
    "Debug mode" : "Foutopsporingsmodus",
    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Deze instantie draait in foutopsporingsmodus. Gelieve deze modus enkel te gebruiken voor lokale ontwikkeling, en niet in productie omgevingen.",
    "Debug mode is disabled." : "Foutopsporingsmodus uitgeschakeld",
    "Default phone region" : "Standaard telefoonregio",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective ISO 3166-1 code of the region to your config file." : "Je installatie heeft geen standaard telefoonregio. Dit is nodig om telefoonnummers te valideren in de profielinstellingen zonder landcode. Om nummers zonder landcode toe te staan, voeg je \"default_phone_region\" met de respectieve ISO 3166-1-code van de regio toe aan je configuratiebestand.",
    "Email test" : "E-mail test",
    "Email test was successfully sent" : "Test e-mail is succesvol verzonden",
    "You have not set or verified your email server configuration, yet. Please head over to the \"Basic settings\" in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "U heeft uw emailserverconfiguratie nog niet ingesteld of geverifieerd. Navigeer alstublieft naar de Standaardinstellingen om deze in te stellen. Hierna kunt u de \"Stuur email\" knop onder dit formulier gebruiken om uw instellingen te verifiëren",
    "HTTPS access and URLs" : "HTTPS toegang en URL's",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "Connectie via HTTP. U wordt aangeraden uw server in te stellen om het gebruik van HTTPS af te dwingen. Zonder HTTPS zullen functies zoals \"kopieer naar klembord\" en \"service workers\" niet werken.",
    "Accessing site insecurely via HTTP." : "Site wordt onveiligd benaderd via HTTP.",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This likely means that your instance is behind a reverse proxy and the Nextcloud `overwrite*` config values are not set correctly." : "Je verbindt met je server over een beveiligde verbinding, maar je server genereert onveilige URLs. Waarschijnlijk zit je achter een reverse proxy en zijn de overschijf configuratievariabelen niet goed ingesteld. ",
    "Your instance is generating insecure URLs. If you access your instance over HTTPS, this likely means that your instance is behind a reverse proxy and the Nextcloud `overwrite*` config values are not set correctly." : "Je server genereert onveilige URLs. Als je je server benadert via een beveiligde HTTPS-verbinding, zit je waarschijnlijk achter een reverse proxy en zijn de overschijf configuratievariabelen niet goed ingesteld. ",
    "You are accessing your instance over a secure connection, and your instance is generating secure URLs." : "Je verbindt met de server via een beveiligde verbinding en je server genereert veilige URL's.",
    "Internet connectivity" : "Internetverbinding",
    "Internet connectivity is disabled in configuration file." : "Verbinding met het internet is uitgeschakeld in het configuratiebestand.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Deze server heeft geen werkende internetverbinding: meerdere endpoints kunnen niet worden bereikt. Dat betekent dat sommige functies, zoals het gebruik van externe opslag, notificaties over updates of installatie van apps van derde partijen niet werken. Ook het benaderen van bestanden vanaf een remote locatie en het versturen van notificatie emails kan mislukken. We adviseren om de internetverbinding voor deze server in te schakelen als je alle functies wilt gebruiken.",
    "JavaScript modules support" : "JavaScript modules support",
    "Your webserver is not set up to serve `.js.map` files. Without these files, JavaScript Source Maps won't function properly, making it more challenging to troubleshoot and debug any issues that may arise." : "Jouw webserver is niet ingesteld om `.js.map`-bestanden te verwerken. Zonder deze bestanden zullen JavaScript Source Maps niet goed functioneren, waardoor het een grotere uitdaging wordt om eventuele problemen op te lossen en op te sporen.",
    "Disabled" : "Uitgeschakeld",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Het oude server-side-encryptie formaat is ingeschakeld. We raden aan om dit uit te schakelen.",
    "The logging level is set to debug level. Use debug level only when you have a problem to diagnose, and then reset your log level to a less-verbose level as it outputs a lot of information, and can affect your server performance." : "Het logniveau is ingesteld op foutopsporingsniveau. Gebruik het foutopsporingsniveau alleen om een probleem te diagnosticeren, en reset vervolgens uw log-niveau naar een niveau met minder informatie, omdat het veel informatie oplevert en de prestaties van uw server kan beïnvloeden.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "De PHP functie \"set_time_limit\" is niet beschikbaar. Dit kan erin resulteren dat de scripts halverwege stoppen, waardoor de installatie ontregeld raakt. We adviseren sterk om deze functie in te schakelen.",
    "Supported" : "Ondersteund",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Je PHP heeft geen FreeType ondersteuning. Dit zal leiden tot verminkte profielafbeeldingen en instellingeninterface.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP lijkt niet goed te zijn ingesteld voor opvragen systeemomgevingsvariabelen. De test met getenv(\"PATH\") gaf een leeg resultaat.",
    "PHP modules" : "PHP modules",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "De PHP OPcache is niet geladen.  Voor betere prestaties adviseren we die te laden in je php.ini instellingen.",
    "OPcache is disabled. For better performance, it is recommended to apply \"opcache.enable=1\" to your PHP configuration." : "OPcache is uitgeschakeld. Voor betere prestaties wordt aanbevolen om \"opcache.enable=1\" toe te passen in je PHP-configuratie.",
    "The shared memory based OPcache is disabled. For better performance, it is recommended to apply \"opcache.file_cache_only=0\" to your PHP configuration and use the file cache as second level cache only." : "De shared memory based OPcache is uitgeschakeld. Voor betere prestaties wordt aanbevolen om \"opcache.file_cache_only=0\" toe te passen in je PHP-configuratie en de bestandscache alleen te gebruiken als second level cache.",
    "OPcache is not working as it should, opcache_get_status() returns false, please check configuration." : "OPcache werkt niet zoals zou moeten, opcache_get_status() retourneert false, controleer de configuratie.",
    "PHP version" : "PHP versie",
    "Secure" : "Beveiligd",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "De alleen-lezen config is ingeschakeld. Dit voorkomt het via de webinterface wijzigen van verschillende instellingen. Bovendien moet het bestand voor elke aanpassing handmatig op beschrijfbaar worden ingesteld.",
    "Architecture" : "Architectuur",
    "64-bit" : "64-bit",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Je database draait niet met \"READ COMMITTED\" transactie-isolatie niveau. Dit kan problemen opleveren als er meerdere acties tegelijkertijd worden uitgevoerd.",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Profielfoto, volledige naam, e-mailadres, telefoonnummer, adres, website, Twitter, organisatie, rol, kop, biografie en of je profiel is ingeschakeld",
    "Nextcloud settings" : "Nextcloud instellingen",
    "Enable" : "Inschakelen",
    "Task:" : "Taak:",
    "Here you can decide which group can access certain sections of the administration settings." : "Hier kun je beslissen welke groep toegang heeft tot bepaalde onderdelen van de beheerders instellingen.",
    "Unable to modify setting" : "Kan instelling niet aanpassen",
    "None" : "Geen",
    "Allow apps to use the Share API" : "Apps toestaan de Share API te gebruiken",
    "Allow resharing" : "Opnieuw delen toestaan",
    "Allow sharing with groups" : "Sta delen met groepen toe",
    "Restrict users to only share with users in their groups" : "Laat gebruikers alleen delen met andere gebruikers in hun groepen",
    "Ignore the following groups when checking group membership" : "Negeer de volgende groepen bij het controleren van groepslidmaatschap",
    "Allow users to share via link and emails" : "Sta gebruikers toe om te delen via een link en e-mail",
    "Allow public uploads" : "Sta publieke uploads toe",
    "Always ask for a password" : "Vraag altijd naar een wachtwoord",
    "Enforce password protection" : "Dwing wachtwoordbeveiliging af",
    "Exclude groups from password requirements" : "Sluit groepen uit van wachtwoordvereisten",
    "Exclude groups from creating link shares" : "Sta deze groepen niet toe om deellinks te maken",
    "Limit sharing based on groups" : "Beperk delen op basis van groepen",
    "Allow sharing for everyone (default)" : "Iedereen toestaan te delen (standaard)",
    "Exclude some groups from sharing" : "Sta bepaalde groepen niet toe om te delen",
    "Limit sharing to some groups" : "Beperk het delen naar bepaalde groepen",
    "Groups allowed to share" : "Groepen die mogen delen",
    "Groups excluded from sharing" : "Groepen die niet mogen delen",
    "Not allowed groups will still be able to receive shares, but not to initiate them." : "Groepen zonder toestemming kunnen gedeelde mappen en bestanden ontvangen, maar kunnen zelf niets delen.",
    "Set default expiration date for internal shares" : "Instellen standaard vervaldatum voor deellinks",
    "Enforce expiration date" : "Het kiezen van een vervaldatum verplichten",
    "Default expiration time of new shares in days" : "Standaard vervalperiode van nieuwe deellinks in dagen",
    "Expire shares after x days" : "Laat deellinks vervallen na x dagen",
    "Set default expiration date for shares to other servers" : "Instellen standaard vervaldatum voor deellink naar andere servers",
    "Enforce expiration date for remote shares" : "Vervaldatum voor externe deellinks afdwingen",
    "Default expiration time of remote shares in days" : "Standaard vervalperiode van externe deellinks in dagen",
    "Expire remote shares after x days" : "Laat externe deellinks vervallen na x dagen",
    "Set default expiration date for shares via link or mail" : "Instellen standaard vervaldatum voor share via link of e-mail",
    "Default expiration time of shares in days" : "Standaard vervalperiode van deellinks in dagen",
    "Privacy settings for sharing" : "Privacyinstellingen voor delen",
    "Allow account name autocompletion in share dialog and allow access to the system address book" : "Accountnaam automatisch aanvullen en toegang tot het systeemadresboek toestaan aan gebruikers in dezelfde groepen",
    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Als automatisch aanvullen \"dezelfde groep\" en \"telefoonnummer integratie\" zijn ingeschakeld, is een overeenkomst in een van beide voldoende om de gebruiker te tonen.",
    "Restrict account name autocompletion and system address book access to users within the same groups" : "Accountnaam automatisch aanvullen en toegang tot het systeemadresboek beperken tot gebruikers in dezelfde groepen",
    "Restrict account name autocompletion to users based on phone number integration" : "Beperk automatisch aanvullen van gebruikersnamen tot gebruikers gebaseerd op telefoonnummerintegratie",
    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Automatisch aanvullen toestaan bij het invoeren van de volledige naam of het e-mailadres (ontbrekende overeenkomst in het telefoonboek negeren en deel uitmaken van dezelfde groep)",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Toon disclaimer tekst op de publieke link upload pagina (alleen getoond wanneer de bestandslijst verborgen is)",
    "This text will be shown on the public link upload page when the file list is hidden." : "Deze tekst wordt getoond op de openbare link uploadpagina als het bestandsoverzicht is verborgen.",
    "Default share permissions" : "Standaard deelmachtigingen",
    "Two-Factor Authentication" : "Tweestapsverificatie",
    "Two-factor authentication can be enforced for all accounts and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Tweestapsverificatie kan worden geforceerd voor alle accounts en specifieke groepen. Als ze geen tweestaps-provider hebben geconfigureerd, kunnen ze niet inloggen in het systeem.",
    "Enforce two-factor authentication" : "Forceer het gebruik van tweestapsverificatie",
    "Limit to groups" : "Beperk tot groepen",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Het forceren van het gebruik van tweestapsverificatie kan alleen voor bepaalde groepen worden ingesteld.",
    "Two-factor authentication is enforced for all members of the following groups." : "Tweetrapsauthenticatie wordt geforceerd voor alle leden van de volgende groepen.",
    "Enforced groups" : "Afgedwongen groepen",
    "Two-factor authentication is not enforced for members of the following groups." : "Tweestapsverificatie wordt niet geforceerd voor leden van de volgende groepen.",
    "Excluded groups" : "Uitgesloten groepen",
    "Save changes" : "Wijzigingen bewaren",
    "Default" : "Standaard",
    "Registered Deploy daemons list" : "Lijst van geregistreerde Deploy Daemons",
    "No Deploy daemons configured" : "Geen Deploy Daemons geconfigureerd",
    "Register a custom one or setup from available templates" : "Registreer met de hand of gebruik een van de beschikbare templates",
    "Show details for {appName} app" : "Toon details voor {appName} app",
    "Update to {update}" : "Update naar {update}",
    "Remove" : "Verwijderen",
    "Featured" : "Aanbevolen",
    "This app is supported via your current Nextcloud subscription." : "Deze app wordt ondersteund via je huidige Nextcloud abonnement.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Aanbevolen apps worden ontwikkeld door en binnen de community. Ze bieden centrale functionaliteit en zijn klaar voor productie.",
    "Community rating: {score}/5" : "Gemeenschapsscore: {score}/5",
    "Disable all" : "Alles uitschakelen",
    "Download and enable all" : "Download en alles inschakelen",
    "All apps are up-to-date." : "Alle apps zijn up-to-date.",
    "Icon" : "Pictogram",
    "Name" : "Naam",
    "Version" : "Versie",
    "Level" : "Niveau",
    "Actions" : "Acties",
    "Results from other categories" : "Resultaten van andere categorieën",
    "No apps found for your version" : "Geen apps gevonden voor jouw versie",
    "_%n app has an update available_::_%n apps have an update available_" : ["Voor %n app is een update beschikbaar","Voor %n apps is een update beschikbaar"],
    "_Update_::_Update all_" : ["Update","Update alles"],
    "Failed to create group" : "Creëren groep mislukt",
    "Creating group…" : "Creëren groep...",
    "Create group" : "Creëer groep",
    "Group name" : "Groepsnaam",
    "Please enter a valid group name" : "Voer een valide groepsnaam in",
    "Loading groups…" : "Laden groepen...",
    "Could not load app discover section" : "Kon het onderdeel app ontdekken niet laden",
    "Could not render element" : "Kon het element niet verwerken",
    "Nothing to show" : "Niets te tonen",
    "Could not load section content from app store." : "Kon de inhoud van het onderdeel niet laden vanuit de app store.",
    "Loading" : "Laden",
    "Fetching the latest news…" : "Ophalen laatste nieuws...",
    "Carousel" : "Caroussel",
    "Previous slide" : "Vorige dia",
    "Next slide" : "Volgende dia",
    "Choose slide to display" : "Kies dia om te tonen",
    "{index} of {total}" : "{index} van {total}",
    "Daemon" : "Daemon",
    "Deploy Daemon" : "Deploy Daemon",
    "Type" : "Type",
    "Display Name" : "Weergavenaam",
    "GPUs support" : "GPUs support",
    "Compute device" : "Compute apparaat",
    "Learn more" : "Meer weten",
    "Confirm" : "Bevestigen",
    "Cancel" : "Annuleren",
    "Description" : "Omschrijving",
    "View in store" : "Bekijk in winkel",
    "Visit website" : "Bezoek website",
    "Usage documentation" : "Gebruiksdocumentatie",
    "Admin documentation" : "Beheerdersdocumentatie",
    "Developer documentation" : "Ontwikkelaarsdocumentatie",
    "Details" : "Details",
    "All" : "Alle",
    "Limit app usage to groups" : "Beperk appgebruik tot groepen",
    "No results" : "Geen resultaten",
    "Update to {version}" : "Update naar {version}",
    "Default Deploy daemon is not accessible" : "Standaard Deploy Daemon niet toegankelijk",
    "Delete data on remove" : "Bij verwijderen ook data verwijderen",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Deze app heeft geen minimum Nextcloud versie toegewezen gekregen. In de toekomst wordt dit wordt een fout.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Deze app heeft geen maximum Nextcloud versie toegewezen gekregen. In de toekomst wordt dit wordt een fout.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Deze app kan niet worden geïnstalleerd, omdat de volgende afhankelijkheden niet zijn ingevuld:",
    "Latest updated" : "Laatste update",
    "Author" : "Auteur",
    "Categories" : "Categorieën",
    "Resources" : "Bronnen",
    "Documentation" : "Documentatie",
    "Interact" : "Interacteren",
    "Report a bug" : "Rapporteer een fout",
    "Request feature" : "Vraag functionaliteit aan",
    "Ask questions or discuss" : "Stel vragen of discussieer",
    "Rate the app" : "Beoordeel de app",
    "Rate" : "Beoordelen",
    "Changelog" : "Wijzigingslog",
    "Google Chrome for Android" : "Google Chrome voor Android",
    "{productName} iOS app" : "{productName} iOS app",
    "{productName} Android app" : "{productName} Android app",
    "{productName} Talk for iOS" : "{productName} Talk for iOS",
    "{productName} Talk for Android" : "{productName} Talk voor Android",
    "This session" : "Huidige sessie",
    "Device name" : "Apparaatnaam",
    "Cancel renaming" : "Annuleer hernoemen",
    "Save new name" : "Bewaar nieuwe naam",
    "Marked for remote wipe" : "Aangemerkt voor wissen op afstand",
    "Device settings" : "Apparaatinstellingen",
    "Allow filesystem access" : "Toestaan toegang bestandssysteem",
    "Rename" : "Hernoemen",
    "Revoke" : "Intrekken",
    "Wipe device" : "Apparaat wissen",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Intrekken van deze token kan het wissen van uw apparaat voorkomen als het nog niet is begonnen met wissen.",
    "Device" : "Apparaat",
    "Last activity" : "Laatste activiteit",
    "Devices & sessions" : "Apparaten & sessies",
    "Web, desktop and mobile clients currently logged in to your account." : "Web, desktop en mobiele clients die momenteel zijn ingelogd op je account.",
    "Error while creating device token" : "Fout bij creëren apparaat-token",
    "App name" : "App naam",
    "Create new app password" : "Creëer een nieuw app wachtwoord",
    "App password copied!" : "Appwachtwoord gekopieerd!",
    "Copy app password" : "Kopieer appwachtwoord",
    "Login name copied!" : "Loginnaam gekopieerd!",
    "Copy login name" : "Kopieer loginnaam",
    "Could not copy app password. Please copy it manually." : "Kon app wachtwoord niet kopiëren. Kopieer het handmatig.",
    "Could not copy login name. Please copy it manually." : "Kon loginnaam niet kopiëren. Kopieer handmatig a.u.b.",
    "New app password" : "Nieuw appwachtwoord",
    "Use the credentials below to configure your app or device. For security reasons this password will only be shown once." : "Gebruik de gegevens hieronder om je app of apparaat te configureren. Uit veiligheidsoverwegingen wordt dit wachtwoord slecht eenmaal getoond.",
    "Login" : "Login",
    "Password" : "Wachtwoord",
    "Show QR code for mobile apps" : "Toon QR code voor mobiele apps",
    "Use system cron service to call the cron.php file every 5 minutes." : "Gebruik de systeemcron service om cron.php elke 5 minuten aan te roepen.",
    "Last job execution ran {time}. Something seems wrong." : "Laatste taakuitvoering liep {time}. Er lijkt iets fout gegaan.",
    "Last job ran {relativeTime}." : "Laatste taak liep {relativeTime}.",
    "AJAX" : "AJAX",
    "Webcron" : "Webcron",
    "Profile" : "Profiel",
    "Password confirmation is required" : "Wachtwoordbevestiging vereist",
    "Server-side encryption" : "Server-side versleuteling",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Server-side versleuteling maakt het mogelijk om bestanden te versleutelen die worden geüploaded. Dit betekent wel enig prestatieverlies, dus schakel het alleen in als het nodig is.",
    "Enable server-side encryption" : "Server-side versleuteling inschakelen",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Er is geen cryptomodule geladen, activeer een cryptomodule in het appmenu",
    "Select default encryption module:" : "Selecteer de standaard cryptomodule:",
    "Enable encryption" : "Schakel encryptie in",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Als versleuteling is ingeschakeld, worden alle geüploade bestanden vanaf dat moment versleuteld opgeslagen op de server.  Het is alleen mogelijk om de versleuteling later uit te schakelen als de actieve versleutelingsmodule dit ondersteunt en aan alle pré-condities (mn de ingestelde herstelsleutel) wordt voldaan.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Versleuteling alleen gerandeert geen beveiliging van het systeem. Lees de documentatie voor meer achtergrond over de werking van de crypto app an de relevante use cases.",
    "Be aware that encryption always increases the file size." : "Let erop dat versleuteling de bestandsomvang altijd laat toenemen.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Het is altijd verstandig om regelmatig backups van je bestanden te maken. Zorg ervoor dat je in geval van versleuteling ook de cryptosleutel met je gegevens backupt.",
    "This is the final warning: Do you really want to enable encryption?" : "Dit is de laatste waarschuwing: Wil je versleuteling echt inschakelen?",
    "Submit" : "Verwerken",
    "Rename group" : "Hernoem groep",
    "Current password" : "Huidig wachtwoord",
    "New password" : "Nieuw wachtwoord",
    "Change password" : "Wachtwoord wijzigen",
    "Choose your profile picture" : "Kies je profielafbeelding",
    "Please select a valid png or jpg file" : "Selecteer alstublieft een geldig png of jpg bestand",
    "Error setting profile picture" : "Fout bij instellen profielafbeelding",
    "Error cropping profile picture" : "Fout bij aanpassen profielafbeelding",
    "Error saving profile picture" : "Fout bij opslaan profielafbeelding",
    "Error removing profile picture" : "Fout bij verwijderen profielafbeelding",
    "Your profile picture" : "Je profielafbeelding",
    "Upload profile picture" : "Upload profielafbeelding",
    "Choose profile picture from Files" : "Kies afbeelding via Bestanden",
    "Remove profile picture" : "Verwijder profielafbeelding",
    "The file must be a PNG or JPG" : "Het bestand moet een PNG of JPG bestand zijn",
    "Picture provided by original account" : "Afbeelding is verstrekt door originele account.",
    "Set as profile picture" : "Kies als profielafbeelding",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Let erop dat het tot 24 uur kan duren voordat je profielaafbeelding overal aangepast is.",
    "Unable to update date of birth" : "Kan geboortedatum niet aanpassen",
    "Enter your date of birth" : "Voer je geboortedatum in",
    "You are using {s}{usage}{/s}" : "Je gebruikt {s}{usage}{/s}",
    "You are using {s}{usage}{/s} of {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})" : "Je gebruikt {s}{usage}{/s} van {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})",
    "You are a member of the following groups:" : "Je bent lid van de volgende groepen:",
    "Your full name" : "Je volledige naam",
    "Email options" : "E-mail-opties",
    "Options for additional email address {index}" : "Opties voor extra e-mailadressen {index}",
    "Remove primary email" : "Verwijder primair e-mailadres",
    "Delete email" : "Verwijder e-mailadres",
    "This address is not confirmed" : "Dit adres is niet bevestigd",
    "Unset as primary email" : "Verwijder instelling als primaire e-mail",
    "Set as primary email" : "Instellen als primair e-mailadres",
    "Additional email address {index}" : "Extra e-mailadres {index}",
    "Unable to delete primary email address" : "Kan primair e-mailadres niet verwijderen",
    "Unable to update primary email address" : "Kan primair e-mailadres niet updaten",
    "Unable to add additional email address" : "Kan extra e-mailadres niet toevoegen",
    "Unable to update additional email address" : "Kan extra e-mailadres niet updaten",
    "Unable to delete additional email address" : "Kan extra e-mailadres niet verwijderen",
    "Primary email for password reset and notifications" : "Primair e-mailadres voor wachtwoordherstel en meldingen",
    "No email address set" : "Geen e-mailadres opgegeven",
    "Derived from your locale ({weekDayName})" : "Afgeleid van je regionale instellingen {weekDayName}",
    "Unable to update first day of week" : "Kan Eerste dag van de week niet aanpassen",
    "Day to use as the first day of week" : "Eerste dag van de week",
    "Your headline" : "Jouw hoofdlijn",
    "Unable to update language" : "Kan taal niet updaten",
    "Languages" : "Talen",
    "Help translate" : "Help met vertalen",
    "No language set" : "Geen taal ingesteld",
    "Unable to update locale" : "Kan regionale instellingen niet aanpassen",
    "Locales" : "Regionale instellingen",
    "Week starts on {firstDayOfWeek}" : "Week begint op {firstDayOfWeek}",
    "No locale set" : "Geen regionale instelling ingevuld",
    "Your city" : "Je stad",
    "Your organisation" : "Jouw organisatie",
    "Your phone number" : "Jouw telefoonnummer",
    "Edit your Profile visibility" : "Wijzig je Profiel zichtbaarheid",
    "Unable to update profile enabled state" : "Kan profiel-inschakelstatus niet updaten",
    "Enable profile" : "Schakel profiel in",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "De meer restrictieve de instelling van de zichtbaarheidsscope wordt gerespecteerd in je Profiel. Bijvoorbeeld als je zichtbaarheid is ingesteld op \"Zichtbaar voor iedereen\" en de scope is ingesteld op \"Privé\" wordt \"Privé\" gerespecteerd.",
    "Unable to update visibility of {displayId}" : "Kan zichtbaarheid van {displayId} niet updaten",
    "she/her" : "zij/haar",
    "he/him" : "hij/hem",
    "they/them" : "zij/hun",
    "Your role" : "Jouw rol",
    "Your X (formerly Twitter) handle" : "Je X (voorheen Twitter) handle",
    "Your website" : "Je website",
    "Invalid value" : "Ongeldige waarde",
    "Unable to update {property}" : "Kan {property} niet aanpassen",
    "No {property} set" : "Geen {property} ingesteld",
    "Unable to update federation scope of the primary {property}" : "Kan federatiescope van de primaire {property} niet updaten",
    "Unable to update federation scope of additional {property}" : "Kan federatiescope van de additionele {property} niet updaten",
    "Add additional email" : "Toevoegen extra e-mailadres",
    "Add" : "Toevoegen",
    "Create" : "Creëer",
    "Change" : "Pas aan",
    "Delete" : "Verwijderen",
    "Reshare" : "Doordelen",
    "Default language" : "Standaardtaal",
    "Common languages" : "Gebruikelijke talen",
    "Other languages" : "Andere talen",
    "Password change is disabled because the master key is disabled" : "Wachtwoordwijziging is uitgeschakeld omdat de hoofdsleutel is uitgeschakeld",
    "No accounts" : "Geen accounts",
    "Loading accounts …" : "Laden van accounts …",
    "Manager" : "Manager",
    "Account name will be autogenerated" : "Accountnaam wordt automatisch gegenereert",
    "Account name (required)" : "Accountnaam (vereist)",
    "New account" : "Nieuw account",
    "Display name" : "Weergave naam",
    "Either password or email is required" : "Wachtwoord of e-mail is vereist",
    "Password (required)" : "Wachtwoord (vereist)",
    "Email (required)" : "E-mail (vereist)",
    "Email" : "E-mailadres",
    "Member of the following groups (required)" : "Lid van de volgende groepen (vereist)",
    "Member of the following groups" : "Lid van de volgende groepen",
    "Set account groups" : "Selecteer accountgroepen",
    "Admin of the following groups" : "Beheerder van de volgende groepen",
    "Set account as admin for …" : "Maak account beheerder voor ...",
    "Quota" : "Limieten",
    "Set account quota" : "Voer account quota in",
    "Language" : "Taal",
    "Set default language" : "Voer standaardtaal in",
    "Add new account" : "Voeg nieuw account toe",
    "Total rows summary" : "Aantal rijen samenvatting",
    "Scroll to load more rows" : "Scroll om meer rijen te laden",
    "Password or insufficient permissions message" : "Wachtwoord of onvoldoende machtigingen bericht",
    "Avatar" : "Avatar",
    "Account name" : "Accountnaam",
    "Group admin for" : "Groepsbeheerder voor",
    "Storage location" : "Opslag locatie",
    "Last login" : "Laatste login",
    "Account actions" : "Accountacties",
    "{size} used" : "{size} gebruikt",
    "Delete account" : "Account verwijderen",
    "Disconnect all devices and delete local data" : "Ontkoppel alle apparaten en verwijder lokale data",
    "Disable account" : "Deactiveer account",
    "Enable account" : "Activeer account",
    "Resend welcome email" : "Verstuur welkomst-e-mail opnieuw",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "In het geval van een verloren apparaat of het verlaten van de organisatie, kan dit op afstand de Nextcloud-gegevens wissen van alle apparaten die zijn gekoppeld aan {userid}. Werkt alleen als de apparaten zijn verbonden met het internet.",
    "Remote wipe of devices" : "Op afstand leegmaken toestellen",
    "Wipe {userid}'s devices" : "{userid}'s apparaat wissen",
    "Wiped {userid}'s devices" : "{userid}'s apparaten gewist",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "{userid}'s account volledig verwijderen, inclusief alle persoonlijke bestanden, app-gegevens, etc.",
    "Account deletion" : "Accountverwijdering",
    "Delete {userid}'s account" : "{userid}'s account verwijderen",
    "Display name was successfully changed" : "Weergavenaam was succesvol gewijzigd",
    "Password was successfully changed" : "Wachtwoord was succesvol gewijzigd.",
    "Email was successfully changed" : "E-mail succesvol gewijzigd",
    "Welcome mail sent!" : "Welkomst-e-mail verstuurd!",
    "Loading account …" : "Account laden ...",
    "Change display name" : "Weergavenaam wijzigen",
    "Set new password" : "Instellen nieuw wachtwoord",
    "You do not have permissions to see the details of this account" : "Je hebt niet de machtigingen om de details van dit account te zien",
    "Set new email address" : "Voer nieuw e-mailadres in",
    "Add account to group" : "Voeg account toe aan groep",
    "Set account as admin for" : "Maak account beheerder voor ...",
    "Select account quota" : "Selecteer accountquota",
    "Set the language" : "Voer  de taal in",
    "Toggle account actions menu" : "Omschakelen gebruikersactiemenu",
    "Done" : "Klaar",
    "Edit" : "Bewerken",
    "Account management settings" : "Accountbeheerinstellingen",
    "Visibility" : "Zichtbaarheid",
    "Show language" : "Toon taal",
    "Show account backend" : "Toon account backend",
    "Show storage path" : "Tonen opslagpad",
    "Show last login" : "Toon laatste inlog",
    "Sorting" : "Sorteren",
    "Send email" : "Verstuur e-mail",
    "Send welcome email to new accounts" : "Stuur welkom e-mail naar nieuwe accounts",
    "Defaults" : "Standaard",
    "Default quota" : "Standaard quota",
    "Select default quota" : "Selecteer standaardquotum",
    "Server error while trying to complete WebAuthn device registration" : "Serverfout tijdens registratie van het WebAuthn apparaat",
    "Passwordless authentication requires a secure connection." : "Inloggen zonder wachtwoord vereist een beveiligde verbinding.",
    "Add WebAuthn device" : "WebAuthn-apparaat toevoegen",
    "Please authorize your WebAuthn device." : "Autoriseer je WebAuthn toestel.",
    "Adding your device …" : "Je apparaat toevoegen...",
    "Unnamed device" : "Naamloos toestel",
    "Passwordless Authentication" : "Inloggen zonder wachtwoord",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Stel voor je account wachtwoordloze authenticatie in volgens de FIDO2 standaard.",
    "No devices configured." : "Geen apparaten geconfigureerd.",
    "The following devices are configured for your account:" : "De volgende apparaten zijn ingesteld voor je account:",
    "Your browser does not support WebAuthn." : "De browser ondersteunt geen WebAuthn.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Als beheerder kun je gedetailleerde regels voor delen instellen. Bekijk de documentatie voor meer informatie.",
    "You need to enable the File sharing App." : "Je dient de File sharing App in te schakelen",
    "App Store" : "App winkel",
    "Loading app list" : "Laden applijst",
    "Loading categories" : "Laden categorieën",
    "Developer documentation ↗" : "Ontwikkelaarsdocumentatie ↗",
    "Version {version}, {license}-licensed" : "Versie {version}, {license}-licensed",
    "Version {version}" : "Versie {version}",
    "All accounts" : "Alle accounts",
    "Admins" : "Beheerders",
    "Account group: {group}" : "Accountgroep: {group}",
    "Account management" : "Accountbeheer",
    "Sending…" : "Versturen...",
    "Email sent" : "E-mail verzonden",
    "Location" : "Locatie",
    "Profile picture" : "Profielafbeelding",
    "About" : "Over",
    "Date of birth" : "Geboortedatum",
    "Full name" : "Volledige naam",
    "Additional email" : "Extra e-mailadres",
    "Headline" : "Hoofdlijn",
    "Organisation" : "Organisatie",
    "Phone number" : "Telefoonnummer",
    "Role" : "Rol",
    "X (formerly Twitter)" : "X (voorheen Twitter)",
    "Website" : "Website",
    "Profile visibility" : "Profiel zichtbaarheid",
    "Locale" : "Regionale instellingen",
    "First day of week" : "Eerste dag van de week",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Niet beschikbaar omdat deze eigenschap benodigd is voor de basisfunctionaliteit inclusief bestandsdeling en kalender uitnodigingen",
    "Discover" : "Ontdekken",
    "Your apps" : "Jouw apps",
    "Active apps" : "Ingeschakelde apps",
    "Disabled apps" : "Uitgeschakelde apps",
    "Updates" : "Updates",
    "App bundles" : "App bundels",
    "Featured apps" : "Aanbevolen apps",
    "Supported apps" : "Ondersteunde apps",
    "Show to everyone" : "Laat zien aan iedereen",
    "Show to logged in accounts only" : "Laat alleen zien aan ingelogde accounts",
    "Hide" : "Verbergen",
    "{progress}% Deploying …" : "{progress} % implementeren ...",
    "{progress}% Initializing …" : "{progress} % initialiseren ...",
    "Health checking" : "Gezondheidscheck",
    "Deploy and Enable" : "Implementeren en inschakelen",
    "Download and enable" : "Downloaden en inschakelen",
    "Disable" : "Uitschakelen",
    "Allow untested app" : "Niet-geteste apps toestaan",
    "The app will be downloaded from the App Store" : "De app zal worden gedownload van de App Store",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Deze is niet aangeduid als compatibel met jouw versie van Nextcloud. Als je verdergaat, zal je de app kunnen installeren. Let op dat de app misschien niet werkt zoals verwacht.",
    "Unknown" : "Onbekend",
    "Never" : "Nooit",
    "Could not register device: Network error" : "Kon apparaat niet registreren: netwerkfout",
    "Could not register device: Probably already registered" : "Kon apparaat niet registreren: waarschijnlijk al geregistreerd",
    "Could not register device" : "Kon apparaat niet registreren",
    "An error occurred during the request. Unable to proceed." : "Er is een fout opgetreden tijdens het verzoek. Kan niet doorgaan.",
    "The app has been enabled but needs to be updated." : "De app is ingeschakeld maar moet bijgewerkt worden.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Fout: Deze app kan niet ingeschakeld worden, omdat die de server onstabiel maakt",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "De app is ingeschakeld maar moet worden geüpdate. Je wordt over 5 seconden doorgeleid naar de updatepagina.",
    "Do you really want to wipe your data from this device?" : "Weet je zeker dat je de gegevens van dit apparaat wilt wissen?",
    "Confirm wipe" : "Bevestig wissen",
    "Could not delete the app token" : "Kon de app token niet verwijderen",
    "Error while wiping the device with the token" : "Fout tijdens het wissen van het apparaat met de token",
    "Error while updating device token name" : "Fout tijdens bijwerken device tokennaam",
    "Error while updating device token scope" : "Fout tijdens bijwerken device tokenscope",
    "Could not set group sorting" : "Kon groepsorteren niet instellen",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Er waren te veel aanvragen afkomstig uit uw netwerk. Probeer later opnieuw of contacteer de beheerder als dat niet correct is.",
    "Error" : "Fout",
    "Administration documentation" : "Beheerdersdocumentatie",
    "Forum" : "Forum",
    "Nextcloud help & privacy resources" : "Nextcloud help- & privacy-bronnen",
    "General documentation" : "Algemene documentatie",
    "Legal notice" : "Juridische bepalingen",
    "Privacy policy" : "Privacybeleid",
    "SSL" : "SSL",
    "Open documentation" : "Open documentatie",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Het is belangrijk deze server zo in te stellen dat er ook e-mails verstuurd kunnen worden om wachtwoord resets en meldingen bijvoorbeeld te versturen.",
    "Send mode" : "Verstuurmodus",
    "Encryption" : "Versleuteling",
    "Sendmail mode" : "Sendmail modus",
    "From address" : "Afzenderadres",
    "Server address" : "Server adres",
    "Port" : "Poort",
    "Authentication" : "Authenticatie",
    "Authentication required" : "Authenticatie vereist",
    "Credentials" : "Inloggegevens",
    "SMTP Password" : "SMTP wachtwoord",
    "Save" : "Bewaar",
    "Test and verify email settings" : "Test en controleer de e-mailinstellingen",
    "Security & setup warnings" : "Beveiligings- en instellingswaarschuwingen",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Voor beveiliging en prestaties van je server is het belangrijk dat alles goed is geconfigureerd. Om je hierbij te helpen doen we paar automatische controles. Bekijk de gerelateerde documentatie voor meer informatie.",
    "All checks passed." : "Alle controles geslaagd",
    "There are some errors regarding your setup." : "Er zitten foutjes in je configuratie.",
    "There are some warnings regarding your setup." : "Er zijn waarschuwingen over je configuratie.",
    "Checking for system and security issues." : "Controleren op systeem- en beveiligingsproblemen.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Lees de <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installatie-handleiding ↗</a> goed door en controleer <a href=\"%2$s\">de logs</a> op fouten en waarschuwingen.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Controleer de beveiliging van je Nextcloud via <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">onze securityscan ↗</a>.",
    "Reasons to use Nextcloud in your organization" : "Redenen om Nextcloud te gebruiken in jouw organisatie",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Ontwikkeld door de {communityopen}Nextcloud community{linkclose}, de {githubopen}broncode{linkclose} is gelicenseerd onder de {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Vind onze Facebook pagina leuk",
    "Follow us on X" : "Volg ons op X",
    "Follow us on Mastodon" : "Volg ons op Mastodon",
    "Check out our blog" : "Lees ons blog",
    "Subscribe to our newsletter" : "Abonneer jezelf op onze nieuwsbrief",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Deze community release van Nextcloud wordt niet ondersteund en instant meldingen zijn niet beschikbaar",
    "Use a second factor besides your password to increase security for your account." : "Gebruik een tweede factor naast je wachtwoord om de beveiliging van je account te verhogen. ",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Als u toepassingen van derden gebruikt om met Nextcloud te verbinden, zorg er dan voor om voor elke app een wachtwoord te maken en te configureren voordat \"tweede factor authenticatie\" wordt geactiveerd.",
    "Logged in account must be a subadmin" : "Aangemeld account moet een subadmin zijn",
    "Set default expiration date for shares" : "Instellen standaard vervaldatum voor deellinks",
    "Your biography" : "Jouw biografie",
    "You are using <strong>{usage}</strong>" : "Je gebruikt <strong>{usage}</strong>",
    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Je gebruikt <strong>{usage}</strong> van <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)"
},
"nplurals=2; plural=(n != 1);");
