OC.L10N.register(
    "comments",
    {
    "Comments" : "Komentar",
    "You commented" : "Anda berkomentar",
    "{author} commented" : "{author} berkomentar",
    "You commented on %1$s" : "Anda berkomentar pada %1$s",
    "You commented on {file}" : "Anda berkomentar pada {file} ",
    "%1$s commented on %2$s" : "%1$s dikomentari pada %2$s",
    "{author} commented on {file}" : "{author} berkomentar pada {file}",
    "<strong>Comments</strong> for files" : "<strong>komentar</strong> pada file",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} menyebut Anda dalam sebuah komentar pada \"{file}\" ",
    "Files app plugin to add comments to files" : "Plugin aplikasi file untuk menambah komentar pada file",
    "Edit comment" : "Sunting komentar",
    "Delete comment" : "Hapus komentar",
    "Cancel edit" : "Batal sunting",
    "Post comment" : "Posting komentar",
    "Unable to load the comments list" : "Tidak dapat memuat daftar komentar",
    "No comments yet, start the conversation!" : "Belum ada yang berkomentar, mulailah perbincangan!",
    "No more messages" : "Tidak ada pesan lagi",
    "Retry" : "Ulangi",
    "Comment" : "Komentar",
    "An error occurred while trying to edit the comment" : "Terjadi kesalahan ketika mencoba menyunting komentar",
    "Comment deleted" : "Komentar dihapus",
    "An error occurred while trying to delete the comment" : "Terjadi kesalahan ketika mencoba untuk menghapus komentar",
    "An error occurred while trying to create the comment" : "Terjadi kesalahan ketika mencoba untuk membuat komentar"
},
"nplurals=1; plural=0;");
