OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Első indítási varázsló",
    "Add your profile information! For example your email is needed to receive notifications." : "Adja hozzá a profiladatait. Például az e-mail szükséges az értesítések fogadásához.",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "Adja hozzá a profiladatait. Például az e-mail szükséges az értesítések fogadásához és a jelszó-visszaállításához.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Adja meg a profiladatait. Állítson be profilképet és adja meg a teljes nevét az egyszerűbb azonosíthatóság érdekében az összes szolgáltatásban.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Adja meg a profiladatait. Állítsa be a teljes nevét az egyszerűbb azonosíthatóság érdekében az összes szolgáltatásban.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Adja meg a profiladat. Állítson be profilképet az egyszerűbb azonosíthatóság érdekében az összes szolgáltatásban.",
    "App recommendation: Calendar" : "Alkalmazásjavaslat: Naptár",
    "Schedule work & meetings, synced with all your devices." : "Ütemezze munkáját és találkozóit, szinkronizálva az összes eszközén.",
    "App recommendation: Contacts" : "Alkalmazásjavaslat: Névjegyek",
    "Keep your colleagues and friends in one place without leaking their private info." : "Tartsa egy helyen kollégáit és barátait, anélkül hogy kiszivárogtatná a személyes adataikat.",
    "App recommendation: Mail" : "Alkalmazásjavaslat: Levél",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Egyszerű e-mail alkalmazás, amely szépen integrálódik a Fájlok, Névjegyek és Naptár alkalmazásokkal.",
    "App recommendation: Tasks" : "Alkalmazásjavaslat: Feladatok",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "Szinkronizálja a különböző eszközökről származó feladatokat, és szerkessze online őket a Nextcloud segítségével.",
    "App recommendation: Deck" : "Alkalmazásjavaslat: Kártyák",
    "Kanban style organization for personal planning and team projects." : "Kanban stílusú szervező személyes tervezéshez és csapatos projektekhez.",
    "App recommendation: Forms" : "Alkalmazásjavaslat: Űrlapok",
    "Simple surveys and questionnaires, self-hosted" : "Egyszerű felmérések és kérdőívek, saját kiszolgálón",
    "App recommendation: Recognize" : "Alkalmazásjavaslat: Felismerés",
    "Smart media tagging for Nextcloud" : "Okos médiacímkézés a Nextcloudhoz",
    "App recommendation: Group folders" : "Alkalmazásjavaslat: Csoportmappák",
    "Admin-configured folders shared by everyone in a group." : "A rendszergazda által beállított könyvtárak, melyek a csoporton belül mindenkivel meg vannak osztva.",
    "App recommendation: Whiteboard" : "Alkalmazásjavaslat: Tábla",
    "Create and share whiteboards with others and collaborate in real-time." : "Hozzon létre táblákat, ossza meg másokkal és működjön együtt valós időben.",
    "Connect your calendar" : "Kapcsolódás a naptárhoz",
    "Connect your contacts" : "Kapcsolódás a címjegyzékekhez",
    "Access files via WebDAV" : "Fájlok elérése WebDAV protokoll segítségével",
    "Download macOS/iOS configuration profile" : "MacOS/iOS konfigurációs profil letöltése",
    "Desktop client" : "Asztali kliens",
    "Android app on Google Play Store" : "Androidos alkalmazás a Google Play Áruházból",
    "Android app on F-Droid" : "Androidos alkalmazás az F-Droidból",
    "iOS app" : "iOS-es alkalmazás",
    "About & What's new" : "Névjegy & újdonságok",
    "A welcome and introduction wizard for Nextcloud" : "Egy üdvözlő és bevezető varázsló a Nextcloudhoz",
    "This application enables a pop-up window when a user first logs into Nextcloud. This window welcomes new users to Nextcloud, and contains links to the standard desktop client, Android app, and the iOS app. The window also shows a link for accessing Nextcloud via WebDAV. At any time, the first run wizard can be opened again via link \"About\" on settings menu.\nThe First run wizard can be customized to meet specific design goals, or to change links and messages. Create an appropriate theme following the Theming documentation, and changes to the look and feel of this Wizard are simple. More information is available in the first run wizard documentation, as well as the theming documentation." : "Ez az alkalmazás engedélyez egy előugró ablakot, amely a felhasználó első Nextcloudba történő bejelentkezésekor jelenik meg. Ez az új felhasználó üdvözlő ablak hivatkozásokat tartalmaz a szokásos asztali klienshez, az andoridos alkalmazáshoz és az iOS-es alkalmazáshoz. Az ablak tartalmaz egy további hivatkozást a Nextcloud WebDAV-on keresztüli eléréséhez. Az első futtatás varázsló bármikor újra megnyitható a beállítások menü „Névjegy” hivatkozásán keresztül.\nAz Első futtatás varázsló testreszabható úgy, hogy megfeleljen a meghatározott céloknak, és módosíthatja a hivatkozásokat és az üzeneteket. Hozzon létre egy Önnek megfelelő témát a Témázás dokumentációja alapján, és változtassa meg a varázsló megjelenését. További információ az első futtatás varázsló dokumentációjában, valamint a témázás dokumentációjában található.",
    "Download on Apple app store" : "Alkalmazás letöltése az Apple app storeból",
    "Download on Google play store" : "Alkalmazás letöltése az Google play storeból",
    "Go to previous page" : "Ugrás az előző oldalra",
    "Close" : "Bezárás",
    "More about Nextcloud" : "További információk a Nextcloudról",
    "Explore more apps ↗" : "További alkalmazások felfedezése ↗",
    "Extend the functionality of Nextcloud with hundreds of community-developed apps." : "Növeld a Nextcloud funkcióit több száz közösségi alkalmazással.",
    "Get involved! ↗" : "Légy részese! ↗",
    "Be a part of the community that helps build, design, translate and promote Nextcloud!" : "Légy részese a közsségnek amelyik segít szerkeszteni, fordítani és előmozdítani a Nextcloudot!",
    "Need help? ↗" : "Segítségre van szüksége? ↗",
    "Find out more about your Nextcloud setup with the admin, user or developer documentation." : "Tudj meg többet a Nextcloud beállításairól az rendszergazda, felhasználói vagy fejlesztői dokumentációkból.",
    "For large organisations ↗" : "Nagyobb szervezeteknek ↗",
    "Get Nextcloud Enterprise for mission critical environments where advanced security and compliance are important." : "Szerezd be a Nextcloud vállalati verzióját szolgáltatás kritikus környezetben ahol a kiterjesztett biztonság és megfelelés fontos.",
    "Seamless integration with your devices." : "Zökkenőmentes integráció az eszközeivel. ",
    "Sync your files across your devices with the desktop and mobile apps, and connect your calendar and contacts." : "Szinkronizálja fájljait az asztali és mobilalkalmazásokkal az összes eszközén, és csatlakoztassa naptárát és névjegyeit.",
    "Desktop app ↗" : "Asztali alkalmazás ↗",
    "Download For Windows, Mac OS and Linux." : "Letöltés Windowsra, Mac OS-re és Linuxra.",
    "Calendar and contacts ↗" : "Naptár és névjegyek ↗",
    "Connect your calendar and contacts with your devices." : "Kapcsolja össze a naptárát és névjegyeit az eszközein.",
    "Introducing Nextcloud Hub {version}" : "Nextcloud Hub {version} bemutatása",
    "Welcome to {cloudName}!" : "Üdvözli a(z) {cloudName}!",
    "This Nextcloud is on version {version}" : "Ezen Nextcloud verziója {version}",
    "A collaboration platform that puts you in control" : "Együttműködési platform, ami az Ön kezébe adja az irányítást",
    "Privacy" : "Adatvédelem",
    "Host your data and files where you decide." : "Ott tárolja az adatait és fájljait, ahol Ön szeretné.",
    "Productivity" : "Produktivitás",
    "Collaborate and communicate across any platform." : "Együttműködés és kommunikáció bármely platform között.",
    "Interoperability" : "Interoperabilitás",
    "Import and export anything you want with open standards." : "Importálhat és exportálhat bármit, amit csak kíván a nyílt szabványok segítségével.",
    "Community" : "Közösség",
    "Enjoy constant improvements from a thriving open-source community." : "Élvezze a nyílt forráskódú közösség folyamatos fejlesztéseit.",
    "Nextcloud Hub {version} release" : "Nextcloud Hub {version} kiadás",
    "Read more about it on the Nextcloud Hub {version} blog" : "További részleteket olvashat a Nextcloud Hub {version} blogon",
    "Find out more on the blog" : "További részleteket talál a blogon",
    "Read the Nextcloud Hub {version} blog" : "Olvassa a Nextcloud Hub {version} blogot",
    "Share your opinion about Nextcloud Hub {version}" : "Ossz meg többet a Nextcloud Hub {version}verzióról",
    "Share via email" : "Megosztás e-mailben",
    "Share on {socialMedia}" : "Megosztva itt {socialMedia}",
    "New in Nextcloud Hub {version}" : "Nextcloud Hub {version} újdonságai",
    "Connect other apps to {productName}" : "Csatlakoztasson más alkalmazásokat a(z) {productName}hoz",
    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to {productName}." : "A mobilalkalmazások és az asztali kliens mellett bármilyen más olyan szoftvert is csatlakoztathat a {productName}hoz, mely támogatja a WebDAV/CalDAV/CardDAV protokollokat.",
    "Apps to connect to {productName}" : "Alkalmazások amik csatlakoznak a {productName}",
    "Set up sync clients using an {linkStart}app password{linkEnd}. That way you can make sure you are able to revoke access in case you lose that device." : "Állítsa be a szinkronizálási klienseket egy {linkStart}alkalmazásjelszó {linkEnd} használatával. Így biztos lehet abban, hogy visszavonhatja a hozzáférést abban az esetbe, ha elveszítené az eszközt.",
    "Get the apps to sync your files" : "Alkalmazások a fájljai szinkronizálásához",
    "{productName} gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "A {productName} hozzáférést biztosít a fájljaihoz, akárhol is legyen. A könnyen kezelhető asztali és mobil kliensünk ingyenesen elérhető az összes főbb platformon.",
    "App for syncing" : "Alkalmazás szinkronizáláshoz",
    "URL copied" : "Hivatkozás kimásolva",
    "Could not copy the URL, please copy manually" : "Nem sikerült a hivatkozást másolni, kérem másolja manuálisan",
    "Server address" : "Kiszolgálócím",
    "Use this link to connect your apps and desktop client to this server:" : "Használja ezt a hivatkozást az alkalmazások és az asztali kliens csatlakoztatásához a kiszolgálóhoz:",
    "What's new?" : "Újdonságok",
    "Nextcloud on all your devices" : "Nextcloud az összes eszközén",
    "Nextcloud Hub {version}" : "Nextcloud Hub {version}",
    "Read more" : "Továbbolvasás",
    "Share on social media" : "Megosztás a közösségi médiában",
    "Get started!" : "Kezdjen bele!",
    "App recommendation: Nextcloud Calendar" : "Alkalmazásjavaslat: Nextcloud Naptár",
    "App recommendation: Nextcloud Contacts" : "Alkalmazásjavaslat: Nextcloud Névjegyek",
    "App recommendation: Nextcloud Mail" : "Alkalmazásjavaslat: Nextcloud Levelezés",
    "Federated collaboration: file sharing, messaging, calls" : "Szövetségi együttműködés: fájl megosztás, üzenetküldés, hívások",
    "Nextcloud Whiteboard" : "Nextcloud Tábla",
    "Workflow Engine" : "Munkafolyamat Motor",
    "Safer and swifter mail" : "Biztonságosabb és gyorsabb levél",
    "Public Collectives sharing, previews and QR-codes" : "Nyilvános kollektívák megosztása, előnézetei és QR kódok",
    "Office and PDF templates" : "Office és PDF minták",
    "Chat mode for Nextcloud Assistant" : "Chat mód a Nextcloud Assistant-hoz",
    "Get to know the new features of Hub 9" : "Tudj meg többet a HUB 9 újdonságairól"
},
"nplurals=2; plural=(n != 1);");
