OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : " %s करीता वैयक्तिक क्रिया फीड",
    "Your feed URL is invalid" : "तुमची फीड युआरएल अवैध आहे",
    "Activity feed" : "क्रियेची फीड",
    "Your settings have been updated." : "तुमच्या सेटिंग अद्ययावत करण्यात आल्या.",
    "Settings have been updated." : "सेटिंग अद्ययावत करण्यात आल्या.",
    "Recent activity" : "अलीकडील क्रिया",
    "No activities" : "कोणत्याही क्रिया नाहीत",
    "Daily activity summary for %s" : " %s च्या दैनंदिन क्रियांचा सारांश",
    "All activities" : "सर्व क्रिया",
    "By others" : "इतरांद्वारे",
    "By you" : "तुमच्याद्वारे",
    "Hello %s" : "नमस्कार %s",
    "Hello %s," : "नमस्कार %s,",
    "There was some activity at %s" : "%s येथे काही क्रिया झाली",
    "_and %n more _::_and %n more _" : ["आणि इतर %n","आणि इतर %n"],
    "Mail" : "मेल",
    "Push" : "पाठविलेली",
    "Activity" : "क्रिया",
    "Notifications" : "अधिसूचना",
    "Today" : "आज",
    "Yesterday" : "काल",
    "As soon as possible" : "लवकरात लवकर",
    "Hourly" : "ताशी",
    "Daily" : "दैनिक",
    "Weekly" : "साप्ताहिक",
    "Open {filename}" : "उघडा {filename}",
    "in {path}" : " {path} मध्ये",
    "Home" : "होम",
    "No activity yet" : "अजुन कोणतीही क्रिया नाही",
    "Unable to load the activity list" : "क्रियेची यादी घेता आली नाही",
    "Enable notification emails" : "अधिसूचना ई-मेल सुरु करा",
    "Daily activity summary" : "दैनिक क्रिया सारांश",
    "Default settings" : "मूळ सेटींग"
},
"nplurals=2; plural=(n != 1);");
