<?php
namespace Aws\OAM\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **CloudWatch Observability Access Manager** service.
 */
class OAMException extends AwsException {}
