OC.L10N.register(
    "files_external",
    {
    "Grant access" : "Дозволи пристап",
    "Error configuring OAuth2" : "Грешка во конфигурацијата на OAuth2",
    "Generate keys" : "Генерирај клучеви",
    "Error generating key pair" : "Грешка при генерирање на клучеви",
    "Storage with ID \"%d\" not found" : "Складиште со ID \"%d\" не е пронајдено",
    "Invalid mount point" : "Погрешна точка на монтирање",
    "Insufficient data: %s" : "Недоволни податоци: %s",
    "%s" : "%s",
    "Access key" : "Клуч за пристап",
    "Secret key" : "Таен клуч",
    "Builtin" : "Вграден",
    "None" : "Ништо",
    "OAuth2" : "OAuth2",
    "Client ID" : "Клиент ИД",
    "Client secret" : "Тајна на клиент",
    "OpenStack v2" : "OpenStack v2",
    "Login" : "Најава",
    "Password" : "Лозинка",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Домен",
    "API key" : "API key",
    "Global credentials" : "Глобални акредитиви",
    "Log-in credentials, save in database" : "Акредитиви за најавување, зачувани во базата со податоци",
    "Log-in credentials, save in session" : "Акредитиви за најавување, зачувани во сесија",
    "RSA public key" : "RSA јавен клуч",
    "Public key" : "Јавен клуч",
    "RSA private key" : "RSA приватен клуч",
    "Private key" : "Приватен клуч",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Кофа",
    "Hostname" : "Име на серверот",
    "Port" : "Порта",
    "Region" : "Регион",
    "Enable SSL" : "Овозможи SSL",
    "WebDAV" : "WebDAV",
    "URL" : "Адреса",
    "Remote subfolder" : "Подпапка на серверот",
    "Secure https://" : "Безбедна https://",
    "FTP" : "FTP",
    "Host" : "Домаќин",
    "Secure ftps://" : "Безбедна ftps://",
    "Local" : "Локален",
    "Location" : "Локација",
    "Nextcloud" : "Cloud",
    "SFTP" : "SFTP",
    "Root" : "Корен",
    "SFTP with secret key login" : "SFTP најава со безбедносен клуч",
    "Share" : "Сподели",
    "Show hidden files" : "Прикажи сокриени датотеки",
    "Timeout" : "Времето истече",
    "Service name" : "Име на сервисот",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Поддршка за cURL во PHP не е овозможена или не е инсталирана. Монтирањето на %s не е возможно. Контактирајте го администраторот.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Поддршка за FTP во PHP не е овозможена или не е инсталирана. Монтирањето на %s не е возможно. Контактирајте го администраторот.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "\"%1$s\" не е инсалиран. Монтирањето на %2$s не е возможно. Контактирајте го администраторот.",
    "External storage" : "Надворешно складиште",
    "External storage support" : "Поддршка за надворешно складиште",
    "Confirm" : "Потврди",
    "Open in Files" : "Отвори во датотеките",
    "There was an error with this external storage. Do you want to review this mount point config in the settings page?" : "Се појави грешка со ова надворешно складиште. Дали сакате да ја прегледате оваа конфигурација на страницата со поставки?",
    "External mount error" : "Грешка при надворешно монтирање",
    "List of external storage." : "Листа на надворешни складишта.",
    "There is no external storage configured. You can configure them in your Personal settings." : "Нема конфигурирано надворешно складирање. Можете да ги конфигурирате во вашите лични поставки.",
    "There is no external storage configured and you don't have the permission to configure them." : "Нема конфигурирано надворешно складирање и немате дозвола да го конфигурирате.",
    "No external storage" : "Нема надворешно складиште",
    "Storage type" : "Вид на складиште",
    "Unknown" : "Непознат",
    "Scope" : "Опсег",
    "Personal" : "Лично",
    "System" : "Систем",
    "(Group)" : "(Група)",
    "Compatibility with Mac NFD encoding (slow)" : "Компатибилно со Mac NFD енкрипција (бавно)",
    "Enable encryption" : "Овозможи енкрипција",
    "Enable previews" : "Овозможи прегледување",
    "Enable sharing" : "Овозможи споделување",
    "Check for changes" : "Провери за промени",
    "Never" : "Никогаш",
    "Once every direct access" : "Еднаш секој пристап",
    "Read only" : "Само читај",
    "Disconnect" : "Исклучи",
    "Admin defined" : "Дефинирано од администраторот",
    "Delete storage?" : "Избриши складиште?",
    "Click to recheck the configuration" : "Кликни за проверка на конфигурацијата",
    "Saved" : "Снимено",
    "Saving …" : "Зачувува ...",
    "Save" : "Сними",
    "No external storage configured or you don't have the permission to configure them" : "Немате конфигурирано надворешно складиште или немате дозвола да го конфигурирате",
    "Open documentation" : "Отвори ја документацијата",
    "Folder name" : "Име на папка",
    "Authentication" : "Автентикација",
    "Configuration" : "Конфигурација",
    "Available for" : "Достапно за",
    "Add storage" : "Додади складиште",
    "Advanced settings" : "Напредни параметри",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Глобалните акредитиви можат да се искористат за пристапување во повеќе надворешни складишта кој користат исти акредитиви.",
    "Error configuring OAuth1" : "Грешка во конфигурацијата на OAuth1",
    "Please provide a valid app key and secret." : "Внесете валиден клуч на апликацијата и лозинка.",
    "OAuth1" : "OAuth1",
    "App key" : "Клуч на апликацијата",
    "App secret" : "Тајна на апликацијата"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
