OC.L10N.register(
    "nextcloud_announcements",
    {
    "Nextcloud announcements" : "Nextcloud 공지",
    "Nextcloud announcement" : "Nextcloud 공지",
    "Read more" : "더 읽기",
    "Disable announcements" : "공지 비활성화",
    "(These announcements are only shown to administrators)" : "(이 공지들은 오직 관리자들에게만 보여집니다.)",
    "Nextcloud announcements brings the latest news of Nextcloud into your notifications" : "Nextcloud 공지를 통해서 Nextcloud 최신 뉴스를 알림에서 받아 볼 수 ᄋᅠᆻ습니다."
},
"nplurals=1; plural=0;");
