OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Προστέθηκε στα αγαπημένα",
    "Removed from favorites" : "Αφαιρέθηκε από τα αγαπημένα",
    "You added {file} to your favorites" : "Προσθέσατε το {file} στα αγαπημένα σας",
    "You removed {file} from your favorites" : "Αφαιρέσατε το {file} από τα αγαπημένα σας",
    "Favorites" : "Αγαπημένα",
    "File changes" : "Αλλαγές αρχείου",
    "Created by {user}" : "Δημιουργήθηκε από τον {user}",
    "Changed by {user}" : "Άλλαξε από τον {user}",
    "Deleted by {user}" : "Διαγράφτηκε από τον {user}",
    "Restored by {user}" : "Επαναφέρθηκε από τον {user}",
    "Renamed by {user}" : "Μετονομάστηκε από τον {user}",
    "Moved by {user}" : "Μετακινήθηκε από τον {user}",
    "You created {file}" : "Δημιουργήσατε το {file}",
    "You created an encrypted file in {file}" : "Δημιουργήσατε ένα κρυπτογραφημένο αρχείο στο {file}",
    "{user} created {file}" : "Ο/η {user} δημιούργησε {file}",
    "{user} created an encrypted file in {file}" : "Ο/η {user} δημιούργησε ένα κρυπτογραφημένο αρχείο στο {file}",
    "{file} was created in a public folder" : "Το {file} δημιουργήθηκε σε δημόσιο φάκελο",
    "You changed {file}" : "Αλλάξατε το {file}",
    "You changed an encrypted file in {file}" : "Αλλάξατε ένα κρυπτογραφημένο αρχείο {file}",
    "{user} changed {file}" : "Ο/η {user} άλλαξε το {file}",
    "{user} changed an encrypted file in {file}" : "Ο/η {user} άλλαξε κρυπτογραφημένο αρχείο {file}",
    "You deleted {file}" : "Διαγράψτε το {file}",
    "You deleted an encrypted file in {file}" : "Διαγράψατε ένα κρυπτογραφημένο αρχείο {file}",
    "{user} deleted {file}" : "Ο/η {user} διέγραψε το {file}",
    "{user} deleted an encrypted file in {file}" : "Ο/η {user} διέγραψε κρυπτογραφημένο αρχείο σε {file}",
    "You restored {file}" : "Επαναφέρατε το {file}",
    "{user} restored {file}" : "Ο/η {user} επανέφερε το {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Μετονομάσατε από {oldfile} (hidden) σε {newfile} (hidden)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Μετονομάσατε το {oldfile} (hidden) σε {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Μετονομάσατε το {oldfile} (hidden) σε {newfile}",
    "You renamed {oldfile} to {newfile}" : "Μετονομάσατε το {oldfile} σε {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "Ο/Η {user} μετονομάστηκε σε {oldfile} (hidden) σε {newfile} (hidden)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "Ο/Η {user} μετονόμασε σε {oldfile} (hidden) σε {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "Ο/Η {user} μετονόμασε σε {oldfile} σε {newfile} (hidden)",
    "{user} renamed {oldfile} to {newfile}" : "Ο/η {user} μετονόμασε το {oldfile} σε {newfile}",
    "You moved {oldfile} to {newfile}" : "Μεταφέρατε το {oldfile} σε {newfile}",
    "{user} moved {oldfile} to {newfile}" : "Ο/η {user} μετέφερε το {oldfile} σε {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Ένα αρχείο έχει προστεθεί ή αφαιρεθεί από τα <strong>αγαπημένα</strong> σας",
    "Files" : "Αρχεία",
    "A file or folder has been <strong>changed</strong>" : "Ένα αρχείο ή κατάλογος έχουν <strong>αλλάξει</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Ένα αγαπημένο αρχείο ή φάκελός σας έχει <strong>τροποποιηθεί</strong>.",
    "No favorites" : "Δεν υπάρχουν αγαπημένα",
    "Accept" : "Αποδοχή",
    "Reject" : "Απόρριψη",
    "Incoming ownership transfer from {user}" : "Εισερχόμενη μεταβίβαση κυριότητας από τον {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Δέχεστε την διαδρομή {path}?\n\nΣημείωση: Η διαδικασία μεταφοράς μπορεί να διαρκέσει πάνω από μία ώρα.",
    "Ownership transfer denied" : "Η μεταφορά κυριότητας απορρίφθηκε",
    "Your ownership transfer of {path} was denied by {user}." : "Η μεταφορά της κυριότητας του {path} απορρίφθηκε από τον χρήστη {user}.",
    "Ownership transfer failed" : "Η μεταφορά κυριότητας απέτυχε",
    "Your ownership transfer of {path} to {user} failed." : "Η μεταφορά κυριότητας σας του {path} στον {user} απέτυχε.",
    "The ownership transfer of {path} from {user} failed." : "Η μεταφορά κυριότητας του {path} από {user} απέτυχε.",
    "Ownership transfer done" : "Η μεταφορά κυριότητας ολοκληρώθηκε",
    "Your ownership transfer of {path} to {user} has completed." : "Η μεταφορά κυριότητας σας του {path} στον {user} ολοκληρώθηκε.",
    "The ownership transfer of {path} from {user} has completed." : "Η μεταφορά κυριότητας του {path} στον {user} ολοκληρώθηκε.",
    "in %s" : "σε %s",
    "Transferred from %1$s on %2$s" : "Μεταβιβάστηκε από %1$s σε %2$s",
    "Enforce Windows compatibility" : "Επιβολή συμβατότητας με Windows",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Αυτό θα αποκλείσει ονόματα αρχείων που δεν είναι έγκυρα σε συστήματα Windows, όπως η χρήση δεσμευμένων ονομάτων ή ειδικών χαρακτήρων. Αλλά αυτό δεν θα επιβάλει τη συμμόρφωση ως προς την διάκριση πεζών-κεφαλαίων.",
    "File Management" : "Διαχείριση αρχείων",
    "Home" : "Αρχική",
    "Target folder does not exist any more" : "Ο φάκελος προορισμού δεν υπάρχει πια",
    "Reload current directory" : "Επαναφόρτωση τρέχοντος καταλόγου",
    "Go to the \"{dir}\" directory" : "Μετάβαση στον κατάλογο \"{dir}\"",
    "Current directory path" : "Τρέχουσα διαδρομή καταλόγου",
    "Your have used your space quota and cannot upload files anymore" : "Έχετε χρησιμοποιήσει το όριο χώρου σας και δεν μπορείτε να μεταφορτώσετε αρχεία πλέον",
    "Drag and drop files here to upload" : "Σύρετε και αφήστε αρχεία εδώ για να τα μεταφορτώσετε",
    "Favorite" : "Αγαπημένο",
    "Back" : "Επιστροφή",
    "Toggle selection for file \"{displayName}\"" : "Εναλλαγή επιλογής για το αρχείο \"{displayName}\"",
    "Toggle selection for folder \"{displayName}\"" : "Εναλλαγή επιλογής για τον φάκελο \"{displayName}\"",
    "Filename" : "Όνομα αρχείου",
    "Folder name" : "Όνομα φακέλου",
    "This node is unavailable" : "Αυτός ο κόμβος δεν είναι διαθέσιμος",
    "Another entry with the same name already exists." : "Μια άλλη καταχώρηση με το ίδιο όνομα υπάρχει ήδη.",
    "Invalid filename." : "Μη έγκυρο όνομα αρχείου",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Μετονομασία του \"{oldName}\" σε \"{newName}\"",
    "Rename file" : "Μετονομασία αρχείου",
    "Folder" : "Φάκελος",
    "Pending" : "Εκκρεμεί",
    "Clear filter" : "Εκκαθάριση φίλτρου",
    "Modified" : "Τροποποιήθηκε",
    "Search everywhere" : "Αναζητήστε παντού",
    "Type" : "Τύπος",
    "Active filters" : "Ενεργά φίλτρα",
    "Remove filter" : "Αφαίρεση φίλτρου",
    "Total rows summary" : "Συνολική σύνοψη γραμμών",
    "Toggle selection for all files and folders" : "Εναλλαγή επιλογής για όλα τα αρχεία και τους φακέλους",
    "Name" : "Όνομα",
    "Size" : "Μέγεθος",
    "Actions" : "Ενέργειες",
    "List of files and folders." : "Λίστα αρχείων και φακέλων.",
    "Column headers with buttons are sortable." : "Οι επικεφαλίδες στηλών με κουμπιά είναι ταξινομήσιμες.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Η λίστα αυτή δεν εμφανίζεται πλήρως για λόγους απόδοσης. Τα αρχεία θα εμφανίζονται καθώς πλοηγείστε στη λίστα.",
    "File not found" : "Δε βρέθηκε το αρχείο",
    "{usedQuotaByte} used" : "{usedQuotaByte} χρησιμοποιείται",
    "{used} of {quota} used" : "Χρήση {used} από {quota} ",
    "{relative}% used" : "{relative}% χρησιμοποιείται",
    "Could not refresh storage stats" : "Δεν ήταν δυνατή η ανανέωση των στατιστικών αποθήκευσης",
    "Your storage is full, files can not be updated or synced anymore!" : "Ο αποθηκευτικός σας χώρος είναι γεμάτος, τα αρχεία δεν μπορούν να ενημερωθούν ή να συγχρονιστούν πια!",
    "Storage information" : "Πληροφορίες αποθήκευσης",
    "New folder" : "Νέος φάκελος",
    "Create new folder" : "Δημιουργία νέου φακέλου",
    "This name is already in use." : "Αυτό το όνομα χρησιμοποιείται ήδη.",
    "Create" : "Δημιουργία",
    "Submit" : "Υποβολή",
    "Choose a file or folder to transfer" : "Επιλέξτε αρχείο ή φάκελο για μεταφορά",
    "Transfer" : "Μεταφορά",
    "Transfer {path} to {userid}" : "Μεταφορά {path} στον {userid}",
    "Invalid path selected" : "Επιλέχθηκε μη έγκυρη διαδρομή",
    "Unknown error" : "Άγνωστο σφάλμα",
    "Ownership transfer request sent" : "Αποστολή αίτησης μεταβίβασης κυριότητας",
    "Cannot transfer ownership of a file or folder you do not own" : "Δεν είναι δυνατή η μεταβίβαση της κυριότητας ενός αρχείου ή φακέλου που δε σας ανήκει",
    "Transfer ownership of a file or folder" : "Μεταβίβαση κυριότητας αρχείου ή φακέλου",
    "Choose file or folder to transfer" : "Επιλέξτε αρχείο ή φάκελο για μεταφορά",
    "Change" : "Αλλαγή",
    "New owner" : "Νέος κάτοχος",
    "Select file or folder to link to" : "Επιλέξτε αρχείο ή φάκελο για σύνδεση",
    "Choose {file}" : "Επιλέξτε {file}",
    "Share" : "Διαμοιρασμός",
    "Shared by link" : "Διαμοιρασμένα μέσω συνδέσμου",
    "Shared" : "Κοινόχρηστα",
    "Switch to list view" : "Αλλαγή σε προβολή λίστας",
    "Switch to grid view" : "Εναλλαγή σε προβολή πλέγματος",
    "Upload was cancelled by user" : "Η μεταφόρτωση ακυρώθηκε από τον χρήστη",
    "Not enough free space" : "Δεν επαρκεί ο ελεύθερος χώρος",
    "Operation is blocked by access control" : "Η λειτουργία μπλοκάρεται από τον έλεγχο πρόσβασης",
    "Error during upload: {message}" : "Σφάλμα κατά τη μεταφόρτωση: {message}",
    "Error during upload, status code {status}" : "Σφάλμα κατά τη μεταφόρτωση, κωδικός κατάστασης {status}",
    "Unknown error during upload" : "Άγνωστο σφάλμα κατά τη μεταφόρτωση",
    "Loading current folder" : "Φόρτωση τρέχοντος φακέλου",
    "Retry" : "Δοκιμή ξανά",
    "No files in here" : "Δεν υπάρχουν αρχεία εδώ",
    "Upload some content or sync with your devices!" : "Μεταφόρτωση περιεχομένου ή συγχρονισμός με τις συσκευές σας!",
    "Go back" : "Επιστροφή",
    "Views" : "Προβολές",
    "Files settings" : "Ρυθμίσεις αρχείων",
    "Your files" : "Τα αρχεία σας",
    "Open in files" : "Άνοιγμα στα αρχεία",
    "File cannot be accessed" : "Δεν είναι δυνατή η πρόσβαση στο αρχείο",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Το αρχείο δεν βρέθηκε ή δεν έχετε δικαιώματα προβολής του. Ζητήστε από τον αποστολέα να το μοιράσει.",
    "Clipboard is not available" : "Το πρόχειρο δεν είναι διαθέσιμο",
    "General" : "Γενικά",
    "All files" : "Όλα τα αρχεία",
    "Personal files" : "Προσωπικά αρχεία",
    "Sort favorites first" : "Ταξινόμηση των αγαπημένων πρώτα",
    "Sort folders before files" : "Ταξινόμηση φακέλων πριν από τα αρχεία",
    "Appearance" : "Εμφάνιση",
    "Show hidden files" : "Εμφάνιση κρυφών αρχείων",
    "Crop image previews" : "Περικοπή προεπισκόπησης εικόνας",
    "Additional settings" : "Επιπρόσθετες ρυθμίσεις",
    "WebDAV" : "WebDAV",
    "Copy" : "Αντιγραφή",
    "Keyboard shortcuts" : "Συντομεύσεις πληκτρολογίου",
    "File actions" : "Ενέργειες αρχείου",
    "Rename" : "Μετονομασία",
    "Delete" : "Διαγραφή",
    "Manage tags" : "Διαχείριση ετικετών",
    "Selection" : "Επιλογή",
    "Deselect all" : "Αναίρεση επιλογής όλων",
    "Navigation" : "Πλοήγηση",
    "View" : "Προβολή",
    "Toggle grid view" : "Εναλλαγή σε προβολή πλέγματος",
    "You" : "Εσύ",
    "Error while loading the file data" : "Σφάλμα κατά την φόρτωση αρχείου δεδομένων",
    "Owner" : "Κάτοχος",
    "Remove from favorites" : "Αφαίρεση από τα αγαπημένα",
    "Add to favorites" : "Προσθήκη στα αγαπημένα",
    "Tags" : "Ετικέτες",
    "Blank" : "Κενό",
    "Unable to create new file from template" : "Δεν είναι δυνατή η δημιουργία νέου αρχείου από το πρότυπο",
    "Pick a template for {name}" : "Επιλέξτε ένα πρότυπο για {name}",
    "Create a new file with the selected template" : "Δημιουργήστε ένα νέο αρχείο με το επιλεγμένο πρότυπο",
    "Creating file" : "Δημιουργία αρχείου",
    "Leave this share" : "Αποχώρηση από αυτό το κοινόχρηστο",
    "Leave these shares" : "Αποχώρηση από αυτά τα κοινόχρηστα",
    "Disconnect storage" : "Αποσύνδεση αποθηκευτικού χώρου",
    "Delete permanently" : "Διαγραφή οριστικά",
    "Delete and unshare" : "Διαγραφή και κατάργηση κοινής χρήσης",
    "Delete file" : "Διαγραφή αρχείου",
    "Delete files" : "Διαγραφή αρχείων",
    "Delete folder" : "Διαγραφή φακέλου",
    "Delete folders" : "Διαγραφή φακέλων",
    "Confirm deletion" : "Επιβεβαίωση διαγραφής",
    "Cancel" : "Ακύρωση",
    "Download" : "Λήψη",
    "Destination is not a folder" : "Ο προορισμός δεν είναι φάκελος",
    "This file/folder is already in that directory" : "Αυτό το αρχείο/φάκελος βρίσκεται ήδη σε αυτόν τον κατάλογο",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Δεν μπορείτε να μετακινήσετε ένα αρχείο/φάκελο στον εαυτό του ή σε έναν υποφάκελο του ίδιου του φακέλου.",
    "(copy)" : "(αντιγραφή)",
    "(copy %n)" : "(αντιγραφή %n)",
    "A file or folder with that name already exists in this folder" : "Ένα αρχείο ή ένας φάκελος με αυτό το όνομα υπάρχει ήδη σε αυτόν το φάκελο",
    "The files are locked" : "Το αρχεία είναι κλειδωμένα",
    "The file does not exist anymore" : "Το αρχείο δεν υπάρχει πλέον",
    "Choose destination" : "Επιλέξτε προορισμό",
    "Copy to {target}" : "Αντιγραφή σε {target}",
    "Move to {target}" : "Μετακίνηση σε {target}",
    "Move" : "Μετακίνηση",
    "Move or copy operation failed" : "Η λειτουργία μετακίνησης ή αντιγραφής απέτυχε",
    "Move or copy" : "Μετακίνηση ή αντιγραφή",
    "Open folder {displayName}" : "Άνοιγμα φακέλου {displayName}",
    "Open in Files" : "Άνοιγμα στα Αρχεία",
    "Failed to redirect to client" : "Αποτυχία ανακατεύθυνσης στον πελάτη",
    "Details" : "Λεπτομέρειες",
    "View in folder" : "Προβολή στον φάκελο",
    "Today" : "Σήμερα",
    "Last 7 days" : "Τελευταίες 7 ημέρες",
    "Last 30 days" : "Τελευταίες 30 ημέρες",
    "This year ({year})" : "Αυτό το έτος ({year})",
    "Last year ({year})" : "Το περασμένο έτος ({year})",
    "Documents" : "Έγγραφα",
    "Presentations" : "Παρουσιάσεις",
    "Audio" : "Ήχος",
    "Images" : "Εικόνες",
    "Videos" : "Βίντεο",
    "Created new folder \"{name}\"" : "Δημιουργήθηκε νέος φάκελος \"{name}\"",
    "Unable to initialize the templates directory" : "Δεν είναι δυνατή η προετοιμασία του καταλόγου προτύπων",
    "Templates" : "Πρότυπα",
    "In folder" : "Σε φάκελο",
    "Search in folder: {folder}" : "Αναζήτηση στον φάκελο: {folder}",
    "One of the dropped files could not be processed" : "Ένα από τα αρχεία που ελήφθησαν δεν μπόρεσε να επεξεργαστεί",
    "Some files could not be uploaded" : "Μερικά αρχεία δεν μπόρεσαν να μεταφορτωθούν",
    "Files uploaded successfully" : "Τα αρχεία μεταφορτώθηκαν επιτυχώς",
    "No files to process" : "Δεν υπάρχουν αρχεία προς επεξεργασία",
    "Some files could not be copied" : "Ορισμένα αρχεία δεν μπόρεσαν να αντιγραφούν",
    "Some files could not be moved" : "Αδυναμία μετακίνησης μερικών αρχείων",
    "Files copied successfully" : "Τα αρχεία αντιγράφηκαν επιτυχώς",
    "Files moved successfully" : "Τα αρχεία μετακινήθηκαν επιτυχώς",
    "Upload cancelled" : "Η μεταφόρτωση ακυρώθηκε",
    "Could not rename \"{oldName}\", it does not exist any more" : "Δεν ήταν δυνατή η μετονομασία του \"{oldName}\", δεν υπάρχει πλέον",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Το όνομα \"{newName}\" χρησιμοποιείται ήδη στον φάκελο \"{dir}\". Παρακαλώ επιλέξτε ένα διαφορετικό όνομα.",
    "Could not rename \"{oldName}\"" : "Δεν ήταν δυνατή η μετονομασία του \"{oldName}\"",
    "This operation is forbidden" : "Αυτή η λειτουργία απαγορεύεται",
    "Storage is temporarily not available" : "Μη διαθέσιμος χώρος αποθήκευσης προσωρινά",
    "_%n file_::_%n files_" : ["%n αρχείο","%n αρχεία"],
    "_%n folder_::_%n folders_" : ["%n φάκελος","%n φάκελοι"],
    "Filename must not be empty." : "Το όνομα αρχείου δεν πρέπει να είναι κενό.",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\" δεν επιτρέπεται μέσα σε όνομα αρχείου.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" είναι δεσμευμένο όνομα και δεν επιτρέπεται για ονόματα αρχείων.",
    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" δεν είναι επιτρεπτός τύπος αρχείου.",
    "Filenames must not end with \"{extension}\"." : "Τα ονόματα αρχείων δεν πρέπει να τελειώνουν με \"{extension}\".",
    "No favorites yet" : "Κανένα αγαπημένο ακόμα",
    "Files and folders you mark as favorite will show up here" : "Τα αρχεία και οι φάκελοι που σημειώνονται ως αγαπημένα θα εμφανιστούν εδώ",
    "List of your files and folders." : "Λίστα των αρχείων και φακέλων σας.",
    "List of your files and folders that are not shared." : "Λίστα αρχείων και φακέλων που δεν είναι κοινόχρηστα.",
    "No personal files found" : "Δε βρέθηκαν προσωπικά αρχεία",
    "Files that are not shared will show up here." : "Τα αρχεία που δεν είναι κοινόχρηστα θα εμφανίζονται εδώ.",
    "Recent" : "Πρόσφατα",
    "List of recently modified files and folders." : "Λίστα των πρόσφατα τροποποιημένων αρχείων και φακέλων.",
    "No recently modified files" : "Δεν υπάρχουν πρόσφατα τροποποιημένα αρχεία",
    "Files and folders you recently modified will show up here." : "Εδώ θα εμφανίζονται τα αρχεία και οι φάκελοι που τροποποιήσατε πρόσφατα.",
    "Search" : "Αναζήτηση",
    "No entries found in this folder" : "Δεν βρέθηκαν καταχωρήσεις σε αυτόν το φάκελο",
    "Select all" : "Επιλογή όλων",
    "Upload too large" : "Πολύ μεγάλο αρχείο προς μεταφόρτωση",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Τα αρχεία που προσπαθείτε να μεταφορτώσετε υπερβαίνουν το μέγιστο μέγεθος μεταφόρτωσης αρχείων σε αυτόν τον διακομιστή.",
    "File could not be found" : "Δεν μπορεί να βρεθεί το αρχείο",
    "Show list view" : "Προβολή λίστας",
    "Show grid view" : "Προβολή πλέγματος",
    "Close" : "Κλείσιμο",
    "Could not create folder \"{dir}\"" : "Αδυναμία δημιουργίας του φακέλου \"{dir}\"",
    "This will stop your current uploads." : "Αυτό θα σταματήσει τις τρέχουσες μεταφορτώσεις.",
    "Upload cancelled." : "Η μεταφόρτωση ακυρώθηκε.",
    "Processing files …" : "Γίνεται επεξεργασία των αρχείων …",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Αδυναμία φόρτωσης {filename} καθώς είναι κατάλογος ή έχει 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Δεν υπάρχει αρκετός ελεύθερος χώρος, μεταφορτώνεται {size1} αλλά υπάρχει χώρος μόνο για {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Ο φάκελος προορισμού \"{dir}\" δεν υπάρχει πλέον",
    "An unknown error has occurred" : "Προέκυψε άγνωστο σφάλμα.",
    "File could not be uploaded" : "Δεν ήταν δυνατή η μεταφόρτωση του αρχείου",
    "Uploading …" : "Μεταφόρτωση σε εξέλιξη ...",
    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
    "Uploading … ({currentNumber}/{total})" : "Μεταφόρτωση … ({currentNumber}/{total})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} από {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Η μεταφόρτωση αυτού του αντικειμένου δεν υποστηρίζεται",
    "Error when assembling chunks, status code {status}" : "Σφάλμα κατά την συλλογή τμημάτων, κωδικός κατάστασης {status}",
    "Choose target folder" : "Επιλογή φακέλου προορισμού",
    "Set reminder" : "Προσθήκη υπενθύμισης",
    "Edit locally" : "Επεξεργασία τοπικά",
    "Open" : "Άνοιγμα",
    "Could not load info for file \"{file}\"" : "Αδυναμία φόρτωσης πληροφοριών για το αρχείο \"{file}\"",
    "Please select tag(s) to add to the selection" : "Επιλέξτε ετικέτα (ες) για προσθήκη στην επιλογή",
    "Apply tag(s) to selection" : "Εφαρμογή ετικετών στην επιλογή",
    "Select directory \"{dirName}\"" : "Επιλέξτε κατάλογο \"{dirName}\"",
    "Select file \"{fileName}\"" : "Επιλέξτε αρχείο \"{fileName}\"",
    "Unable to determine date" : "Αδυναμία προσδιορισμού ημερομηνίας",
    "This directory is unavailable, please check the logs or contact the administrator" : "Ο κατάλογος δεν είναι διαθέσιμος, παρακαλούμε ελέγξτε τα αρχεία καταγραφής ή επικοινωνήστε με το διαχειριστή",
    "Could not move \"{file}\", target exists" : "Αδυναμία μετακίνησης του \"{file}\", υπάρχει ήδη αρχείο με αυτό το όνομα",
    "Could not move \"{file}\"" : "Αδυναμία μετακίνησης του \"{file}\"",
    "copy" : "αντιγραφή",
    "Could not copy \"{file}\", target exists" : "Αδυναμία αντιγραφής του \"{file}\", υπάρχει ήδη.",
    "Could not copy \"{file}\"" : "Αδυναμία αντιγραφής του \"{file}\"",
    "Copied {origin} inside {destination}" : "Αντιγράφτηκε το {origin} στο {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Αντιγράφτηκε το {origin} και {nbfiles} άλλα αρχεία στο {destination}",
    "{newName} already exists" : "Το {newName} υπάρχει ήδη",
    "Could not create file \"{file}\"" : "Αδυναμία δημιουργίας του αρχείου \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Αδυναμία δημιουργίας του αρχείου \"{file}\" επειδή υπάρχει ήδη",
    "Could not create folder \"{dir}\" because it already exists" : "Αδυναμία δημιουργίας του φακέλου \"{dir}\" επειδή υπάρχει ήδη",
    "Could not fetch file details \"{file}\"" : "Δεν είναι δυνατή η ανάγνωση λεπτομερειών του αρχείου \"{file}\"",
    "Error deleting file \"{fileName}\"." : "Σφάλμα διαγραφής του \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Κανένα αποτέλεσμα αναζήτησης σε άλλους φακέλους για {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Εισαγάγετε περισσότερους από δύο χαρακτήρες για αναζήτηση σε άλλους φακέλους",
    "{dirs} and {files}" : "{dirs} και {files}",
    "_including %n hidden_::_including %n hidden_" : ["περιλαμβάνεται %n κρυφό","περιλαμβάνονται %n κρυφά"],
    "You do not have permission to upload or create files here" : "Δεν έχετε δικαιώματα μεταφόρτωσης ή δημιουργίας αρχείων εδώ",
    "_Uploading %n file_::_Uploading %n files_" : ["Μεταφόρτωση %n αρχείου","Μεταφόρτωση %n αρχείων"],
    "New" : "Νέα",
    "New file/folder menu" : "Μενού νέου αρχείου/φακέλου",
    "Select file range" : "Επιλέξτε εύρος αρχείων",
    "{used}%" : "{used}%",
    "{used} used" : "Σε χρήση {used}",
    "\"{name}\" is an invalid file name." : "Το \"{name}\" δεν είναι έγκυρο όνομα αρχείου.",
    "File name cannot be empty." : "Το όνομα αρχείου δεν μπορεί να είναι κενό.",
    "\"/\" is not allowed inside a file name." : "Το \"/\" δεν είναι επιτρεπτό εντός του ονόματος αρχείου.",
    "\"{name}\" is not an allowed filetype" : "Το \"{name}\" δεν είναι ένας επιτρεπτός τύπος αρχείου",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Ο αποθηκευτικός χώρος του/της {owner} είναι πλήρης, τα αρχεία δεν μπορούν να ενημερωθούν ή να συγχρονιστούν πλέον!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Ο φάκελος της ομάδας \"{mountPoint}\" είναι πλήρης, τα αρχεία δεν μπορούν να ενημερωθούν ή να συγχρονιστούν πλέον!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Ο εξωτερικός χώρος αποθήκευσης \"{mountPoint}\" είναι πλήρης, τα αρχεία δεν μπορούν να ενημερωθούν ή να συγχρονιστούν πλέον!",
    "Your storage is full, files cannot be updated or synced anymore!" : "Ο αποθηκευτικός σας χώρος είναι πλήρης, τα αρχεία δεν μπορούν να ενημερωθούν ή να συγχρονιστούν πλέον!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Ο αποθηκευτικός χώρος του {owner} είναι σχεδόν γεμάτος ({usedSpacePercent}%)",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Ο φάκελος ομάδας \"{mountPoint}\" είναι σχεδόν πλήρης ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Ο εξωτερικός χώρος αποθήκευσης \"{mountPoint}\" είναι σχεδόν πλήρης ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Ο αποθηκευτικός σας χώρος είναι σχεδόν γεμάτος ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["Ταιριάζει \"{filter}\"","Ταιριάζουν \"{filter}\""],
    "Direct link was copied (only works for people who have access to this file/folder)" : "Ο άμεσος σύνδεσμος αντιγράφηκε (λειτουργεί μόνο για άτομα που έχουν πρόσβαση σε αυτό το αρχείο/φάκελο)",
    "Path" : "Διαδρομή",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Copy direct link (only works for people who have access to this file/folder)" : "Αντιγραφή άμεσου συνδέσμου (λειτουργεί μόνο για άτομα που έχουν πρόσβαση στο αρχείο/φάκελο)",
    "Upload file" : "Μεταφόρτωση αρχείου",
    "An error occurred while trying to update the tags" : "Ένα σφάλμα προέκυψε κατά τη διάρκεια ενημέρωσης των ετικετών",
    "Upload (max. %s)" : "Μεταφόρτωση (max. %s)",
    "\"{displayName}\" action executed successfully" : "Η ενέργεια του/της \"{displayName}\" εκτελέστηκε επιτυχώς",
    "\"{displayName}\" action failed" : "Η ενέργεια του \"{displayName}\" απέτυχε",
    "\"{displayName}\" batch action executed successfully" : "Η μαζική ενέργεια του/της \"{displayName}\" εκτελέστηκε επιτυχώς",
    "Filter filenames…" : "Φιλτράρετε τα ονόματα αρχείων...",
    "WebDAV URL copied to clipboard" : "Ο σύνδεσμος WebDAV αντιγράφηκε στο πρόχειρο",
    "Enable the grid view" : "Ενεργοποίηση της προβολής πλέγματος",
    "Copy to clipboard" : "Αντιγραφή στο πρόχειρο",
    "Use this address to access your Files via WebDAV" : "Χρήση αυτής της διεύθυνση για πρόσβαση στα Αρχεία σας μέσω WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Εάν έχετε ενεργοποιήσει το 2FA, πρέπει να δημιουργήσετε και να χρησιμοποιήσετε έναν νέο κωδικό πρόσβασης εφαρμογής κάνοντας κλικ εδώ.",
    "Deletion cancelled" : "Διαγραφή ακυρώθηκε",
    "Move cancelled" : "Μετακίνηση ακυρώθηκε",
    "Cancelled move or copy operation" : "Ακυρώθηκε η λειτουργία μετακίνησης ή αντιγραφής",
    "Open details" : "Άνοιγμα λεπτομερειών",
    "Photos and images" : "Φωτογραφίες και εικόνες",
    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} φάκελος","{folderCount} φακέλοι"],
    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} αρχείο","{fileCount} αρχεία"],
    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 αρχείο και {folderCount} φάκελος","1 αρχείο και {folderCount} φακέλοι"],
    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} αρχείο και 1 φάκελος","{fileCount} αρχεία και 1 φάκελος"],
    "{fileCount} files and {folderCount} folders" : "{fileCount} αρχεία και {folderCount} φακέλοι",
    "Personal Files" : "Προσωπικά Αρχεία",
    "Text file" : "Αρχείο κειμένου",
    "New text file.txt" : "Νέο αρχείο file.txt"
},
"nplurals=2; plural=(n != 1);");
