OC.L10N.register(
    "photos",
    {
    "Photos" : "Зурагнууд",
    "Videos" : "Бичлэгүүд",
    "Folders" : "Хавтсууд",
    "Favorites" : "Онцолсон",
    "Shared with you" : "тантай хуваалцсан",
    "Tags" : "Tag-үүд",
    "Back" : "буцах",
    "Save" : "Хадгалах",
    "Shared by" : "Хуваалцсан",
    "Favorite" : "Дуртай",
    "Go back" : "Буцах",
    "Home" : "Нүүр",
    "Remove from favorites" : "Remove from favorites",
    "Details" : "Дэлгэрэнгүй",
    "Add" : "нэмэх"
},
"nplurals=2; plural=(n != 1);");
