OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Sık kullanılanlara eklendi",
    "Removed from favorites" : "Sık kullanılanlardan çıkarıldı",
    "You added {file} to your favorites" : "{file} dosyasını sık kullandıklarınıza eklediniz",
    "You removed {file} from your favorites" : "{file} dosyasını sık kullandıklarınızdan çıkardınız",
    "Favorites" : "Sık kullanılanlar",
    "File changes" : "Dosya değişikleri",
    "Created by {user}" : "{user} tarafından eklendi",
    "Changed by {user}" : "{user} tarafından değiştirildi",
    "Deleted by {user}" : "{user} tarafından silindi",
    "Restored by {user}" : "{user} tarafından geri yüklendi",
    "Renamed by {user}" : "{user} tarafından adı değiştirildi",
    "Moved by {user}" : "{user} tarafından taşındı",
    "\"remote account\"" : "\"uzak hesap\"",
    "You created {file}" : "{file} dosyasını eklediniz",
    "You created an encrypted file in {file}" : "{file} içinde şifrelenmiş bir dosya oluşturdunuz",
    "{user} created {file}" : "{user}, {file} dosyasını ekledi",
    "{user} created an encrypted file in {file}" : "{user} kullanıcısı {file} içinde şifrelenmiş bir dosya oluşturdu",
    "{file} was created in a public folder" : "{file} dosyası herkese açık klasör içine eklendi",
    "You changed {file}" : "{file} dosyasını değiştirdiniz",
    "You changed an encrypted file in {file}" : "{file} içindeki şifrelenmiş bir dosyayı değiştirdiniz",
    "{user} changed {file}" : "{user}, {file} dosyasını değiştirdi",
    "{user} changed an encrypted file in {file}" : "{user} kullanıcısı {file} içindeki şifrelenmiş bir dosyayı değiştirdi",
    "You deleted {file}" : "{file} dosyasını sildiniz",
    "You deleted an encrypted file in {file}" : "{file} içindeki şifrelenmiş bir dosyayı sildiniz",
    "{user} deleted {file}" : "{user}, {file} dosyasını sildi",
    "{user} deleted an encrypted file in {file}" : "{user} kullanıcısı {file} içindeki şifrelenmiş bir dosyayı sildi",
    "You restored {file}" : "{file} dosyasını geri yüklediniz",
    "{user} restored {file}" : "{user}, {file} dosyasını geri yükledi",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "{oldfile} (gizli) dosyasını {newfile} (gizli) olarak yeniden adlandırdınız",
    "You renamed {oldfile} (hidden) to {newfile}" : "{oldfile} (gizli) dosyasını {newfile} olarak yeniden adlandırdınız",
    "You renamed {oldfile} to {newfile} (hidden)" : "{oldfile} dosyasını {newfile} (gizli) olarak yeniden adlandırdınız",
    "You renamed {oldfile} to {newfile}" : "{oldfile} dosyasının adını {newfile} olarak değiştirdiniz",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "[user], {oldfile} (gizli) dosyasını {newfile} (gizli) olarak yeniden adlandırdı",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "[user], {oldfile} (gizli) dosyasını {newfile} olarak yeniden adlandırdı",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "[user], {oldfile} dosyasını {newfile} (gizli) olarak yeniden adlandırdı",
    "{user} renamed {oldfile} to {newfile}" : "{user}, {oldfile} dosyasının adını {newfile} olarak değiştirdi",
    "You moved {oldfile} to {newfile}" : "{oldfile} dosyasını {newfile} klasörüne taşıdınız",
    "{user} moved {oldfile} to {newfile}" : "{user}, {oldfile} dosyasının {newfile} dosyasına taşıdı",
    "A file has been added to or removed from your <strong>favorites</strong>" : "<strong>Sık kullandıklarınıza</strong> bir dosya eklendi ya da silindi",
    "Files" : "Dosyalar",
    "A file or folder has been <strong>changed</strong>" : "Bir dosya ya da klasör <strong>değiştirildiğinde</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Sık kullanılan bir dosya ya da klasör <strong>değiştirildiğinde</strong>",
    "Failed to authorize" : "İzin verilemedi",
    "Invalid folder path" : "Klasör yolu geçersiz",
    "Folder not found" : "Klasör bulunamadı",
    "The file cannot be found" : "Dosya bulunamadı",
    "The destination path does not exist: %1$s" : "Hedef yolu bulunamadı: %1$s",
    "You do not have permission to create a file at the specified location" : "Belirtilen konumda bir dosya oluşturma izniniz yok",
    "The file could not be converted." : "Dosya dönüştürülemedi.",
    "Could not get relative path to converted file" : "Dönüştürülen dosyanın yolu göreli yolu alınamadı",
    "Favorite files" : "Sık kullanılan dosyalar",
    "No favorites" : "Sık kullanılan bir öge yok",
    "More favorites" : "Diğer sık kullanılanlar",
    "Accept" : "Kabul et",
    "Reject" : "Reddet",
    "Incoming ownership transfer from {user}" : "{user} kullanıcısından gelen sahiplik aktarımı ",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "{path} yolunu onaylamak istiyor musunuz?\n\nNot: Onay verdikten sonra aktarım işleminin tamamlanması 1 saat kadar sürebilir.",
    "Ownership transfer denied" : "Sahiplik aktarımı reddedildi",
    "Your ownership transfer of {path} was denied by {user}." : "{path} sahipliğini aktarma işleminiz {user} tarafından reddedildi.",
    "Ownership transfer failed" : "Sahiplik aktarılamadı",
    "Your ownership transfer of {path} to {user} failed." : "{path} yolundaki sahipliğiniz {user} kullanıcısına aktarılamadı.",
    "The ownership transfer of {path} from {user} failed." : "{path} yolundaki {user} kullanıcısının sahipliği size aktarılamadı.",
    "Ownership transfer done" : "Sahiplik aktarıldı",
    "Your ownership transfer of {path} to {user} has completed." : "{path} yolundaki sahipliğiniz {user} kullanıcısına aktarıldı.",
    "The ownership transfer of {path} from {user} has completed." : "{path} yolundaki {user} kullanıcısının sahipliği size aktarıldı.",
    "in %s" : "%s içinde",
    "Transferred from %1$s on %2$s" : "%1$s üzerinden %2$s zamanında aktarıldı",
    "Files compatibility" : "Dosyalar uygulaması uyumluluğu",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Dosyaların tüm istemcilerle eşitlenebilmesi için dosya adlarının kısıtlanmasını sağlar. Varsayılan olarak POSIX içinde geçerli olan tüm dosya adlarına (Linux veya macOS) izin verilir.",
    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Windows uyumlu dosya adları açıldıktan sonra, var olan dosyalar artık değiştirilemez. Ancak sahipleri tarafından geçerli yeni adlarla yeniden adlandırılabilir.",
    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Bu ayarı açtıktan sonra dosyaları otomatik olarak da aktarılabilir. Lütfen occ komutuyla ilgili belgelere bakın.",
    "Enforce Windows compatibility" : "Windows uyumluluğu zorunlu kılınsın",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Ayrılmış adlar veya özel karakterler kullanmak gibi Windows sistemlerinde geçerli olmayan dosya adlarını engeller. Ancak büyük/küçük harf duyarlılığı uyumluluğunu zorunlu kılmaz.",
    "File Management" : "Dosya yönetimi",
    "Home" : "Giriş",
    "Target folder does not exist any more" : "Hedef klasör artık yok",
    "Reload current directory" : "Geçerli klasörü yeniden yükle",
    "Go to the \"{dir}\" directory" : "\"{dir}\" klasörüne git",
    "Current directory path" : "Geçerli klasör yolu",
    "Your have used your space quota and cannot upload files anymore" : "Depolama alanınızın tümünü kullandığınız için başka dosya yüklemezsiniz",
    "You do not have permission to upload or create files here." : "Buraya dosya yükleme ya da ekleme izniniz yok.",
    "Drag and drop files here to upload" : "Yüklemek istediğiniz dosyaları sürükleyip buraya bırakın",
    "Favorite" : "Sık kullanılanlara ekle",
    "Back" : "Geri",
    "Toggle selection for file \"{displayName}\"" : "\"{displayName}\" dosyasını seç/bırak",
    "Toggle selection for folder \"{displayName}\"" : "\"{displayName}\" klasörünü seç/bırak",
    "File is loading" : "Dosya yükleniyor",
    "Folder is loading" : "Klasör yükleniyor",
    "Filename" : "Dosya adı",
    "Folder name" : "Klasör adı",
    "This node is unavailable" : "Bu düğüm kullanılamıyor",
    "Another entry with the same name already exists." : "Aynı adlı bir kayıt zaten var.",
    "Invalid filename." : "Dosya adı geçersiz.",
    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" adı \"{newName}\" olarak değiştirildi",
    "Rename file" : "Dosyayı yeniden adlandır",
    "Folder" : "Klasör",
    "Unknown file type" : "Dosya türü bilinmiyor",
    "{ext} image" : "{ext} görsel",
    "{ext} video" : "{ext} görüntü",
    "{ext} audio" : "{ext} ses",
    "{ext} text" : "{ext} metin",
    "Pending" : "Bekliyor",
    "Unknown date" : "Tarih bilinmiyor",
    "Clear filter" : "Süzgeci temizle",
    "Modified" : "Değiştirilme",
    "Search everywhere" : "Her yerde ara",
    "Type" : "Tür",
    "Active filters" : "Etkin süzgeçler",
    "Remove filter" : "Süzgeci kaldır",
    "Total rows summary" : "Toplam satır özeti",
    "Toggle selection for all files and folders" : "Tüm dosyaları ve klasörleri seç/bırak",
    "Name" : "Ad",
    "File type" : "Dosya türü",
    "Size" : "Boyut",
    "Actions" : "İşlemler",
    "(selected)" : "(seçilmiş)",
    "List of files and folders." : "Dosya ve klasörlerin listesi.",
    "You have used your space quota and cannot upload files anymore." : "Depolama alanınızın tümünü kullandığınız için başka dosya yüklemezsiniz.",
    "Column headers with buttons are sortable." : "Düğmeler olan sütunlar sıralanabilir.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Başarımı olumsuz etkilememek için listenin tümü görüntülenmiyor. Listede ilerledikçe dosyalar görüntülenecek.",
    "File not found" : "Dosya bulunamadı",
    "_{count} selected_::_{count} selected_" : ["{count} seçilmiş","{count} seçilmiş"],
    "Search scope options" : "Arama kapsamı seçenekleri",
    "{usedQuotaByte} used" : "{usedQuotaByte} kullanılmış",
    "{used} of {quota} used" : "{used} / {quota} kullanılmış",
    "{relative}% used" : "%{relative} kullanılmış",
    "Could not refresh storage stats" : "Depolama istatistikleri yenilenemedi",
    "Your storage is full, files can not be updated or synced anymore!" : "Boş depolama alanınız kalmadı. Artık dosyalar güncellenmeyecek ya da eşitlenmeyecek!",
    "Storage information" : "Depolama alanı bilgileri",
    "Storage quota" : "Depolama alanı kotası",
    "New folder" : "Yeni klasör",
    "Create new folder" : "Klasör ekle",
    "This name is already in use." : "Bu ad zaten kullanılıyor.",
    "Create" : "Ekle",
    "Files starting with a dot are hidden by default" : "Bir nokta ile başlayan dosyalar varsayılan olarak gizlidir",
    "Fill template fields" : "Kalıp alanlarını doldur",
    "Submitting fields …" : "Alanlar gönderiliyor…",
    "Submit" : "Gönder",
    "Choose a file or folder to transfer" : "Sahipliği aktarılacak bir dosya ya da klasör seçin",
    "Transfer" : "Sahipliği aktar",
    "Transfer {path} to {userid}" : "{path} yolunun sahipliğini {userid} kullanıcısına aktar",
    "Invalid path selected" : "Seçilen yol geçersiz",
    "Unknown error" : "Bilinmeyen sorun",
    "Ownership transfer request sent" : "Sahiplik aktarımı isteği gönderildi",
    "Cannot transfer ownership of a file or folder you do not own" : "Sahibi olmadığınız bir dosya ya da klasörün sahipliğini aktaramazsınız",
    "Transfer ownership of a file or folder" : "Bir dosya ya da klasörün sahipliğini aktarabilirsiniz",
    "Choose file or folder to transfer" : "Sahipliği aktarılacak dosya ya da klasörü seçin",
    "Change" : "Değiştir",
    "New owner" : "Yeni sahip",
    "Keep {old}" : "{old} kalsın",
    "Keep without extension" : "Uzantı olmadan kalsın",
    "Use {new}" : "{new} kullanılsın",
    "Remove extension" : "Uzantıyı kaldır",
    "Change file extension" : "Dosya uzantısını değiştir",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "\"{old}\" dosya uzantısının \"{new}\" olarak değiştirilmesi dosyayı okunamaz yapabilir.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "\"{old}\" dosya uzantısının kaldırılması dosyayı okunamaz yapabilir.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "\"{new}\" dosya uzantısının eklenmesi dosyayı okunamaz yapabilir.",
    "Do not show this dialog again." : "Bu ileti bir daha görüntülenmesin.",
    "Select file or folder to link to" : "Bağlantı verilecek dosya ya da klasörü seçin",
    "Choose {file}" : "{file} seçin",
    "Share" : "Paylaş",
    "Shared by link" : "Bağlantı ile paylaşılmış",
    "Shared" : "Paylaşılan",
    "Switch to list view" : "Liste görünümüne geç",
    "Switch to grid view" : "Tablo görünümüne geç",
    "The file could not be found" : "Dosya bulunamadı",
    "Upload was cancelled by user" : "Kullanıcı yüklemeyi iptal etti",
    "Not enough free space" : "Yeterli boş alan yok",
    "Operation is blocked by access control" : "İşlem erişim denetimi tarafından engellendi",
    "Error during upload: {message}" : "Yükleme sırasında sorun çıktı: {message}",
    "Error during upload, status code {status}" : "Yüklenirken sorun çıktı, durum kodu {status}",
    "Unknown error during upload" : "Yükleme sırasında bilinmeyen bir sorun çıktı",
    "Loading current folder" : "Geçerli klasör yükleniyor",
    "Retry" : "Yeniden dene",
    "No files in here" : "Burada herhangi bir dosya yok",
    "Upload some content or sync with your devices!" : "Bir şeyler yükleyin ya da aygıtlarınızla eşitleyin!",
    "Go back" : "Geri dön",
    "Views" : "Görünümler",
    "Files settings" : "Dosyalar ayarları",
    "Your files" : "Dosyalarınız",
    "Open in files" : "Dosyalar uygulamasında aç",
    "File cannot be accessed" : "Dosyaya erişilemedi",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Dosya bulunamadı ya da görüntüleme izniniz olmayabilir. Gönderenden paylaşmasını isteyin",
    "No search results for “{query}”" : "“{query}” için bir arama sonucu bulunamadı",
    "Search for files" : "Dosya ara",
    "Clipboard is not available" : "Pano kullanılamıyor",
    "General" : "Genel",
    "Default view" : "Varsayılan görünüm",
    "All files" : "Tüm dosyalar",
    "Personal files" : "Kişisel dosyalar",
    "Sort favorites first" : "Sık kullanılanlar üstte sıralansın",
    "Sort folders before files" : "Klasörler dosyaların üzerinde sıralansın",
    "Appearance" : "Görünüm",
    "Show hidden files" : "Gizli dosyaları görüntüle",
    "Show file type column" : "Dosya türü sütunu görüntülensin",
    "Crop image previews" : "Görsel ön izlemeleri kırpılsın",
    "Additional settings" : "Ek ayarlar",
    "WebDAV" : "WebDAV",
    "WebDAV URL" : "WebDAV adresi",
    "Copy" : "Kopyala",
    "Warnings" : "Uyarılar",
    "Keyboard shortcuts" : "Kısayol tuşları",
    "File actions" : "Dosya işlemleri",
    "Rename" : "Yeniden adlandır",
    "Delete" : "Sil",
    "Manage tags" : "Etiket yönetimi",
    "Selection" : "Seçim",
    "Select all files" : "Tüm dosyaları seçer",
    "Deselect all" : "Tümünü bırak",
    "Navigation" : "Gezinme",
    "View" : "Görüntüle",
    "Toggle grid view" : "Tablo görünümünü aç/kapat",
    "Show those shortcuts" : "Bu kısayolları görüntüler",
    "You" : "Siz",
    "Shared multiple times with different people" : "Farklı kişilerle birkaç kez paylaşılmış",
    "Unable to change the favorite state of the file" : "Dosyanın sık kullanılan durumu değiştirilemedi",
    "Error while loading the file data" : "Dosya verileri yüklenirken sorun çıktı",
    "Owner" : "Sahibi",
    "Remove from favorites" : "Sık kullanılanlardan kaldır",
    "Add to favorites" : "Sık kullanılanlara ekle",
    "Tags" : "Etiketler",
    "Blank" : "Boş",
    "Unable to create new file from template" : "Kalıptan yeni dosya eklenemedi",
    "Pick a template for {name}" : "{name} için bir kalıp seçin",
    "Create a new file with the selected template" : "Seçilmiş kalıp ile yeni bir dosya ekle",
    "Creating file" : "Dosya ekleniyor",
    "Save as {displayName}" : "{displayName} olarak kaydet",
    "Save as …" : "Farklı kaydet…",
    "Converting files …" : "Dosyalar dönüştürülüyor…",
    "Failed to convert files: {message}" : "Dosyalar dönüştürülemedi: {message}",
    "All files failed to be converted" : "Tüm dosyalar dönüştürülemedi",
    "One file could not be converted: {message}" : "Bir dosya dönüştürülemedi: {message}",
    "_One file could not be converted_::_%n files could not be converted_" : ["Bir dosya dönüştürülemedi","%n dosya dönüştürülemedi"],
    "_One file successfully converted_::_%n files successfully converted_" : ["Bir dosya dönüştürüldü","%n dosya dönüştürüldü"],
    "Files successfully converted" : "Dosyalar dönüştürüldü",
    "Failed to convert files" : "Dosyalar dönüştürülemedi",
    "Converting file …" : "Dosya dönüştürülüyor…",
    "File successfully converted" : "Dosya dönüştürüldü",
    "Failed to convert file: {message}" : "Dosya dönüştürülemedi: {message}",
    "Failed to convert file" : "Dosya dönüştürülemedi",
    "Leave this share" : "Bu paylaşımdan ayrıl",
    "Leave these shares" : "Bu paylaşımlardan ayrıl",
    "Disconnect storage" : "Depolama bağlantısını kes",
    "Disconnect storages" : "Depolama alanlarının bağlantısını kes",
    "Delete permanently" : "Kalıcı olarak sil",
    "Delete and unshare" : "Sil ve paylaşımdan kaldır",
    "Delete file" : "Dosyayı sil",
    "Delete files" : "Dosyaları sil",
    "Delete folder" : "Klasörü sil",
    "Delete folders" : "Klasörleri sil",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["{count} ögeyi kalıcı olarak silmek üzeresiniz","{count} ögeyi kalıcı olarak silmek üzeresiniz"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["{count} ögeyi silmek üzeresiniz","{count} ögeyi silmek üzeresiniz"],
    "Confirm deletion" : "Silmeyi onaylayın",
    "Cancel" : "İptal",
    "Download" : "İndir",
    "Moving \"{source}\" to \"{destination}\" …" : "\"{source}\", \"{destination}\" hedefine taşınıyor…",
    "Copying \"{source}\" to \"{destination}\" …" : "\"{source}\", \"{destination}\" hedefine kopyalanıyor…",
    "Destination is not a folder" : "Hedef bir klasör değil",
    "This file/folder is already in that directory" : "Dosya ya da klasör bu klasörde zaten var",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Bir dosyayı ya da klasörü kendi üzerine veya kendisinin alt klasörüne taşıyamazsınız",
    "(copy)" : "(kopya)",
    "(copy %n)" : "(%n kopyası)",
    "A file or folder with that name already exists in this folder" : "Bu klasörde aynı adlı bir dosya ya da klasör zaten var",
    "The files are locked" : "Dosyalar kilitli",
    "The file does not exist anymore" : "Dosya artık yok",
    "Choose destination" : "Hedefi seçin",
    "Copy to {target}" : "{target} içine kopyala",
    "Move to {target}" : "{target} içine taşı",
    "Move" : "Taşı",
    "Move or copy operation failed" : "Taşıma ya da kopyalama yapılamadı",
    "Move or copy" : "Taşı ya da kopyala",
    "Open folder {displayName}" : "{displayName} klasörünü aç",
    "Open in Files" : "Dosyalar uygulamasında aç",
    "Open locally" : "Yerel olarak aç",
    "Failed to redirect to client" : "İstemciye yönlendirilemedi",
    "Open file locally" : "Dosyayı yerel olarak aç",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Dosya artık aygıtınızda açılmalıdır. Açılmazsa lütfen bilgisayar uygulamasının kurulu olduğundan emin olun.",
    "Retry and close" : "Yeniden deneyip kapat",
    "Open online" : "Çevrim içi aç",
    "Details" : "Ayrıntılar",
    "View in folder" : "Klasörde görüntüle",
    "Today" : "Bugün",
    "Last 7 days" : "Önceki 7 gün",
    "Last 30 days" : "Önceki 30 gün",
    "This year ({year})" : "Bu yıl ({year})",
    "Last year ({year})" : "Önceki yıl ({year})",
    "Documents" : "Belgeler",
    "Spreadsheets" : "Çalışma sayfaları",
    "Presentations" : "Sunumlar",
    "PDFs" : "PDF dosyaları",
    "Folders" : "Klasörler",
    "Audio" : "Ses",
    "Images" : "Görseller",
    "Videos" : "Görüntüler",
    "Created new folder \"{name}\"" : "\"{name}\" yeni klasörü oluşturuldu",
    "Unable to initialize the templates directory" : "Kalıp klasörü hazırlanamadı",
    "Create templates folder" : "Kalıplar klasörü oluştur",
    "Templates" : "Kalıplar",
    "New template folder" : "Yeni kalıp klasörü",
    "In folder" : "Klasörde",
    "Search in folder: {folder}" : "Şu klasörde ara: {folder}",
    "One of the dropped files could not be processed" : "Bırakılan dosyalardan biri işlenemedi",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Tarayıcınız dosya sistemi API uygulamasını desteklemiyor. Klasörler yüklenemeyecek",
    "No files to upload" : "Yüklenecek bir dosya yok",
    "Unable to create the directory {directory}" : "{directory} klasörü oluşturulamadı",
    "Some files could not be uploaded" : "Bazı dosyalar yüklenemedi",
    "Files uploaded successfully" : "Dosyalar yüklendi",
    "No files to process" : "İşlenecek bir dosya yok",
    "Some files could not be copied" : "Bazı dosyalar kopyalanamadı",
    "Some files could not be moved" : "Bazı dosyalar taşınamadı",
    "Files copied successfully" : "Dosyalar kopyalandı",
    "Files moved successfully" : "Dosyalar taşındı",
    "Conflicts resolution skipped" : "Çakışma çözümleme atlandı",
    "Upload cancelled" : "Yükleme iptal edildi",
    "Could not rename \"{oldName}\", it does not exist any more" : "\"{oldName}\" adı artık olmadığından değiştirilemedi. ",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{newName}\" adı \"{dir}\" klasöründe zaten kullanılmış. Lütfen başka bir ad seçin.",
    "Could not rename \"{oldName}\"" : "\"{oldName}\" adı değiştirilemedi",
    "This operation is forbidden" : "Bu işleme izin verilmiyor",
    "Storage is temporarily not available" : "Depolama geçici olarak kullanılamıyor",
    "Unexpected error: {error}" : "Beklenmeyen bir sorun çıktı: {error}",
    "_%n file_::_%n files_" : ["%n dosya","%n dosya"],
    "_%n folder_::_%n folders_" : ["%n klasör","%n klasör"],
    "_%n hidden_::_%n hidden_" : ["%n gizli","%n gizli"],
    "Filename must not be empty." : "Dosya adı boş olamaz.",
    "\"{char}\" is not allowed inside a filename." : "Dosya adlarında \"{char}\" kullanılamaz.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" ayrılmış bir ad olduğundan dosya adlarında kullanılamaz.",
    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" dosya uzantısına izin verilmiyor.",
    "Filenames must not end with \"{extension}\"." : "Dosya adları \"{extension}\" ile bitemez.",
    "List of favorite files and folders." : "Sık kullanılan dosya ve klasör listesi.",
    "No favorites yet" : "Henüz sık kullanılan bir öge yok",
    "Files and folders you mark as favorite will show up here" : "Sık kullanılanlara eklediğiniz dosya ve klasörler burada görüntülenir",
    "List of your files and folders." : "Dosya ve klasörlerinizin listesi",
    "List of your files and folders that are not shared." : "Paylaşılmayan dosya ve klasörlerinizin listesi.",
    "No personal files found" : "Herhangi bir kişisel dosya bulunamadı",
    "Files that are not shared will show up here." : "Paylaşımayan dosyalar burada görüntülenir.",
    "Recent" : "Son",
    "List of recently modified files and folders." : "Son değiştirilen dosya ve klasörlerin listesi.",
    "No recently modified files" : "Yakınlarda değiştirilmiş bir dosya yok",
    "Files and folders you recently modified will show up here." : "Son zamanlarda değiştirdiğiniz dosya ve klasörler burada görüntülenir.",
    "Search" : "Ara",
    "Search results within your files." : "Dosyalarınızda arama sonuçları.",
    "No entries found in this folder" : "Bu klasörde herhangi bir kayıt bulunamadı",
    "Select all" : "Tümünü seç",
    "Upload too large" : "Yükleme boyutu çok büyük",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Yüklemeye çalıştığınız dosyalar bu sunucuya yüklenmesine izin verilen en büyük dosya boyutunu aşıyor.",
    "File could not be found" : "Dosya bulunamadı",
    "Show list view" : "Liste görünümüne geç",
    "Show grid view" : "Tablo görünümüne geç",
    "Close" : "Kapat",
    "Could not create folder \"{dir}\"" : "\"{dir}\" klasörü oluşturulamadı",
    "This will stop your current uploads." : "Bu işlem geçerli yüklemeleri durduracak.",
    "Upload cancelled." : "Yükleme iptal edildi.",
    "Processing files …" : "Dosyalar işleniyor …",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "{filename} bir klasör ya da 0 bayt boyutunda olduğundan yüklenemedi",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Yeterli boş alan yok. Yüklemek istediğiniz boyut {size1} ancak yalnızca {size2} boş alan var",
    "Target folder \"{dir}\" does not exist any more" : "\"{dir}\" hedef klasörü artık yok",
    "An unknown error has occurred" : "Bilinmeyen bir sorun çıktı",
    "File could not be uploaded" : "Dosya yüklenemedi",
    "Uploading …" : "Yükleniyor …",
    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
    "Uploading … ({currentNumber}/{total})" : "Yükleniyor… ({currentNumber}/{total})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Bu ögenin yüklenmesi desteklenmiyor",
    "Error when assembling chunks, status code {status}" : "Kümeler oluşturulurken sorun çıktı, durum kodu {status}",
    "Choose target folder" : "Hedef klasörü seçin",
    "Set reminder" : "Anımsatıcı ayarla",
    "Edit locally" : "Yerel olarak düzenle",
    "Open" : "Aç",
    "Could not load info for file \"{file}\"" : "\"{file}\" dosyasının bilgileri alınamadı",
    "Please select tag(s) to add to the selection" : "Seçime eklemek için etiketleri seçin",
    "Apply tag(s) to selection" : "Etiketleri seçime uygula",
    "Select directory \"{dirName}\"" : "\"{dirName}\" klasörünü seçin",
    "Select file \"{fileName}\"" : "\"{fileName}\" dosyasını seçin",
    "Unable to determine date" : "Tarih belirlenemedi",
    "This directory is unavailable, please check the logs or contact the administrator" : "Bu klasör yazılabilir değil. Lütfen günlük kayıtlarına bakın ya da BT yöneticiniz ile görüşün",
    "Could not move \"{file}\", target exists" : "\"{file}\" taşınamadı, hedef zaten var",
    "Could not move \"{file}\"" : "\"{file}\" taşınamadı",
    "copy" : "kopya",
    "Could not copy \"{file}\", target exists" : "\"{file}\" dosyası kopyalanamadı, hedef zaten var",
    "Could not copy \"{file}\"" : "\"{file}\" kopyalanamadı",
    "Copied {origin} inside {destination}" : "{origin} dosyası, {destination} içine kopyalandı",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} ve diğer {nbfiles} dosya, {destination} içine kopyalandı",
    "{newName} already exists" : "{newName} zaten var",
    "Could not create file \"{file}\"" : "\"{file}\" dosyası oluşturulamadı",
    "Could not create file \"{file}\" because it already exists" : "\"{file}\" dosyası zaten var olduğundan oluşturulamadı",
    "Could not create folder \"{dir}\" because it already exists" : "\"{dir}\" klasörü zaten var olduğundan oluşturulamadı",
    "Could not fetch file details \"{file}\"" : "\"{file}\" dosyasının ayrıntıları alınamadı",
    "Error deleting file \"{fileName}\"." : "\"{fileName}\" dosyası silinirken sorun çıktı.",
    "No search results in other folders for {tag}{filter}{endtag}" : "{tag}{filter}{endtag} için diğer klasörlerde herhangi bir arama sonucu yok",
    "Enter more than two characters to search in other folders" : "Diğer klasörlerde aramak için iki karakterden fazla yazın",
    "{dirs} and {files}" : "{dirs} ve {files}",
    "_including %n hidden_::_including %n hidden_" : ["%n gizli ile birlikte","%n gizli ile birlikte"],
    "You do not have permission to upload or create files here" : "Buraya dosya yükleme ya da ekleme izniniz yok",
    "_Uploading %n file_::_Uploading %n files_" : ["%n dosya yükleniyor","%n dosya yükleniyor"],
    "New" : "Yeni",
    "New file/folder menu" : "Yeni dosya/klasör menüsü",
    "Select file range" : "Dosya aralığını seçin",
    "{used}%" : "%{used}",
    "{used} used" : "{used} kullanılmış",
    "\"{name}\" is an invalid file name." : "\"{name}\" geçersiz bir dosya adı.",
    "File name cannot be empty." : "Dosya adı boş olamaz.",
    "\"/\" is not allowed inside a file name." : "Dosya adında \"/\" kullanılamaz.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" dosya türüne izin verilmiyor",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "{owner} için boş depolama alanı kalmadı. Artık dosyalar güncellenmeyecek ya da eşitlenmeyecek!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "\"{mountPoint}\" grup klasöründe boş alan kalmadı. Artık güncellenemeyecek ya da eşitlenemeyecek!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "\"{mountPoint}\" dış depolamasında boş alan kalmadı. Artık güncellenemeyecek ya da eşitlenemeyecek!",
    "Your storage is full, files cannot be updated or synced anymore!" : "Boş depolama alanınız kalmadı. Artık dosyalar güncellenmeyecek ya da eşitlenmeyecek!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "{owner} boş depolama alanı bitmek üzere ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "\"{mountPoint}\" grup klasöründeki boş alan bitmek üzere ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "\"{mountPoint}\" dış depolamasındaki boş alan bitmek üzere ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Boş depolama alanınız bitmek üzere ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["\"{filter}\" ile eşleşiyor","\"{filter}\" ile eşleşiyor"],
    "Direct link was copied (only works for people who have access to this file/folder)" : "Doğrudan bağlantı kopyalandı (yalnızca bu dosya ya da klasöre erişim izni olan kişiler kullanabilir)",
    "Path" : "Yol",
    "_%n byte_::_%n bytes_" : ["%n bayt","%n bayt"],
    "Favored" : "Sık kullanılanlara eklenmiş",
    "Favor" : "Sık kullanılanlara ekle",
    "Copy direct link (only works for people who have access to this file/folder)" : "Doğrudan bağlantıyı kopyala (yalnızca bu dosya ya da klasöre erişim izni olan kişiler için)",
    "Upload file" : "Dosya yükle",
    "Not favored" : "Sık kullanılanlara eklenmemiş",
    "An error occurred while trying to update the tags" : "Etiketler güncellenirken bir sorun çıktı",
    "Upload (max. %s)" : "Yükle (en büyük: %s)",
    "\"{displayName}\" action executed successfully" : "\"{displayName}\" işlemi tamamlandı",
    "\"{displayName}\" action failed" : "\"{displayName}\" işlemi tamamlanamadı",
    "\"{displayName}\" failed on some elements" : "\"{displayName}\" bazı bileşenlerde tamamlanamadı",
    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" toplu işlemi tamamlandı",
    "Submitting fields…" : "Alanlar gönderiliyor…",
    "Filter filenames…" : "Dosya adlarını süz…",
    "WebDAV URL copied to clipboard" : "WebDAV adresi panoya kopyalandı",
    "Enable the grid view" : "Tablo görünümü kullanılsın",
    "Enable folder tree" : "Klasör ağacını aç",
    "Copy to clipboard" : "Panoya kopyala",
    "Use this address to access your Files via WebDAV" : "Dosyalarınıza WebDAV üzerinden erişmek için bu adresi kullanın",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "İki adımlı doğrulamayı açtıysanız buraya tıklayarak yeni bir uygulama parolası oluşturmalısınız.",
    "Deletion cancelled" : "Silme iptal edildi",
    "Move cancelled" : "Taşıma iptal edildi",
    "Cancelled move or copy of \"{filename}\"." : "\"{filename}\" dosyasını taşıma ya da kopyalama işlemi iptal edildi",
    "Cancelled move or copy operation" : "Taşıma ya da kopyalama işlemi iptal edildi",
    "Open details" : "Ayrıntıları aç",
    "Photos and images" : "Fotoğraflar ve görseller",
    "New folder creation cancelled" : "Yeni klasör oluşturma işlemi iptal edildi",
    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} klasör","{folderCount} klasör"],
    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} dosya","{fileCount} dosya"],
    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 dosya ve {folderCount} klasör","1 dosya ve {folderCount} klasör"],
    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} dosya ve 1 klasör","{fileCount} dosya ve 1 klasör"],
    "{fileCount} files and {folderCount} folders" : "{fileCount} dosya ve {folderCount} klasör",
    "All folders" : "Tüm klasörler",
    "Personal Files" : "Kişisel dosyalar",
    "Text file" : "Metin dosyası",
    "New text file.txt" : "Yeni metin dosyası.txt",
    "%1$s (renamed)" : "%1$s (yeniden adlandırıldı)",
    "renamed file" : "dosyayı yeniden adlandırdı",
    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Windows uyumlu dosya adları açıldıktan sonra, var olan dosyalar artık değiştirilemez. Ancak sahipleri tarafından geçerli yeni adlarla yeniden adlandırılabilir.",
    "Filter file names …" : "Dosya adlarını süz…",
    "Prevent warning dialogs from open or reenable them." : "Uyarı pencerelerinin görüntülenmesini açın ya da kapatın.",
    "Show a warning dialog when changing a file extension." : "Dosya uzantısı değiştirilirken uyarı penceresi görüntülensin.",
    "Speed up your Files experience with these quick shortcuts." : "Şu kısayol tuşlarını kullanarak Dosyalar deneyiminizi hızlandırabilirsiniz.",
    "Open the actions menu for a file" : "Bir dosyanın işlemler menüsünü açar",
    "Rename a file" : "Bir dosyayı yeniden adlandırır",
    "Delete a file" : "Bir dosyayı siler",
    "Favorite or remove a file from favorites" : "Bir dosyayı sık kullanılanlara ekler ya da kaldırır",
    "Manage tags for a file" : "Bir dosyanın etiketlerini yönetir",
    "Deselect all files" : "Tüm dosyaları bırakır",
    "Select or deselect a file" : "Bir dosyayı seçer ya da bırakır",
    "Select a range of files" : "Bir dosya grubunu seçer",
    "Navigate to the parent folder" : "Üst klasöre gider",
    "Navigate to the file above" : "Üstteki dosyaya gider",
    "Navigate to the file below" : "Aşağıdaki dosyaya gider",
    "Navigate to the file on the left (in grid mode)" : "Soldaki dosyaya gider (ızgara görünümünde)",
    "Navigate to the file on the right (in grid mode)" : "Sağdaki dosyaya gider (ızgara görünümünde)",
    "Toggle the grid view" : "Izgara görünümünü açar ya da kapatır",
    "Open the sidebar for a file" : "Bir dosyanın kenar çubuğunu açar"
},
"nplurals=2; plural=(n > 1);");
