OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Info o CPU nie je dostupné",
    "CPU Usage:" : "Využitie CPU:",
    "Load average: {percentage} % ({load}) last minute" : "Priemerné zaťaženie: {percentage} % ({load})za poslednú minútu",
    "{lastMinutePercentage} % ({lastMinute}) last Minute\n{last5MinutesPercentage} % ({last5Minutes}) last 5 Minutes\n{last15MinutesPercentage} % ({last15Minutes}) last 15 Minutes" : "{lastMinutePercentage}% ({lastMinute}) za poslednú minútu\n{last5MinutesPercentage} % ({last5Minutes}) za posledných 5 minút\n{last15MinutesPercentage} % ({last15Minutes}) za posledných 15 minút",
    "RAM Usage:" : "Využitie RAM:",
    "SWAP Usage:" : "Využitie SWAPu:",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Celkom: {memTotalBytes}/Využité: {memUsageBytes}",
    "RAM info not available" : "Informácia o RAM nie je prístupná",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Celkom: {swapTotalBytes}/Využité: {swapUsageBytes}",
    "SWAP info not available" : "Informácia o SWAPe nie je prístupná",
    "Copied!" : "Skopírované!",
    "Not supported!" : "Nepodporované!",
    "Press ⌘-C to copy." : "Pre kopírovanie, stlačte ⌘-C.",
    "Press Ctrl-C to copy." : "Pre kopírovanie, stlačte Ctrl-C.",
    "System" : "Systém",
    "Monitoring" : "Sledovanie",
    "Monitoring app with useful server information" : "Monitorovacia apka s užitočnými informáciami o serveri",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Poskytuje užitočné informácie o serveri, ako napríklad vyťaženie CPU, RAM, využitie diskov, počet používateľov, atď.",
    "Operating System:" : "Operačný systém:",
    "CPU:" : "CPU:",
    "Memory:" : "Pamäť:",
    "Server time:" : "Čas na serveri:",
    "Uptime:" : "Doba behu:",
    "Temperature" : "Teplota",
    "Load" : "Záťaž",
    "Memory" : "Pamäť",
    "Disk" : "Disk",
    "Mount:" : "Prípojný bod:",
    "Filesystem:" : "Súborový systém:",
    "Size:" : "Veľkosť:",
    "Available:" : "Dostupné:",
    "Used:" : "Využité:",
    "Files:" : "Súbory:",
    "Storages:" : "Úložiská:",
    "Free Space:" : "Voľné miesto:",
    "Network" : "Sieť",
    "Hostname:" : "Názov servera:",
    "Gateway:" : "Brána:",
    "Status:" : "Stav:",
    "Speed:" : "Rýchlosť:",
    "Duplex:" : "Duplex:",
    "MAC:" : "MAC adresa:",
    "IPv4:" : "Adresa IPv4:",
    "IPv6:" : "Adresa IPv6:",
    "Active users" : "Aktívni používatelia",
    "Last hour" : "Posledná hodina",
    "%s%% of all users" : "%s%% všetkých používateľov",
    "Last 24 Hours" : "Posledných 24 hodín",
    "Last 7 Days" : "Posledných 7 dní",
    "Last 30 Days" : "Posledných 30 dní",
    "Shares" : "Sprístupnené položky",
    "Users:" : "Používatelia:",
    "Groups:" : "Skupiny:",
    "Links:" : "Odkazy:",
    "Emails:" : "E-maily:",
    "Federated sent:" : "Združené odoslané:",
    "Federated received:" : "Združené prijaté:",
    "Talk conversations:" : "Talk /Rozhovor/ konverzácia",
    "PHP" : "PHP",
    "Version:" : "Verzia:",
    "Memory limit:" : "Obmedzenie pamäte:",
    "Max execution time:" : "Maximálny čas spustenia:",
    "Upload max size:" : "Maximálna veľkosť pre nahratie:",
    "OPcache Revalidate Frequency:" : "Frekvencia opätovného overenia pamäte OPcache:",
    "Extensions:" : "Rozšírenia:",
    "Unable to list extensions" : "Nepodarilo sa zobraziť rozšírenia",
    "Show phpinfo" : "Zobraziť phpinfo",
    "FPM worker pool" : "Skupina procesov FPM",
    "Pool name:" : "Názov skupiny:",
    "Pool type:" : "Typ skupiny:",
    "Start time:" : "Čas štartu:",
    "Accepted connections:" : "Akceptovať pripojenia:",
    "Total processes:" : "Celkový počet procesov:",
    "Active processes:" : "Aktívne procesy:",
    "Idle processes:" : "Nečinné procesy:",
    "Listen queue:" : "Fronta čakajúca na spojenia:",
    "Slow requests:" : "Pomalé požiadavky:",
    "Max listen queue:" : "Maximálna dĺžka čakajúcej fronty:",
    "Max active processes:" : "Maximálny počet aktívnych procesov:",
    "Max children reached:" : "Maximálny počet podprocesov:",
    "Database" : "Databáza",
    "Type:" : "Typ:",
    "External monitoring tool" : "Externý sledovací nástroj",
    "Use this end point to connect an external monitoring tool:" : "Použite tento prípojný bod pre externý monitorovací nástroj:",
    "Copy" : "Kopírovať",
    "Output in JSON" : "Výstup v JSON",
    "Skip apps section (including apps section will send an external request to the app store)" : "Vynechať sekciu aplikácií ( zahrnutie sekcie aplikácií odošle externú požiadavku do obchodu s aplikáciami)",
    "Skip server update" : "Preskočiť aktualizáciu servera",
    "To use an access token, please generate one then set it using the following command:" : "Pre používanie prístupového tokenu ho vygenerujte a potom ho nastavte použitím nasledujúceho príkazu:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Pri dotazovaní na vyššie uvedenú adresu URL potom poslať token s hlavičkou „NC-Token“.",
    "Unknown Processor" : "Neznámy procesor"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
