OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "마지막 보고서 전송: {on}",
    "An error occurred while sending your report." : "보고서를 보내는 중 오류가 발생했습니다.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "앱 목록<em>(개별 앱의 이름, 버전, 활성화 상태)</em>",
    "Database environment <em>(type, version, database size)</em>" : "데이터베이스 환경<em>(종류, 버전, 데이터베이스 크기)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "암호화 정보<em>(활성화 여부, 기본 모듈)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "공유 개수<em>(형식 및 권한별)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP 환경<em>(버전, 메모리 제한, 최대 실행 시간, 최대 파일 크기)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "서버 인스턴스 정보<em>(버전, memcache 사용, 잠금/미리 보기/아바타 상태)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "통계<em>(파일 개수, 사용자 수, 종류별 저장소 개수, 댓글과 태그 개수)</em>",
    "Usage survey" : "사용량 통계 조사",
    "Help improve Nextcloud" : "Nextcloud 기능 개선 돕기",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Nextcloud 개선을 돕기 위해서 설치 및 사용 통계를 익명으로 전송하시겠습니까? 관리자 설정에서 언제든지 비활성화할 수 있습니다.",
    "Send usage" : "통계 보내기",
    "Not now" : "지금은 하지 않음",
    "Never" : "절대 보내지 않음",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Nextcloud에 익명 사용량 통계를 전송하여 기능 개선을 돕습니다.",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n\t\talways have full control over the content sent to Nextcloud and can disable\n\t\tit again at any time." : "Nextcloud의 개선을 돕기 위해 익명화된 데이터를 Nextcloud에 전송합니다. 귀하는\n\t\t항상 Nextcloud에 전송할 내용에 관한 통제권을 가지고 있으며,\n\t\t언제든 다시 비활성화할 수 있습니다.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Nextcloud 개선을 돕기 위해서 설치 및 사용 통계를 익명으로 전송할 수 있습니다.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. To delete the stored usage data, upload an empty report by unchecking all of the boxes then sending a new report." : "우리는 귀하의 프라이버시를 존중합니다. 데이터 전송은 기본적으로 비활성화되어 있으며, 귀하께서 기능을 켜시면, 가장 먼저 익명화를 거치고, 어떤 내용을 공유해주실 것인지를 직접 선택할 수 있도록 옵션을 제공할 것입니다. 보고서를 수신하면, 이전의 보고서는 삭제됩니다. 그러므로 모든 체크박스를 선택 취소한 후 새 보고서, 즉 빈 보고서를 업로드하여 저장된 사용 데이터를 삭제할 수 있습니다.",
    "Send new report now" : "지금 새 보고서 보내기",
    "Send usage survey monthly" : "월별 사용 통계 보내기",
    "Data to send" : "보낼 데이터",
    "Last report sent on: %s" : "마지막 보고서 전송: %s",
    "Last report" : "마지막 보고"
},
"nplurals=1; plural=0;");
