OC.L10N.register(
    "serverinfo",
    {
    "Copied!" : "I kopjuar!",
    "Not supported!" : "Nuk mbështetet!",
    "Press ⌘-C to copy." : "Shtyp ⌘-C për të kopjuar.",
    "Press Ctrl-C to copy." : "Shtyp Ctrl-C për të kopjuar",
    "System" : "Sistem",
    "Monitoring" : "Vëzhgim",
    "Temperature" : "Temperatura",
    "Size:" : "Madhësia:",
    "Files:" : "Skedarët: ",
    "Active users" : "Përdoruesit aktivë",
    "Shares" : "Shpërndarje",
    "Users:" : "Përdoruesit:",
    "PHP" : "PHP",
    "Version:" : "Versioni: ",
    "Upload max size:" : "Ngarkoni madhësinë maksimale: ",
    "Database" : "Databazë",
    "Type:" : "Lloji:",
    "External monitoring tool" : "Mjet i kontrollit të jashtëm",
    "Copy" : "Kopjo"
},
"nplurals=2; plural=(n != 1);");
