OC.L10N.register(
    "files_sharing",
    {
    "File shares" : "Fildelinger",
    "Downloaded via public link" : "Downloaded via et offentligt link",
    "Downloaded by {email}" : "Downloaded af {email}",
    "{file} downloaded via public link" : "{file} downloaded via et offentligt link",
    "{email} downloaded {file}" : "{email} downloadede {file}",
    "Shared with group {group}" : "Delt med gruppe {group}",
    "Removed share for group {group}" : "Fjernede deling med gruppe {group}",
    "{actor} shared with group {group}" : "{actor} delte med gruppe {group}",
    "{actor} removed share for group {group}" : "{actor} fjernede deling fra gruppe {group}",
    "Share for group {group} expired" : "Deling med gruppe {group} udløbet",
    "You shared {file} with group {group}" : "Du delte {file} med gruppe {group}",
    "You removed group {group} from {file}" : "Du fjernede {group} fra {file}",
    "{actor} shared {file} with group {group}" : "{actor} delte {file} med gruppe {group}",
    "{actor} removed group {group} from {file}" : "{actor} fjernede {group} fra {file}",
    "Share for file {file} with group {group} expired" : "Deling af {file} med gruppe {group} udløbet",
    "Shared as public link" : "Delte som offentligt link",
    "Removed public link" : "Fjernede offentlige link",
    "Public link expired" : "Offentligt link er udløbet",
    "{actor} shared as public link" : "{actor} delt som offentligt link",
    "{actor} removed public link" : "{actor} fjernede offentligt link",
    "Public link of {actor} expired" : "Offentligt link fra {actor} udløbet",
    "You shared {file} as public link" : "Du har delt {file} som offentligt link",
    "You removed public link for {file}" : "Du fjernede offentligt link til {file}",
    "Public link expired for {file}" : "Offentligt link til {file} er udløbet",
    "{actor} shared {file} as public link" : "{actor} delte {file} med et offentligt link",
    "{actor} removed public link for {file}" : "{actor} fjernede offentlig link til {file}",
    "Public link of {actor} for {file} expired" : "Offentligt link fra {actor} for {file} er udløbet",
    "{user} accepted the remote share" : "{user} accepterede den afsides deling",
    "{user} declined the remote share" : "{user} afviste den afsides deling",
    "You received a new remote share {file} from {user}" : "Du modtog en ny ekstern deling til {file} fra {user}",
    "{user} accepted the remote share of {file}" : "{user} accepterede den afsides deling af {file}",
    "{user} declined the remote share of {file}" : "{user} afviste den afsides deling af {file}",
    "{user} unshared {file} from you" : " {user} stoppede deling af {file} med dig",
    "Shared with {user}" : "Delt med  {user}",
    "Removed share for {user}" : "Fjernede deling med {user}",
    "You removed yourself" : "Du fjernede dig selv",
    "{actor} removed themselves" : "{actor} fjernede dem selv",
    "{actor} shared with {user}" : "{actor} delte med {user}",
    "{actor} removed share for {user}" : "{actor} fjernede deling med {user}",
    "Shared by {actor}" : "Delt af {actor}",
    "{actor} removed share" : "{actor} fjernede deling",
    "Share for {user} expired" : "Deling med {user} udløbet",
    "Share expired" : "Deling udløbet",
    "You shared {file} with {user}" : "Du delte {file} med gruppe {user}",
    "You removed {user} from {file}" : "Du fjernede {user} fra {file}",
    "You removed yourself from {file}" : "Du fjernede dig selv fra {file}",
    "{actor} removed themselves from {file}" : "{actor} fjernede dem selv fra {file}",
    "{actor} shared {file} with {user}" : "{actor} delte {file} med {user}",
    "{actor} removed {user} from {file}" : "{actor} fjernede {user} fra {file}",
    "{actor} shared {file} with you" : "{actor} delte {file} med dig",
    "{actor} removed you from the share named {file}" : "{actor} fjernede dig fra delingen af {file}",
    "Share for file {file} with {user} expired" : "Deling af {file} med {user} udløbet",
    "Share for file {file} expired" : "Deling af {file} udløbet",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "En fil eller mapper delt vie mail eller offentligt link blev <strong>downloaded</strong>",
    "Files have been <strong>uploaded</strong> to a folder shared by mail or by public link" : "Filer er blevet <strong>uploadet</strong> til en mappe delt via mail eller et offentligt link",
    "A file or folder was shared from <strong>another server</strong>" : "En fil eller mappe blev delt fra <strong>en anden server</strong>",
    "Sharing" : "Deling",
    "A file or folder has been <strong>shared</strong>" : "En fil eller mappe er blevet <strong>delt</strong>",
    "Shared link" : "Delt link",
    "Wrong share ID, share does not exist" : "Forkert DelingsID, deling findes ikke",
    "Could not delete share" : "Kunne ikke slette deling",
    "Please specify a file or folder path" : "Præciser venligst en fil eller mappesti",
    "Wrong path, file/folder does not exist" : "Forkert sti, fil/mappe findes ikke",
    "Could not create share" : "Kunne ikke oprette deling",
    "Please specify a valid account to share with" : "Præciser venligst en gyldig konto at dele med",
    "Group sharing is disabled by the administrator" : "Gruppedeling er deaktiveret af administratoren",
    "Please specify a valid group" : "Angiv en gyldig gruppe",
    "Public link sharing is disabled by the administrator" : "Deling med offentligt link er deaktiveret af administratoren",
    "Please specify a valid email address" : "Angiv venligst en gyldig e-mailadresse",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Deler %s afsendelse af adgangskoden med Nextcloud Snak fejlede, fordi Nextcloud Snak ikke er aktiveret",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "Deling af %1$s mislykkedes fordi backenden ikke tillader delinger fra typen %2$s",
    "Please specify a valid federated account ID" : "Angiv venligst et gyldigt sammenkoblings konto-ID",
    "Please specify a valid federated group ID" : "Angiv venligst et gyldigt sammenkoblings gruppe-ID",
    "You cannot share to a Team if the app is not enabled" : "Du kan ikke dele til et Team, hvis app'en ikke er aktiveret",
    "Please specify a valid team" : "Angiv venligst et gyldigt team",
    "Sharing %s failed because the back end does not support room shares" : "Deling af %s mislykkedes fordi backenden ikke tillader delinger af rumdeling",
    "Sharing %s failed because the back end does not support ScienceMesh shares" : "Kunne ikke dele %s fordi backenden ikke understøtter deling af ScienceMesh",
    "Unknown share type" : "Ukendt deletype",
    "Not a directory" : "Ikke en mappe",
    "Could not lock node" : "Kunne ikke låse node",
    "Public upload is only possible for publicly shared folders" : "Offentligt upload er kun muligt i mapper der er delt offentligt",
    "Share must at least have READ or CREATE permissions" : "Deling skal som minimum have LÆS eller OPRET rettigheder",
    "Share must have READ permission if UPDATE or DELETE permission is set" : "Deling skal have LÆSE rettigheder hvis OPDATER eller SLET rettigheder er sat",
    "Public upload disabled by the administrator" : "Offentlige uploads er slået fra af administratoren",
    "Could not lock path" : "Stien kunne ikke låses",
    "no sharing rights on this item" : "ingen delingsrettigheder på dette element",
    "You are not allowed to edit incoming shares" : "Du har ikke tilladelse til at redigere indkommende delinger",
    "Wrong or no update parameter given" : "Forkert eller manglende opdateringsparameter",
    "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled." : "\"Afsendelse af adgangskoden med Nextcloud Snak\" for at dele en fil eller en mappe fejlede fordi Nextcloud Snak ikke er aktiveret.",
    "Custom share link tokens have been disabled by the administrator" : "Brugerdefinerede delings link token er blevet deaktiverede af administratoren",
    "Tokens must contain at least 1 character and may only contain letters, numbers, or a hyphen" : "Tokens skal indeholde minimum 1 karakter og må kun indeholde bogstaver, tal, eller en bindestreg",
    "Invalid date. Format must be YYYY-MM-DD" : "Ugyldig dato. Formatet skal være ÅÅÅÅ-MM-DD",
    "No sharing rights on this item" : "Ingen delingsrettigheder på dette element",
    "Invalid share attributes provided: \"%s\"" : "Ugyldig delingsattribut angivet: \"%s\"",
    "You are not allowed to send mail notifications" : "Du har ikke tilladelse til at sende mailnotifikationer",
    "No mail notification configured for this share type" : "Ingen mailnotifikation konfigureret for denne delingstype",
    "Wrong password" : "Forkert adgangskode",
    "Error while sending mail notification" : "Fejl under afsendelse af mailnotifikation",
    "Failed to generate a unique token" : "Kunne ikke generere en unikt token",
    "This share does not exist or is no longer available" : "Denne deling eksisterer ikke eller er ikke længere tilgængelig",
    "shared by %s" : "delt af %s",
    "Download" : "Download",
    "Add to your %s" : "Tilføj til din %s",
    "Direct link" : "Direkte link",
    "Share API is disabled" : "Delings-API er slået fra",
    "File sharing" : "Fildeling",
    "Share will expire tomorrow" : "Deling vil udløbe i morgen",
    "Your share of {node} will expire tomorrow" : "Din deling af {node} vil udløbe i morgen",
    "You received {share} as a share by {user}" : "Du modtog {share} som en deling af {user}",
    "You received {share} to group {group} as a share by {user}" : "Du modtog {share} til gruppe {group} som en deling af {user}",
    "Accept" : "Accepter",
    "Decline" : "Afvis",
    "Remember to upload the files to %s" : "Husk at uploade filerne til %s",
    "We would like to kindly remind you that you have not yet uploaded any files to the shared folder." : "Vi vil venligst minde dig om at du endnu ikke har uploadet nogen filer til delingsmappen.",
    "Open \"%s\"" : "Åben \"%s\"",
    "This application enables people to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable people can then share files and folders with other accounts and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other people outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation." : "Denne applikation gør det muligt for folk at dele filer i Nextcloud. Hvis den er aktiveret, så kan administratoren vælge, hvilke grupper der kan dele filer. De relevante personer kan derefter dele filer og mapper med andre konti og grupper i Nextcloud. Hvis administratoren aktiverer delelink-funktionen, kan et eksternt link derudover bruges til at dele filer med andre personer uden for Nextcloud. Administratorer kan også gennemtvinge adgangskoder, udløbsdatoer og aktivere server-til-server-deling via delelinks samt deling fra mobile enheder.\nDeaktivering af funktionen fjerner delte filer og mapper på serveren for alle delingsmodtagere og også på synkroniseringsklienterne og mobilapps. Mere information er tilgængelig i Nextcloud-dokumentationen.",
    "People" : "Personer",
    "Filter accounts" : "Filtrer konti",
    "The request will expire on {date} at midnight and will be password protected." : "Forespørgslen vil udløbe den {date} ved midnat og vil være adgangskodebeskyttet.",
    "The request will expire on {date} at midnight." : "Forespørgslen vil udløbe den {date} ved midnat.",
    "The request will be password protected." : "Forespørgslen vil være adgangskodebeskyttet.",
    "When should the request expire?" : "Hvornår skal forespørgslen udløbe?",
    "Set a submission expiration date" : "Angiv en udløbsdato for indsendelse",
    "Expiration date" : "Udløbsdato",
    "Select a date" : "Vælg en dato",
    "Your administrator has enforced a {count} days expiration policy." : "Din administrator har gennemtvunget en {count} dages udløbspolitik.",
    "What password should be used for the request?" : "Hvilken adgangskode skal anvendes til denne forespørgsel?",
    "Set a password" : "Indstil en adgangskode",
    "Password" : "Kodeord",
    "Enter a valid password" : "Angiv en gyldig adgangskode",
    "Generate a new password" : "Generer en ny adgangskode",
    "Your administrator has enforced a password protection." : "Din administrator har gennemtvunget en adgangskodebeskyttelse",
    "Automatically copying failed, please copy the share link manually" : "Automatisk kopiering fejlede. Kopier venligst delingslinket manuelt",
    "Link copied" : "Link kopieret",
    "Email already added" : "E-mailen er allerede tilføjet",
    "Invalid email address" : "Ugyldig e-mailadresse",
    "_The following email address is not valid: {emails}_::_The following email addresses are not valid: {emails}_" : ["Den følgende e-mailadresse er ikke gldig: {emails}","De følgende e-mailadresser er ikke gyldige: {emails}"],
    "_{count} email address already added_::_{count} email addresses already added_" : ["{count} e-mailadressen er allerede tilføjet","{count} e-mailadressen er allerede tilføjet"],
    "_{count} email address added_::_{count} email addresses added_" : ["{count} e-mailadresse tilføjet","{count} e-mailadresser tilføjet"],
    "You can now share the link below to allow people to upload files to your directory." : "Du kan nu dele linket nedenfor for at tillade folk at uploade filer til din mappe.",
    "Share link" : "Del link",
    "Copy" : "Kopiér",
    "Send link via email" : "Send link via e-mail",
    "Enter an email address or paste a list" : "Angiv en e-mailadresse eller indsæt en liste",
    "Remove email" : "Fjern e-mail",
    "Select a destination" : "Vælg en destination",
    "Select" : "Vælg",
    "What are you requesting?" : "Hvad efterspørger du?",
    "Request subject" : "Forespørgselsemne",
    "Birthday party photos, History assignment…" : "Fødselsdagsfest fotos, historik tildeling...",
    "Where should these files go?" : "Hvor skal disse filer hen?",
    "Upload destination" : "Upload destination",
    "Revert to default" : "Tilbage til standard",
    "The uploaded files are visible only to you unless you choose to share them." : "De uploadede filer er kun synlige for dig med mindre du vælger at dele dem.",
    "Add a note" : "Tilføj en bemærkning",
    "Note for recipient" : "Bemærkning til modtager",
    "Add a note to help people understand what you are requesting." : "Tilføj en bemærkning for at hjælpe folk med at forstå hvad du efterspørger.",
    "You can add links, date or any other information that will help the recipient understand what you are requesting." : "Du kan tilføje links, dato eller enhver anden information som kan hjælpe modtageren til at forstå hvad du efterspørger.",
    "Close" : "Luk",
    "_Send email and close_::_Send {count} emails and close_" : ["Send e-mail og luk","Send {count} e-mails og luk"],
    "Please select a folder, you cannot share the root directory." : "Vælg venligst en mappe. Du kan ikke dele rodmappen.",
    "File request created" : "Filforespørgsel oprettet",
    "_File request created and email sent_::_File request created and {count} emails sent_" : ["Filforespørgsel oprettet og e-mail sendt","Filforespørgsel oprettet og {count} e-mails sendt"],
    "Error creating the share: {errorMessage}" : "Fejl under oprettelse af delingen: {errorMessage}",
    "Error creating the share" : "Fejl ved skabelse af delt drev",
    "Error sending emails: {errorMessage}" : "Fejl under afsendelse af e-mails: {errorMessage}",
    "Error sending emails" : "Fejl under afsendelse af e-mails",
    "Create a file request" : "Opret en filefterspørgsel",
    "Collect files from others even if they do not have an account." : "Indsaml filer fra andre, selvom de ikke har en konto.",
    "To ensure you can receive files, verify you have enough storage available." : "For at sikre at du kan modtage filer, så vær sikker på at du har nok plads tilgængelig.",
    "File request" : "Filforespørgsler",
    "Previous step" : "Forrige trin",
    "Cancel" : "Annuller",
    "Cancel the file request creation" : "Annuller oprettelse af filforespørgslen",
    "Close without sending emails" : "Luk uden at sende e-mails",
    "Continue" : "Videre",
    "Error while toggling options" : "Fejl under skift af indstillinger",
    "Accept shares from other accounts and groups by default" : "Accepter delinger fra andre konti og grupper som standard",
    "Choose a default folder for accepted shares" : "Vælg en standard mappe til accepterede delinger",
    "Invalid path selected" : "Ugyldig sti valgt.",
    "Unknown error" : "Ukendt fejl",
    "Set default folder for accepted shares" : "Angiv standard mappe for accepterede delinger",
    "Reset" : "Nulstil",
    "Reset folder to system default" : "Nulstil mappe til systemstandard",
    "Share Expiration" : "Delings Udløb",
    "group" : "gruppe",
    "conversation" : "samtale",
    "remote" : "ekstern",
    "remote group" : "ekstern gruppe",
    "guest" : "Gæst",
    "by {initiator}" : "af {initiator}",
    "Shared with the group {user} by {owner}" : "Delt med gruppen {user} af {owner}",
    "Shared with the conversation {user} by {owner}" : "Delt med samtalen {user} af {owner}",
    "Shared with {user} by {owner}" : "Delt med {user} af {owner}",
    "Open Sharing Details" : "Åben delingsdetaljer",
    "Added by {initiator}" : "Tilføjet af {initiator}",
    "Via “{folder}”" : "Via “{folder}”",
    "Unshare" : "Fjern deling",
    "Cannot copy, please copy the link manually" : "Kan ikke kopiere, kopier venligst linket manuelt",
    "Copy internal link" : "Kopier internt link",
    "Internal link" : "Internt link",
    "{shareWith} by {initiator}" : "{shareWith} af {initiator}",
    "Shared via link by {initiator}" : "Delt via link af {initiator}",
    "File request ({label})" : "Filforespørgsel ({label})",
    "Mail share ({label})" : "Mail deling ({label})",
    "Share link ({label})" : "Delingslnk ({label})",
    "Mail share" : "Mail deling",
    "Share link ({index})" : "Delingslink ({index})",
    "Create public link" : "Opret offentligt link",
    "Actions for \"{title}\"" : "Handlinger for \"{title}\"",
    "Error, please enter proper password and/or expiration date" : "Fejl, angiv venligst passende adgangskode og/eller udløbsdato",
    "Link share created" : "Linkdeling oprettet",
    "Error while creating the share" : "Fejl under oprettelse af delingen",
    "Please enter the following required information before creating the share" : "Angiv følgende krævede informationer inden oprettelse af delingen",
    "Password protection (enforced)" : "Adgangsbeskyttelse (gennemtvunget)",
    "Password protection" : "Adgangskodebeskyttelse",
    "Enter a password" : "Indtast en adgangskode",
    "Enable link expiration (enforced)" : "Aktiver link udløb (gennemtvunget)",
    "Enable link expiration" : "Aktiver link udøb",
    "Enter expiration date (enforced)" : "Angiv udløbsdato (gennemtvunget)",
    "Enter expiration date" : "Angiv udløbsdato",
    "Create share" : "Opret share",
    "Customize link" : "Brugerdefineret link",
    "Generate QR code" : "Generer QR-kode",
    "Add another link" : "Tilføj et link mere",
    "Create a new share link" : "Opret et nyt delingslink",
    "Quick share options, the current selected is \"{selectedOption}\"" : "Hurtigdelingsmuligheder, de aktuelt valgte er \"{selectedOption}\"",
    "View only" : "Kun visning",
    "Can edit" : "Kan redigere",
    "Custom permissions" : "Brugerdefinerede rettigheder",
    "Resharing is not allowed" : "Gendeling er ikke tilladt",
    "Name or email …" : "Navne eller e-mail ...",
    "Name, email, or Federated Cloud ID …" : "Navn, e-mail, eller sammenkoblings cloud ID …",
    "Searching …" : "Søger ...",
    "No elements found." : "Ingen elementer fundet.",
    "Search everywhere" : "Søg overalt",
    "Guest" : "Gæst",
    "Group" : "Gruppe",
    "Email" : "E-mail",
    "Team" : "Team",
    "Talk conversation" : "Snak samtale",
    "Deck board" : "Opslagstavle",
    "ScienceMesh" : "ScienceMesh",
    "on {server}" : "på {server}",
    "Enter external recipients" : "Angiv eksterne modtagere",
    "Search for internal recipients" : "Søg efter interne modtagere",
    "Note from" : "Bemærkning fra",
    "Note:" : "Bemærkning:",
    "File drop" : "Fil drop",
    "Upload files to {foldername}." : "Upload filer til {foldername}.",
    "By uploading files, you agree to the terms of service." : "Ved at uploade filer, acceptere du servicebetingelserne.",
    "View terms of service" : "Vis servicebetingelser",
    "Terms of service" : "Servicebetingelser",
    "Share with email {email}" : "Del med e-mail {email}",
    "Share with group" : "Del med gruppe",
    "Share in conversation" : "Del i samtale",
    "Share with {user} on remote server {server}" : "Del med {user} på fjernserver {server}",
    "Share with remote group" : "Del med fjerngruppe",
    "Share with guest" : "Del med gæst",
    "Update share" : "Opdater deling",
    "Save share" : "Gem deling",
    "Read" : "Læst",
    "Create" : "Opret",
    "Edit" : "Rediger",
    "Share" : "Del",
    "Delete" : "Slet",
    "Password field cannot be empty" : "Adgangskodefeltet må ikke være tomt",
    "Replace current password" : "Erstat aktuel adgangskode",
    "Failed to generate a new token" : "Kunne ikke generere et nyt token",
    "Allow upload and editing" : "Tillad upload og redigering",
    "Allow editing" : "Tillad redigering",
    "Upload only" : "Kun upload",
    "Advanced settings" : "Avancerede indstillinger",
    "Share label" : "Del label",
    "Share link token" : "Del link token",
    "Set the public share link token to something easy to remember or generate a new token. It is not recommended to use a guessable token for shares which contain sensitive information." : "Sæt det offentlige delingslink til noget der er let at huske eller generer en ny token. Det anbefales ikke at anvende en token der er let at gætte, til delinger som indeholder følsomme informationer.",
    "Generating…" : "Genererer...",
    "Generate new token" : "Generer ny token",
    "Set password" : "Angiv adgangskode",
    "Password expires {passwordExpirationTime}" : "Adgangskode udløber {passwordExpirationTime}",
    "Password expired" : "Adgangskode udløbet",
    "Video verification" : "Video verificering",
    "Expiration date (enforced)" : "Udløbsdato (gennemtvunget)",
    "Set expiration date" : "Angiv udløbsdato",
    "Hide download" : "Skjul download",
    "Allow download and sync" : "Tillad download og synkronisering",
    "Note to recipient" : "Note til modtager",
    "Enter a note for the share recipient" : "Angiv en bermækning til delingsmodtageren",
    "Show files in grid view" : "Vis filer i gittervisning",
    "Delete share" : "Slet deling",
    "Others with access" : "Andre med adgang",
    "No other accounts with access found" : "Ingen andre konti med adgang fundet",
    "Toggle list of others with access to this directory" : "Vis/skjul liste over andre med adgang til denne mappe",
    "Toggle list of others with access to this file" : "Vis/skjul liste over andre med adgang til denne fil",
    "Unable to fetch inherited shares" : "Kan ikke hente nedarvede delinger",
    "Link shares" : "Link delinger",
    "Shares" : "Delinger",
    "Unable to load the shares list" : "Kan ikke indlæse liste med delinger",
    "Expires {relativetime}" : "Udløber {relativetime}",
    "this share just expired." : "denne deling er netop udløbet.",
    "Shared with you by {owner}" : "Delt med dig {owner}",
    "Internal shares" : "Interne delinger",
    "Internal shares explanation" : "Interne delinger forklaring",
    "External shares" : "Eksterne delinger",
    "External shares explanation" : "Eksterne delinger forklaring",
    "Additional shares" : "Yderligere delinger",
    "Additional shares explanation" : "Yderliger delinger forklaring",
    "Link to a file" : "Link til en fil",
    "_Accept share_::_Accept shares_" : ["Accepter deling","Accepter delinger"],
    "Open in Files" : "Vis i filer",
    "_Reject share_::_Reject shares_" : ["Afvis dealing","Afvis delinger"],
    "_Restore share_::_Restore shares_" : ["Genskab delinger","Genskab delinger"],
    "Shared" : "Delt",
    "Shared by {ownerDisplayName}" : "Delt af {ownerDisplayName}",
    "Shared multiple times with different people" : "Delt flere gange med forskellige mennesker",
    "Shared with others" : "Delt med andre",
    "Create file request" : "Opret filforespørgsel",
    "Upload files to {foldername}" : "Upload filer til {foldername}",
    "Public file share" : "Offentlig fildeling",
    "Publicly shared file." : "Offentligt delt fil",
    "No file" : "Ingen fil",
    "The file shared with you will show up here" : "Filen der er delt med dig vil vises her",
    "Public share" : "Offentlig deling",
    "Publicly shared files." : "Offentligt delte filer.",
    "No files" : "Ingen filer",
    "Files and folders shared with you will show up here" : "Filer og mapper delt med dig, vil blive vist her",
    "Overview of shared files." : "Oversigt over delte filer.",
    "No shares" : "Ingen delinger",
    "Files and folders you shared or have been shared with you will show up here" : "Filer og mapper som du delte eller som er blevet delt med dig vil blive vist her",
    "Shared with you" : "Delt med dig",
    "List of files that are shared with you." : "Liste med filer som er delt med dig.",
    "Nothing shared with you yet" : "Der deles ikke noget med dig endnu",
    "Files and folders others shared with you will show up here" : "Filer og mapper som andre har delt med dig, vil blive vist her",
    "List of files that you shared with others." : "Liste med filer som du har delt med andre.",
    "Nothing shared yet" : "Der deles endnu ikke noget",
    "Files and folders you shared will show up here" : "Filer og mapper som du delte vil blive vist her",
    "Shared by link" : "Delt via link",
    "List of files that are shared by link." : "Liste med filer som er delt via link.",
    "No shared links" : "Ingen delte link",
    "Files and folders you shared by link will show up here" : "Filer og mapper som du delte med link vil blive vist her",
    "File requests" : "Filforespørgsler",
    "List of file requests." : "Liste over filforspørgsler.",
    "No file requests" : "Ingen filforespørgsler",
    "File requests you have created will show up here" : "Filforespørgsler som du har oprettet vil vises her",
    "Deleted shares" : "Slettede delinger",
    "List of shares you left." : "Liste med delinger som du forlod.",
    "No deleted shares" : "Ingen slettede delinger",
    "Shares you have left will show up here" : "Delinger som du har forladt vil blive vist her",
    "Pending shares" : "Afventende delinger",
    "List of unapproved shares." : "List over ikke godkendte delinger.",
    "No pending shares" : "Ingen afventende delinger",
    "Shares you have received but not approved will show up here" : "Delinger som du har modtager men ikke godkendt, vil blive vist her",
    "Error updating the share: {errorMessage}" : "Fejl under opdatering af delingen: {errorMessage}",
    "Error updating the share" : "Fejl under opdatering af delingen",
    "File \"{path}\" has been unshared" : "Deling af filen \"{path}\" er blevet fjernet",
    "Folder \"{path}\" has been unshared" : "Deling af mappen \"{path}\" er blevet fjernet",
    "Could not update share" : "Kunne ikke opdatere delingen",
    "Share saved" : "Deling gemt",
    "Share expiry date saved" : "Udløbsdato for deling er gemt",
    "Share hide-download state saved" : "Deling skjul-download tilstand gemt",
    "Share label saved" : "Delingslabel gemt",
    "Share note for recipient saved" : "Delingsbemærkning for modtagere gemt",
    "Share password saved" : "Delingsadgangskode delt",
    "Share permissions saved" : "Delingsrettigheder gemt",
    "Upload files to {folder}" : "Upload filer til {folder}",
    "{ownerDisplayName} shared a folder with you." : "{ownerDisplayName} delte en mappe med dig.",
    "Shared by" : "Delt af",
    "Shared with" : "Delt med",
    "Password created successfully" : "Adgangskode oprettet",
    "Error generating password from password policy" : "Fejl under generering af adgangskode fra adgangskodepolitik",
    "Shared with you and the group {group} by {owner}" : "Delt med dig og grupp {group} af {owner}",
    "Shared with you and {circle} by {owner}" : "Delt med dig og {circle} af {owner}",
    "Shared with you and the conversation {conversation} by {owner}" : "Delt med dig og konversationen {conversation} af {owner}",
    "Shared with you in a conversation by {owner}" : "Delt med dig og konversationen af {owner}",
    "Share not found" : "Delt fil ikke fundet",
    "Back to %s" : "Tilbage til %s",
    "Add to your Nextcloud" : "Tilføj til din Nextcloud",
    "Waiting…" : "Venter …",
    "error" : "fejl",
    "finished" : "Færdiggjort",
    "This will stop your current uploads." : "Dette vil stoppe din nuværende uploads.",
    "Move or copy" : "Flyt eller kopier",
    "You can upload into this folder" : "Du kan overføre til denne mappe",
    "Show list view" : "Vis som liste",
    "Show grid view" : "Vis som gitter",
    "No compatible server found at {remote}" : "Ingen kompatible servere fundet på {remote}",
    "Invalid server URL" : "Ugyldig server adresse",
    "Failed to add the public link to your Nextcloud" : "Fejl ved tilføjelse af offentligt link til din Nextcloud",
    "You are not allowed to edit link shares that you don't own" : "Du har ikke tilladelse til at redigere link delinger som du ikke ejer",
    "Download all files" : "Download alle filer",
    "Link copied to clipboard" : "Link kopieret til udklipsholder",
    "_1 email address already added_::_{count} email addresses already added_" : ["1 e-mailadresse allerede tilføjet","{count} e-mailadresser allerede tilføjet"],
    "_1 email address added_::_{count} email addresses added_" : ["1 e-mailadresse tilføjet","{count} e-mailadresser tilføjet"],
    "Copy to clipboard" : "Kopier til udklipsholder",
    "Copy internal link to clipboard" : "Kopier internt link til klippebord",
    "Only works for people with access to this folder" : "Virker kun for personer med adgang til denne mappe",
    "Only works for people with access to this file" : "Virker kun for personer med adgang til denne fil",
    "Copy public link of \"{title}\" to clipboard" : "Kopier offentligt link af \"{title}\" til udklipsholder",
    "Search globally" : "Søg globalt",
    "Search for share recipients" : "Søge efter delemodtagerefor share recipients",
    "No recommendations. Start typing." : "Ingen anbefalinger. Begynd at skrive.",
    "To upload files, you need to provide your name first." : "For at uploade filer skal du først angive dit navn.",
    "Enter your name" : "Angiv dit navn",
    "Submit name" : "Angiv navn",
    "Share with {userName}" : "Del med {userName}",
    "Show sharing options" : "Vis delingsmuligheder",
    "Share note" : "Del note",
    "Upload files to %s" : "Upload filer til %s",
    "%s shared a folder with you." : "%s delte en mappe med dig.",
    "Note" : "Note",
    "Select or drop files" : "Vælg eller slip filer",
    "Uploading files" : "Uploader filer",
    "Uploaded files:" : "Uploadede filer:",
    "By uploading files, you agree to the %1$sterms of service%2$s." : "Ved at uploade filer accepterer du %1$sservicebetingelserne%2$s.",
    "Name" : "Navn",
    "Use this method to share files with individuals or teams within your organization. If the recipient already has access to the share but cannot locate it, you can send them the internal share link for easy access." : "Anvend denne metode til at dele filer med brugere eller teams indenfor din organisation. Hvis modtageren allerede har adgang til delingen, men ikke kan finde det, så kan du sende det interne delingslink til dem, så de har let adgang",
    "Use this method to share files with individuals or organizations outside your organization. Files and folders can be shared via public share links and email addresses. You can also share to other Nextcloud accounts hosted on different instances using their federated cloud ID." : "Anvend denne metode til at dele filer med brugere eller organisationer udenfor din organisation. Filer og mapper kan deles via offentlige delingslinks og e-mailadresser. Du kan også dele til andre Nextcloud konti der er hostet på andre instanser ved anvendelse af sammenkoblings cloud ID.",
    "Shares that are not part of the internal or external shares. This can be shares from apps or other sources." : "Delinger som ikke er del af de interne eller eksterne delinger. Dette kan være delinger fra apps eller andre kilder.",
    "Share with accounts and teams" : "Deling med konti og teams",
    "Email, federated cloud id" : "E-mail, sammenkoblings cloud id",
    "Filename must not be empty." : "Filnavnet må ikke være tomt."
},
"nplurals=2; plural=(n != 1);");
