OC.L10N.register(
    "files_external",
    {
    "Grant access" : "Bevilja åtkomst",
    "Error configuring OAuth2" : "Misslyckades konfigurera OAuth2",
    "Generate keys" : "Generera nycklar",
    "Error generating key pair" : "Fel vid generering av nyckelpar",
    "You are not logged in" : "Du är inte inloggad",
    "Permission denied" : "Åtkomst nekad",
    "Forbidden to manage local mounts" : "Förbjudet att hantera lokala monteringar",
    "Storage with ID \"%d\" not found" : "Lagringsutrymme med ID \"%d\" hittades inte",
    "Invalid backend or authentication mechanism class" : "Ogiltig backend eller autentiseringsmekanism-klass",
    "Invalid mount point" : "Ogiltig monteringspunkt",
    "Objectstore forbidden" : "Objekt förbjudet",
    "Invalid storage backend \"%s\"" : "Ogiltig lagrings-backend \"%s\"",
    "Not permitted to use backend \"%s\"" : "Inte tillåtet att använda backend \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Inte tillåtet att använda autentiseringsmekanism \"%s\"",
    "Unsatisfied backend parameters" : "Otillfredsställda backend parametrar",
    "Unsatisfied authentication mechanism parameters" : "Otillfredsställda autentiseringsmekanism parametrar",
    "Insufficient data: %s" : "Otillräcklig data: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not editable by non-admins" : "Lagring med ID \"%d\" kan inte redigeras av icke-administratörer",
    "Access key" : "Åtkomstnyckel",
    "Secret key" : "Hemlig nyckel",
    "Builtin" : "Inbyggt",
    "None" : "Ingen",
    "OAuth2" : "OAuth2",
    "Client ID" : "Klient ID",
    "Client secret" : "Klienthemlighet",
    "OpenStack v2" : "OpenStack v2",
    "Login" : "Logga in",
    "Password" : "Lösenord",
    "Tenant name" : "Namn på arrendator",
    "Identity endpoint URL" : "Identitet endpoint-webbadress",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Domän",
    "Rackspace" : "Rackutrymme",
    "API key" : "API-nyckel",
    "Global credentials" : "Globala uppgifter",
    "Log-in credentials, save in database" : "Inloggningsuppgifter sparade i databasen",
    "Login and password" : "Inloggning och lösenord",
    "Log-in credentials, save in session" : "Inloggningsuppgifter, spara i sessionen",
    "Global credentials, manually entered" : "Globala uppgifter, manuellt inmatade",
    "Manually entered, store in database" : "Manuellt inmatad, lagra i databas",
    "RSA public key" : "RSA offentlig nyckel",
    "Public key" : "Offentlig nyckel",
    "RSA private key" : "RSA privat nyckel",
    "Private key" : "Privat nyckel",
    "Kerberos default realm, defaults to \"WORKGROUP\"" : "Kerberos standardområde sätts som standard till \"WORKGROUP\"",
    "Kerberos ticket Apache mode" : "Kerberos-biljett Apache-läge",
    "Kerberos ticket" : "Kerberos-biljett",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Värdnamn",
    "Port" : "Port",
    "Region" : "Län",
    "Storage Class" : "Lagringsklass",
    "Enable SSL" : "Aktivera SSL",
    "Enable Path Style" : "Aktivera Path Style",
    "Legacy (v2) authentication" : "Legacy (v2) autentisering",
    "Enable multipart copy" : "Aktivera flerdelad kopiering",
    "SSE-C encryption key" : "SSE-C krypteringsnyckel",
    "WebDAV" : "WebDAV",
    "URL" : "Webbadress",
    "Remote subfolder" : "Extern undermapp",
    "Secure https://" : "Säker https://",
    "FTP" : "FTP",
    "Host" : "Server",
    "Secure ftps://" : "Säker ftps://",
    "Local" : "Lokal",
    "Location" : "Plats",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP-inloggning med hemlig nyckel",
    "SMB/CIFS" : "SMB/CIFS",
    "Share" : "Dela",
    "Show hidden files" : "Visa dolda filer",
    "Case sensitive file system" : "Skiftlägeskänsligt filsystem",
    "Disabling it will allow to use a case insensitive file system, but comes with a performance penalty" : "Inaktivering gör det möjligt att använda ett skiftlägesokänsligt filsystem, men det kommer att påverka prestandan",
    "Verify ACL access when listing files" : "Verifiera ACL-åtkomst i fil-listningar",
    "Check the ACL's of each file or folder inside a directory to filter out items where the account has no read permissions, comes with a performance penalty" : "Kontrollera ACL:er för varje fil eller mapp inuti en sökväg för att filtrera bort element för vilka användaren saknar läsbehörighet, innebär en viss prestandaminskning",
    "Timeout" : "Timeout",
    "SMB/CIFS using OC login" : "SMB/CIFS med OC-inloggning",
    "Login as share" : "Logga in som delning",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Namn på tjänst",
    "Request timeout (seconds)" : "Sekunder för anslutningsförsök",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "cURL-stödet i PHP är inte aktiverat eller installerat. Montering av %s är inte möjlig. Vänligen be din systemadministratör att installera den.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "FTP-stöd i PHP är inte aktiverat eller har inte installerats. Montering av %s är inte möjlig. Be din systemadministratör om installation.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "\"%1$s\" är inte installerad. Montering av %2$s är inte möjlig. Be din systemadministratör att installera den.",
    "External storage" : "Extern lagring",
    "External storage support" : "Stöd för extern lagring",
    "Adds basic external storage support" : "Lägger till grundläggande stöd för extern lagring",
    "This application enables administrators to configure connections to external storage providers, such as FTP servers, S3 or SWIFT object stores, other Nextcloud servers, WebDAV servers, and more. Administration can choose which types of storage to enable and can mount these storage locations for an account, a group, or the entire system. Users will see a new folder appear in their root Nextcloud directory, which they can access and use like any other Nextcloud folder. External storage also allows people to share files stored in these external locations. In these cases, the credentials for the owner of the file are used when the recipient requests the file from external storage, thereby ensuring that the recipient can access the shared file.\n\nExternal storage can be configured using the GUI or at the command line. This second option provides the administration with more flexibility for configuring bulk external storage mounts and setting mount priorities. More information is available in the external storage GUI documentation and the external storage Configuration File documentation." : "Denna applikation tillåter serveradministratörer konfigurera anslutningar till externa lagringsleverantörer, så som FTP-servrar, S3 eller SWIFT -servrar, andra Nextcloud-servrar, WebDAV-servrar, med flera. Administrationen kan välja vilka typer av lagring som är aktiverade och kan montera dessa lagringsplatser för ett konto, en grupp eller för hela servern. Användare kommer se en ny mapp dyka upp i deras dokument-rot, vilken de kan använda som en vanlig mapp. Extern lagring tillåter också delning av filer lagrade i dessa externa platser. I de fallen används fil-ägarens uppgifter när mottagaren begär filen från den externa lagringen, vilket på så vis garanterar att mottagaren får tillgång till den delade filen.\n\nExtern lagring kan konfigureras genom det grafiska gränssnittet eller kommandoraden. Det sistnämnda alternativet erbjuder administrationen mer flexibilitet vid konfigurering av flertalet lagringsplatser samt monteringsprioriteter. Mer information finns tillgänglig i dokumentationen för användargränssnittet samt för konfigurationsfilen.",
    "Confirm" : "Bekräfta",
    "Storage credentials" : "Uppgifter för lagring",
    "To access the storage, you need to provide the authentication credentials." : "För att komma åt lagringen måste du ange autentiseringsuppgifterna.",
    "Enter the storage login" : "Ange inloggning för lagringen",
    "Enter the storage password" : "Ange lösenord för lagringen",
    "Unable to update this external storage config. {statusMessage}" : "Det gick inte att uppdatera denna externa lagringskonfiguration. {statusMessage}",
    "New configuration successfully saved" : "Ny konfiguration har sparats",
    "Enter missing credentials" : "Ange saknade inloggningsuppgifter",
    "Credentials successfully set" : "Autentiseringsuppgifter har sparats",
    "Error while setting credentials: {error}" : "Fel vid inställning av autentiseringsuppgifter: {error}",
    "Checking storage …" : "Kontrollerar lagring …",
    "There was an error with this external storage." : "Det uppstod ett fel med denna externa lagring.",
    "We were unable to check the external storage {basename}" : "Vi kunde inte kontrollera den externa lagringen {basename}",
    "Examine this faulty external storage configuration" : "Undersök denna felaktiga externa lagringskonfiguration",
    "Open in Files" : "Öppna i Filer",
    "There was an error with this external storage. Do you want to review this mount point config in the settings page?" : "Det uppstod ett fel med denna externa lagring. Vill du granska denna monteringspunktskonfiguration på inställningssidan?",
    "External mount error" : "Fel vid extern montering",
    "List of external storage." : "Lista över extern lagring.",
    "There is no external storage configured. You can configure them in your Personal settings." : "Det finns ingen extern lagring konfigurerad. Du kan konfigurera dem i dina personliga inställningar.",
    "There is no external storage configured and you don't have the permission to configure them." : "Det finns ingen extern lagring konfigurerad och du har inte behörighet att konfigurera dem.",
    "No external storage" : "Ingen extern lagring",
    "Storage type" : "Lagringstyp",
    "Unknown" : "Okänd",
    "Scope" : "Sammanhang",
    "Personal" : "Privat",
    "System" : "System",
    "Type to select account or group." : "Skriv för att välja konto eller grupp.",
    "(Group)" : "(Grupp)",
    "Compatibility with Mac NFD encoding (slow)" : "Kompatibilitet med Mac NFD kodning (slö)",
    "Enable encryption" : "Aktivera kryptering",
    "Enable previews" : "Aktivera förhandsgranskningar",
    "Enable sharing" : "Aktivera delning",
    "Check for changes" : "Sök efter ändringar",
    "Never" : "Aldrig",
    "Once every direct access" : "En gång vid varje direktåtkomst",
    "Read only" : "Skrivskyddad",
    "Disconnect" : "Koppla från",
    "Unknown backend: {backendName}" : "Okänd backend: {backendName}",
    "Admin defined" : "Admin definerad",
    "Automatic status checking is disabled due to the large number of configured storages, click to check status" : "Automatisk statuskontroll är inaktiverad på grund av det stora antalet konfigurerade lagringar, klicka för att kontrollera status",
    "Are you sure you want to disconnect this external storage? It will make the storage unavailable in Nextcloud and will lead to a deletion of these files and folders on any sync client that is currently connected but will not delete any files and folders on the external storage itself." : "Är du säker på att du vill koppla bort den här externa lagringen? Det kommer att göra lagringen otillgänglig i Nextcloud och kommer att leda till en radering av dessa filer och mappar på alla synkroniseringsklienter som för närvarande är anslutna men kommer inte att radera några filer och mappar på den externa lagringen i sig.",
    "Delete storage?" : "Ta bort lagring?",
    "Click to recheck the configuration" : "Klicka för att kontrollera inställningarna igen",
    "Saved" : "Sparad",
    "Saving …" : "Sparar ...",
    "Save" : "Spara",
    "Failed to save global credentials" : "Kunde inte spara globala autentiseringsuppgifter",
    "Failed to save global credentials: {message}" : "Kunde inte spara globala autentiseringsuppgifter: {message}",
    "No external storage configured or you don't have the permission to configure them" : "Ingen extern lagring konfigurerad eller så har du inte behörighet att konfigurera dem",
    "Open documentation" : "Öppna dokumentationen",
    "External storage enables you to mount external storage services and devices as secondary Nextcloud storage devices. You may also allow people to mount their own external storage services." : "Externt lagringsutrymme gör det möjligt att montera externa lagringstjänster och enheter som sekundära Nextcloud-lagringsenheter. Du kan också tillåta användare att montera sina egna externa lagringstjänster.",
    "Folder name" : "Mappnamn",
    "Authentication" : "Autentisering",
    "Configuration" : "Konfiguration",
    "Available for" : "Tillgänglig för",
    "Add storage" : "Lägg till lagring",
    "All people" : "Alla användare",
    "Advanced settings" : "Avancerade inställningar",
    "Allow people to mount external storage" : "Tillåt användare att montera extern lagring",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Globala användaruppgifter kan användas för att autentisera med flera externa lagrings-instanser som använder samma användaruppgifter.",
    "Error configuring OAuth1" : "Misslyckades konfigurera OAuth1",
    "Please provide a valid app key and secret." : "Ange en giltig applikationsnyckel och hemlig fras.",
    "OAuth1" : "OAuth1",
    "App key" : "Appnyckel",
    "App secret" : "Apphemlighet"
},
"nplurals=2; plural=(n != 1);");
