OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalender",
    "Tasks" : "Uppgifter",
    "Personal" : "Privat",
    "{actor} created calendar {calendar}" : "{actor} skapade kalender {calendar}",
    "You created calendar {calendar}" : "Du skapade kalender {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} tog bort kalender {calendar}",
    "You deleted calendar {calendar}" : "Du tog bort kalender {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} uppdaterade kalender {calendar}",
    "You updated calendar {calendar}" : "Du uppdaterade kalender {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} återställde kalender {calendar}",
    "You restored calendar {calendar}" : "Du återställde kalender {calendar}",
    "You shared calendar {calendar} as public link" : "Du delade kalender {calendar} som offentlig länk",
    "You removed public link for calendar {calendar}" : "Du tog bort offentlig länk för kalender {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} delade kalender {calendar} med dig",
    "You shared calendar {calendar} with {user}" : "Du delade kalender {calendar} med {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} delade kalender {calendar} med {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} slutade dela kalender {calendar} med dig",
    "You unshared calendar {calendar} from {user}" : "Du slutade dela kalender {calendar} med {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} slutade dela kalender {calendar} med {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} slutade dela kalender {calendar} med sig själv",
    "You shared calendar {calendar} with group {group}" : "Du delade kalender {calendar} med grupp {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} delade kalender {calendar} med grupp {group}",
    "You unshared calendar {calendar} from group {group}" : "Du slutade dela kalender {calendar} med gruppen {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} slutade dela kalender {calendar} med gruppen {group}",
    "Untitled event" : "Namnlös händelse",
    "{actor} created event {event} in calendar {calendar}" : "{actor} skapade händelse {event} i kalender {calendar}",
    "You created event {event} in calendar {calendar}" : "Du skapade händelse {event} i kalender {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} tog bort händelse {event} från kalender {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Du tog bort händelse {event} från kalender {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} uppdaterade händelse {event} i kalender {calendar}",
    "You updated event {event} in calendar {calendar}" : "Du uppdaterade händelse {event} i kalender {calendar}",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} flyttade händelse {event} från kalender {sourceCalendar} till kalender {targetCalendar}",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Du flyttade händelse {event} från kalender {sourceCalendar} till kalender {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} återställde händelsen {event} i kalendern {calendar}",
    "You restored event {event} of calendar {calendar}" : "Du återställde händelsen {event} i kalendern {calendar}",
    "Busy" : "Upptagen",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} skapade uppgift {todo} i listan {calendar}",
    "You created to-do {todo} in list {calendar}" : "Du skapade uppgift {todo} i listan {calendar}",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} tog bort uppgift {todo} från listan {calendar}",
    "You deleted to-do {todo} from list {calendar}" : "Du tog bort uppgift {todo} från listan {calendar}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} uppdaterade uppgift {todo} i listan {calendar}",
    "You updated to-do {todo} in list {calendar}" : "Du uppdaterade uppgift {todo} i listan {calendar}",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} löste uppgift {todo} i listan {calendar}",
    "You solved to-do {todo} in list {calendar}" : "Du löste uppgift {todo} i listan {calendar}",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} återupptog uppgift {todo} i listan {calendar}",
    "You reopened to-do {todo} in list {calendar}" : "Du återupptog uppgift {todo} i listan {calendar}",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} flyttade uppgift {todo} från lista {sourceCalendar} till lista {targetCalendar}",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Du flyttade uppgift {todo} från lista {sourceCalendar} till lista {targetCalendar}",
    "Calendar, contacts and tasks" : "Kalender, kontakter och uppgifter",
    "A <strong>calendar</strong> was modified" : "En <strong>kalender</strong> ändrades",
    "A calendar <strong>event</strong> was modified" : "En kalender-<strong>händelse</strong> ändrades",
    "A calendar <strong>to-do</strong> was modified" : "En kalender <strong>uppgift</strong> ändrades",
    "Contact birthdays" : "Födelsedagar",
    "Death of %s" : "%ss död ",
    "Untitled calendar" : "Namnlös kalender",
    "Calendar:" : "Kalender:",
    "Date:" : "Datum:",
    "Where:" : "Var:",
    "Description:" : "Beskrivning:",
    "_%n year_::_%n years_" : ["%n år","%n år"],
    "_%n month_::_%n months_" : ["%n månad","%n månader"],
    "_%n day_::_%n days_" : ["%n dag","%n dagar"],
    "_%n hour_::_%n hours_" : ["%n timme","%n timmar"],
    "_%n minute_::_%n minutes_" : ["%n minut","%n minuter"],
    "%s (in %s)" : "%s (på %s)",
    "%s (%s ago)" : "%s (%s sedan)",
    "Calendar: %s" : "Kalender: %s",
    "Date: %s" : "Datum: %s",
    "Description: %s" : "Beskrivning: %s",
    "Where: %s" : "Var: %s",
    "%1$s via %2$s" : "%1$s via %2$s",
    "In the past on %1$s for the entire day" : "Tidigare den %1$s hela dagen",
    "_In a minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["Om en minut den %1$s hela dagen","Om %n minuter den %1$s hela dagen"],
    "_In a hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["Om en timme den %1$s hela dagen","Om %n timmar den %1$s hela dagen"],
    "_In a day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["Om en dag den %1$s hela dagen","Om %n dagar den %1$s hela dagen"],
    "_In a week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["Om en vecka den %1$s hela dagen","Om %n veckor den %1$s hela dagen"],
    "_In a month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["Om en månad den %1$s hela dagen","Om %n månader den %1$s hela dagen"],
    "_In a year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["Om en år den %1$s hela dagen","Om %n år den %1$s hela dagen"],
    "In the past on %1$s between %2$s - %3$s" : "Tidigare den %1$s mellan %2$s - %3$s",
    "_In a minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["Om en minut den %1$s mellan %2$s - %3$s","Om %n minuter den %1$s mellan %2$s - %3$s"],
    "_In a hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["Om en timme den %1$s mellan %2$s - %3$s","Om %n timmar den %1$s mellan %2$s - %3$s"],
    "_In a day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["Om en dag den %1$s mellan %2$s - %3$s","Om %n dagar den %1$s mellan %2$s - %3$s"],
    "_In a week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["Om en vecka den %1$s mellan %2$s - %3$s","Om %n veckor den %1$s mellan %2$s - %3$s"],
    "_In a month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["Om en månad den %1$s mellan %2$s - %3$s","Om %n månader den %1$s mellan %2$s - %3$s"],
    "_In a year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["Om ett år den %1$s mellan %2$s - %3$s","Om %n år den %1$s mellan %2$s - %3$s"],
    "Could not generate when statement" : "Kunde inte generera ett när-villkor",
    "Every Day for the entire day" : "Varje dag hela dagen",
    "Every Day for the entire day until %1$s" : "Varje dag hela dagen tills den %1$s",
    "Every Day between %1$s - %2$s" : "Varje dag mellan %1$s - %2$s",
    "Every Day between %1$s - %2$s until %3$s" : "Varje dag mellan %1$s - %2$s tills den %3$s",
    "Every %1$d Days for the entire day" : "Varje %1$d dagar, hela dagen",
    "Every %1$d Days for the entire day until %2$s" : "Varje %1$d dagar hela dagen tills den %2$s",
    "Every %1$d Days between %2$s - %3$s" : "Varje %1$d dagar mellan %2$s - %3$s",
    "Every %1$d Days between %2$s - %3$s until %4$s" : "Varje %1$d dagar mellan %2$s - %3$s tills den %4$s",
    "Could not generate event recurrence statement" : "Kunde inte generera händelseupprepning",
    "Every Week on %1$s for the entire day" : "Varje vecka på %1$s, hela dagen",
    "Every Week on %1$s for the entire day until %2$s" : "Varje vecka på %1$s hela dagen tills den %2$s",
    "Every Week on %1$s between %2$s - %3$s" : "Varje vecka på %1$s mellan %2$s - %3$s",
    "Every Week on %1$s between %2$s - %3$s until %4$s" : "Varje vecka på %1$s mellan %2$s - %3$s till den %4$s",
    "Every %1$d Weeks on %2$s for the entire day" : "Varje %1$d vecka på %2$s hela dagen",
    "Every %1$d Weeks on %2$s for the entire day until %3$s" : "Varje %1$d vecka på %2$s för hela dagen till %3$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s" : "Varje %1$d vecka på %2$s mellan %3$s - %4$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s until %5$s" : "Varje %1$d vecka på %2$s mellan %3$s - %4$s till %5$s",
    "Every Month on the %1$s for the entire day" : "Varje månad på den %1$s hela dagen",
    "Every Month on the %1$s for the entire day until %2$s" : "Varje månad på den %1$s hela dagen till %2$s",
    "Every Month on the %1$s between %2$s - %3$s" : "Varje månad på den %1$s mellan %2$s - %3$s",
    "Every Month on the %1$s between %2$s - %3$s until %4$s" : "Varje månad på den %1$s mellan %2$s - %3$s till %4$s",
    "Every %1$d Months on the %2$s for the entire day" : "Varje %1$d månad på den %2$s hela dagen",
    "Every %1$d Months on the %2$s for the entire day until %3$s" : "Varje %1$d månad på den %2$s hela dagen till %3$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s" : "Varje %1$d månad på den %2$s mellan %3$s - %4$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s until %5$s" : "Varje %1$d månad på den %2$s mellan %3$s - %4$s till %5$s",
    "Every Year in %1$s on the %2$s for the entire day" : "Varje år %1$s på den %2$s hela dagen",
    "Every Year in %1$s on the %2$s for the entire day until %3$s" : "Varje år i %1$s på den %2$s hela dagen till %3$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s" : "Varje år i %1$s på den %2$s mellan %3$s - %4$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s until %5$s" : "Varje år i %1$s på den %2$s mellan %3$s - %4$s till %5$s",
    "Every %1$d Years in %2$s on the %3$s for the entire day" : "Vart %1$d år i %2$s på den %3$s hela dagen",
    "Every %1$d Years in %2$s on the %3$s for the entire day until %4$s" : "Vart %1$d år i %2$s på den %3$s hela dagen till %4$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s" : "Vart %1$d år i %2$s på den %3$s mellan %4$s - %5$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "Vart %1$d år i %2$s på den %3$s mellan %4$s - %5$s till %6$s",
    "On specific dates for the entire day until %1$s" : "På specifika datum hela dagen fram till kl %1$s",
    "On specific dates between %1$s - %2$s until %3$s" : "På specifika datum mellan %1$s - %2$s tills %3$s",
    "In the past on %1$s" : "Tidigare den %1$s",
    "_In a minute on %1$s_::_In %n minutes on %1$s_" : ["Om en minut den %1$s","Om %n minuter den %1$s"],
    "_In a hour on %1$s_::_In %n hours on %1$s_" : ["Om en timme den %1$s","Om %n timmar den %1$s"],
    "_In a day on %1$s_::_In %n days on %1$s_" : ["Om en dag den %1$s","Om %n dagar den %1$s"],
    "_In a week on %1$s_::_In %n weeks on %1$s_" : ["Om en vecka den %1$s","Om %n veckor den %1$s"],
    "_In a month on %1$s_::_In %n months on %1$s_" : ["Om en månad den %1$s","Om %n månader den %1$s"],
    "_In a year on %1$s_::_In %n years on %1$s_" : ["Om ett år den %1$s","Om %n år den %1$s"],
    "In the past on %1$s then on %2$s" : "Tidigare den %1$s och sedan den %2$s",
    "_In a minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["Om en minu den %1$s och sedan den %2$s","Om %n minuter den %1$s och sedan den %2$s"],
    "_In a hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["Om en timme den %1$s och sedan den %2$s","Om %n timmar den %1$s och sedan den %2$s"],
    "_In a day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["Om en dag den %1$s och sedan den %2$s","Om %n dagar den %1$s och sedan den %2$s"],
    "_In a week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["Om en vecka den %1$s och sedan den %2$s","Om %n veckor den %1$s och sedan den %2$s"],
    "_In a month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["Om en månad den %1$s och sedan den %2$s","Om %n månader den %1$s och sedan den %2$s"],
    "_In a year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["Om ett år den %1$s och sedan den %2$s","Om %n år den %1$s och sedan den %2$s"],
    "In the past on %1$s then on %2$s and %3$s" : "Tidigare den %1$s sedan den %2$s och %3$s",
    "_In a minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["Om en minut den %1$s sedan den %2$s och %3$s","Om %n minuter den %1$s sedan den %2$s och %3$s"],
    "_In a hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["Om en timme den %1$s sedan den %2$s och %3$s","Om %n timmar den %1$s sedan den %2$s och %3$s"],
    "_In a day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["Om en dag den %1$s sedan den %2$s och %3$s","Om %n dagar den %1$s sedan den %2$s och %3$s"],
    "_In a week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["Om en vecka den %1$s sedan den %2$s och %3$s","Om %n veckor den %1$s sedan den %2$s och %3$s"],
    "_In a month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["Om en månad den %1$s sedan den %2$s och %3$s","Om %n månader den %1$s sedan den %2$s och %3$s"],
    "_In a year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["Om ett år den %1$s sedan den %2$s och %3$s","Om %n år den %1$s sedan den %2$s och %3$s"],
    "Could not generate next recurrence statement" : "Kunde inte generera nästa händelseupprepning",
    "Cancelled: %1$s" : "Avbruten: %1$s",
    "\"%1$s\" has been canceled" : "\"%1$s\" har avbrutits",
    "Re: %1$s" : "Sv: %1$s",
    "%1$s has accepted your invitation" : "%1$s har accepterat din inbjudan",
    "%1$s has tentatively accepted your invitation" : "%1$s har preliminärt accepterat din inbjudan",
    "%1$s has declined your invitation" : "%1$s har tackat nej till din inbjudan",
    "%1$s has responded to your invitation" : "%1$s har svarat på din inbjudan",
    "Invitation updated: %1$s" : "Inbjudan uppdaterad: %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s uppdaterade händelse \"%2$s\"",
    "Invitation: %1$s" : "Inbjudan: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s har bjudit in dig till \"%2$s\"",
    "Organizer:" : "Arrangör:",
    "Attendees:" : "Deltagare:",
    "Title:" : "Titel:",
    "When:" : "När",
    "Location:" : "Ort:",
    "Link:" : "Länk:",
    "Occurring:" : "Förekommer:",
    "Accept" : "Acceptera",
    "Decline" : "Avböj",
    "More options …" : "Fler alternativ ...",
    "More options at %s" : "Fler alternativ på %s",
    "Monday" : "Måndag",
    "Tuesday" : "Tisdag",
    "Wednesday" : "Onsdag",
    "Thursday" : "Torsdag",
    "Friday" : "Fredag",
    "Saturday" : "Lördag",
    "Sunday" : "Söndag",
    "January" : "Januari",
    "February" : "Februari",
    "March" : "Mars",
    "April" : "April",
    "May" : "Maj",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "Augusti",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "December",
    "First" : "Första",
    "Second" : "Andra",
    "Third" : "Tredje",
    "Fourth" : "Fjärde",
    "Fifth" : "Femte",
    "Last" : "Sista",
    "Second Last" : "Näst sist",
    "Third Last" : "Tredje sist",
    "Fourth Last" : "Fjärde sist",
    "Fifth Last" : "Femte sista",
    "Contacts" : "Kontakter",
    "{actor} created address book {addressbook}" : "{actor} skapade adressboken {addressbook}",
    "You created address book {addressbook}" : "Du skapade adressboken {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} tog bort adressboken {addressbook}",
    "You deleted address book {addressbook}" : "Du tog bort adressboken {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} uppdaterade adressboken {addressbook}",
    "You updated address book {addressbook}" : "Du uppdaterade adressboken {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} delade adressboken {addressbook} med dig",
    "You shared address book {addressbook} with {user}" : "Du delade adressboken {addressbook} med {user}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} delade adressboken {addressbook} med {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} slutade dela adressboken {addressbook} med dig",
    "You unshared address book {addressbook} from {user}" : "Du slutade dela adressboken {addressbook} med {user}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} slutade dela adressboken {addressbook} med {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} tog bort delning adressboken {addressbook} från sig själv",
    "You shared address book {addressbook} with group {group}" : "Du delade adressboken {addressbook} med gruppen {group}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} delade adressboken {addressbook} med gruppen {group}",
    "You unshared address book {addressbook} from group {group}" : "Du slutade dela adressboken {addressbook} med gruppen {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} slutade dela adressboken {addressbook} med gruppen {group}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} skapade kontakten {card} i adressboken {addressbook}",
    "You created contact {card} in address book {addressbook}" : "Du skapade kontakten {card} i adressboken {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} tog bort kontakten {card} från adressboken {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Du tog bort kontakten {card} från adressboken {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} uppdaterade kontakten {card} i adressboken {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Du uppdaterade kontakten {card} i adressboken {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "En <strong>kontakt</strong> eller <strong>adressbok</strong> ändrades",
    "Accounts" : "Konton",
    "System address book which holds all accounts" : "Systemadressbok som innehåller alla konton",
    "File is not updatable: %1$s" : "Fil kan inte uppdateras: %1$s",
    "Failed to get storage for file" : "Kunde inte få lagringsutrymme för filen",
    "Could not write to final file, canceled by hook" : "Kunde ej skriva till den slutgiltiga filen, avbröts av en kopplad åtgärd",
    "Could not write file contents" : "Kunde inte skriva filens innehåll",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "Fel vid kopiering av fil till målplats (kopierade: %1$s, förväntad filstorlek: %2$s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "Förväntad filstorlek på %1$s men läste (från Nextcloud-klienten) och skrev (till Nextcloud-lagringen) %2$s. Kan antingen vara ett nätverksproblem på sändnings-sidan eller problem med att skriva till lagringen på server-sidan.",
    "Could not rename part file to final file, canceled by hook" : "Kunde inte byta namn på filfragment till slutgiltigt filnamn, avbröts av en kopplad åtgärd.",
    "Could not rename part file to final file" : "Kunde inte ändra namn från temporära filen till slutliga filen",
    "Failed to check file size: %1$s" : "Kunde inte kontrollera filstorleken: %1$s",
    "Could not open file: %1$s, file does seem to exist" : "Kunde inte öppna filen: %1$s, filen verkar inte finnas",
    "Could not open file: %1$s, file doesn't seem to exist" : "Kunde inte öppna filen: %1$s, filen verkar inte finnas",
    "Encryption not ready: %1$s" : "Kryptering ej redo: %1$s",
    "Failed to open file: %1$s" : "Kunde inte öppna fil: %1$s",
    "Failed to unlink: %1$s" : "Kunde inte ta bort: %1$s",
    "Failed to write file contents: %1$s" : "Kunde inte skriva filinnehåll: %1$s",
    "File not found: %1$s" : "Filen hittades inte: %1$s",
    "Invalid target path" : "Ogiltig målsökväg",
    "System is in maintenance mode." : "Systemet är i underhållsläge.",
    "Upgrade needed" : "Uppdatering nödvändig",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Din %s måste konfigureras att använda HTTPS för CalDAV och CardDAV med iOS/macOS.",
    "Configures a CalDAV account" : "Konfigurerar ett CalDAV-konto",
    "Configures a CardDAV account" : "Konfigurerar ett CardDAV-konto",
    "Events" : "Händelser",
    "Untitled task" : "Namnlös uppgift",
    "Completed on %s" : "Slutförd %s",
    "Due on %s by %s" : "Slutar den %s vid %s",
    "Due on %s" : "Slutar den %s",
    "Example event - open me!" : "Exempelhändelse – öppna mig!",
    "System Address Book" : "Systemadressbok",
    "The system address book contains contact information for all users in your instance." : "Systemadressboken innehåller kontaktinformation för alla användare i din instans.",
    "Enable System Address Book" : "Aktivera systemadressboken",
    "DAV system address book" : "DAV-systemets adressbok",
    "No outstanding DAV system address book sync." : "Ingen utestående synkronisering för DAV-systemets adressbok.",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "DAV-systemets adressbokssynkronisering har inte körts ännu eftersom din instans har fler än 1000 användare eller för att ett fel uppstod. Kör det manuellt genom att anropa \"occ dav:sync-system-addressbook\".",
    "WebDAV endpoint" : "WebDAV endpoint",
    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "Det gick inte att kontrollera att din webbserver är korrekt inställd för att tillåta filsynkronisering över WebDAV. Kontrollera manuellt.",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Din webbserver är ännu inte korrekt inställd för att tillåta filsynkronisering, eftersom WebDAV-gränssnittet verkar vara trasigt.",
    "Your web server is properly set up to allow file synchronization over WebDAV." : "Din webbserver är korrekt inställd för att tillåta filsynkronisering över WebDAV.",
    "Migrated calendar (%1$s)" : "Migrerade kalender (%1$s)",
    "Calendars including events, details and attendees" : "Kalendrar inklusive händelser, detaljer och deltagare",
    "Contacts and groups" : "Kontakter och grupper",
    "WebDAV" : "WebDAV",
    "Absence saved" : "Frånvaro sparad",
    "Failed to save your absence settings" : "Kunde inte spara dina frånvaroinställningar",
    "Absence cleared" : "Frånvaro rensad",
    "Failed to clear your absence settings" : "Kunde inte rensa dina frånvaroinställningar",
    "First day" : "Första dagen",
    "Last day (inclusive)" : "Sista dagen (inklusive)",
    "Out of office replacement (optional)" : "Ersättare utanför kontoret (valfritt)",
    "Name of the replacement" : "Namn på ersättaren",
    "No results." : "Inga resultat.",
    "Start typing." : "Börja skriva.",
    "Short absence status" : "Meddelande om kort frånvaro",
    "Long absence Message" : "Meddelande om långvarig frånvaro",
    "Save" : "Spara",
    "Disable absence" : "Inaktivera frånvaro",
    "Failed to load availability" : "Misslyckades med att ladda tidsluckor",
    "Saved availability" : "Sparade tidslucka",
    "Failed to save availability" : "Misslyckades med att spara tidslucka",
    "Time zone:" : "Tidszon:",
    "to" : "till",
    "Delete slot" : "Radera lucka",
    "No working hours set" : "Inga arbetstimmar satta",
    "Add slot" : "Lägg till lucka",
    "Weekdays" : "Vardagar",
    "Pick a start time for {dayName}" : "Välj en starttid för {dayName}",
    "Pick a end time for {dayName}" : "Välj en sluttid för {dayName}",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Sätt automatiskt användarstatus till \"Stör ej\" utanför tillgängliga tider för att tysta alla notifikationer.",
    "Cancel" : "Avbryt",
    "Import" : "Importera",
    "Error while saving settings" : "Fel vid sparande av inställningar",
    "Contact reset successfully" : "Kontakten har återställts",
    "Error while resetting contact" : "Fel vid återställning av kontakt",
    "Contact imported successfully" : "Kontakten har importerats",
    "Error while importing contact" : "Fel vid import av kontakt",
    "Import contact" : "Importera kontakt",
    "Reset to default" : "Återställ till grundinställningar",
    "Import contacts" : "Importera kontakter",
    "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "Att importera en ny .vcf-fil kommer att radera den befintliga standardkontakten och ersätta den med den nya. Vill du fortsätta?",
    "Failed to save example event creation setting" : "Kunde inte spara exemplet för inställning av händelseskapande",
    "Failed to upload the example event" : "Kunde inte ladda upp exempelhändelsen",
    "Custom example event was saved successfully" : "Anpassad exempelhändelse sparades",
    "Failed to delete the custom example event" : "Kunde inte ta bort den anpassade exempelhändelsen",
    "Custom example event was deleted successfully" : "Anpassad exempelhändelse har raderats",
    "Import calendar event" : "Importera kalenderhändelse",
    "Uploading a new event will overwrite the existing one." : "Om du laddar upp en ny händelse kommer den att skriva över den befintliga.",
    "Upload event" : "Ladda upp händelse",
    "Availability" : "Din tillgänglighet",
    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Om du konfigurerar dina arbetstider kommer andra att se när du är frånvarande när de bokar ett möte.",
    "Absence" : "Frånvaro",
    "Configure your next absence period." : "Konfigurera din nästa frånvaroperiod.",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installera även {calendarappstoreopen}Kalender-app{linkclose}, eller {calendardocopen}anslut din dator & mobil för synkronisering ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Verifiera och säkerställ inställningar för {emailopen}e-postserver{linkclose}.",
    "Calendar server" : "Kalenderserver",
    "Send invitations to attendees" : "Skicka inbjudan till deltagare",
    "Automatically generate a birthday calendar" : "Generera en födelsedagskalender automatiskt",
    "Birthday calendars will be generated by a background job." : "Födelsedagskalender kommer skapas som ett bakgrundsjobb.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Därför kommer de inte vara tillgängliga direkt efter aktivering men kommer dyka upp efter en tid.",
    "Send notifications for events" : "Skicka notiser för händelser",
    "Notifications are sent via background jobs, so these must occur often enough." : "Notiser skickas genom bakgrundsjobb, så dessa måste ske tillräckligt ofta.",
    "Send reminder notifications to calendar sharees as well" : "Skicka även påminnelser till kalenderdeltagare",
    "Reminders are always sent to organizers and attendees." : "Påminnelser skickas alltid till arrangörer och deltagare.",
    "Enable notifications for events via push" : "Aktivera notiser för händelser via push",
    "Example content" : "Exempelinnehåll",
    "Example content serves to showcase the features of Nextcloud. Default content is shipped with Nextcloud, and can be replaced by custom content." : "Exempelinnehåll används för att visa upp funktionerna i Nextcloud. Standardinnehåll levereras med Nextcloud och kan ersättas med anpassat innehåll.",
    "There was an error updating your attendance status." : "Ett fel uppstod vid uppdatering av din närvarostatus.",
    "Please contact the organizer directly." : "Vänligen kontakta arrangören direkt.",
    "Are you accepting the invitation?" : "Acceptera inbjudan?",
    "Tentative" : "Preliminärt",
    "Your attendance was updated successfully." : "Dina närvaro uppdaterades."
},
"nplurals=2; plural=(n != 1);");
