OC.L10N.register(
    "circles",
    {
    "Teams" : "Команды",
    "You created the team {circle}" : "Вы создали группу {circle}",
    "{author} created the team {circle}" : "{author} создал круг {circle}",
    "You deleted {circle}" : "Вы удалили круг «{circle}»",
    "{author} deleted {circle}" : "{author} удалил(а) круг «{circle}»",
    "You made {member} join {circle}" : "Вы присоединили {member} к {circle}",
    "{author} made {member} join {circle}" : "{author} присоединил {member} к {circle}",
    "You added team {member} as member to {circle}" : "Вы добавили группу {member} в качестве участника в {circle}",
    "{author} added team {member} as member to {circle}" : "{author}добавил группу {member} в качестве участника  {circle}",
    "You made {member} leave {circle}" : "Вы исключили {member} из {circle}",
    "{author} made {member} leave {circle}" : "{author} исключил {member} из {circle}",
    "You removed {member} from {circle}" : "Вы удалили пользователя {member} из круга «{circle}»",
    "{author} removed {member} from {circle}" : "{author} удалил {member} из {circle}",
    "You joined {circle}" : "Вы присоединились к «{circle}»",
    "{member} joined {circle}" : "{member} присоединился(ась) к «{circle}»",
    "You accepted the invitation to join {circle}" : "Вы приняли приглашение на присоединение к «{circle}»",
    "{member} accepted the invitation to join {circle}" : "{member} принял(а) приглашение присоединиться к кругу «{circle}»",
    "You added {member} as member to {circle}" : "Вы добавили пользователя {member} в круг «{circle}»",
    "You have been added as member to {circle} by {author}" : "Вы были добавлены в круг «{circle}» пользователем {author}",
    "{member} has been added as member to {circle} by {author}" : "{author} добавил(а) {member} участником в круг «{circle}»",
    "You added {external} to {circle}" : "Вы добавили {external} в круг «{circle}»",
    "{external} has been added to {circle} by {author}" : " {author} добавил(а) {external} в круг «{circle}»",
    "You accepted {member}'s request to join {circle}" : "Вы одобрили запрос пользователя {member} на присоединение к кругу «{circle}»",
    "Your request to join {circle} has been accepted by {author}" : "{author} одобрил(а) ваш запрос на присоединение к кругу «{circle}»",
    "{member}'s request to join {circle} has been accepted by {author}" : "Запрос пользователя {member} на присоединение к кругу «{circle}» был одобрен пользователем {author}",
    "You left {circle}" : "Вы покинули «{circle}»",
    "{member} left {circle}" : "{member} покинул(а) круг «{circle}»",
    "You declined the invitation to join {circle}" : "Вы отклонили приглашение в круг «{circle}»",
    "{member} declined an invitation to join {circle}" : "{member} отклонил(а) приглашение в круг «{circle}»",
    "You cancelled your request to join {circle}" : "Вы отменили свой запрос на присоединение к кругу «{circle}»",
    "{member} cancelled a request to join {circle}" : "{member} отменил запрос на вступление в {circle}",
    "You have been removed from {circle} by {author}" : "{author} удалил вас из круга «{circle}»",
    "{member} has been removed from {circle} by {author}" : "{author} удалил(а) участника {member} из круга «{circle}»",
    "You removed {external} from {circle}" : "Вы удалили {external} из круга «{circle}»",
    "{external} has been removed from {circle} by {author}" : "{author} удалил(а) {external} из круга «{circle}»",
    "You cancelled {member}'s invitation to join {circle}" : "Вы отменили приглашение пользователя {member} в круг «{circle}»",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} отменил(а) ваше приглашение присоединиться к кругу «{circle}»",
    "{author} cancelled {member}'s invitation to join {circle}" : "{autor} отменил(а) приглашение пользователся {member} присоединиться к кругу «{circle}»",
    "You dismissed {member}'s request to join {circle}" : "Вы отклонили запрос пользователя {member} на присоединение к кругу «{circle}»",
    "Your request to join {circle} has been dismissed by {author}" : "{author} отклонил(а) ваш запрос на присоединение к кругу «{circle}»",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} отклонил(а) запрос пользователя {member} на присоединение к кругу «{circle}»",
    "You invited {member} to join {circle}" : "Вы пригласили пользователя {member} присоединиться к кругу «{circle}»",
    "You have been invited to join {circle} by {author}" : "{author} пригласил(а) вас присоединиться к кругу «{circle}»",
    "{member} has been invited to join {circle} by {author}" : "{author} пригласил(а) пользователя {member} присоединиться к кругу «{circle}»",
    "You changed {member}'s level in {circle} to %1$s" : "Вы изменили уровень участка {member} в круге «{circle}» на %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} изменил(а) ваш уровень в круге «{circle}» на %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} изменил(а) уровень участника {member} в круге «{circle}» на %1$s",
    "You sent a request to join {circle}" : "Вы отправили запрос на присоединение «{circle}»",
    "{member} sent a request to join {circle}" : "{member} отправил(а) запрос на вступление в «{circle}»",
    "You are the new owner of {circle}" : "Вы стали владельцем «{circle}»",
    "{member} is the new owner of {circle}" : "{member} новый владелец «{circle}»",
    "On events happening in a <strong>team</strong> of which you are a member" : "О событиях, происходящих в <strong>группе</strong>, членом которой вы являетесь",
    "Any important event in a <strong>team</strong> you are moderating" : "Любое важное событие в <strong>группе</strong>, которую вы модерируете",
    "On global events happening in any <strong>team</strong>" : "О глобальных событиях, происходящих в любой <strong>группе</strong>",
    "Single" : "Единственный",
    "Personal" : "Личный",
    "System" : "Системный",
    "Visible" : "Видимый",
    "Open" : "Открытый",
    "Invite" : "Приглашение",
    "Join request" : "Запрос на вступление",
    "Friends" : "Друзья",
    "Password protected" : "Защищено паролем",
    "No Owner" : "Нет владельца",
    "Hidden" : "Скрыто",
    "Backend" : "Внутренний",
    "Local" : "Локальный",
    "Root" : "Корневой",
    "Team invite" : "Приглашение группы",
    "Federated" : "Федеративный",
    "Mount point" : "Точка сборки",
    "Nextcloud Account" : "Учётная запись Nextcloud",
    "Nextcloud Group" : "Группа Nextcloud",
    "Email address" : "Email адрес",
    "Contact" : "Контакт",
    "Circle" : "Круг",
    "Nextcloud App" : "Приложение Nextcloud",
    "Member" : "Участник",
    "Moderator" : "Модератор",
    "Admin" : "Администратор",
    "Owner" : "Владелец",
    "%s shared »%s« with you." : "%s предоставил(а) вам доступ к «%s».",
    "%s shared »%s« with \"%s\"." : "%s предоставил(а) »%s« с \"%s\".",
    "%s on %s" : "%s на %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : " %1$s поделился »%2$s« с вами.\nВы уже должны были получить отдельное письмо со ссылкой на доступ к нему.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s поделился »%2$s« с вами. Вы уже должны были получить отдельное письмо со ссылкой для доступа к нему.",
    "Password to access »%1$s« shared to you by %2$s" : "Пароль для доступа к «%1$s», общий доступ к которому предоставлен вам пользователем %2$s",
    "Password to access »%s«" : "Пароль для доступа к «%s»",
    "It is protected with the following password:" : "Доступ защищён следующим паролем: ",
    "%1$s via %2$s" : "%1$sчерез %2$s",
    "Click the button below to open it." : "Нажмите кнопку ниже, чтобы открыть его.",
    "Open »%s«" : "Открыть «%s»",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s поделился с вами несколькими файлами.\nВы уже должны были получить отдельное письмо со ссылкой для доступа к ним.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s поделился с вами несколькими файлами. Вы уже должны были получить отдельное письмо со ссылкой для доступа к ним.",
    "Password to access files shared to you by %1$s" : "Пароль для доступа к файлам, общий доступ к которому предоставлен вам пользователем %1$s",
    "Password to access files" : "Пароль для доступа к файлам",
    "%s shared multiple files with \"%s\"." : "%s поделился несколькими файлами с \"%s\".",
    "%s shared multiple files with you." : "%s предоставил(а) вам доступ к нескольким файлам.",
    "Boot up" : "Загрузка",
    "Nextcloud Initialization" : "Инициализация Nextcloud",
    "Circles App Initialization" : "Инициализация приложения \"Круги\"",
    "Fresh installation status" : "Статус новой установки",
    "Building Local Database" : "Создание локальной базы данных",
    "Testing Basic Circle Creation" : "Тестирование базового созданного Круга",
    "Adding local users and moderators" : "Добавление локальных пользователей и модераторов",
    "Show all teams" : "Показать все группы",
    "Create a new team" : "Создать новую группу",
    "Files" : "Файлы",
    "This feature is not available for personal circles" : "Эта возможность недоступна для личных кругов",
    "The team is not federated" : "Не федеративная группа",
    "You cannot join this team" : "Вы не можете вступить в эту группу",
    "This member is not a moderator" : "Это участник — не модератор",
    "Insufficient privileges" : "Недостаточно прав доступа",
    "This member does not exist" : "Этот участник не существует",
    "This member is the owner of the team" : "Этот участник является владельцем группы",
    "Level cannot be changed for this type of member" : "Невозможно изменить уровень участника такого типа",
    "You are already a member of this circle" : "Вы уже участник этого круга",
    "You have been blocked from this circle" : "Вы заблокированы от участия в этом круге",
    "The account is already a member of this circle" : "Эта учётная запись уже участник этого круга",
    "The account has already been invited into this circle" : "Эта учётная запись уже приглашена в этот круг",
    "%s (Team owned by %s)" : "%s (Группа принадлежит %s)",
    "You are now a member of the Team \"%2$s\"" : "Вы теперь участник Группы \"%2$s\"",
    "You have been invited by %1$s into the Team \"%2$s\"" : "Вы были приглашены %1$s s в Группу \"%2$s\"",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s отправил запрос на членство в Группе \"%2$s\"",
    "Accept" : "Принять",
    "Refuse" : "Отказаться",
    "Leave the team" : "Покинуть группу",
    "%s" : "%s",
    "Personal team" : "Личная группа",
    "%s owned by %s" : "%sпринадлежащий %s",
    "You have no permission to create a new team" : "У вас нет разрешений для создания новой группы",
    "%s shared a file with \"%s\"." : "%s поделился файлом с \"%s\".",
    "%s shared a file with you." : "%s поделился с вами файлом.",
    "Open %s" : "Открыть %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s поделился с вами некоторыми материалами.\nВы уже должны были получить отдельное письмо со ссылкой для доступа к нему.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s поделился с вами некоторыми материалами. Вы уже должны были получить отдельное письмо со ссылкой для доступа к нему.",
    "Password to access content shared with you by %1$s" : "Пароль для доступа к содержимому, предоставленному вам %1$s",
    "Password to access content" : "Пароль для доступа к содержимому",
    "This item is already shared with this team" : "Этот элемент уже открыт для общего доступа этой группой",
    "Bring cloud-users closer together." : "Объедините пользователей облачных технологий.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Команды позволяют людям создавать свои группы людей/коллег/друзей.\nЗатем эти группы людей могут быть использованы любым другим приложением для совместного использования.",
    "No files in here" : "Здесь нет файлов",
    "No entries found in this folder" : "В этой папке ничего нет",
    "Name" : "Имя",
    "Size" : "Размер",
    "Modified" : "Изменён",
    "Teams' files" : "Файлы групп",
    "Select team to filter by" : "Выберите группу для фильтрации по",
    "No teams found" : "Группы не найдены",
    "Please select teams to filter by" : "Пожалуйста, выберите группы для фильтрации по",
    "No files found for the selected teams" : "Для выбранных групп файлы не найдены",
    "Shared to Circles" : "Предоставленный кругам общий доступ"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
