OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Noteikta pieteikšanās no jaunas atrašanās vietas",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "Tika noteikta jauna pieteikšanās Tavā kontā. IP adrese %s tika novērtēta kā aizdomīga. Ja to darīji Tu, šo ziņojumu var neņemt vērā. Pretējā gadījumā vajadzētu nomainīt savu paroli.",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
