OC.L10N.register(
    "circles",
    {
    "Personal" : "Personleg",
    "System" : "System",
    "Password protected" : "Passordverna",
    "Local" : "Lokal",
    "Federated" : "Federated",
    "Contact" : "Kontakt",
    "Circle" : "Sirkel",
    "Moderator" : "Moderator",
    "Admin" : "Administrer",
    "Owner" : "Owner",
    "Open »%s«" : "Opna »%s«",
    "Open %s" : "Opne{filnamn}",
    "No files in here" : "Ingen filer her",
    "No entries found in this folder" : "Ingen oppføringar funne i denne mappa",
    "Name" : "Namn",
    "Size" : "Storleik",
    "Modified" : "Endra"
},
"nplurals=2; plural=(n != 1);");
