<?php
namespace Aws\Pricing\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Price List Service** service.
 */
class PricingException extends AwsException {}
