OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Salasana on vanhentunut. Käytä \"Unohdin salasanani\"-palautusta nollataksesi salasanasi",
    "Password must not have been used recently before." : "Salasanaa ei saa olla käytetty aiemmin.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Salasana on yksi miljoonasta yleisimmästä. Tee salasanasta erikoisempi.",
    "Password is present in compromised password list. Please choose a different password." : "Salasana kuuluu murrettujen salasanojen listalle. Valitse eri salasana.",
    "Password needs to be at least %s characters long." : "Salasanan tulee sisältää vähintään %s merkkiä.",
    "Password needs to contain at least one numeric character." : "Salasanassa tulee olla vähintään yksi numeerinen merkki.",
    "Password needs to contain at least one special character." : "Salasanassa tulee olla vähintään yksi erikoismerkki.",
    "Password needs to contain at least one lower and one upper case character." : "Salasanan tulee sisältää vähintään yksi pieni ja yksi iso kirjain.",
    "Password policy" : "Salasanakäytäntö",
    "Allows admins to configure a password policy" : "Mahdollistaa ylläpitäjien määrittää salasanakäytännön",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Salli ylläpitäjän määrittää ennalta määritettyjä ehtoja salasanalle, esimerkiksi vähimmäispituuden",
    "Number of days until user password expires" : "Salasanan vanhenemisen aika päivissä",
    "Minimum password length" : "Salasanan vähimmäispituus",
    "Forbid common passwords" : "Kiellä yleisimmät salasanat",
    "Enforce upper and lower case characters" : "Pakota käyttämään isoja ja pieniä kirjaimia",
    "Enforce numeric characters" : "Pakota käyttämään numeroita",
    "Enforce special characters" : "Pakota käyttämään erikoismerkkejä",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Tarkista salasanan vastaavuus haveibeenpwned.comin keräämiin vuotaneisiin salasanoihin",
    "Unknown error" : "Tuntematon virhe",
    "Settings saved" : "Asetukset tallennettu",
    "Error while saving settings" : "Virhe tallennettaessa asetuksia",
    "User password history" : "Käyttäjän salasanahistoria"
},
"nplurals=2; plural=(n != 1);");
