<?php

declare(strict_types=1);
/**
 * SPDX-FileCopyrightText: 2018-2024 Nextcloud GmbH and Nextcloud contributors
 * SPDX-FileCopyrightText: 2014-2015 ownCloud, Inc.
 * SPDX-License-Identifier: AGPL-3.0-only
 */
namespace OCA\Files_PDFViewer\AppInfo;

return ['routes' => [
	['name' => 'display#showPdfViewer', 'url' => '/', 'verb' => 'GET'],
]];
