OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Przypomnienia o plikach",
    "Reminder for {name}" : "Przypomnienie dla {name}",
    "View file" : "Zobacz plik",
    "View folder" : "Wyświetl katalog",
    "Set file reminders" : "Ustaw przypomnienia o plikach",
    "Set reminder for \"{fileName}\"" : "Ustaw przypomnienie dla \"{fileName}\"",
    "Clear reminder" : "Wyczyść przypomnienie",
    "Please choose a valid date & time" : "Wybierz prawidłową datę i godzinę",
    "Reminder set for \"{fileName}\"" : "Przypomnienie ustawione dla \"{fileName}\"",
    "Failed to set reminder" : "Nie udało się ustawić przypomnienia",
    "Failed to clear reminder" : "Nie udało się wyczyścić przypomnienia",
    "We will remind you of this file" : "Przypomnimy Tobie o tym pliku",
    "Cancel" : "Anuluj",
    "Set reminder" : "Ustaw przypomnienie",
    "Later today" : "Później dzisiaj",
    "Set reminder for later today" : "Ustaw przypomnienie na dzisiaj na późniejszy czas",
    "Tomorrow" : "Jutro",
    "Set reminder for tomorrow" : "Ustaw przypomnienie na jutro",
    "This weekend" : "W ten weekend",
    "Set reminder for this weekend" : "Ustaw przypomnienie na ten weekend",
    "Next week" : "Następny tydzień",
    "Set reminder for next week" : "Ustaw przypomnienie na przyszły tydzień",
    "Set reminder at custom date & time" : "Ustaw przypomnienie o własnej dacie i godzinie",
    "Set custom reminder" : "Ustaw niestandardowe przypomnienie"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
