OC.L10N.register(
    "logreader",
    {
    "Logging" : "Zapisivanje",
    "Log Reader" : "Čitač zapisa",
    "A log reader for Nextcloud" : "Čitač zapisa za Nextcloud",
    "Log reader for Nextcloud" : "Čitač zapisa za Nextcloud",
    "Level" : "Razina",
    "App" : "Aplikacija",
    "Time" : "Vrijeme",
    "Download logs" : "Preuzmi zapise",
    "Relative" : "Relativno",
    "Message" : "Poruka",
    "Show details" : "Prikaži pojedinosti",
    "Debug" : "Otklanjanje pogrešaka",
    "Info" : "Informacije",
    "Warning" : "Upozorenje",
    "Error" : "Pogreška",
    "Fatal" : "Fatalno"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
