OC.L10N.register(
    "profile",
    {
    "Profile" : "Профіль",
    "You have not added any info yet" : "Вы пакуль не дадалі ніякай інфармацыі",
    "{user} has not added any info yet" : "{user} пакуль не дадаў(-ла) ніякай інфармацыі",
    "Edit Profile" : "Рэдагаваць профіль",
    "Profile not found" : "Профіль не знойдзены",
    "The profile does not exist." : "Профіль не існуе.",
    "Back to %s" : "Назад да %s"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
