OC.L10N.register(
    "app_api",
    {
    "Cancel" : "අවලංගු",
    "Edit" : "සංස්කරණය",
    "Name" : "නම",
    "Host" : " ධාරකය",
    "Enabled" : "සබල කර ඇත",
    "Confirm" : "තහවුරු කරන්න",
    "Remove" : "ඉවත් කරන්න",
    "Version" : "අනුවාදය",
    "Actions" : "ක්‍රියාමාර්ග",
    "Disable" : "අබල කරන්න"
},
"nplurals=2; plural=(n != 1);");
