OC.L10N.register(
    "profile",
    {
    "Profile" : "Profile",
    "This application provides the profile" : "This application provides the profile",
    "Provides a customisable user profile interface." : "Provides a customisable user profile interface.",
    "You have not added any info yet" : "You have not added any info yet",
    "{user} has not added any info yet" : "{user} has not added any info yet",
    "Error opening the user status modal, try hard refreshing the page" : "Error opening the user status modal, try hard refreshing the page",
    "Edit Profile" : "Edit Profile",
    "The headline and about sections will show up here" : "The headline and about sections will show up here",
    "Profile not found" : "Profile not found",
    "The profile does not exist." : "The profile does not exist.",
    "Back to %s" : "Back to %s"
},
"nplurals=2; plural=(n != 1);");
