OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "%sအတွက် ကိုယ်ပိုင် လုပ်ဆောင်မှု ပေးပို့ချက်",
    "Your feed URL is invalid" : "သင်၏ ပေးပို့ချက် URL မှားယွင်းနေသည်။",
    "Your settings have been updated." : "သင်၏ ပြင်ဆင်ချက်များကို မွမ်းမံပြီးဖြစ်သည်။",
    "Settings have been updated." : "ပြင်ဆင်ချက်များ မွမ်းမံပြီးပြီ။",
    "All activities" : "လုပ်ဆောင်ချက်အားလုံး",
    "By others" : "အခြားသူများမှ",
    "By you" : "သင့်ထံမှ",
    "Hello %s" : "မင်္ဂလာပါ %s",
    "Hello %s," : "မင်္ဂလာပါ %s၊",
    "There was some activity at %s" : "%sက လုပ်ဆောင်မှု အချို့ ရှိခဲ့သည်။",
    "_and %n more _::_and %n more _" : ["နှင့် အပို%n"],
    "Mail" : "စာ",
    "Activity" : "လုပ်ဆောင်မှု",
    "Today" : "ယနေ့",
    "Yesterday" : "မနေ့က",
    "in {path}" : "{path} တွင်",
    "Home" : "ပင်မစာမျက်နှာ",
    "This stream will show events like additions, changes & shares" : "ဤ လမ်းကြောင်းသည်  ပေါင်းထည့်ခြင်း၊ ပြောင်းလဲခြင်းနှင့် မျှဝေခြင်း စသည့် အဖြစ်အပျက်များကို ပြသပေးပါမည်။",
    "No activity yet" : "လုပ်ဆောင်မှုမရှိသေး"
},
"nplurals=1; plural=0;");
