OC.L10N.register(
    "oauth2",
    {
    "OAuth 2.0" : "O.Auth 2.0",
    "OAuth 2.0 clients" : "Klientë OAuth 2.0",
    "Name" : "Emri",
    "Redirection URI" : "URI Ridrejtimi",
    "Client Identifier" : "Identifikues Klienti",
    "Secret key" : "Kyç i fshehtë",
    "Add client" : "Shto klient",
    "Add" : "Shto ",
    "Delete" : "Delete"
},
"nplurals=2; plural=(n != 1);");
