<?php
/**
 * SPDX-FileCopyrightText: 2022 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */
\OCP\Util::addScript('activity', 'activity-personalSettings');
?>

<div id="activity-user-settings"></div>

<div id="activity-digest-user-settings"></div>
