OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Pridėtas į patikimų serverių sąrašą",
    "No server found with ID: %s" : "Nerasta jokio serverio, kurio ID: %s",
    "Could not remove server" : "Nepavyko pašalinti serverio",
    "Server is already in the list of trusted servers." : "Serveris jau yra patikimų serverių sąraše.",
    "No server to federate with found" : "Nerasta jokio serverio, su kuriuo jungtis į federaciją",
    "Could not add server" : "Nepavyko pridėti serverio",
    "Trusted servers" : "Patikimi serveriai",
    "Federation" : "Federacija",
    "+ Add trusted server" : "+ Pridėti patikimą serverį",
    "Trusted server" : "Patikimas serveris",
    "Add" : "Pridėti"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
