<?php
namespace Aws\KafkaConnect\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Managed Streaming for Kafka Connect** service.
 */
class KafkaConnectException extends AwsException {}
