OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Fil d’activitat personal per %s",
    "Your feed URL is invalid" : "L’URL del fil es invalida",
    "Activity feed" : "Flux d’activitat",
    "Your settings have been updated." : "Los paramètres son estats actualizats.",
    "Settings have been updated." : "Los paramètres son estats actualizats.",
    "Recent activity" : "Activitat recenta",
    "No activities" : "Cap d’activitat",
    "More activities" : "Mai d’activitats",
    "Daily activity summary for %s" : "Resumit d’activitat quotidian per%s",
    "All activities" : "Totas las activitats",
    "By others" : "Per d’autres",
    "By you" : "Per vos",
    "Activity at %s" : "Activitat sus %s",
    "Hello %s" : "Adieu %s",
    "Hello %s," : "Adieu %s,",
    "There was some activity at %s" : "I a agut una activitat a %s",
    "_and %n more _::_and %n more _" : ["e %n mai","e %n mai "],
    "Mail" : "Mail",
    "Activity" : "Activitat",
    "Notifications" : "Notificacions",
    "Send email" : "Enviar email",
    "Activity notification configuration" : "Configuracion de las notificacions d’activitat",
    "Today" : "Uèi",
    "Yesterday" : "Ièr",
    "As soon as possible" : "Tre que possible",
    "Hourly" : "Cada ora",
    "Daily" : "Quotidian",
    "Weekly" : "Setmanièr",
    "You commented" : "Avètz comentat",
    "Message deleted by author" : "Messatge suprimit per son autor",
    "Open {filename}" : "Dobrir {filename}",
    "in {path}" : "dins {path}",
    "Home" : "Domicili",
    "This stream will show events like additions, changes & shares" : "Aqueste fil cronologic mòstra los eveniments coma las addicions, los cambiaments e los partejats.",
    "No activity yet" : "Cap d’activitat pel moment",
    "Activity settings" : "Paramètres d'activitat",
    "Enable RSS feed" : "Activar lo flux RSS",
    "RSS feed" : "Flux RSS",
    "Personal notification settings" : "Paramètres de notificacions personalas",
    "Unable to load the activity list" : "Cargament impossible de la lista de las activitats",
    "Notification" : "Notificacion",
    "Enable notification emails" : "Activar las notificacions per corrièl",
    "Daily activity summary" : "Resumit d’activitat quotidian",
    "Send daily activity summary in the morning" : "Envejar lo resumit d'activitat quotidian lo maitin",
    "Default settings" : "Paramètres par defaut",
    "No more events to load" : "Pas mai d’eveniment de cargar"
},
"nplurals=2; plural=(n > 1);");
