OC.L10N.register(
    "app_api",
    {
    "Cancel" : "Скасувати",
    "Delete" : "Вилучати",
    "Edit" : "Редагувати",
    "Name" : "Назва",
    "Host" : "Хост",
    "Enabled" : "Увімкнено",
    "Display name" : "Ім'я для показу",
    "Network" : "Мережа",
    "Confirm" : "Підтвердити",
    "Save" : "Зберегти",
    "Register" : "Зареєструватися",
    "External Apps" : "Зовнішні застосунки",
    "Update to {version}" : "Оновити до {version}",
    "Remove" : "Вилучити",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Цей застосунок не має обмежень щодо мінімальної версії Nextcloud. В майбутньому це може викликати певні помилки.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Для цього застосунку не визначено найвищу версію Nextcloud. Це може викликати помилку в майбутньому.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Цей застосунок не буде встановлено, оскільки такі залежності неможливо виконати:",
    "View in store" : "Переглянути у крамниці застосунків",
    "Visit website" : "Перейти на вебсайт",
    "Report a bug" : "Повідомити про помилку",
    "User documentation" : "Користувацька документація",
    "Admin documentation" : "Документація адміністратора",
    "Developer documentation" : "Документація для розробника",
    "{license}-licensed" : "Ліцензія: {license}",
    "This app is supported via your current Nextcloud subscription." : "Підтримка застосунку через вашу поточну передплату Nextcloud.",
    "Supported" : "Підтримано",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Функціональні застосунки розробляються спільнотою. Вони пропонують основну функціональність і готові до використання у продуктовому середовищі.",
    "Featured" : "Функціональні",
    "Update to {update}" : "Оновити до {update}",
    "Icon" : "Значок",
    "Version" : "Версія",
    "Daemon" : "Демон",
    "Level" : "Рівень",
    "Actions" : "Дії",
    "Results from other categories" : "Результати з інших категорій",
    "_Update_::_Update all_" : ["Оновити","Оновити все","Оновити все","Оновити все"],
    "Type" : "Тип",
    "Your apps" : "Ваші застосунки",
    "Documentation" : "Документація",
    "Details" : "Деталі",
    "Changelog" : "Зміни",
    "by {author}\n{license}" : "Автор: {author}\n{license}",
    "Active apps" : "Активні застосунки",
    "Disabled apps" : "Неактивні застосунки",
    "Updates" : "Оновлення",
    "Featured apps" : "Функціональне",
    "Supported apps" : "Застосунки, що підтримуються",
    "Enable" : "Увімкнути",
    "Disable" : "Вимкнути",
    "Allow untested app" : "Дозволити непротестовані застосунки",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Відсутня інформація щодо підтримки цього застосунку вашою версією Nextcloud. Ви зможете встановити цей застосунок, проте він може працювати не так, як ви очікуєте.",
    "An error occurred during the request. Unable to proceed." : "Під час запиту сталася помилка. Неможливо продовжити.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Помилка: цей застосунок неможливо увімкнути, оскільки він робить сервер нестабільним"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
