OC.L10N.register(
    "survey_client",
    {
    "An error occurred while sending your report." : "Prodúxose un error mentanto s'unviaba l'informe.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Llista d'aplicaciones <em>(nome, versión estáu d'activación de cada aplicación)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Entornu de la base de datos <em>(tipu, versión, tamañu de la base de datos)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Información del cifráu <em>(estáu de l'activación y el módulu predetermináu)</em>",
    "Usage survey" : "Encuesta d'usu",
    "Help improve Nextcloud" : "Ayuda a ameyorar Nextcloud",
    "Send usage" : "Unviar l'usu",
    "Not now" : "Agora non",
    "Never" : "Enxamás",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Unvia datos anónimos a Nextcloud p'ayudanos a ameyorar Nextcloud.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Pues ayuda a ameyorar Nextcloud unviándonos dalgunos datos tocante a la configuración y l'usu actuales.",
    "Data to send" : "Datos a unviar"
},
"nplurals=2; plural=(n != 1);");
