OC.L10N.register(
    "dav",
    {
    "Calendar" : "التقويم",
    "Tasks" : "المهام",
    "Personal" : "خاص",
    "{actor} created calendar {calendar}" : "{actor} قام بإنشاء تقويم {calendar}",
    "You created calendar {calendar}" : "قمت بإنشاء التقويم {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} قام بفسخ التقويم {calendar}",
    "You deleted calendar {calendar}" : "لقد قمت بحذف التقويم {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} حدّث التقويم {calendar}",
    "You updated calendar {calendar}" : "لقد قمت بتحديث التقويم {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} استعاد التقويم {calendar}",
    "You restored calendar {calendar}" : "أنت استعدت التقويم {calendar}",
    "You shared calendar {calendar} as public link" : "أنت شاركت التقويم {calendar} كرابطٍ عموميٍ public link",
    "You removed public link for calendar {calendar}" : "أنت ألغيب الرابط العمومي للتقويم {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} قام بمشاركة التقويم {calendar} معك",
    "You shared calendar {calendar} with {user}" : "لقد قمت بمشاركة التقويم {calendar} مع {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} قام بمشاركة التقويم {calendar} مع {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} أزال مشاركة التقويم {calendar} منك",
    "You unshared calendar {calendar} from {user}" : "لقد أزلت مشاركة التقويم {calendar} من {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} أزال مشاركة التقويم {calendar} من {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} أزال مشاركة التقويم {calendar} من نفسه",
    "You shared calendar {calendar} with group {group}" : "أنت شاركت التقويم {calendar} مع المجموعة {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} شارك التقويم {calendar} مع المجموعة {group}",
    "You unshared calendar {calendar} from group {group}" : "أنت أزلت مشاركة التقويم {calendar} من المجموعة {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} أزال مشاركة التقويم {calendar} من المجموعة {group}",
    "Untitled event" : "حدث بدون اسم",
    "{actor} created event {event} in calendar {calendar}" : "{actor} أنشأ الحدث {event} في التقويم {calendar}",
    "You created event {event} in calendar {calendar}" : "أنت أنشأت الحدث {event} في التقويم {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} حذف الحدث {event} من التقويم {calendar}",
    "You deleted event {event} from calendar {calendar}" : "أنت حذفت الحدث {event} من التقويم {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} عدّل الحدث {event} في التقويم {calendar}",
    "You updated event {event} in calendar {calendar}" : "أنت عدّلت الحدث {event} في التقويم {calendar}",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} نقل الحدث {event} من التقويم {sourceCalendar} إلى التقويم {targetCalendar}",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "أنت نقلت الحدث {event} من التقويم {sourceCalendar} إلى التقويم {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} قام باستعادة الحدث {event} للتقويم {calendar}",
    "You restored event {event} of calendar {calendar}" : "أنت قمت باستعادة الحدث {event} للتقويم {calendar}",
    "Busy" : "مشغول",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} قائمة بإنشاء مهمة {todo} في القائمة {calendar}",
    "You created to-do {todo} in list {calendar}" : "أنت قمت بإنشاء مهمة {todo} في القائمة {calendar}",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} قام بحذف مهمة {todo} من القائمة {calendar}",
    "You deleted to-do {todo} from list {calendar}" : "أنت قمت بحذف مهمة {todo} من القائمة {calendar}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} قام بتعديل مهمة {todo} في القائمة {calendar}",
    "You updated to-do {todo} in list {calendar}" : "أنت قمت بتعديل مهمة {todo} في القائمة {calendar}",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} أنجز المهمة {todo} في القائمة{calendar}",
    "You solved to-do {todo} in list {calendar}" : "أنت أنجزت المهمة {todo} في القائمة {calendar}",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} أعاد فتح المهمة {todo} في القائمة {calendar}",
    "You reopened to-do {todo} in list {calendar}" : "أنت أعدت فتح المهمة {todo} في القائمة {calendar}",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} قام بنقل المهمة {todo} من القائمة {sourceCalendar} إلى القائمة {targetCalendar}",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "أنت قمت بنقل المهمة {todo} من القائمة {sourceCalendar} إلى القائمة {targetCalendar}",
    "Calendar, contacts and tasks" : "التقويم، و جهات الاتصال، و قائمة المهام",
    "A <strong>calendar</strong> was modified" : " <strong>تقويم</strong> تمّ تعديله",
    "A calendar <strong>event</strong> was modified" : "<strong>حدث</strong> في تقويم تمّ تعديله",
    "A calendar <strong>to-do</strong> was modified" : " <strong>مهمة</strong> في تقويم تمّ تعديلها",
    "Contact birthdays" : "أعياد ميلاد جهات الاتصال",
    "Death of %s" : "وفاة %s",
    "Untitled calendar" : "تقويم بدون اسم",
    "Calendar:" : "التقويم:",
    "Date:" : "التاريخ:",
    "Where:" : "المكان:",
    "Description:" : "الوصف:",
    "_%n year_::_%n years_" : ["في %n أعوام","في %nعام","في %nأعوام","في %nأعوام","في %n أعوام","في %nأعوام"],
    "_%n month_::_%n months_" : [" %n شهور","%n شهر","%n  شهور","%n  شهور","%n  شهور","%n شهور"],
    "_%n day_::_%n days_" : ["%n أيام","%n يوم","%nأيام","%nأيام","%n أيام","%n أيام"],
    "_%n hour_::_%n hours_" : ["%nساعات","%n ساعة","%n ساعات","%n ساعات","%n ساعات","%n ساعات"],
    "_%n minute_::_%n minutes_" : ["%n دقيقة","%n دقيقة","%n دقيقتيْن","%n دقائق","%n دقائق","%n دقائق"],
    "%s (in %s)" : "%s (في %s)",
    "%s (%s ago)" : "%s (%s مضت)",
    "Calendar: %s" : "التقويم: %s",
    "Date: %s" : "التاريخ: %s",
    "Description: %s" : "الوصف: %s",
    "Where: %s" : "المكان: %s",
    "%1$s via %2$s" : "%1$s عبر %2$s",
    "In the past on %1$s for the entire day" : "في الماضي في %1$s لكامل اليوم",
    "_In a minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["في %n دقيقة في %1$s لكامل اليوم","في  %1$s for the entire day","في %n دقيقة في %1$s لكامل اليوم","في %n دقائق في %1$s لكامل اليوم","في %n دقيقة في %1$s لكامل اليوم","في %n دقيقة في %1$s لكامل اليوم"],
    "_In a hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["في %n ساعة في %1$s لكامل اليوم","في ساعة واحدة في %1$s لكامل اليوم","في %n ساعة في %1$s لكامل اليوم","في %n ساعات في %1$s لكامل اليوم","في %n ساعة في %1$s لكامل اليوم","في %n ساعة في %1$s لكل اليوم"],
    "_In a day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["في%n يوم في %1$s لكامل اليوم","في يوم واحد في %1$s لكامل اليوم","في %n يوم في %1$s لكامل اليوم","في %n أيام في %1$s لكامل ايوم","في %n يوم في %1$s لكامل اليوم","في %n يوم في %1$s لكامل اليوم"],
    "_In a week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["في %n أسبوع في %1$s طيلة اليوم","في أسبوع في %1$s طيلة اليوم","في %n أسبوع في %1$s طيلة اليوم","في %n أسابيع في %1$s طيلة اليوم","في %n أسبوع في %1$s طيلة اليوم","في %n أسبوع في %1$s طيلة اليوم"],
    "_In a month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["في %n شهر في %1$s طيلة اليوم","في شهر في %1$s طيلة اليوم","في %n شهر في %1$s طيلة اليوم","في %n أشهر في %1$s طيلة اليوم","في %n شهر في %1$s طيلة اليوم","في %n شهر في %1$s طيلة اليوم"],
    "_In a year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["في %n سنة في %1$s طيلة اليوم","في سنة في %1$s طيلة اليوم","في %n سنة في %1$s طيلة اليوم","في %n سنوات في %1$s طيلة اليوم","في %n سنة في %1$s طيلة اليوم","في %n سنة في %1$s طيلة اليوم"],
    "In the past on %1$s between %2$s - %3$s" : "في الماضي في %1$s بين %2$s - %3$s",
    "_In a minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["في %n دقيقة في %1$s بين %2$s - %3$s","في دقيقة فقي %1$s بين %2$s - %3$s","في %n دقيقة فقي %1$s بين %2$s - %3$s","في %n دقائق في %1$s بين %2$s - %3$s","في %n دقيقة في %1$s بين %2$s - %3$s","في %n دقيقة في %1$s بين %2$s - %3$s"],
    "_In a hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["في %n ساعة في %1$s بين %2$s - %3$s","في ساعة واحدة %1$s بين %2$s - %3$s","في %n ساعة في %1$s بين %2$s - %3$s","في %n ساعات في %1$s بين %2$s - %3$s","في %n ساعة في %1$s بين %2$s - %3$s","في %n ساعة في %1$s بين %2$s - %3$s"],
    "_In a day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["في%n يوم في %1$s بين %2$s - %3$s","في يوم واحد في %1$s بين %2$s - %3$s","في %n يوم %1$s بين %2$s - %3$s","في %n أيام في %1$s بين %2$s - %3$s","في %n يوم في %1$s بين %2$s - %3$s","في %n يوم في %1$s بين %2$s - %3$s"],
    "_In a week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["في %n أسبوع في %1$s بين %2$s - %3$s","في أسبوع واحد في %1$s بين %2$s - %3$s","في %n أسبوع في %1$s بين %2$s - %3$s","في %n أسابيع في %1$s في %2$s - %3$s","في %n أسبوع في %1$s بين %2$s - %3$s","في %n أسبوع في %1$s بين %2$s - %3$s"],
    "_In a month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["في %n شهر في %1$s بين %2$s - %3$s","في شهر واحد في %1$s بين %2$s - %3$s","في %n شهر في %1$s بين %2$s - %3$s","في %n شهور في %1$s بين %2$s - %3$s","في %n شهر في %1$s بين %2$s - %3$s","In %n months on %1$s between %2$s - %3$s"],
    "_In a year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["في %n سنة في %1$s بين %2$s - %3$s","في سنة واحدة في %1$s بين %2$s - %3$s","في %n سنة في %1$s بين %2$s - %3$s","في %n سنوات في %1$s بين %2$s - %3$s","في %n سنة في %1$s بين %2$s - %3$s","في %n سنة في %1$s بين %2$s - %3$s"],
    "Could not generate when statement" : "يتعذّر تكوين عبارة \"متى\"",
    "Every Day for the entire day" : "كل يوم لكامل اليوم",
    "Every Day for the entire day until %1$s" : "كل يوم كامل اليوم حتى %1$s",
    "Every Day between %1$s - %2$s" : "كل يوم بين%1$s - %2$s",
    "Every Day between %1$s - %2$s until %3$s" : "كل يوم بين %1$s - %2$s حتى %3$s",
    "Every %1$d Days for the entire day" : "كل أيام %1$d لكامل اليوم",
    "Every %1$d Days for the entire day until %2$s" : "كل أيام %1$d كل اليوم حتى %2$s",
    "Every %1$d Days between %2$s - %3$s" : "كل أيام %1$d بين %2$s - %3$s",
    "Every %1$d Days between %2$s - %3$s until %4$s" : "كل أيام %1$d بين %2$s - %3$s حتى %4$s",
    "Could not generate event recurrence statement" : "يتعذّر توليد عبارة تكرار الحدث",
    "Every Week on %1$s for the entire day" : "كل أسبوع أيام %1$s كامل اليوم",
    "Every Week on %1$s for the entire day until %2$s" : "كل أسبوع أيام %1$s كامل اليوم حتى %2$s",
    "Every Week on %1$s between %2$s - %3$s" : "كل أسبوع أيام %1$s بين %2$s - %3$s",
    "Every Week on %1$s between %2$s - %3$s until %4$s" : "كل أسبوع أيام %1$s بين %2$s - %3$s حتى %4$s",
    "Every %1$d Weeks on %2$s for the entire day" : "كل%1$d أسبوع أيام %2$s كامل اليوم",
    "Every %1$d Weeks on %2$s for the entire day until %3$s" : "كل %1$d أسبوع أيام %2$s كامل اليوم حتى %3$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s" : "كل %1$d أسبوع أيام %2$s بين %3$s - %4$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s until %5$s" : "كل %1$d أسبوع %2$s بين %3$s - %4$s حتى %5$s",
    "Every Month on the %1$s for the entire day" : "كل شهر أيام %1$s كامل اليوم",
    "Every Month on the %1$s for the entire day until %2$s" : "كل شهر أيام %1$s كامل اليوم حتى %2$s",
    "Every Month on the %1$s between %2$s - %3$s" : "كل شهر أيام %1$s بين %2$s - %3$s",
    "Every Month on the %1$s between %2$s - %3$s until %4$s" : "كل شهر أيام %1$s بين %2$s - %3$s حتى %4$s",
    "Every %1$d Months on the %2$s for the entire day" : "كل %1$d شهر أيام %2$s كامل اليوم",
    "Every %1$d Months on the %2$s for the entire day until %3$s" : "كل %1$d شهر أيام %2$s كامل اليوم حتى %3$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s" : "كل %1$d شهر أيام %2$s بين %3$s - %4$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s until %5$s" : "كل %1$d شهر أيام %2$s بين %3$s - %4$s حتى %5$s",
    "Every Year in %1$s on the %2$s for the entire day" : "كل سنة في %1$s أيام %2$s كامل اليوم",
    "Every Year in %1$s on the %2$s for the entire day until %3$s" : "كل سنة في %1$s أيام %2$s كامل اليوم حتى %3$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s" : "كل سنة في %1$s أيام %2$s بين %3$s - %4$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s until %5$s" : "كل سنة في %1$s أيام %2$s بين %3$s - %4$s حتى %5$s",
    "Every %1$d Years in %2$s on the %3$s for the entire day" : "كل %1$d سنة في %2$s أيام %3$s كامل اليوم",
    "Every %1$d Years in %2$s on the %3$s for the entire day until %4$s" : "كل %1$d سنة في %2$s أيام %3$s كامل اليوم حتى %4$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s" : "كل %1$d سنة في %2$s أيام %3$s بين %4$s - %5$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "كل %1$d سنة في %2$s أيام %3$s بين %4$s - %5$s حتى %6$s",
    "On specific dates for the entire day until %1$s" : "في تورايخ محددة كامل اليوم حتى%1$s",
    "On specific dates between %1$s - %2$s until %3$s" : "في تواريخ محددة بين %1$s - %2$s حتى %3$s",
    "In the past on %1$s" : "في الماضي في %1$s",
    "_In a minute on %1$s_::_In %n minutes on %1$s_" : ["في %n دقيقة في %1$s","في دقيقة واحدة في %1$s","في %n دقيقة في %1$s","في %n دقائق في %1$s","في %n دقيقة في %1$s","في %n دقيقة في %1$s"],
    "_In a hour on %1$s_::_In %n hours on %1$s_" : ["في %n ساعة في %1$s","في ساعة واحدة في%1$s","في %n ساعة في %1$s","في %n ساعات في %1$s","في %n ساعة في %1$s","في %n ساعة في %1$s"],
    "_In a day on %1$s_::_In %n days on %1$s_" : ["في %n يوم في %1$s","في يوم واحد في%1$s","في %n يوم في %1$s","في %n أيام في %1$s","في %n يوم في%1$s","في %n يوم في %1$s"],
    "_In a week on %1$s_::_In %n weeks on %1$s_" : ["في %n أسبوع في %1$s","في أسبوع واحد في %1$s","في %n أسبوع في %1$s","في %n أسابيع في %1$s","في %n أسبوع في %1$s","في %n أسبوع في %1$s"],
    "_In a month on %1$s_::_In %n months on %1$s_" : ["في %n شهر في %1$s","في شهر واحد في %1$s","في %n شهر في %1$s","في %n أشهر في %1$s","في %n شهر في %1$s","في %n شهر في %1$s"],
    "_In a year on %1$s_::_In %n years on %1$s_" : ["في %n سنة في %1$s","في سنة واحدة في %1$s","في %n سنة في %1$s","في %n سنوات في %1$s","في %n سنة في %1$s","في %n سنة في %1$s"],
    "In the past on %1$s then on %2$s" : "في الماضي في %1$s ثم في %2$s",
    "_In a minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["في %n دقيقة في %1$s ثم في %2$s","في دقيقة واحدة في %1$s ثم في %2$s","في %n دقيقة في %1$s ثم في %2$s","فيب %n دقائق في %1$s ثم في %2$s","في %n دقيقة في %1$s ثم في %2$s","في %n دقيقة في %1$s ثم في %2$s"],
    "_In a hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["في %n ساعة في %1$s ثم في %2$s","في ساعة واحدة في %1$s ثم في %2$s","في %n ساعة في %1$s ثم في %2$s","في %n ساعات في %1$s ثم في %2$s","في %n ساعة في %1$s ثم في %2$s","في %n ساعة في %1$s ثم في %2$s"],
    "_In a day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["في %n يوم في %1$s ثم في %2$s","في يوم واحد في %1$s ثم في %2$s","في %n يوم في %1$s ثم في %2$s","في %n أيام في %1$s ثم في %2$s","في %n يوم في %1$s ثم في %2$s","في %n يوم في %1$s ثم في %2$s"],
    "_In a week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["في %n أسبوع في %1$s ثم في %2$s","في أسبوع واحد في %1$s ثم في %2$s","في %n أسبوع في %1$s ثم في %2$s","في %n أسابيع في %1$s ثم في %2$s","في %n أسبوع في %1$s ثم في %2$s","في %n أسبوع في %1$s ثم في %2$s"],
    "_In a month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["في %n شهر في %1$s ثم في %2$s","في شهر واحد في %1$s ثم في %2$s","في %n شهر في %1$s ثم في %2$s","في %n شهور في %1$s ثم في %2$s","في %n شهر في %1$sثم في %2$s","في %n شهر في %1$s ثم في %2$s"],
    "_In a year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["في %n سنة في %1$s ثم في %2$s","في سنة واحدة في %1$s ثم في %2$s","في %n سنة في %1$s ثم في %2$s","في %n سنوات في %1$s ثم في %2$s","في %n سنة في %1$s ثم في %2$s","في %n سنة في %1$s ثم في %2$s"],
    "In the past on %1$s then on %2$s and %3$s" : "في الماضي في %1$s ثم في %2$s و %3$s",
    "_In a minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["في %n دقيقة في %1$s ثم في %2$s و %3$s","في دقيقة واحدة في %1$s ثم في %2$s و %3$s","في %n دقيقة في %1$s ثم في %2$s و %3$s","في %n دقائق في %1$s ثم في %2$s و %3$s","في %n دقيقة في %1$s ثم في %2$s و %3$s","في %n دقيقة في %1$s ثم في %2$s و %3$s"],
    "_In a hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["في %n ساعة في %1$s ثم في %2$s و %3$s","في ساعة واحدة في %1$s ثم في %2$s و %3$s","في %n ساعة في %1$s ثم في %2$s و %3$s","في %n ساعات في %1$s ثم في %2$s و %3$s","في %n ساعة في %1$s ثم في %2$s و %3$s","في %n ساعة في %1$s ثم في %2$s و %3$s"],
    "_In a day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["في %n يوم في %1$s ثم في %2$s و %3$s","في يوم واحد في %1$s ثم ف %2$s و %3$s","في %n يوم في %1$s ثم في %2$s و %3$s","في %n أيام في %1$s ثم في %2$s و %3$s","في %n يوم في %1$s ثم في %2$s و %3$s","في %n يوم في %1$s ثم في %2$s و %3$s"],
    "_In a week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["في %n أسبوع في %1$s ثم في %2$s و %3$s","في أسبوع واحد في %1$s ثم في %2$s و %3$s","في %n أسبوع في %1$s ثم في %2$s و %3$s","في %n أسابيع في %1$s ثم في %2$s و %3$s","في %n أسبوع في %1$s ثم في %2$s و %3$s","في %n أسبوع في %1$s ثم في %2$s و %3$s"],
    "_In a month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["في %n شهر في %1$s ثم في %2$s و %3$s","في شهر واحد في %1$s ثم في %2$s و %3$s","في %n شهر في %1$s ثم في %2$s و %3$s","في %n شهور في %1$s ثم في %2$s و %3$s","في %n شهر في %1$s ثم في %2$s و %3$s","في %n شهر في %1$s ثم في %2$s و %3$s"],
    "_In a year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["في%n سنة في %1$s ثم في %2$s و %3$s","في سنة واحدة في %1$s ثم في %2$s و %3$s","في %n سنة في %1$s ثم في %2$s و %3$s","في %n سنوات في %1$s ثم في %2$s و %3$s","في %n سنة في %1$s ثم في %2$s و %3$s","في %n سنة في %1$s ثم في %2$s و %3$s"],
    "Could not generate next recurrence statement" : "يتعذّر توليد عبارة التكرار التالي",
    "Cancelled: %1$s" : "مُلغىً: %1$s",
    "\"%1$s\" has been canceled" : "\"%1$s\" تمّ إلغاؤه",
    "Re: %1$s" : "إعادة: %1$s",
    "%1$s has accepted your invitation" : "%1$s قبل دعوتك",
    "%1$s has tentatively accepted your invitation" : "%1$s قبل دعوتك بشكل مبدئي",
    "%1$s has declined your invitation" : "%1$s لم يقبل دعوتك",
    "%1$s has responded to your invitation" : "%1$s استجاب لدعوتك",
    "Invitation updated: %1$s" : "تحديث الدعوة: %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s تحديث الحدث \"%2$s\"",
    "Invitation: %1$s" : "دعوة: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s يرغب في دعوتكم إلى \"%2$s\"",
    "Organizer:" : "تنظيم:",
    "Attendees:" : "الحُضُور:",
    "Title:" : "العنوان:",
    "When:" : "متى:",
    "Location:" : "المكان :",
    "Link:" : "الرابط:",
    "Occurring:" : "التكرار:",
    "Accept" : "قبول",
    "Decline" : "رفض",
    "More options …" : "مزيد مِن الخيارات…",
    "More options at %s" : "خيارات أخرى في %s",
    "Monday" : "الإثنين",
    "Tuesday" : "الثلاثاء",
    "Wednesday" : "الأربعاء",
    "Thursday" : "الخميس",
    "Friday" : "الجمعة",
    "Saturday" : "السبت",
    "Sunday" : "الأحد",
    "January" : "يناير",
    "February" : "فبراير",
    "March" : "مارس",
    "April" : "أبريل",
    "May" : "مايو",
    "June" : "يونيو",
    "July" : "يوليو",
    "August" : "اغسطس",
    "September" : "سبتمبر",
    "October" : "أكتوبر",
    "November" : "نوفمبر",
    "December" : "ديسمبر",
    "First" : "أول",
    "Second" : "ثاني",
    "Third" : "ثالث",
    "Fourth" : "رابع",
    "Fifth" : "خامس",
    "Last" : "آخِر",
    "Second Last" : "ما قبل الأخير",
    "Third Last" : "الثالث من الآخِر",
    "Fourth Last" : "الرابع من الآخِر",
    "Fifth Last" : "خامس من الأخير",
    "Contacts" : "جهات الاتصال",
    "{actor} created address book {addressbook}" : "{actor} أنشأ دفتر العناوين {addressbook}",
    "You created address book {addressbook}" : "أنت أنشأت دفتر العناوين {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} قام بحذف دفتر العناوين {addressbook}",
    "You deleted address book {addressbook}" : "أنت قمت بحذف دفتر العناوين {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} قام بتعديل دفتر العناوين {addressbook}",
    "You updated address book {addressbook}" : "أنت قمت بتعديل دفتر العناوين {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} قام بمشاركة دفتر العناوين {addressbook} معك",
    "You shared address book {addressbook} with {user}" : "أنت قمت بمشاركة دفتر العناوين {addressbook} مع {user}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} قام بمشاركة دفتر العناوين {addressbook} مع {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} قام بإلغاء مشاركة دفتر العناوين {addressbook} معك",
    "You unshared address book {addressbook} from {user}" : "أنت قمت بإلغاء مشاركة دفتر العناوين {addressbook} مع {user}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} قام بإلغاء مشاركة دفتر العناوين {addressbook} مع {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} قام بإلغاء مشاركته في دفتر العناوين {addressbook} ",
    "You shared address book {addressbook} with group {group}" : "أنت قمت بمشاركة دفتر العناوين {addressbook} مع المجموعة {group}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} قام بمشاركة دفتر العناوين {addressbook} مع المجموعة {group}",
    "You unshared address book {addressbook} from group {group}" : "أنت قمت بإلغاء مشاركة دفتر العناوين {addressbook} مع المجموعة {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} قام بإلغاء مشاركة دفتر العناوين {addressbook} مع المجموعة {group}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} قام بإنشاء جهة اتصال {card} في دفتر العناوين {addressbook}",
    "You created contact {card} in address book {addressbook}" : "أنت قمت بإنشاء جهة اتصال {card} في دفتر العناوين {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} قام بحذف جهة الاتصال {card} من دفتر العناوين {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "أنت قمت بحذف جهة الاتصال {card} من دفتر العناوين {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} قام بتحديث جهة الاتصال {card} في دفتر العناوين {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "أنت قمت بتحديث جهة الاتصال {card} في دفتر العناوين {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "تمّ تعديل <strong>جهة الاتصال</strong> أو <strong>دفتر العناوين</strong> ",
    "Accounts" : "الحسابات",
    "System address book which holds all accounts" : "دفتر عناوين النظام الذي يحتوي على جميع الحسابات",
    "File is not updatable: %1$s" : "ملف غير قابل للتعديل: %1$s",
    "Failed to get storage for file" : "تعذّر الحصول على مكان لتخزين الملف",
    "Could not write to final file, canceled by hook" : "تعذرت الكتابة إلى الملف النهائي، تم إلغاؤه بواسطة خطّاف hook",
    "Could not write file contents" : "تعذرت كتابة محتويات الملف",
    "_%n byte_::_%n bytes_" : ["بايت","بايت","بايت","بايت","بايت","%n بايت"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "حدث خطأ أثناء نسخ الملف إلى الموقع الهدف  (تمّ نسخه: %1$s, حجم الملف المتوقع: %2$s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "الحجم المتوقع للملف هو %1$s؛ بينما المقروء من ( الجهاز العميل لنكست كلاود)  و المكتوب في (تخزين نكست كلاود) هو %2$s. يمكن أن يكون السبب إمّا مشكلة اتصال في جانب الجهاز العميل أو مشكلة في الكتابة في وحدة التخزين في جانب خادم نكست كلاود .",
    "Could not rename part file to final file, canceled by hook" : "تعذّرت إعادة تسمية ملف جزئي إلى ملف نهائي. تمّ الإلغاء من قِبَل الخطّاف hook.",
    "Could not rename part file to final file" : "تعذّرت إعادة تسمية ملف جزئي إلى ملف نهائي",
    "Failed to check file size: %1$s" : "فشل في تحديد حجم الملف: %1$s",
    "Could not open file: %1$s, file does seem to exist" : "يتعذّر فتح الملف: %1$s, يبدو أن الملف غير موجود",
    "Could not open file: %1$s, file doesn't seem to exist" : "يتعذّر فتح الملف: %1$s, يبدو أن الملف غير موجود",
    "Encryption not ready: %1$s" : "التشفير غير جاهز: %1$s",
    "Failed to open file: %1$s" : "تعذّر فتح الملف: %1$s",
    "Failed to unlink: %1$s" : "تعذّر فك الارتباط: %1$s",
    "Failed to write file contents: %1$s" : "فشل في كتابة محتويات الملف: %1$s",
    "File not found: %1$s" : "ملف غير موجود: %1$s",
    "Invalid target path" : "المسار الهدف غير صحيح",
    "System is in maintenance mode." : "النظام في حالة صيانة.",
    "Upgrade needed" : "يجب التحديث",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "%s الخاص بك يجب تهيئته لاستخدام HTTPS حتى يمكن استعمال CalDAV و CardDAV في نظام التشغيل iOS/macOS. ",
    "Configures a CalDAV account" : "تكوين حساب CalDAV",
    "Configures a CardDAV account" : "تكوين حساب CardDAV",
    "Events" : "أحداث",
    "Untitled task" : "مهمة بدون اسم",
    "Completed on %s" : "تمّ الانتهاء منه في %s",
    "Due on %s by %s" : "مطلوبٌ في %s من قِبَل%s",
    "Due on %s" : "مطلوبٌ في %s",
    "System Address Book" : "دفتر عناوين النظام",
    "The system address book contains contact information for all users in your instance." : "دفتر عناوين النظام يحتوي على معلومات الاتصال لجميع المستخدِمين على خادومك. ",
    "Enable System Address Book" : "تمكين دفتر عناوين النظام",
    "DAV system address book" : "دفتر عناوين نظام DAV",
    "No outstanding DAV system address book sync." : "لا توجد أي مزامنات معلقة لدفتر عناوني نظام DAV.",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "لم يتم تشغيل مزامنة دفتر عناوين نظام DAV حتى الآن بسبب أن الخادم الخاص بك يحتوي على أكثر من 1000 مستخدم أو بسبب حدوث خطأ. يرجى تشغيل المزامنة يدويًا عن طريق الأمر السطري:\n\"occ dav:sync-system-addressbook\"",
    "WebDAV endpoint" : "النقطة النهائية endpoint لـ WebDAV",
    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "تعذر التحقُّق من إعداد خادم الويب عندك بالشكل الصحيح للسماح بمزامنة الملفات عبر WebDAV. يرجى التحقُّق يدوياً.",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : " لم يتم تعيين السماح لخادمك السحابي بتزامن الملف، بسبب واجهة التأليف الموزع على الويب وتعيين الإصدار WebDAV غير متصلة.",
    "Your web server is properly set up to allow file synchronization over WebDAV." : "خادم الويب عندك مُهيّءٌ بالشكل الصحيح للسماح بمزامنة الملفات عبر WebDAV.",
    "Migrated calendar (%1$s)" : "تقويم مُرحّل (%1$s)",
    "Calendars including events, details and attendees" : "تحوي التقاويم الأحداث، و تفاصيلها، و الحُضُور",
    "Contacts and groups" : "جهات الاتصال والمجموعات",
    "WebDAV" : "WebDAV",
    "Absence saved" : "تمّ حفظ الغياب",
    "Failed to save your absence settings" : "تعذّر حفظ إعداداتك للغياب",
    "Absence cleared" : "تمّ محو الغياب",
    "Failed to clear your absence settings" : "تعذّر محو إعداداتك للغياب",
    "First day" : "أول يوم",
    "Last day (inclusive)" : "آخر يوم (متضمن)",
    "Out of office replacement (optional)" : "البديل لمن هو خارج المكتب (إختياري)",
    "Name of the replacement" : "اسم البديل",
    "No results." : "لا نتائج",
    "Start typing." : "أبدا الكتابة",
    "Short absence status" : "حالة الغياب القصير",
    "Long absence Message" : "رسالة الغياب الطويل",
    "Save" : "حفظ",
    "Disable absence" : "تعطيل الغياب",
    "Failed to load availability" : "فشل في تحميل أوقات التواجد",
    "Saved availability" : "تمّ حفظ أوقات التواجد",
    "Failed to save availability" : "تعذّر حفظ أوقات التواجد",
    "Time zone:" : "منطقة زمنية:",
    "to" : "إلى",
    "Delete slot" : "حذف الخانة الزمنية",
    "No working hours set" : "لم يتم تحديد ساعات العمل",
    "Add slot" : "إضافة خانة زمنية",
    "Weekdays" : "أيام الأسبوع",
    "Pick a start time for {dayName}" : "إختَر وقت البدء ليوم {dayName}",
    "Pick a end time for {dayName}" : "إختَر وقت الانتهاء ليوم {dayName}",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "قم بتعيين حالة المستخدم تلقائيًا على \"عدم الإزعاج\" خارج نطاق أوقات التواجد لكتم جميع الإشعارات",
    "Cancel" : "إلغاء",
    "Import" : "إستيراد",
    "Error while saving settings" : "خطأ أثناء حفظ الإعدادات",
    "Contact reset successfully" : "تمّت إعادة تعيين جهة الاتصال بنجاحٍ",
    "Error while resetting contact" : "خطأ أثناء إعادة تعيين جهة الاتصال",
    "Contact imported successfully" : "تمّ استيراد جهة الاتصال بنجاحٍ",
    "Error while importing contact" : "خطأ أثناء استيراد جهة الاتصال",
    "Import contact" : "استيراد جهة اتصال",
    "Reset to default" : "اعادة تعيين الافتراضيات",
    "Import contacts" : "استيراد جهات اتصال",
    "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "استيراد ملف .cvf جديد سوف يؤدي إلى حذف جهات الاتصال التلقائية الحالية واستبدالها بالجديدة. هل ترغب في الاستمرار؟",
    "Availability" : "أوقات التواجد ",
    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "إذا قمت بضبط ساعات عملك، سيرى الآخرون متى تكون خارج المكتب عندما يقومون بحجز اجتماع معك.",
    "Absence" : "غياب",
    "Configure your next absence period." : "تهيئة فترة غيابك القادمة.",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "قم أيضاً بتنصيب {calendarappstoreopen} تطبيق التقويم {linkclose}, أو  {calendardocopen} أوصل جهازك و موبايلك للمُزامنة ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "رجاءُ، تأكّد من الإعداد الصحيح لـ {emailopen} خادم البريد الالكتروني {linkclose}.",
    "Calendar server" : "خادم التقويم",
    "Send invitations to attendees" : "إرسال دعوات للمطلوب حضورهم",
    "Automatically generate a birthday calendar" : "تجاهل تقويم أعياد الميلاد تلقائيّاً",
    "Birthday calendars will be generated by a background job." : "تقويم أعياد الميلاد سيتم توليده من قِبَل مهمةٍ في الخلفية.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "ومن ثمّ لن تكون متاحةً فور التفعيل بل ستظهر بعد مرور بعض الوقت.",
    "Send notifications for events" : "إرسال إشعارات حول الأحداث",
    "Notifications are sent via background jobs, so these must occur often enough." : "يتمّ إرسال الإشعارات من قِبَل مهمّةٍ في الخلفية. لذا سيتكرر عمل هذا المهام حسب الحاجة.",
    "Send reminder notifications to calendar sharees as well" : "أرسل إشعارات للتذكير إلى المشتركين بالتقويم كذلك",
    "Reminders are always sent to organizers and attendees." : "إشعارات التذكير يتم إرسالها دائماً إلى مُنظّم أو مُنظّمي الحدث و المستهدفين بحضوره.",
    "Enable notifications for events via push" : "تمكين الإشعارات حول الأحداث عن طريق أسلوب دفع الإشعارات Push",
    "There was an error updating your attendance status." : "حدث خطأ في تحديث حالة حضورك.",
    "Please contact the organizer directly." : "يرجى الاتصال بالمنظم مباشرةً",
    "Are you accepting the invitation?" : "هل تقبل الدعوة؟",
    "Tentative" : "مبدئي",
    "Your attendance was updated successfully." : "حضورك تم تحديثه بنجاحٍ"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
