OC.L10N.register(
    "circles",
    {
    "Personal" : "ផ្ទាល់​ខ្លួន",
    "Password protected" : "បាន​ការ​ពារ​ដោយ​ពាក្យ​សម្ងាត់",
    "Federated" : "Federated",
    "Admin" : "អ្នក​គ្រប់​គ្រង",
    "Owner" : "Owner",
    "Open %s" : "បើក %s",
    "Name" : "ឈ្មោះ",
    "Size" : "ទំហំ",
    "Modified" : "បាន​កែ​ប្រែ"
},
"nplurals=1; plural=0;");
