OC.L10N.register(
    "files_trashbin",
    {
    "restored" : "Leheneratuta",
    "Deleted files" : "Ezabatutako fitxategiak",
    "Deleted files and folders in the trash bin (may expire during export if you are low on storage space)" : "Ezabatutako fitxategiak eta karpetak zakarrontziko edukiontzian (Esportatzean iraungi daitezke biltegiratze-toki gutxi baduzu)",
    "This application enables people to restore files that were deleted from the system." : "Aplikazio honek pertsonei sistematik ezabatutako fitxategiak leheneratzeko aukera ematen die.",
    "This application enables people to restore files that were deleted from the system. It displays a list of deleted files in the web interface, and has options to restore those deleted files back to the people file directories or remove them permanently from the system. Restoring a file also restores related file versions, if the versions application is enabled. When a file is deleted from a share, it can be restored in the same manner, though it is no longer shared. By default, these files remain in the trash bin for 30 days.\nTo prevent an account from running out of disk space, the Deleted files app will not utilize more than 50% of the currently available free quota for deleted files. If the deleted files exceed this limit, the app deletes the oldest files until it gets below this limit. More information is available in the Deleted Files documentation." : "Aplikazio honek aukera ematen die pertsonei sistematik ezabatutako fitxategiak leheneratzeko. Web interfazean ezabatutako fitxategien zerrenda bistaratzen du, eta ezabatutako fitxategiak erabiltzaileen fitxategi direktorioetara leheneratu edo sistematik betirako kentzeko aukerak ditu. Fitxategia leheneratzeak erlazionatutako fitxategi bertsioak ere leheneratzen ditu, bertsioen aplikazioa gaituta badago.  Fitxategia partekatzetik ezabatzen denean, modu berean leheneratu daiteke, jada partekatzen ez bada ere. Modu lehenetsian, fitxategi hauek 30 egunez geratzen dira zakarrontzian.\nKontua diskoan lekurik gabe geratzea saihesteko, Ezabatutako Fitxategiak aplikazioak ez du ezabatutako fitxategietarako uneko kuota librearen % 50 baino gehiago erabiliko. Ezabatutako fitxategiek muga hori gainditzen badute, aplikazioak fitxategi zaharrenak ezabatuko ditu muga horren azpitik egon arte. Informazio gehiago erabilgarri dago Ezabatutako Fitxategiak ataleko dokumentazioan.",
    "Restore" : "Leheneratu",
    "Empty deleted files" : "Hustu ezabatutako fitxategiak",
    "Confirm permanent deletion" : "Berretsi betirako ezabatzea",
    "Are you sure you want to permanently delete all files and folders in the trash? This cannot be undone." : "Ziur betiko ezabatu nahi dituzula zakarrontziko fitxategi eta karpetak? Hau ezin da desegin.",
    "Cancel" : "Utzi",
    "Original location" : "Jatorrizko kokalekua",
    "Deleted by" : "Honek ezabatuta",
    "Deleted" : "Ezabatuta",
    "A long time ago" : "Orain dela denbora asko",
    "Unknown" : "Ezezaguna",
    "All files" : "Fitxategi guztiak",
    "You" : "Zu ",
    "List of files that have been deleted." : "Ezabatu diren fitxategien zerrenda.",
    "No deleted files" : "Ez dago ezabatutako fitxategirik",
    "Files and folders you have deleted will show up here" : "Ezabatu dituzun fitxategi eta karpetak hemen agertuko dira",
    "Deletion cancelled" : "Ezabatzea bertan behera utzi da"
},
"nplurals=2; plural=(n != 1);");
