<?php
namespace Aws\B2bi\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS B2B Data Interchange** service.
 */
class B2biException extends AwsException {}
