OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Додано зірочку",
    "Removed from favorites" : "Вилучено зірочку",
    "You added {file} to your favorites" : "Ви додали зірочку для {file}",
    "You removed {file} from your favorites" : "Ви прибрали зірочку для {file}",
    "Favorites" : "Із зірочкою",
    "File changes" : "Зміни у файлах",
    "Created by {user}" : "Створено користувачем {user}",
    "Changed by {user}" : "Змінено користувачем {user}",
    "Deleted by {user}" : "Вилучено користувачем {user}",
    "Restored by {user}" : "Відновлено користувачем {user}",
    "Renamed by {user}" : "Перейменовано користувачем {user}",
    "Moved by {user}" : "Переміщено користувачем {user}",
    "\"remote account\"" : "\"віддалений обліковий запис\"",
    "You created {file}" : "Ви створили {file}",
    "You created an encrypted file in {file}" : "Ви створили зашифрований файл у {file}",
    "{user} created {file}" : "{user} створив(-ла) файл {file}",
    "{user} created an encrypted file in {file}" : "{user} створив(-ла) зашифрований файл у {file}",
    "{file} was created in a public folder" : "Файл {file} створено у публічному каталозі",
    "You changed {file}" : "Ви змінили файл {file}",
    "You changed an encrypted file in {file}" : "Ви змінили зашифрований файл у {file}",
    "{user} changed {file}" : "{user} змінив(-ла) файл {file}",
    "{user} changed an encrypted file in {file}" : "{user} змінив(-ла) зашифрований файл {file}",
    "You deleted {file}" : "Ви вилучили {file}",
    "You deleted an encrypted file in {file}" : "Ви вилучити зашифрований файл у {file}",
    "{user} deleted {file}" : "{user} вилучив(-ла) {file}",
    "{user} deleted an encrypted file in {file}" : "{user} вилучив зашифрований файл у {file}",
    "You restored {file}" : "Ви відновили {file}",
    "{user} restored {file}" : "{user} відновив(-ла) {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Ви перейменували файл {oldfile} (прихований) на {newfile} (прихований)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Ви перейменували файл {oldfile} (прихований) на {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Ви перейменували файл {oldfile} на {newfile} (прихований)",
    "You renamed {oldfile} to {newfile}" : "Ви перейменували файл {oldfile} на {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} перейменував {oldfile} (прихований) у {newfile} (прихований)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} перейменував {oldfile} (прихований) у {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} перейменував {oldfile} у {newfile} (прихований)",
    "{user} renamed {oldfile} to {newfile}" : "{user} перейменував(-ла) {oldfile} у {newfile}",
    "You moved {oldfile} to {newfile}" : "Ви перемістили {oldfile} до {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} перемістив(-ла) {oldfile} до {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Файл було додано або вилучено з ваших документів <strong>із зірочкою</strong>",
    "Files" : "Файли",
    "A file or folder has been <strong>changed</strong>" : "Файл або каталог було <strong> змінено </strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Файл або каталог із зірочкою було <strong>змінено</strong>",
    "Failed to authorize" : "Не вдалося авторизуватися",
    "Invalid folder path" : "Недійсний шлях до каталогу",
    "Folder not found" : "Каталог не знайдено",
    "The file cannot be found" : "Цей файл неможливо знайти",
    "The destination path does not exist: %1$s" : "Шлях призначення відсутній: %1$s",
    "You do not have permission to create a file at the specified location" : "У вас відсутні права на створення файлу у визначеному розташуванні",
    "The file could not be converted." : "Файл неможливо конвертувати",
    "Could not get relative path to converted file" : "Не вдалося отримати відносний шлях до сконвертованого файлу",
    "Favorite files" : "Файли із зіркою",
    "No favorites" : "Немає улюблених",
    "More favorites" : "Ще файли із зіркою",
    "Accept" : "Прийняти",
    "Reject" : "Відхилити",
    "Incoming ownership transfer from {user}" : "Запит від користувача {user} на передавання прав власника",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Прийняти {path}?\n\nУвага: Процес передавання після прийняття запиту може тривати до 1 години.",
    "Ownership transfer denied" : "Перенесення прав власності відхилено",
    "Your ownership transfer of {path} was denied by {user}." : "Перенесення прав на ваші дані {path} відхилено користувачем {user}.",
    "Ownership transfer failed" : "Не вдалося передати право власності",
    "Your ownership transfer of {path} to {user} failed." : "Не вдалося перадати ваші права власника на {path} користувачеві {user}.",
    "The ownership transfer of {path} from {user} failed." : "Не вдалося передати права власника на {path} від користувача {user}.",
    "Ownership transfer done" : "Право власності передано",
    "Your ownership transfer of {path} to {user} has completed." : "Ваші права власника на {path} успішно передано користувачеві {user}.",
    "The ownership transfer of {path} from {user} has completed." : "Завершено передавання права власника на {path} від користувача {user}.",
    "in %s" : "в %s",
    "Transferred from %1$s on %2$s" : "Перенесено від %1$s до %2$s",
    "Files compatibility" : "Сумісність файлів",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Дозволити обмежувати імена файлів для забезпечення сумісності з різними клієнтами. Типово всі імена файлів, які  відповідають моделі POSIX (напр., Linux, macOS), дозволені.",
    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Після увімкнення сумісности імен файлів з системою Windows наявні файли неможливо буде змінити, але власники зможуть перейменувати ці файли на нові з дійсними іменами.",
    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Також можлива автоматична міграція файлів після увімкнення цих налаштувань. Ознайомтеся з документацією відповідної команди occ.",
    "Enforce Windows compatibility" : "Увімкнути сумісність із Windows",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Це унеможливить використання імен файлів, які не сумісні з системами Windows, напр., використанння зарезервованих імен або спеціальних символів. Зауважте, що це не обмежить сумісність за регістром символів.",
    "File Management" : "Керування файлами",
    "Home" : "Домівка",
    "Target folder does not exist any more" : "Каталог призначення більше не дійсний",
    "Reload current directory" : "Перезавантажити поточний каталог",
    "Go to the \"{dir}\" directory" : "Перейти до каталогу \"{dir}\"",
    "Current directory path" : "Шлях до поточного каталогу",
    "Your have used your space quota and cannot upload files anymore" : "Ви вже використали квоту на місце та не можете завантажувати файли",
    "You do not have permission to upload or create files here." : "У вас відсутній дозвіл завантажувати або створювати тут файли.",
    "Drag and drop files here to upload" : "Перетягніть файли сюди для завантаження",
    "Favorite" : "Додати зірочку",
    "Back" : "Назад",
    "Toggle selection for file \"{displayName}\"" : "Перемкнути вибір для файлу \"{displayName}\"",
    "Toggle selection for folder \"{displayName}\"" : "Перемкнути вибір для каталогу \"{displayName}\"",
    "File is loading" : "Завантаження файлу",
    "Folder is loading" : "Завантаження каталогу",
    "Filename" : "Ім'я файлу",
    "Folder name" : "Назва каталогу",
    "This node is unavailable" : "Цей вузол не доступний",
    "Another entry with the same name already exists." : "Інший запис з таким же ім'ям вже присутній",
    "Invalid filename." : "Недійсне ім'я файлу.",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Перейменовано \"{oldName}\" на \"{newName}\"",
    "Rename file" : "Перейменувати файл",
    "Folder" : "Каталог",
    "Unknown file type" : "Невідомий тип файлу",
    "{ext} image" : "{ext} зображення",
    "{ext} video" : "{ext} відео",
    "{ext} audio" : "{ext} аудіо",
    "{ext} text" : "{ext} текст",
    "Pending" : "Очікування",
    "Unknown date" : "Невідома дата",
    "Clear filter" : "Очистити фільтр",
    "Modified" : "Змінено",
    "Search everywhere" : "Шукати всюди",
    "Type" : "Тип",
    "Active filters" : "Активні фільтри",
    "Remove filter" : "Вилучити фільтр",
    "Total rows summary" : "Загалом рядків",
    "Toggle selection for all files and folders" : "Перемкнути вибір для всіх файлів та каталогів",
    "Name" : "Ім'я",
    "File type" : "Тип файлу",
    "Size" : "Розмір",
    "{displayName}: failed on some elements" : "{displayName}: не вдалося виконати деякі елементи",
    "{displayName}: done" : "{displayName}: готово",
    "{displayName}: failed" : "{displayName}: не вдалося",
    "Actions" : "Дії",
    "(selected)" : "(вибрано)",
    "List of files and folders." : "Список файлів та каталогів",
    "You have used your space quota and cannot upload files anymore." : "Ви вже використали ліміт сховища та більше не зможете завантажувати файли.",
    "Column headers with buttons are sortable." : "Назви стовпців з кнопками можна впорядковувати",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Список не подається повністю з міркувань обчислювальних потужностей. Файли показуватимуться під час прокручування списку.",
    "File not found" : "Файл не знайдено",
    "_{count} selected_::_{count} selected_" : ["Вибрано {count}","Вибрано {count}","Вибрано {count} ","Вибрано {count} "],
    "Search everywhere …" : "Шукати всюди ...",
    "Search here …" : "Шукати тут …",
    "Search scope options" : "Визначити місце пошуку",
    "Search here" : "Шукати тут",
    "{usedQuotaByte} used" : "{usedQuotaByte} використано",
    "{used} of {quota} used" : "Використано {used} із {quota}",
    "{relative}% used" : "{relative}% використано",
    "Could not refresh storage stats" : "Неможливо оновити статистику сховища",
    "Your storage is full, files can not be updated or synced anymore!" : "Ваше сховище переповнене, файли більше не можуть бути оновлені або синхронізовані!",
    "Storage information" : "Інформація про сховище",
    "Storage quota" : "Квота сховища",
    "New folder" : "Новий каталог",
    "Create new folder" : "Створити новий каталог",
    "This name is already in use." : "Це ім'я вже використовується",
    "Create" : "Створити",
    "Files starting with a dot are hidden by default" : "Файли, що починаються з крапки, типово приховано",
    "Fill template fields" : "Заповнити поля шаблону",
    "Submitting fields …" : "Надсилання полів ...",
    "Submit" : "Відправити",
    "Choose a file or folder to transfer" : "Виберіть файл або каталог",
    "Transfer" : "Передати",
    "Transfer {path} to {userid}" : "Передати {path} користувачеві {userid}",
    "Invalid path selected" : "Вибрано неправильний шлях",
    "Unknown error" : "Невідома помилка",
    "Ownership transfer request sent" : "Запит на передавання прав власника надіслано",
    "Cannot transfer ownership of a file or folder you do not own" : "Неможливо передати права власності на файл або каталог, якими ви не володієте",
    "Transfer ownership of a file or folder" : "Передавання прав власника на файл або каталог",
    "Choose file or folder to transfer" : "Виберіть цільовий файл або каталог",
    "Change" : "Змінити",
    "New owner" : "Новий власник",
    "Keep {old}" : "Зберегти {old}",
    "Keep without extension" : "Зберегти без розширення",
    "Use {new}" : "Використовувати {new}",
    "Remove extension" : "Вилучити розширення файлу",
    "Change file extension" : "Змінити розширення файлу",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Заміна розширення файлу з \"{old}\" на \"{new}\" може зробити файл недоступним.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "Вилучення розширення файлу \"{old}\" може зробити файл недоступним.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "Додавання розширення до файлу \"{new}\" може зробити файл недоступним.",
    "Do not show this dialog again." : "Не показувати цей діялог подалі.",
    "Select file or folder to link to" : "Виберіть файл або каталог, до якого потрібно застосувати посилання",
    "Choose {file}" : "Виберіть {file}",
    "Share" : "Поширити",
    "Shared by link" : "Доступ за посиланням",
    "Shared" : "Спільне",
    "Switch to list view" : "У вигляді списку",
    "Switch to grid view" : "У вигляді сітки",
    "The file could not be found" : "Неможливо знайти файл",
    "Upload was cancelled by user" : "Завантаження скасовано користувачем",
    "Not enough free space" : "Недостатньо вільного місця",
    "Operation is blocked by access control" : "Операцію заблоковано через контроль доступу",
    "Error during upload: {message}" : "Помилка під час завантаження: {message}",
    "Error during upload, status code {status}" : "Помилка під час завантаження, код стану {status}",
    "Unknown error during upload" : "Невідома помилка під час завантаження",
    "Loading current folder" : "Отримання поточного каталогу",
    "Retry" : "Ще раз",
    "No files in here" : "Тут немає файлів",
    "Upload some content or sync with your devices!" : "Завантажте вміст або синхронізуйтеся з вашими пристроями!",
    "Go back" : "Повернутися назад",
    "Views" : "Подання",
    "Files settings" : "Налаштування",
    "Your files" : "Ваші файли",
    "Open in files" : "Відкрити у файлах",
    "File cannot be accessed" : "Неможливо отримати доступ до файлу",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Не вдалося знайти файл або у вас відсутній дозвіл на перегляд файлу. Попросіть поділитися цим файлом.",
    "No search results for “{query}”" : "Відсутні результати для \"{query}\"",
    "Search for files" : "Шукати файли",
    "Clipboard is not available" : "Буфер обміну недоступний",
    "WebDAV URL copied" : "URL-адреса WebDAV скопійована",
    "General" : "Загальне",
    "Default view" : "Типовий вигляд",
    "All files" : "Усі файли",
    "Personal files" : "Мої документи",
    "Sort favorites first" : "Спочатку показувати із зірочкою",
    "Sort folders before files" : "Показувати каталоги перед файлами",
    "Folder tree" : "Дерево каталогів",
    "Appearance" : "Вигляд",
    "Show hidden files" : "Показувати приховані файли",
    "Show file type column" : "Показувати стовпець з типом файлу",
    "Show file extensions" : "Show file extensions",
    "Crop image previews" : "Попередній перегляд перед кадруванням",
    "Additional settings" : "Додатково",
    "WebDAV" : "WebDAV",
    "WebDAV URL" : "URL-адреса WebDAV",
    "Copy" : "Копіювати",
    "How to access files using WebDAV" : "Як отримати доступ до файлів за допомогою WebDAV",
    "Two-Factor Authentication is enabled for your account, and therefore you need to use an app password to connect an external WebDAV client." : "Для вашого облікового запису увімкнено двофакторну авторизацію, таким чином вам потрібно буде використовувати пароль для застосунку для з'єднання із зовнішнім клієнтом WebDAV.",
    "Warnings" : "Застереження",
    "Warn before changing a file extension" : "Попереджати перед зміною розширення файлу",
    "Warn before deleting files" : "Попереджати перед видаленням файлів",
    "Keyboard shortcuts" : "Скорочення",
    "File actions" : "Дії з файлами",
    "Rename" : "Перейменувати",
    "Delete" : "Вилучити",
    "Add or remove favorite" : "Додати або видалити з улюблених",
    "Manage tags" : "Керування мітками",
    "Selection" : "Вибір",
    "Select all files" : "Вибрати всі файли",
    "Deselect all" : "Зняти всі мітки",
    "Select or deselect" : "Вибрати або скасувати вибір",
    "Select a range" : "Виберіть діапазон",
    "Navigation" : "Навігація",
    "Go to parent folder" : "Перейти до батьківської папки",
    "Go to file above" : "Перейти до файлу вище",
    "Go to file below" : "Перейти до файлу нижче",
    "Go left in grid" : "Перейти ліворуч у сітці",
    "Go right in grid" : "Перейти праворуч у сітці",
    "View" : "Подання",
    "Toggle grid view" : "Перемкнути подання сіткою",
    "Open file sidebar" : "Відкрити бічну панель файлів",
    "Show those shortcuts" : "Показувати ці скорочення",
    "You" : "Ви",
    "Shared multiple times with different people" : "Поділилися кілька разів з різними людьми",
    "Unable to change the favorite state of the file" : "Неможливо змінити статус вподобаного файлу",
    "Error while loading the file data" : "Помилка під час отримання даних щодо файлу",
    "Owner" : "Власник",
    "Remove from favorites" : "Прибрати зірочку",
    "Add to favorites" : "Додати зірочку",
    "Tags" : "Мітки",
    "Blank" : "Порожньо",
    "Unable to create new file from template" : "Неможливо створити новий файл з шаблону",
    "Pick a template for {name}" : "Вибрати шаблон для {name}",
    "Create a new file with the selected template" : "Створити новий файл на основі вибраного шаблону",
    "Creating file" : "Створення файлу",
    "Save as {displayName}" : "Зберегти як {displayName}",
    "Save as …" : "Зберегти як ...",
    "Converting files …" : "Конвертування файлів ...",
    "Failed to convert files: {message}" : "Не вдалося конвертувати файли: {message}",
    "All files failed to be converted" : "Не вдалося конвертувати жодний файл",
    "One file could not be converted: {message}" : "Неможливо конвертувати один файл: {message}",
    "_One file could not be converted_::_%n files could not be converted_" : ["Неможливо конвертувати 1 файл","Неможливо конвертувати %n файли","Неможливо конвертувати %n файлів","Неможливо конвертувати %n файлів"],
    "_One file successfully converted_::_%n files successfully converted_" : ["Успішно конвертовано 1 файл","Успішно конвертовано %n файли","Успішно конвертовано %n файлів","Успішно конвертовано %n файлів"],
    "Files successfully converted" : "Файли успішно конвертовано",
    "Failed to convert files" : "Не вдалося конвертувати файли",
    "Converting file …" : "Конвертування файлу ...",
    "File successfully converted" : "Файл успішно конвертовано",
    "Failed to convert file: {message}" : "Не вдалося конвертувати файл: {message}",
    "Failed to convert file" : "Не вдалося конвертувати файл",
    "Leave this share" : "Вийти зі спільного доступу",
    "Leave these shares" : "Вийти зі спільного доступу",
    "Disconnect storage" : "Від’єднати сховище",
    "Disconnect storages" : "Від'єднати сховища",
    "Delete permanently" : "Вилучити назавжди",
    "Delete and unshare" : "Вилучити та прибрати спільний доступ",
    "Delete file" : "Вилучити файл",
    "Delete files" : "Вилучити файли",
    "Delete folder" : "Вилучити каталог",
    "Delete folders" : "Вилучити каталоги",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Ви намагаєтеся назавжли вилучити {count} ресурс","Ви намагаєтеся назавжли вилучити {count} ресурси","Ви намагаєтеся назавжли вилучити {count} ресурсів","Ви намагаєтеся назавжли вилучити {count} ресурсів"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Ви намагаєтеся вилучити {count} ресурс","Ви намагаєтеся вилучити {count} ресурси","Ви намагаєтеся  вилучити {count} ресурсів","Ви намагаєтеся вилучити {count} ресурсів"],
    "Confirm deletion" : "Підтвердіть вилучення",
    "Cancel" : "Скасувати",
    "Download" : "Звантажити",
    "Moving \"{source}\" to \"{destination}\" …" : "Переміщення \"{source}\" до \"{destination}\" …",
    "Copying \"{source}\" to \"{destination}\" …" : "Копіювання \"{source}\" до \"{destination}\" …",
    "Destination is not a folder" : "Місце призначення не є каталогом",
    "This file/folder is already in that directory" : "Такий файл чи каталог вже присутні в цьому каталозі",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Неможливо перемістити файл чи каталог до самого себе або у цей саме підкаталог",
    "(copy)" : "(копія)",
    "(copy %n)" : "(копія %n)",
    "A file or folder with that name already exists in this folder" : "Файл чи каталог з таким ім'ям вже присутній в цьому каталозі",
    "The files are locked" : "Файли заблоковано",
    "The file does not exist anymore" : "Цей файл більше недоступний",
    "Choose destination" : "Виберіть каталог призначення",
    "Copy to {target}" : "Копіювати до {target}",
    "Move to {target}" : "Перемістити до {target}",
    "Move" : "Перемістити",
    "Move or copy operation failed" : "Не вдалося скопіювати або перемістити",
    "Move or copy" : "Перемістити або копіювати",
    "Open folder {displayName}" : "Відкрити каталог {displayName}",
    "Open in Files" : "Відкрити у Файлах",
    "Open locally" : "Відкрити локально",
    "Failed to redirect to client" : "Не вдалося перенаправити на клієнта",
    "Open file locally" : "Відкрити файл локально",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Тепер файл можна відкрити на вашому пристрої. Якщо він не відкривається, перевірте, що у вас встановлено настільний клієнт синхронізації.",
    "Retry and close" : "Спробувати ще раз",
    "Open online" : "Відкрити віддалено",
    "Details" : "Деталі",
    "View in folder" : "Переглянути у каталозі",
    "Today" : "Сьогодні",
    "Last 7 days" : "За останні 7 днів",
    "Last 30 days" : "За останні 30 днів",
    "This year ({year})" : "Цього року ({year})",
    "Last year ({year})" : "Минулого року ({year})",
    "Documents" : "Документи",
    "Spreadsheets" : "Електронні таблиці",
    "Presentations" : "Презентації",
    "PDFs" : "Файли PDF",
    "Folders" : "Каталоги",
    "Audio" : "Аудіо",
    "Images" : "Зображення",
    "Videos" : "Відео",
    "Created new folder \"{name}\"" : "Створив(-ла) новий каталог \"{name}\"",
    "Unable to initialize the templates directory" : "Неможливо встановити каталог з шаблонами",
    "Create templates folder" : "Створити каталог для шаблонів",
    "Templates" : "Шаблони",
    "New template folder" : "Новий каталог шаблонів",
    "In folder" : "У каталозі",
    "Search in all files" : "Пошук у всіх файлах",
    "Search in folder: {folder}" : "Шукати у каталозі: {folder}",
    "One of the dropped files could not be processed" : "Один із завантажених файлів не вдалося обробити",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Ваш бравзер не підтримує Filesystem API. Каталоги не буде завантажено",
    "No files to upload" : "Відсутні файли для завантаження",
    "Unable to create the directory {directory}" : "Неможливо створити каталог {directory}",
    "Some files could not be uploaded" : "Не вдалося завантажити окремі файли",
    "Files uploaded successfully" : "Файли успішно завантажено",
    "No files to process" : "Відсутні файли для обробки",
    "Some files could not be copied" : "Неможливо скопіювати окремі файли",
    "Some files could not be moved" : "Окремі файли неможливо перемістити",
    "Files copied successfully" : "Файли успішно скопійовано",
    "Files moved successfully" : "Файли успішно переміщено",
    "Conflicts resolution skipped" : "Пропущено розв'язання конфліктів",
    "Upload cancelled" : "Завантаження скасовано",
    "Could not rename \"{oldName}\", it does not exist any more" : "Не вдалося перейментувати \"{oldName}\", оскільки він вже відсутній",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Ім'я \"{newName}\" вже використовується у каталозі \"{dir}\". Виберіть інше ім'я.",
    "Could not rename \"{oldName}\"" : "Не вдалося перейменувати \"{oldName}\"",
    "This operation is forbidden" : "Операцію заборонено",
    "This folder is unavailable, please try again later or contact the administration" : "Ця папка недоступна, спробуйте пізніше або зверніться до адміністрації.",
    "Storage is temporarily not available" : "Сховище тимчасово недоступне",
    "Unexpected error: {error}" : "Неочікувана помилка: {error}",
    "_%n file_::_%n files_" : ["%n файл","%n файли","%n файлів","%n файлів"],
    "_%n folder_::_%n folders_" : ["%n каталог ","%n каталоги ","%n каталогів ","%n каталогів"],
    "_%n hidden_::_%n hidden_" : ["%n приховано","%n приховано","%n приховано","%n приховано"],
    "Filename must not be empty." : "Імена файлів не мають бути порожні.",
    "\"{char}\" is not allowed inside a filename." : "Символ \"{char}\" не дозволено у імені файлу.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" є зарезервованим ім'ям і не дозволяється у іменах файлів.",
    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" не є дозволеним типом файлів.",
    "Filenames must not end with \"{extension}\"." : "Імена файлів не мають закінчуватися на \"{extension}\".",
    "List of favorite files and folders." : "Список файлів та каталогів із зірочкою.",
    "No favorites yet" : "Поки немає нічого, позначеного зірочкою",
    "Files and folders you mark as favorite will show up here" : "Файли та каталоги із зірочкою з’являться тут",
    "List of your files and folders." : "Список ваших файлів та каталогів.",
    "List of your files and folders that are not shared." : "Перелік ваших файлів та каталогів, які не є у спільному доступі.",
    "No personal files found" : "Мої документи не знайдено",
    "Files that are not shared will show up here." : "Тут показуватимуться файли, які не є у спільному доступі.",
    "Recent" : "Останні",
    "List of recently modified files and folders." : "Список нещодавно змінених файлів та каталогів.",
    "No recently modified files" : "Відсутні файли із нещодавними змінами",
    "Files and folders you recently modified will show up here." : "Тут показуватимуться файли та каталоги, які було нещодавно змінено.",
    "Search" : "Пошук",
    "Search results within your files." : "Шукати результати серед ваших файлів.",
    "No entries found in this folder" : "В цьому каталозі нічого не знайдено",
    "Select all" : "Вибрати все",
    "Upload too large" : "Файл занадто великий",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Файли, які ви намагаєтеся завантажити, перевищують максимально дозволений розмір завантаження файлів на сервер.",
    "File could not be found" : "Неможливо знайти файл",
    "Show list view" : "Подання списком",
    "Show grid view" : "Подання сіткою",
    "Close" : "Закрити",
    "Could not create folder \"{dir}\"" : "Неможливо створити каталог \"{dir}\"",
    "This will stop your current uploads." : "Ця дія призведе до зупинки поточних завантажень на сервер.",
    "Upload cancelled." : "Завантаження скасовано.",
    "Processing files …" : "Триває обробка файлів...",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Неможливо завантажити {filename}, оскільки він є або каталогом, або файл має розмір 0 байт.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Недостатньо вільного місця, ви завантажуєте {size1}, а залишилося лише {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Каталог призначення \"{dir}\" більше не дійсний.",
    "An unknown error has occurred" : "Сталася невідома помилка",
    "File could not be uploaded" : "Неможливо завантажити файл",
    "Uploading …" : "Завантаження…",
    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber} із {total})",
    "Uploading … ({currentNumber}/{total})" : "Завантаження ... ({currentNumber}/{total})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} з {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Завантаження цього елемента не підтримується",
    "Error when assembling chunks, status code {status}" : "Помилка під час збірки частин, код помилки {status}",
    "Choose target folder" : "Виберіть каталог призначення",
    "Set reminder" : "Встановити нагадування",
    "Edit locally" : "Відкрити на пристрої",
    "Open" : "Відкрити",
    "Could not load info for file \"{file}\"" : "Не вдалося отримати дані щодо файлу \"{file}\"",
    "Please select tag(s) to add to the selection" : "Виберіть мітки, які ви додасте до вибраного",
    "Apply tag(s) to selection" : "Додатки мітки до вибраного",
    "Select directory \"{dirName}\"" : "Виберіть каталог \"{dirName}\"",
    "Select file \"{fileName}\"" : "Вибрати файл \"{fileName}\"",
    "Unable to determine date" : "Неможливо визначити дату",
    "This directory is unavailable, please check the logs or contact the administrator" : "Каталог недоступний, будь ласка, перевірте файл журналу або зверніться до адміністратора  ",
    "Could not move \"{file}\", target exists" : "Не вдалося перемістити файл \"{file}\", оскільки файл з таким ім'ям вже присутній",
    "Could not move \"{file}\"" : "Неможливо перемістити файл \"{file}\"",
    "copy" : "копія",
    "Could not copy \"{file}\", target exists" : "Не вдалося скопіювати файл \"{file}\", оскільки файл з таким ім'ям вже присутній",
    "Could not copy \"{file}\"" : "Неможливо скопіювати \"{file}\"",
    "Copied {origin} inside {destination}" : "Скопійовано {origin} до {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} та {nbfiles} інших файлів скопійовано до {destination}",
    "{newName} already exists" : "{newName} вже існує",
    "Could not create file \"{file}\"" : "Неможливо створити файл \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Неможливо створити файл \"{file}\", оскільки файл з таким ім'ям вже присутній.",
    "Could not create folder \"{dir}\" because it already exists" : "Неможливо створити каталог \"{dir}\", оскільки каталог з таким ім'ям він вже присутній.",
    "Could not fetch file details \"{file}\"" : "Неможливо отримати деталі файлу \"{file}\"",
    "Error deleting file \"{fileName}\"." : "Помилка вилучення файлу \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Нічого не знайдено в інших каталогах за запитом {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Для пошуку в інших каталогах потрібно зазначити більше двох символів",
    "{dirs} and {files}" : "{dirs} та {files}",
    "_including %n hidden_::_including %n hidden_" : ["включаючи %n прихований","включаючи %n прихованих","включаючи %n прихованих","включно %n прихованих"],
    "You do not have permission to upload or create files here" : "У вас відсутні повноваження для завантаження або створення файлів тут",
    "_Uploading %n file_::_Uploading %n files_" : ["Вивантаження %n файлу","Вивантаження %n файлів","Вивантаження %n файлів","Завантаження %n файлів"],
    "New" : "Створити",
    "New file/folder menu" : "Меню з новим файлом/каталогом",
    "Select file range" : "Вибрати кілька файлів",
    "{used}%" : "{used}%",
    "{used} used" : "Використано {used}",
    "\"{name}\" is an invalid file name." : "\"{name}\" є некоректним ім'ям файлу.",
    "File name cannot be empty." : " Ім'я файлу не може бути порожнім.",
    "\"/\" is not allowed inside a file name." : "Символ \"/\" не дозволено в імені файлу.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" є неприпустимим типом файлу",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Сховище {owner} переповнено, подальша синхронізація файлів неможлива!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Груповий каталог \"{mountPoint}\" переповнено, подальша синхронізація файлів неможлива!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Зовнішнє сховище \"{mountPoint}\" переповнено, подальша синхронізація файлів не можлива!",
    "Your storage is full, files cannot be updated or synced anymore!" : "Ваше сховище переповнено, подальша синхронізація файлів неможлива!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Сховище користувача {owner} майже заповнений ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Груповий каталог \"{mountPoint}\" майже заповнений ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Зовнішнє сховище \"{mountPoint}\" майже заповнено ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Ваше сховище майже заповнено ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["відповідає \"{filter}\"","відповідає \"{filter}\"","відповідає \"{filter}\"","відповідає \"{filter}\""],
    "Direct link was copied (only works for people who have access to this file/folder)" : "Пряме посилання було скопійовано (дійсне лише для користувачів, які мають відповідні права доступу)",
    "Path" : "Шлях",
    "_%n byte_::_%n bytes_" : ["%n байт","%n байти","%n байт","%n байт(ів)"],
    "Favored" : "Із зірочкою",
    "Favor" : "Додати зірочку",
    "Copy direct link (only works for people who have access to this file/folder)" : "Копіювати пряме посилання (дійсне лише для користувачів, які мають відповідні права доступу)",
    "Upload file" : "Завантажити файл",
    "Not favored" : "Без зірочки",
    "An error occurred while trying to update the tags" : "Виникла помилка при спробі оновити мітки",
    "Upload (max. %s)" : "Завантаження (макс. %s)",
    "\"{displayName}\" action executed successfully" : "\"{displayName}\" успішно виконано",
    "\"{displayName}\" action failed" : "Не вдалося виконати \"{displayName}\"",
    "\"{displayName}\" failed on some elements" : "\"{displayName}\" не спрацював у деяких елементах",
    "\"{displayName}\" batch action executed successfully" : "Операцію \"{displayName}\" успішно виконано",
    "Submitting fields…" : "Поля для надсилання...",
    "Filter filenames…" : "Вибрати файли за ім'ям ...",
    "WebDAV URL copied to clipboard" : "Послиання WebDAV скопійовано до буферу обміну",
    "Enable the grid view" : "Увімкнути подання сіткою",
    "Enable folder tree" : "Увімкнути дерево каталогів",
    "Copy to clipboard" : "Копіювати до буферу обміну",
    "Use this address to access your Files via WebDAV" : "Адреса для доступу до файлів за допомогою протоколу WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Якщо увімкнено двофакторної авторизацію, вам потрібно створити та використовувати окремий пароль на застосунок. Для цього клацніть тут.",
    "Deletion cancelled" : "Вилучення скасовано",
    "Move cancelled" : "Переміщення скасовано",
    "Cancelled move or copy of \"{filename}\"." : "Скасовано переміщення або копіювання \"{filename}\".",
    "Cancelled move or copy operation" : "Переміщення або копіювання скасовано",
    "Open details" : "Показати деталі",
    "Photos and images" : "Зображення",
    "New folder creation cancelled" : "Створення нового каталогу скасовано",
    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} каталог","{folderCount} каталоги","{folderCount} каталогів","{folderCount} каталогів"],
    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} файл","{fileCount} файли","{fileCount} файлів","{fileCount} файлів"],
    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 файл та {folderCount} каталог","1 файл та {folderCount} каталоги","1 файл та {folderCount} каталогів","1 файл та {folderCount} каталогів"],
    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} файл та 1 каталог","{fileCount} файли та 1 каталог","{fileCount} файлів та 1 каталог","{fileCount} файлів та 1 каталог"],
    "{fileCount} files and {folderCount} folders" : "{fileCount} файлів та {folderCount} каталогів",
    "All folders" : "Усі каталоги",
    "Personal Files" : "Мої документи",
    "Text file" : "Текстовий файл",
    "New text file.txt" : "Новий текстовий файл.txt",
    "%1$s (renamed)" : "%1$s (перейменовано)",
    "renamed file" : "перейменовано файл",
    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Після увімкнення сумісности імен файлів з системою Windows наявні файли неможливо буде змінити, але власники зможуть перейменувати ці файли на нові з дійсними іменами.",
    "Filter file names …" : "Фільтр за іменем файлу ...",
    "Prevent warning dialogs from open or reenable them." : "Не дозволяти показувати діялоги застережень або повторно увімкнути їх.",
    "Show a warning dialog when changing a file extension." : "Показувати діялог застереження у разі зміни розширення файлу.",
    "Speed up your Files experience with these quick shortcuts." : "Пришвідшіть взаємодію у застосунку \"Файли\" за скорочень",
    "Open the actions menu for a file" : "Відкрити меню дій для файлу",
    "Rename a file" : "Перейменувати файл",
    "Delete a file" : "Вилучити файл",
    "Favorite or remove a file from favorites" : "Додати або прибрати зірочку з файлу",
    "Manage tags for a file" : "Керувати мітками файлу",
    "Deselect all files" : "Прибрати вибір всіх файлів",
    "Select or deselect a file" : "Вибрати чи прибрати вибір файлу",
    "Select a range of files" : "Вибрати кілька файлів",
    "Navigate to the parent folder" : "Перейти до каталогу вищого рівня",
    "Navigate to the file above" : "Перейти до файлу вище",
    "Navigate to the file below" : "Перейти до фйлу нижче",
    "Navigate to the file on the left (in grid mode)" : "Перейти до файлу ліворуч (подання сіткою)",
    "Navigate to the file on the right (in grid mode)" : "Перейти до файлу праворуч (подання сіткою)",
    "Toggle the grid view" : "Перемкнути у подання сіткою",
    "Open the sidebar for a file" : "Відкрити бокове меню для файлу"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
