OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "Límit de baixades de fitxers",
    "File link share download limit" : "Límit de baixada compartida d'enllaç de fitxer",
    "Limit downloads" : "Limita les baixades",
    "Set download limit" : "Estableix el límit de baixada",
    "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["Es permet 1 baixada més","Es permeten {count} baixades més"],
    "Download limit" : "Límit de baixades",
    "You have reached the maximum amount of downloads allowed" : "Heu assolit la quantitat màxima de baixades permeses",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "Aquesta compartició té un nombre limitat de baixades. Esteu segur que voleu activar una baixada nova?"
},
"nplurals=2; plural=(n != 1);");
