OC.L10N.register(
    "nextcloud_announcements",
    {
    "Nextcloud announcements" : "اطلاعیه نکست کلود",
    "Nextcloud announcement" : "اعلامیه نکست کلود",
    "Read more" : "بیشتر بخوانید",
    "Disable announcements" : "غیرفعال کردن اعلان ها",
    "(These announcements are only shown to administrators)" : "(این اطلاعیه ها فقط به سرپرستان نشان داده می شوند)",
    "Nextcloud announcements brings the latest news of Nextcloud into your notifications" : "اعلان های نکست کلود آخرین اخبار نکست کلود را در اطلاعیه های شما به ارمغان می آورد"
},
"nplurals=2; plural=(n > 1);");
