OC.L10N.register(
    "app_api",
    {
    "Cancel" : "Anuloje",
    "Delete" : "Fshi",
    "Default" : "Paraprake",
    "Edit" : "Përpuno",
    "Name" : "Emër",
    "Host" : "Strehë",
    "Enabled" : "E aktivizuar",
    "Confirm" : "Konfirmo",
    "Save" : "Ruaje",
    "Register" : "Regjistrohu",
    "Update to {version}" : "Përditëso në {version}",
    "Remove" : "Hiqe",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ky aplikacion nuk ka të caktuar një minimum versioni të Nextcloud. Ky do të jetë një gabim në të ardhmen.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ky aplikacion nuk ka të caktuar një maksimum versioni të Nextcloud. Ky do të jetë një gabim në të ardhmen.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ky aplikacion s’mund të instalohet, ngaqë për të nuk plotësohen varësitë vijuese:",
    "View in store" : "Shiko në dyqan",
    "Visit website" : "Vizitoni sajtin",
    "Report a bug" : "Njoftoni një të metë",
    "User documentation" : "Dokumentacioni i përdoruesit",
    "Admin documentation" : "Dokumentacioni i administratorit",
    "Developer documentation" : "Dokumentacioni e zhvilluesit",
    "Featured" : "I paraqitur",
    "Icon" : "Ikonë",
    "Version" : "Versioni",
    "Level" : "Nivel",
    "Actions" : "Veprimet",
    "Type" : "Tipi",
    "Display Name" : "Trego Emrin",
    "Your apps" : "Aplikacionet tuaja ",
    "Documentation" : "Dokumentacioni",
    "Details" : "Detajet",
    "Changelog" : "Katalogu i ndryshimeve",
    "Active apps" : "Aplikacionet aktive",
    "Disabled apps" : "Aplikacionet pa aftësi ",
    "Updates" : "Përditësime",
    "Enable" : "Aktivizoje",
    "Disable" : "Çaktivizoje"
},
"nplurals=2; plural=(n != 1);");
