OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Pirmojo paleidimo vediklis",
    "Add your profile information! For example your email is needed to receive notifications." : "Pridėkite savo profilio informaciją! Pavyzdžiui, jūsų el. paštas yra reikalingas, kad gautumėte pranešimus.",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "Pridėkite savo profilio informaciją! Pavyzdžiui, jūsų el. paštas yra reikalingas, kad gautumėte pranešimus ir galėtumėte atstatyti slaptažodį.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Papildykite profilį informacija! Pasirinkite paveikslėlį, nurodykite vardą, pavardę, kad lengviau būtumėte atpažinti šioje platformoje.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Papildykite profilį informacija! Nurodykite vardą, pavardę, kad lengviau būtumėte atpažinti šioje platformoje.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Pridėkite savo profilio informaciją! Nustatykite profilio paveikslą, kad lengviau būtumėte atpažinti tarp visų ypatybių.",
    "Schedule work & meetings, synced with all your devices." : "Planuokite su visais jūsų įrenginiais sinchronizuotus darbus ir susitikimus.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Saugokite savo kolegas bei draugus vienoje vietoje, neatskleisdami jų asmeninės informacjios.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Paprasta el. pašto programėlė, tvarkingai integruota su failais, adresatais ir kalendoriumi.",
    "App recommendation: Tasks" : "Programėlės rekomendacija: Nextcloud užduotys",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "Sinchronizuokite užduotis iš įvairių įrenginių naudodami Nextcloud ir taisykite jas tiesiogiai.",
    "App recommendation: Deck" : "Programėlės rekomendacija: Nextcloud darbai",
    "Kanban style organization for personal planning and team projects." : "Kanban stiliaus organizavimas asmeniniam planavimui ir komandiniams projektams.",
    "Connect your calendar" : "Prijunkite savo kalendorių",
    "Connect your contacts" : "Prijunkite savo adresatus",
    "Access files via WebDAV" : "Pasiekite failus per WebDAV",
    "Download macOS/iOS configuration profile" : "Atsisiųsti macOS/iOS konfigūracijos profilį",
    "Desktop client" : "Darbalaukio klientas",
    "iOS app" : "iOS programėlė",
    "About & What's new" : "Apie, kas naujo",
    "A welcome and introduction wizard for Nextcloud" : "Pasisveikinimo ir pristatymo vediklis, skirtas Nextcloud",
    "Close" : "Užverti",
    "More about Nextcloud" : "Daugiau apie Nextcloud",
    "Welcome to {cloudName}!" : "Sveiki atvykę į {cloudName}!",
    "Privacy" : "Privatumas",
    "Community" : "Bendruomenė",
    "Get the apps to sync your files" : "Norėdami sinchronizuoti savo failus, atsisiųskite programėles",
    "Server address" : "Serverio adresas",
    "Use this link to connect your apps and desktop client to this server:" : "Naudokite šią nuorodą norėdami prijungti savo programėles bei darbalaukio kliento programas prie šio serverio:",
    "What's new?" : "Kas naujo?",
    "Read more" : "Daugiau skaitykite",
    "Share on social media" : "Bendrinti socialiniuose tinkluose",
    "App recommendation: Nextcloud Calendar" : "Programėlės rekomendacija: Nextcloud kalendorius",
    "App recommendation: Nextcloud Contacts" : "Programėlės rekomendacija: Nextcloud adresatai",
    "App recommendation: Nextcloud Mail" : "Programėlės rekomendacija: Nextcloud paštas"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
