/*!
 * SPDX-FileCopyrightText: 2016-2024 Nextcloud GmbH and Nextcloud contributors
 * SPDX-FileCopyrightText: 2014 ownCloud, Inc.
 * SPDX-License-Identifier: AGPL-3.0-only
 *//*!
 * SPDX-FileCopyrightText: 2018 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */@media only screen and (max-width: 1024px){#header.share-file{position:absolute !important}table th.column-size,table td.filesize,table th.column-mtime,table td.date{display:none}table td.filename .nametext{max-width:75% !important}#imgframe{width:100%;padding:0}#imgframe .publicpreview{margin-top:32px}.files-fileList a.action img{padding-block:0;padding-inline:12px 6px}.files-fileList a.action:not(.menuitem) span{display:none}.nametext{width:60%;white-space:nowrap;overflow:hidden;text-overflow:ellipsis}#header .menutoggle{padding-inline-end:14px;background-position:center}.note{padding:0 20px}.emptycontent{margin-top:10vh}}/*# sourceMappingURL=mobile.css.map */
