OC.L10N.register(
    "files_sharing",
    {
    "File shares" : "File shares",
    "Downloaded via public link" : "Downloaded via public link",
    "Downloaded by {email}" : "Downloaded by {email}",
    "{file} downloaded via public link" : "{file} downloaded via public link",
    "{email} downloaded {file}" : "{email} downloaded {file}",
    "Shared with group {group}" : "Shared with group {group}",
    "Removed share for group {group}" : "Removed share for group {group}",
    "{actor} shared with group {group}" : "{actor} shared with group {group}",
    "{actor} removed share for group {group}" : "{actor} removed share for group {group}",
    "Share for group {group} expired" : "Share for group {group} expired",
    "You shared {file} with group {group}" : "You shared {file} with group {group}",
    "You removed group {group} from {file}" : "You removed group {group} from {file}",
    "{actor} shared {file} with group {group}" : "{actor} shared {file} with group {group}",
    "{actor} removed group {group} from {file}" : "{actor} removed group {group} from {file}",
    "Share for file {file} with group {group} expired" : "Share for file {file} with group {group} expired",
    "Shared as public link" : "Shared as public link",
    "Removed public link" : "Removed public link",
    "Public link expired" : "Public link expired",
    "{actor} shared as public link" : "{actor} shared as public link",
    "{actor} removed public link" : "{actor} removed public link",
    "Public link of {actor} expired" : "Public link of {actor} expired",
    "You shared {file} as public link" : "You shared {file} as public link",
    "You removed public link for {file}" : "You removed public link for {file}",
    "Public link expired for {file}" : "Public link expired for {file}",
    "{actor} shared {file} as public link" : "{actor} shared {file} as public link",
    "{actor} removed public link for {file}" : "{actor} removed public link for {file}",
    "Public link of {actor} for {file} expired" : "Public link of {actor} for {file} expired",
    "{user} accepted the remote share" : "{user} accepted the remote share",
    "{user} declined the remote share" : "{user} declined the remote share",
    "You received a new remote share {file} from {user}" : "You received a new remote share {file} from {user}",
    "{user} accepted the remote share of {file}" : "{user} accepted the remote share of {file}",
    "{user} declined the remote share of {file}" : "{user} declined the remote share of {file}",
    "{user} unshared {file} from you" : "{user} unshared {file} from you",
    "Shared with {user}" : "Shared with {user}",
    "Removed share for {user}" : "Removed share for {user}",
    "You removed yourself" : "You removed yourself",
    "{actor} removed themselves" : "{actor} removed themselves",
    "{actor} shared with {user}" : "{actor} shared with {user}",
    "{actor} removed share for {user}" : "{actor} removed share for {user}",
    "Shared by {actor}" : "Shared by {actor}",
    "{actor} removed share" : "{actor} removed share",
    "Share for {user} expired" : "Share for {user} expired",
    "Share expired" : "Share expired",
    "You shared {file} with {user}" : "You shared {file} with {user}",
    "You removed {user} from {file}" : "You removed {user} from {file}",
    "You removed yourself from {file}" : "You removed yourself from {file}",
    "{actor} removed themselves from {file}" : "{actor} removed themselves from {file}",
    "{actor} shared {file} with {user}" : "{actor} shared {file} with {user}",
    "{actor} removed {user} from {file}" : "{actor} removed {user} from {file}",
    "{actor} shared {file} with you" : "{actor} shared {file} with you",
    "{actor} removed you from the share named {file}" : "{actor} removed you from the share named {file}",
    "Share for file {file} with {user} expired" : "Share for file {file} with {user} expired",
    "Share for file {file} expired" : "Share for file {file} expired",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "A file or folder shared by mail or by public link was <strong>downloaded</strong>",
    "Files have been <strong>uploaded</strong> to a folder shared by mail or by public link" : "Files have been <strong>uploaded</strong> to a folder shared by mail or by public link",
    "A file or folder was shared from <strong>another server</strong>" : "A file or folder was shared from <strong>another server</strong>",
    "Sharing" : "Sharing",
    "A file or folder has been <strong>shared</strong>" : "A file or folder has been <strong>shared</strong>",
    "Shared link" : "Shared link",
    "Wrong share ID, share does not exist" : "Wrong share ID, share does not exist",
    "Could not delete share" : "Could not delete share",
    "Please specify a file or folder path" : "Please specify a file or folder path",
    "Wrong path, file/folder does not exist" : "Wrong path, file/folder does not exist",
    "Could not create share" : "Could not create share",
    "Please specify a valid account to share with" : "Please specify a valid account to share with",
    "Group sharing is disabled by the administrator" : "Group sharing is disabled by the administrator",
    "Please specify a valid group" : "Please specify a valid group",
    "Public link sharing is disabled by the administrator" : "Public link sharing is disabled by the administrator",
    "Please specify a valid email address" : "Please specify a valid email address",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "Sharing %1$s failed because the back end does not allow shares from type %2$s",
    "Please specify a valid federated account ID" : "Please specify a valid federated account ID",
    "Please specify a valid federated group ID" : "Please specify a valid federated group ID",
    "You cannot share to a Team if the app is not enabled" : "You cannot share to a Team if the app is not enabled",
    "Please specify a valid team" : "Please specify a valid team",
    "Sharing %s failed because the back end does not support room shares" : "Sharing %s failed because the back end does not support room shares",
    "Sharing %s failed because the back end does not support ScienceMesh shares" : "Sharing %s failed because the back end does not support ScienceMesh shares",
    "Unknown share type" : "Unknown share type",
    "Not a directory" : "Not a directory",
    "Could not lock node" : "Could not lock node",
    "Public upload is only possible for publicly shared folders" : "Public upload is only possible for publicly shared folders",
    "Share must at least have READ or CREATE permissions" : "Share must at least have READ or CREATE permissions",
    "Share must have READ permission if UPDATE or DELETE permission is set" : "Share must have READ permission if UPDATE or DELETE permission is set",
    "Public upload disabled by the administrator" : "Public upload disabled by the administrator",
    "Could not lock path" : "Could not lock path",
    "no sharing rights on this item" : "no sharing rights on this item",
    "You are not allowed to edit incoming shares" : "You are not allowed to edit incoming shares",
    "Wrong or no update parameter given" : "Wrong or no update parameter given",
    "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled." : "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled.",
    "Custom share link tokens have been disabled by the administrator" : "Custom share link tokens have been disabled by the administrator",
    "Tokens must contain at least 1 character and may only contain letters, numbers, or a hyphen" : "Tokens must contain at least 1 character and may only contain letters, numbers, or a hyphen",
    "Invalid date. Format must be YYYY-MM-DD" : "Invalid date. Format must be YYYY-MM-DD",
    "No sharing rights on this item" : "No sharing rights on this item",
    "Invalid share attributes provided: \"%s\"" : "Invalid share attributes provided: \"%s\"",
    "You are not allowed to send mail notifications" : "You are not allowed to send mail notifications",
    "No mail notification configured for this share type" : "No mail notification configured for this share type",
    "Wrong password" : "Incorrect password",
    "Error while sending mail notification" : "Error while sending mail notification",
    "Failed to generate a unique token" : "Failed to generate a unique token",
    "This share does not exist or is no longer available" : "This share does not exist or is no longer available",
    "shared by %s" : "shared by %s",
    "Download" : "Download",
    "Add to your %s" : "Add to your %s",
    "Direct link" : "Direct link",
    "Share API is disabled" : "Share API is disabled",
    "File sharing" : "File sharing",
    "Share will expire tomorrow" : "Share will expire tomorrow",
    "Your share of {node} will expire tomorrow" : "Your share of {node} will expire tomorrow",
    "You received {share} as a share by {user}" : "You received {share} as a share by {user}",
    "You received {share} to group {group} as a share by {user}" : "You received {share} to group {group} as a share by {user}",
    "Accept" : "Accept",
    "Decline" : "Decline",
    "Remember to upload the files to %s" : "Remember to upload the files to %s",
    "We would like to kindly remind you that you have not yet uploaded any files to the shared folder." : "We would like to kindly remind you that you have not yet uploaded any files to the shared folder.",
    "Open \"%s\"" : "Open \"%s\"",
    "This application enables people to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable people can then share files and folders with other accounts and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other people outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation." : "This application enables people to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable people can then share files and folders with other accounts and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other people outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation.",
    "People" : "People",
    "Filter accounts" : "Filter accounts",
    "The request will expire on {date} at midnight and will be password protected." : "The request will expire on {date} at midnight and will be password protected.",
    "The request will expire on {date} at midnight." : "The request will expire on {date} at midnight.",
    "The request will be password protected." : "The request will be password protected.",
    "When should the request expire?" : "When should the request expire?",
    "Set a submission expiration date" : "Set a submission expiration date",
    "Expiration date" : "Expiration date",
    "Select a date" : "Select a date",
    "Your administrator has enforced a {count} days expiration policy." : "Your administrator has enforced a {count} days expiration policy.",
    "What password should be used for the request?" : "What password should be used for the request?",
    "Set a password" : "Set a password",
    "Password" : "Password",
    "Enter a valid password" : "Enter a valid password",
    "Generate a new password" : "Generate a new password",
    "Your administrator has enforced a password protection." : "Your administrator has enforced a password protection.",
    "Automatically copying failed, please copy the share link manually" : "Automatically copying failed, please copy the share link manually",
    "Link copied" : "Link copied",
    "Email already added" : "Email already added",
    "Invalid email address" : "Invalid email address",
    "_The following email address is not valid: {emails}_::_The following email addresses are not valid: {emails}_" : ["The following email address is not valid: {emails}","The following email addresses are not valid: {emails}"],
    "_{count} email address already added_::_{count} email addresses already added_" : ["{count} email address already added","{count} email addresses already added"],
    "_{count} email address added_::_{count} email addresses added_" : ["{count} email address added","{count} email addresses added"],
    "You can now share the link below to allow people to upload files to your directory." : "You can now share the link below to allow people to upload files to your directory.",
    "Share link" : "Share link",
    "Copy" : "Copy",
    "Send link via email" : "Send link via email",
    "Enter an email address or paste a list" : "Enter an email address or paste a list",
    "Remove email" : "Remove email",
    "Select a destination" : "Select a destination",
    "Select" : "Select",
    "What are you requesting?" : "What are you requesting?",
    "Request subject" : "Request subject",
    "Birthday party photos, History assignment…" : "Birthday party photos, History assignment…",
    "Where should these files go?" : "Where should these files go?",
    "Upload destination" : "Upload destination",
    "Revert to default" : "Revert to default",
    "The uploaded files are visible only to you unless you choose to share them." : "The uploaded files are visible only to you unless you choose to share them.",
    "Add a note" : "Add a note",
    "Note for recipient" : "Note for recipient",
    "Add a note to help people understand what you are requesting." : "Add a note to help people understand what you are requesting.",
    "You can add links, date or any other information that will help the recipient understand what you are requesting." : "You can add links, date or any other information that will help the recipient understand what you are requesting.",
    "Close" : "Close",
    "_Send email and close_::_Send {count} emails and close_" : ["Send email and close","Send {count} emails and close"],
    "Please select a folder, you cannot share the root directory." : "Please select a folder, you cannot share the root directory.",
    "File request created" : "File request created",
    "_File request created and email sent_::_File request created and {count} emails sent_" : ["File request created and email sent","File request created and {count} emails sent"],
    "Error creating the share: {errorMessage}" : "Error creating the share: {errorMessage}",
    "Error creating the share" : "Error creating the share",
    "Error sending emails: {errorMessage}" : "Error sending emails: {errorMessage}",
    "Error sending emails" : "Error sending emails",
    "Create a file request" : "Create a file request",
    "Collect files from others even if they do not have an account." : "Collect files from others even if they do not have an account.",
    "To ensure you can receive files, verify you have enough storage available." : "To ensure you can receive files, verify you have enough storage available.",
    "File request" : "File request",
    "Previous step" : "Previous step",
    "Cancel" : "Cancel",
    "Cancel the file request creation" : "Cancel the file request creation",
    "Close without sending emails" : "Close without sending emails",
    "Continue" : "Continue",
    "Error while toggling options" : "Error while toggling options",
    "Accept shares from other accounts and groups by default" : "Accept shares from other accounts and groups by default",
    "Choose a default folder for accepted shares" : "Choose a default folder for accepted shares",
    "Invalid path selected" : "Invalid path selected",
    "Unknown error" : "Unknown error",
    "Set default folder for accepted shares" : "Set default folder for accepted shares",
    "Reset" : "Reset",
    "Reset folder to system default" : "Reset folder to system default",
    "Share expiration: {date}" : "Share expiration: {date}",
    "Share Expiration" : "Share Expiration",
    "group" : "group",
    "conversation" : "conversation",
    "remote" : "remote",
    "remote group" : "remote group",
    "guest" : "guest",
    "by {initiator}" : "by {initiator}",
    "Shared with the group {user} by {owner}" : "Shared with the group {user} by {owner}",
    "Shared with the conversation {user} by {owner}" : "Shared with the conversation {user} by {owner}",
    "Shared with {user} by {owner}" : "Shared with {user} by {owner}",
    "Open Sharing Details" : "Open Sharing Details",
    "Added by {initiator}" : "Added by {initiator}",
    "Via “{folder}”" : "Via “{folder}”",
    "Unshare" : "Unshare",
    "Cannot copy, please copy the link manually" : "Cannot copy, please copy the link manually",
    "Copy internal link" : "Copy internal link",
    "For people who already have access" : "For people who already have access",
    "Internal link" : "Internal link",
    "{shareWith} by {initiator}" : "{shareWith} by {initiator}",
    "Shared via link by {initiator}" : "Shared via link by {initiator}",
    "File request ({label})" : "File request ({label})",
    "Mail share ({label})" : "Mail share ({label})",
    "Share link ({label})" : "Share link ({label})",
    "Mail share" : "Mail share",
    "Share link ({index})" : "Share link ({index})",
    "Create public link" : "Create public link",
    "Actions for \"{title}\"" : "Actions for \"{title}\"",
    "Copy public link of \"{title}\"" : "Copy public link of \"{title}\"",
    "Error, please enter proper password and/or expiration date" : "Error, please enter proper password and/or expiration date",
    "Link share created" : "Link share created",
    "Error while creating the share" : "Error while creating the share",
    "Please enter the following required information before creating the share" : "Please enter the following required information before creating the share",
    "Password protection (enforced)" : "Password protection (enforced)",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "Enable link expiration (enforced)" : "Enable link expiration (enforced)",
    "Enable link expiration" : "Enable link expiration",
    "Enter expiration date (enforced)" : "Enter expiration date (enforced)",
    "Enter expiration date" : "Enter expiration date",
    "Create share" : "Create share",
    "Customize link" : "Customise link",
    "Generate QR code" : "Generate QR code",
    "Add another link" : "Add another link",
    "Create a new share link" : "Create a new share link",
    "Quick share options, the current selected is \"{selectedOption}\"" : "Quick share options, the current selected is \"{selectedOption}\"",
    "View only" : "View only",
    "Can edit" : "Can edit",
    "Custom permissions" : "Custom permissions",
    "Resharing is not allowed" : "Resharing is not allowed",
    "Name or email …" : "Name or email …",
    "Name, email, or Federated Cloud ID …" : "Name, email, or Federated Cloud ID …",
    "Searching …" : "Searching …",
    "No elements found." : "No elements found.",
    "Search everywhere" : "Search everywhere",
    "Guest" : "Guest",
    "Group" : "Group",
    "Email" : "Email",
    "Team" : "Team",
    "Talk conversation" : "Talk conversation",
    "Deck board" : "Deck board",
    "ScienceMesh" : "ScienceMesh",
    "on {server}" : "on {server}",
    "Enter external recipients" : "Enter external recipients",
    "Search for internal recipients" : "Search for internal recipients",
    "Note from" : "Note from",
    "Note:" : "Note:",
    "File drop" : "File drop",
    "Upload files to {foldername}." : "Upload files to {foldername}.",
    "By uploading files, you agree to the terms of service." : "By uploading files, you agree to the terms of service.",
    "Successfully uploaded files" : "Successfully uploaded files",
    "View terms of service" : "View terms of service",
    "Terms of service" : "Terms of service",
    "Share with {user}" : "Share with {user}",
    "Share with email {email}" : "Share with email {email}",
    "Share with group" : "Share with group",
    "Share in conversation" : "Share in conversation",
    "Share with {user} on remote server {server}" : "Share with {user} on remote server {server}",
    "Share with remote group" : "Share with remote group",
    "Share with guest" : "Share with guest",
    "Update share" : "Update share",
    "Save share" : "Save share",
    "Read" : "Read",
    "Create" : "Create",
    "Edit" : "Edit",
    "Share" : "Share",
    "Delete" : "Delete",
    "Password field cannot be empty" : "Password field cannot be empty",
    "Replace current password" : "Replace current password",
    "Failed to generate a new token" : "Failed to generate a new token",
    "Allow upload and editing" : "Allow upload and editing",
    "Allow editing" : "Allow editing",
    "Upload only" : "Upload only",
    "Advanced settings" : "Advanced settings",
    "Share label" : "Share label",
    "Share link token" : "Share link token",
    "Set the public share link token to something easy to remember or generate a new token. It is not recommended to use a guessable token for shares which contain sensitive information." : "Set the public share link token to something easy to remember or generate a new token. It is not recommended to use a guessable token for shares which contain sensitive information.",
    "Generating…" : "Generating…",
    "Generate new token" : "Generate new token",
    "Set password" : "Set password",
    "Password expires {passwordExpirationTime}" : "Password expires {passwordExpirationTime}",
    "Password expired" : "Password expired",
    "Video verification" : "Video verification",
    "Expiration date (enforced)" : "Expiration date (enforced)",
    "Set expiration date" : "Set expiration date",
    "Hide download" : "Hide download",
    "Allow download and sync" : "Allow download and sync",
    "Note to recipient" : "Note to recipient",
    "Enter a note for the share recipient" : "Enter a note for the share recipient",
    "Show files in grid view" : "Show files in grid view",
    "Delete share" : "Delete share",
    "Others with access" : "Others with access",
    "No other accounts with access found" : "No other accounts with access found",
    "Toggle list of others with access to this directory" : "Toggle list of others with access to this directory",
    "Toggle list of others with access to this file" : "Toggle list of others with access to this file",
    "Unable to fetch inherited shares" : "Unable to fetch inherited shares",
    "Link shares" : "Link shares",
    "Shares" : "Shares",
    "Share files within your organization. Recipients who can already view the file can also use this link for easy access." : "Share files within your organization. Recipients who can already view the file can also use this link for easy access.",
    "Share files with others outside your organization via public links and email addresses. You can also share to Nextcloud accounts on other instances using their federated cloud ID." : "Share files with others outside your organization via public links and email addresses. You can also share to Nextcloud accounts on other instances using their federated cloud ID.",
    "Shares from apps or other sources which are not included in internal or external shares." : "Shares from apps or other sources which are not included in internal or external shares.",
    "Type names, teams, federated cloud IDs" : "Type names, teams, federated cloud IDs",
    "Type names or teams" : "Type names or teams",
    "Type a federated cloud ID" : "Type a federated cloud ID",
    "Type an email" : "Type an email",
    "Type an email or federated cloud ID" : "Type an email or federated cloud ID",
    "Unable to load the shares list" : "Unable to load the shares list",
    "Expires {relativetime}" : "Expires {relativetime}",
    "this share just expired." : "this share just expired.",
    "Shared with you by {owner}" : "Shared with you by {owner}",
    "Internal shares" : "Internal shares",
    "Internal shares explanation" : "Internal shares explanation",
    "External shares" : "External shares",
    "External shares explanation" : "External shares explanation",
    "Additional shares" : "Additional shares",
    "Additional shares explanation" : "Additional shares explanation",
    "Link to a file" : "Link to a file",
    "_Accept share_::_Accept shares_" : ["Accept share","Accept shares"],
    "Open in Files" : "Open in Files",
    "_Reject share_::_Reject shares_" : ["Reject share","Reject shares"],
    "_Restore share_::_Restore shares_" : ["Restore share","Restore shares"],
    "Shared" : "Shared",
    "Shared by {ownerDisplayName}" : "Shared by {ownerDisplayName}",
    "Shared multiple times with different people" : "Shared multiple times with different people",
    "Sharing options" : "Sharing options",
    "Shared with others" : "Shared with others",
    "Create file request" : "Create file request",
    "Upload files to {foldername}" : "Upload files to {foldername}",
    "Public file share" : "Public file share",
    "Publicly shared file." : "Publicly shared file.",
    "No file" : "No file",
    "The file shared with you will show up here" : "The file shared with you will show up here",
    "Public share" : "Public share",
    "Publicly shared files." : "Publicly shared files.",
    "No files" : "No files",
    "Files and folders shared with you will show up here" : "Files and folders shared with you will show up here",
    "Overview of shared files." : "Overview of shared files.",
    "No shares" : "No shares",
    "Files and folders you shared or have been shared with you will show up here" : "Files and folders you shared or have been shared with you will show up here",
    "Shared with you" : "Shared with you",
    "List of files that are shared with you." : "List of files that are shared with you.",
    "Nothing shared with you yet" : "Nothing shared with you yet",
    "Files and folders others shared with you will show up here" : "Files and folders others shared with you will show up here",
    "List of files that you shared with others." : "List of files that you shared with others.",
    "Nothing shared yet" : "Nothing shared yet",
    "Files and folders you shared will show up here" : "Files and folders you shared will show up here",
    "Shared by link" : "Shared by link",
    "List of files that are shared by link." : "List of files that are shared by link.",
    "No shared links" : "No shared links",
    "Files and folders you shared by link will show up here" : "Files and folders you shared by link will show up here",
    "File requests" : "File requests",
    "List of file requests." : "List of file requests.",
    "No file requests" : "No file requests",
    "File requests you have created will show up here" : "File requests you have created will show up here",
    "Deleted shares" : "Deleted shares",
    "List of shares you left." : "List of shares you left.",
    "No deleted shares" : "No deleted shares",
    "Shares you have left will show up here" : "Shares you have left will show up here",
    "Pending shares" : "Pending shares",
    "List of unapproved shares." : "List of unapproved shares.",
    "No pending shares" : "No pending shares",
    "Shares you have received but not approved will show up here" : "Shares you have received but not approved will show up here",
    "Error deleting the share: {errorMessage}" : "Error deleting the share: {errorMessage}",
    "Error deleting the share" : "Error deleting the share",
    "Error updating the share: {errorMessage}" : "Error updating the share: {errorMessage}",
    "Error updating the share" : "Error updating the share",
    "File \"{path}\" has been unshared" : "File \"{path}\" has been unshared",
    "Folder \"{path}\" has been unshared" : "Folder \"{path}\" has been unshared",
    "Could not update share" : "Could not update share",
    "Share saved" : "Share saved",
    "Share expiry date saved" : "Share expiry date saved",
    "Share hide-download state saved" : "Share hide-download state saved",
    "Share label saved" : "Share label saved",
    "Share note for recipient saved" : "Share note for recipient saved",
    "Share password saved" : "Share password saved",
    "Share permissions saved" : "Share permissions saved",
    "To upload files to {folder}, you need to provide your name first." : "To upload files to {folder}, you need to provide your name first.",
    "Upload files to {folder}" : "Upload files to {folder}",
    "Please confirm your name to upload files to {folder}" : "Please confirm your name to upload files to {folder}",
    "{ownerDisplayName} shared a folder with you." : "{ownerDisplayName} shared a folder with you.",
    "Names must not be empty." : "Names must not be empty.",
    "Names must not start with a dot." : "Names must not start with a dot.",
    "\"{char}\" is not allowed inside a name." : "\"{char}\" is not allowed inside a name.",
    "\"{segment}\" is a reserved name and not allowed." : "\"{segment}\" is a reserved name and not allowed.",
    "\"{extension}\" is not an allowed name." : "\"{extension}\" is not an allowed name.",
    "Names must not end with \"{extension}\"." : "Names must not end with \"{extension}\".",
    "Invalid name." : "Invalid name.",
    "Shared by" : "Shared by",
    "Shared with" : "Shared with",
    "Password created successfully" : "Password created successfully",
    "Error generating password from password policy" : "Error generating password from password policy",
    "Shared with you and the group {group} by {owner}" : "Shared with you and the group {group} by {owner}",
    "Shared with you and {circle} by {owner}" : "Shared with you and {circle} by {owner}",
    "Shared with you and the conversation {conversation} by {owner}" : "Shared with you and the conversation {conversation} by {owner}",
    "Shared with you in a conversation by {owner}" : "Shared with you in a conversation by {owner}",
    "Share not found" : "Share not found",
    "Back to %s" : "Back to %s",
    "Add to your Nextcloud" : "Add to your Nextcloud",
    "Waiting…" : "Waiting…",
    "error" : "error",
    "finished" : "finished",
    "This will stop your current uploads." : "This will stop your current uploads.",
    "Move or copy" : "Move or copy",
    "You can upload into this folder" : "You can upload into this folder",
    "Show list view" : "Show list view",
    "Show grid view" : "Show grid view",
    "No compatible server found at {remote}" : "No compatible server found at {remote}",
    "Invalid server URL" : "Invalid server URL",
    "Failed to add the public link to your Nextcloud" : "Failed to add the public link to your Nextcloud",
    "You are not allowed to edit link shares that you don't own" : "You are not allowed to edit link shares that you don't own",
    "Download all files" : "Download all files",
    "Link copied to clipboard" : "Link copied to clipboard",
    "_1 email address already added_::_{count} email addresses already added_" : ["1 email address already added","{count} email addresses already added"],
    "_1 email address added_::_{count} email addresses added_" : ["1 email address added","{count} email addresses added"],
    "Copy to clipboard" : "Copy to clipboard",
    "Copy internal link to clipboard" : "Copy internal link to clipboard",
    "Only works for people with access to this folder" : "Only works for people with access to this folder",
    "Only works for people with access to this file" : "Only works for people with access to this file",
    "Copy public link of \"{title}\" to clipboard" : "Copy public link of \"{title}\" to clipboard",
    "Search globally" : "Search globally",
    "Search for share recipients" : "Search for share recipients",
    "No recommendations. Start typing." : "No recommendations. Start typing.",
    "To upload files, you need to provide your name first." : "To upload files, you need to provide your name first.",
    "Enter your name" : "Enter your name",
    "Submit name" : "Submit name",
    "Share with {userName}" : "Share with {userName}",
    "Show sharing options" : "Show sharing options",
    "Share note" : "Share note",
    "Upload files to %s" : "Upload files to %s",
    "%s shared a folder with you." : "%s shared a folder with you.",
    "Note" : "Note",
    "Select or drop files" : "Select or drop files",
    "Uploading files" : "Uploading files",
    "Uploaded files:" : "Uploaded files:",
    "By uploading files, you agree to the %1$sterms of service%2$s." : "By uploading files, you agree to the %1$sterms of service%2$s.",
    "Name" : "Surname",
    "Use this method to share files with individuals or teams within your organization. If the recipient already has access to the share but cannot locate it, you can send them the internal share link for easy access." : "Use this method to share files with individuals or teams within your organization. If the recipient already has access to the share but cannot locate it, you can send them the internal share link for easy access.",
    "Use this method to share files with individuals or organizations outside your organization. Files and folders can be shared via public share links and email addresses. You can also share to other Nextcloud accounts hosted on different instances using their federated cloud ID." : "Use this method to share files with individuals or organizations outside your organization. Files and folders can be shared via public share links and email addresses. You can also share to other Nextcloud accounts hosted on different instances using their federated cloud ID.",
    "Shares that are not part of the internal or external shares. This can be shares from apps or other sources." : "Shares that are not part of the internal or external shares. This can be shares from apps or other sources.",
    "Share with accounts, teams, federated cloud id" : "Share with accounts, teams, federated cloud id",
    "Share with accounts and teams" : "Share with accounts and teams",
    "Federated cloud ID" : "Federated cloud ID",
    "Email, federated cloud id" : "Email, federated cloud id",
    "Filename must not be empty." : "Filename must not be empty."
},
"nplurals=2; plural=(n != 1);");
