<?php
namespace Aws\PcaConnectorScep\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Private CA Connector for SCEP** service.
 */
class PcaConnectorScepException extends AwsException {}
