OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Lehen abioko laguntza",
    "Add your profile information! For example your email is needed to receive notifications." : "Gehitu zure profileko informazioa! Adibidez, zure posta elektronikoa beharrezkoa da jakinarazpenak jasotzeko.",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "Gehitu zure profileko informazioa! Adibidez, zure posta elektronikoa beharrezkoa da jakinarazpenak jasotzeko eta pasahitza berrezartzeko.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Gehitu zure profilaren informazioa! Ezarri profileko argazkia eta izena, ezaugarri guztietan errazago ezagutzeko.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Gehitu zure profilaren informazioa! Ezarri izen osoa, ezaugarri guztietan errazago ezagutzeko.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Gehitu zure profilaren informazioa! Ezarri profileko argazkia, ezaugarri guztietan errazago ezagutzeko.",
    "App recommendation: Calendar" : "Aholkatutako aplikazioa: Egutegia",
    "Schedule work & meetings, synced with all your devices." : "Antolatu lana eta bilerak, zure gailu guztiekin sinkronizatuta.",
    "App recommendation: Contacts" : "Aholkatutako aplikazioa: Kontaktuak",
    "Keep your colleagues and friends in one place without leaking their private info." : "Eduki zure lankide eta lagun guztiak leku bakarrean, beren informazioa pribatu mantenduz.",
    "App recommendation: Mail" : "Aholkatutako aplikazioa: Posta",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Fitxategiak, Kontaktuak eta Egutegiarekin integratutako posta elektronikoko aplikazio soila.",
    "App recommendation: Tasks" : "Aholkatutako aplikazioa: Zereginak",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "Sinkronizatu zereginak Nextcloudekin hainbat gailutatik eta edita itzazu linean.",
    "App recommendation: Deck" : "Aholkatutako aplikazioa: Deck",
    "Kanban style organization for personal planning and team projects." : "Kanban estiloko antolaketa, plangintza pertsonalerako eta taldeko proiektuentzat.",
    "App recommendation: Forms" : "Aholkatutako aplikazioa: Galdetegiak",
    "Simple surveys and questionnaires, self-hosted" : "Inkesta sinpleak eta galdetegiak, norberak ostatatuta",
    "App recommendation: Recognize" : "Aholkatutako aplikazioa: Recognize",
    "Smart media tagging for Nextcloud" : "Multimedia etiketatze adimentsua Nextcloudentzako",
    "App recommendation: Group folders" : "Aholkatutako aplikazioa: Talde-karpetak",
    "Admin-configured folders shared by everyone in a group." : "Administratzaileak konfiguratutako karpetak, talde bateko guztien artean partekatuak.",
    "App recommendation: Whiteboard" : "Aholkatutako aplikazioa: Whiteboard",
    "Create and share whiteboards with others and collaborate in real-time." : "Sortu eta partekatu arbelak besteekin eta elkarlanean aritu denbora errealean.",
    "Connect your calendar" : "Konektatu zure egutegia",
    "Connect your contacts" : "Konektatu zure kontaktuak",
    "Access files via WebDAV" : "Atzitu fitxategiak WebDAV bidez",
    "Download macOS/iOS configuration profile" : "Deskargatu macOS/iOSerako konfigurazio profila",
    "Desktop client" : "Mahaigaineko bezeroa",
    "Android app on Google Play Store" : "Android aplikazioa Google Play dendan",
    "Android app on F-Droid" : "Android aplikazioa F-Droid-en",
    "iOS app" : "iOS aplikazioa",
    "About & What's new" : "Honi buruz eta Zer berri",
    "A welcome and introduction wizard for Nextcloud" : "Ongi etorria emateko eta harrera egiteko Nextcloud morroia",
    "This application enables a pop-up window when a user first logs into Nextcloud. This window welcomes new users to Nextcloud, and contains links to the standard desktop client, Android app, and the iOS app. The window also shows a link for accessing Nextcloud via WebDAV. At any time, the first run wizard can be opened again via link \"About\" on settings menu.\nThe First run wizard can be customized to meet specific design goals, or to change links and messages. Create an appropriate theme following the Theming documentation, and changes to the look and feel of this Wizard are simple. More information is available in the first run wizard documentation, as well as the theming documentation." : "Aplikazio honek leiho gainerakor bat gaitzen du erabiltzaileak lehen aldiz Nextclouden saioa hastean. Leiho honek ongietorria ematen die Nextcloudeko erabiltzaile berriei, eta estekak ditu mahaigaineko bezero, Androideko eta iOSeko aplikazio estandarretara. Nextcloud WebDAV bidez atzitzeko esteka ere erakusten du leihoak. Lehen abioko morroia edozein momentutan ireki daiteke berriz ezarpenen menuko \"Honi buruz\" esteka erabiliz.\nLehen abioko morroiaren diseinua, estekak eta mezuak pertsonalizatu daitezke. Horretarako, Gaiak dokumentazioa erabiliz gai bat sortu behar da. Morroi honen itxura eta izaera aldatzea erraza da. Informazio gehiago behar baduzu, lehen abioko morroiaren eta gaien dokumentazioan aurkituko duzu.",
    "Download on Apple app store" : "Deskargatu Apple-en aplikazio biltegitik",
    "Download on Google play store" : "Deskargatu Google-ren aplikazio biltegitik",
    "Go to previous page" : "Itzuli aurreko orrira",
    "Close" : "Itxi",
    "More about Nextcloud" : "Nextcloudi buruz gehiago",
    "Explore more apps ↗" : "Esploratu aplikazio gehiago ↗",
    "Extend the functionality of Nextcloud with hundreds of community-developed apps." : "Hedatu Nextclouden funtzionalitateak komunitateak garaturiko ehundaka aplikaziorekin.",
    "Get involved! ↗" : "Parte hartu! ↗",
    "Be a part of the community that helps build, design, translate and promote Nextcloud!" : "Izan zaitez Nextcloud eraiki, diseinatu, itzuli eta sutatzen duen komunitatearen parte!",
    "Need help? ↗" : "Laguntza behar? ↗",
    "Find out more about your Nextcloud setup with the admin, user or developer documentation." : "Aurkitu informazio gehiago Nextcloud konfigurazioari buruz admin, erabiltzaile edo garatzaileen dokumentazioan.",
    "For large organisations ↗" : "Erakunde handientzako ↗",
    "Get Nextcloud Enterprise for mission critical environments where advanced security and compliance are important." : "Eskura ezazu Nextcloud Enterprise helburu kritikodun testuinguruetan, segurtasuna eta funtzionamendu berme handia garrantzitsuak direnean.",
    "Seamless integration with your devices." : "Etenik gabeko integrazio fina zure gailuen artean.",
    "Sync your files across your devices with the desktop and mobile apps, and connect your calendar and contacts." : "Sinkronizatu fitxategiak zure gailuen artean mahaigaineko eta mugikorreko aplikazioekin, baita zure egutegia eta kontaktuak ere.",
    "Desktop app ↗" : "Mahaigaineko aplikazioa ↗",
    "Download For Windows, Mac OS and Linux." : "Deskargatu Windows, Mac OS edo Linuxerako.",
    "Calendar and contacts ↗" : "Egutegia eta kontaktuak ↗",
    "Connect your calendar and contacts with your devices." : "Konektatu zure egutegi eta kontaktuak zure gailuen artean.",
    "Introducing Nextcloud Hub {version}" : "Nextcloud Hub {version} aurkezten",
    "Welcome to {cloudName}!" : "Ongi etorri {cloudName}(e)ra!",
    "This Nextcloud is on version {version}" : "Nextcloud hau {version} bertsioan dago",
    "A collaboration platform that puts you in control" : "Kontrola zure esku jartzen duen lankidetza plataforma",
    "Privacy" : "Pribatutasuna",
    "Host your data and files where you decide." : "Ostatatu datuak eta fitxategiak zuk erabakitzen duzun lekuan.",
    "Productivity" : "Produktibitatea",
    "Collaborate and communicate across any platform." : "Plataforma ugariren arteko lankidetza eta komunikazioa.",
    "Interoperability" : "Elkarreragintasuna",
    "Import and export anything you want with open standards." : "Inportatu eta esportatu edozein gauza, zuk nahi duzun estandar irekian.",
    "Community" : "Komunitatea",
    "Enjoy constant improvements from a thriving open-source community." : "Gozatu etengabeko hobekuntzekin, open-source komunitate biziari esker.",
    "Nextcloud Hub {version} release" : "Nextcloud Hub {version} bertsioa",
    "Read more about it on the Nextcloud Hub {version} blog" : "Irakurri horri buruzko informazio gehiago Nextcloud Hub {version}-ren blogean",
    "Find out more on the blog" : "Lortu informazio gehiago blogean",
    "Read the Nextcloud Hub {version} blog" : "Irakurri Nextcloud Hub {version}-ren bloga",
    "Share your opinion about Nextcloud Hub {version}" : "Partekatu zure iritzia Nextcloud Hub {version}-i buruz",
    "Share via email" : "Partekatu posta elektroniko bidez",
    "Share on {socialMedia}" : "Partekatu {socialMedia}-en",
    "New in Nextcloud Hub {version}" : "Berria Nextcloud Hub {version}-en",
    "Connect other apps to {productName}" : "Konektatu beste aplikazio batzuk {productName}-ra",
    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to {productName}." : "Mugikorreko aplikazioez eta mahaigaineko bezeroaz gain, WebDAV/CalDAV/CardDAV protokoloak onartzen dituen beste edozein software konekta dezakezu {productName}-ra.",
    "Apps to connect to {productName}" : " {productName}-ra konektatzeko aplikazioak",
    "Set up sync clients using an {linkStart}app password{linkEnd}. That way you can make sure you are able to revoke access in case you lose that device." : "Konfiguratu sinkronizazio bezeroak {linkStart}pasahitz aplikazio{linkEnd} bat erabiliz. Horrela ziurtatu dezakezu sarbidea baliogabetu dezakezula gailu hori galtzen baduzu.",
    "Get the apps to sync your files" : "Lortu aplikazioak zure fitxategiak sinkronizatzeko",
    "{productName} gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "Edonon zaudela, {productName}-k zure fitxategietarako sarbidea ematen dizu. Gure mahaigaineko eta mugikorreko bezero erabiltzeko errazak plataforma nagusi guztietarako eskuragarri daude zero kostuan.",
    "App for syncing" : "Sinkronizatzeko aplikazioa",
    "URL copied" : "URLa kopiatu da",
    "Could not copy the URL, please copy manually" : "Ezin izan da URLa kopiatu, kopiatu eskuz",
    "Server address" : "Zerbitzariaren helbidea",
    "Use this link to connect your apps and desktop client to this server:" : "Erabili esteka hau zure aplikazioak eta mahaigaineko bezeroa zerbitzari honetara konektatzeko:",
    "What's new?" : "Zer berri?",
    "Nextcloud on all your devices" : "Nextcloud zure gailu guztietan",
    "Nextcloud Hub {version}" : "Nextcloud Hub {version}",
    "Read more" : "Irakurri gehiago",
    "Share on social media" : "Partekatu sare sozialetan",
    "Get started!" : "Hasi!",
    "App recommendation: Nextcloud Calendar" : "Aholkatutako aplikazioa: Nextcloud Calendar",
    "App recommendation: Nextcloud Contacts" : "Aholkatutako aplikazioa: Nextcloud Kontaktuak",
    "App recommendation: Nextcloud Mail" : "Aholkatutako aplikazioa: Nextcloud Posta",
    "Federated collaboration: file sharing, messaging, calls" : "Elkarlan federatua: fitxategiak partekatzea, mezularitza, deiak",
    "Nextcloud Whiteboard" : "Nextcloud arbela",
    "Workflow Engine" : "Lan-fluxuen motorra",
    "Safer and swifter mail" : "Posta seguruagoa eta azkarragoa",
    "Public Collectives sharing, previews and QR-codes" : "Kolektibo Publiko partekatzeak, aurreikuspenak eta QR-kodeak",
    "Office and PDF templates" : "Office eta PDF txantiloiak",
    "Chat mode for Nextcloud Assistant" : "Nextcloud Laguntzailerako txat-modua",
    "Get to know the new features of Hub 9" : "Ezagutu Hub 9-ren funtzio berriak"
},
"nplurals=2; plural=(n != 1);");
