OC.L10N.register(
    "circles",
    {
    "Teams" : "Tiimit",
    "You created the team {circle}" : "Loit tiimin {circle}",
    "{author} created the team {circle}" : "{author} loi tiimin {circle}",
    "You deleted {circle}" : "Poistit piirin {circle}",
    "{author} deleted {circle}" : "{author} poisti piirin {circle}",
    "You removed {member} from {circle}" : "Poistit jäsenen {member} piiristä {circle}",
    "You joined {circle}" : "Liityit piiriin {circle}",
    "{member} joined {circle}" : "{member} liittyi piiriin {circle}",
    "You accepted the invitation to join {circle}" : "Hyväksyit kutsun liittyä piirin {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} hyväksyi kutsun liittyä piiriin {circle}",
    "You added {member} as member to {circle}" : "Lisäsit käyttäjän {member} jäsenenä piiriin {circle}",
    "You have been added as member to {circle} by {author}" : "{author} lisäsi sinut jäseneksi piiriin {circle}",
    "{member} has been added as member to {circle} by {author}" : "{member} lisättiin jäseneksi piiriin {circle} käyttäjän {author} toimesta",
    "You added {external} to {circle}" : "Lisäsit {external} piiriin {circle}",
    "{external} has been added to {circle} by {author}" : "{external} on lisätty piiriin {circle} käyttäjän {author} toimesta",
    "You accepted {member}'s request to join {circle}" : "Hyväksyit jäsenen {member} pyynnön liittyä piiriin {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Pyyntösi liittyä piiriin {circle} hyväksyttiin käyttäjän {author} toimesta",
    "{member}'s request to join {circle} has been accepted by {author}" : "Käyttäjän {member} pyyntö liittyä piiriin {circle} hyväksyttiin käyttäjän {author} toimesta",
    "You left {circle}" : "Poistuit piiristä {circle}",
    "{member} left {circle}" : "{member} poistui piiristä {circle}",
    "You declined the invitation to join {circle}" : "Kieltäydyit kutsusta liittyä piiriin {circle}",
    "{member} declined an invitation to join {circle}" : "{member} kieltäytyi kutsusta liittyä piiriin {circle}",
    "You cancelled your request to join {circle}" : "Peruit pyyntösi liittyä piiriin {circle}",
    "You have been removed from {circle} by {author}" : "Sinut poistettiin piiristä {circle} käyttäjän {author} toimesta",
    "{member} has been removed from {circle} by {author}" : "{member} poistettiin piiristä {circle} käyttäjän {author} toimesta",
    "You removed {external} from {circle}" : "Poistit {external} piiristä {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} poistettiin piiristä {circle} käyttäjän {author} toimesta",
    "You cancelled {member}'s invitation to join {circle}" : "Peruit jäsenen {member} kutsun liittyä piiriin {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} perui kutsusi liittyä piiriin {circle}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} perui jäsenen {member} liittymiskutsun piiriin {circle}",
    "You dismissed {member}'s request to join {circle}" : "Hylkäsit jäsenen {member} liittymispyynnön piiriin {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "{author} hylkäsi liittymiskutsusi piiriin {circle}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} perui jäsenen {member} liittymispyynnön piiriin {circle}",
    "You invited {member} to join {circle}" : "Kutsuit jäsenen {member} liittymään piiriin {circle}",
    "You have been invited to join {circle} by {author}" : "Sinut kutsuttiin liittymään piiriin {circle} käyttäjän {author} toimesta",
    "{member} has been invited to join {circle} by {author}" : "{member} kutsuttiin liittymään piiriin {circle} käyttäjän {author} toimesta",
    "{author} changed your level in {circle} to %1$s" : "{author} muutti piirissä {circle} tasoksesi %1$s",
    "You sent a request to join {circle}" : "Lähetit pyynnön liittyä piiriin {circle}",
    "{member} sent a request to join {circle}" : "{member} lähetti pyynnön liittyä piiriin {circle}",
    "You are the new owner of {circle}" : "Olet piirin {circle} uusi omistaja",
    "{member} is the new owner of {circle}" : "{member} on piirin {circle} uusi omistaja",
    "Personal" : "Henkilökohtainen",
    "System" : "Järjestelmä",
    "Visible" : "Näkyvissä",
    "Open" : "Avaa",
    "Invite" : "Kutsu",
    "Join request" : "Liittymispyyntö",
    "Friends" : "Kaverit",
    "Password protected" : "Salasanasuojattu",
    "No Owner" : "Ei omistajaa",
    "Hidden" : "Piilotettu",
    "Local" : "Paikallinen",
    "Root" : "Juurihakemisto",
    "Team invite" : "Tiimikutsu",
    "Federated" : "Federoitu",
    "Mount point" : "Liitospiste",
    "Nextcloud Account" : "Nextcloud-tili",
    "Nextcloud Group" : "Nextcloud-ryhmä",
    "Email address" : "Sähköpostiosoite",
    "Contact" : "Yhteystieto",
    "Circle" : "Piiri",
    "Nextcloud App" : "Nextcloud-sovellus",
    "Member" : "Jäsen",
    "Moderator" : "Moderaattori",
    "Admin" : "Ylläpitäjä",
    "Owner" : "Omistaja",
    "%s shared »%s« with you." : "%s jakoi kohteen »%s« kanssasi.",
    "Password to access »%s«" : "Salasana kohteen »%s« käyttöön",
    "It is protected with the following password:" : "Se on suojattu seuraavalla salasanalla:",
    "%1$s via %2$s" : "%1$s palvelun %2$s kautta",
    "Click the button below to open it." : "Napsauta alla olevaa painiketta avataksesi sen.",
    "Open »%s«" : "Avaa »%s«",
    "Password to access files shared to you by %1$s" : "Salasana jäsenen %1$s kanssasi jakamiin tiedostoihin",
    "Password to access files" : "Salasana tiedostoihin",
    "%s shared multiple files with you." : "%s jakoi useita tiedostoja kanssasi.",
    "Show all teams" : "Näytä kaikki tiimit",
    "Create a new team" : "Luo uusi tiimi",
    "Files" : "Tiedostot",
    "This feature is not available for personal circles" : "Tämä ominaisuus ei ole henkilökohtaisten piirien käytössä",
    "The team is not federated" : "Tiimi ei ole federoitu",
    "You cannot join this team" : "Et voi liittyä tähän tiimiin",
    "This member is not a moderator" : "Tämä jäsen ei ole moderaattori",
    "Insufficient privileges" : "Riittämättömät oikeudet",
    "This member does not exist" : "Tämä jäsen ei ole olemassa",
    "This member is the owner of the team" : "Tämä jäsen on tiimin omistaja",
    "You are already a member of this circle" : "Olet jo jäsenenä tässä piirissä",
    "You have been blocked from this circle" : "Sinut on estetty tästä piiristä",
    "The account is already a member of this circle" : "Tämä tili on jo jäsen tässä piirissä",
    "The account has already been invited into this circle" : "Tämä tili on jo kutsuttu tähän piiriin",
    "%s (Team owned by %s)" : "%s (Tiimin omistaa %s)",
    "Accept" : "Hyväksy",
    "Refuse" : "Hylkää",
    "%s" : "%s",
    "Personal team" : "Henkilökohtainen tiimi",
    "You have no permission to create a new team" : "Sinulla ei ole oikeutta luoda uutta tiimiä",
    "%s shared a file with you." : "%s jakoi tiedoston kanssasi.",
    "Open %s" : "Avaa %s",
    "Password to access content" : "Salasana sisällön käyttämiseksi",
    "Bring cloud-users closer together." : "Tuo pilvikäyttäjät lähemmäksi toisiaan.",
    "No files in here" : "Täällä ei ole tiedostoja",
    "No entries found in this folder" : "Tästä kansiosta ei löytynyt tietueita",
    "Name" : "Nimi",
    "Size" : "Koko",
    "Modified" : "Muokattu",
    "Teams' files" : "Tiimin tiedostot",
    "Select team to filter by" : "Valitse tiimi, jonka perusteella suodatetaan",
    "No teams found" : "Tiimejä ei löytynyt",
    "Please select teams to filter by" : "Valitse tiimit, joiden perusteella suodatetaan",
    "No files found for the selected teams" : "Valitulle tiimille ei löytynyt tiedostoja",
    "Shared to Circles" : "Jaettu piireille"
},
"nplurals=2; plural=(n != 1);");
