OC.L10N.register(
    "app_api",
    {
    "Cancel" : "Poništi",
    "Delete" : "Obriši",
    "Edit" : "Izmeni",
    "Name" : "Ime",
    "Save" : "Sačuvaj",
    "Update to {version}" : "Ažuriraj na verziju {version}",
    "Report a bug" : "Prijavi grešku",
    "Version" : "Verzija",
    "Type" : "Tip",
    "Documentation" : "Dokumentacija",
    "Details" : "Detalji",
    "Disable" : "Isključi"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
