OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "檔案下載限制",
    "File link share download limit" : "檔案連結分享下載限制",
    "This app allows limiting the number of downloads for external link shares." : "此應用程式允許限制外部連結分享的下載數量。",
    "The minimum limit is 1" : "最低限制為 1",
    "Failed to set download limit" : "設定下載限制失敗",
    "Failed to remove download limit" : "移除下載限制失敗",
    "Limit downloads" : "限制下載",
    "Set download limit" : "設定下載限制",
    "Setting a new limit will reset the download count" : "設定新限制將會重設下載次數",
    "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["僅剩 {count} 次可下載"],
    "Failed to set default download limit" : "設定預設下載限制失敗",
    "Download limit" : "下載限制",
    "Configure the default download limit for external shares." : "設定外部分享的預設下載限制。",
    "Set default download limit" : "設定預設下載限制",
    "You have reached the maximum amount of downloads allowed" : "您已到達允許的最大下載量",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "此分享的下載次數有限。您確定要觸發新的下載嗎？"
},
"nplurals=1; plural=0;");
