OC.L10N.register(
    "logreader",
    {
    "Level" : "түвшин",
    "App" : "Аппликэйшин",
    "Time" : "Цаг",
    "Relative" : "Хамаарал",
    "Info" : "Info",
    "Warning" : "Warning",
    "Error" : "Алдаа"
},
"nplurals=2; plural=(n != 1);");
