OC.L10N.register(
    "settings",
    {
    "Private" : "Private",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Only visible to people matched via phone number integration through Talk on mobile",
    "Local" : "Local",
    "Only visible to people on this instance and guests" : "Only visible to people on this instance and guests",
    "Federated" : "Federated",
    "Only synchronize to trusted servers" : "Only synchronize to trusted servers",
    "Published" : "Published",
    "Synchronize to trusted servers and the global and public address book" : "Synchronize to trusted servers and the global and public address book",
    "Verify" : "Verify",
    "Verifying …" : "Verifying …",
    "Unable to change password" : "Unable to change password",
    "Very weak password" : "Very weak password",
    "Weak password" : "Weak password",
    "So-so password" : "So-so password",
    "Good password" : "Good password",
    "Strong password" : "Strong password",
    "Groups" : "Groups",
    "Group list is empty" : "Group list is empty",
    "Unable to retrieve the group list" : "Unable to retrieve the group list",
    "{actor} added you to group {group}" : "{actor} added you to group {group}",
    "You added {user} to group {group}" : "You added {user} to group {group}",
    "{actor} added {user} to group {group}" : "{actor} added {user} to group {group}",
    "An administrator added you to group {group}" : "An administrator added you to group {group}",
    "An administrator added {user} to group {group}" : "An administrator added {user} to group {group}",
    "{actor} removed you from group {group}" : "{actor} removed you from group {group}",
    "You removed {user} from group {group}" : "You removed {user} from group {group}",
    "{actor} removed {user} from group {group}" : "{actor} removed {user} from group {group}",
    "An administrator removed you from group {group}" : "An administrator removed you from group {group}",
    "An administrator removed {user} from group {group}" : "An administrator removed {user} from group {group}",
    "Your <strong>group memberships</strong> were modified" : "Your <strong>group memberships</strong> were modified",
    "{actor} changed your password" : "{actor} changed your password",
    "You changed your password" : "You changed your password",
    "Your password was reset by an administrator" : "Your password was reset by an administrator",
    "Your password was reset" : "Your password was reset",
    "{actor} changed your email address" : "{actor} changed your email address",
    "You changed your email address" : "You changed your email address",
    "Your email address was changed by an administrator" : "Your email address was changed by an administrator",
    "You created an app password for a session named \"{token}\"" : "You created an app password for a session named \"{token}\"",
    "An administrator created an app password for a session named \"{token}\"" : "An administrator created an app password for a session named \"{token}\"",
    "You deleted app password \"{token}\"" : "You deleted app password \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "You renamed app password \"{token}\" to \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "You granted filesystem access to app password \"{token}\"",
    "You revoked filesystem access from app password \"{token}\"" : "You revoked filesystem access from app password \"{token}\"",
    "Security" : "Security",
    "You successfully logged in using two-factor authentication (%1$s)" : "You successfully logged in using two-factor authentication (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "A login attempt using two-factor authentication failed (%1$s)",
    "Remote wipe was started on %1$s" : "Remote wipe was started on %1$s",
    "Remote wipe has finished on %1$s" : "Remote wipe has finished on %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Your <strong>password</strong> or <strong>email</strong> was modified",
    "Settings" : "Settings",
    "Could not remove app." : "Could not remove app.",
    "Could not update app." : "Could not update app.",
    "Wrong password" : "Incorrect password",
    "Unable to change personal password" : "Unable to change personal password",
    "Saved" : "Saved",
    "No Login supplied" : "No Login supplied",
    "Unable to change password. Password too long." : "Unable to change password. Password too long.",
    "Authentication error" : "Authentication error",
    "Please provide an admin recovery password; otherwise, all account data will be lost." : "Please provide an admin recovery password; otherwise, all account data will be lost.",
    "Wrong admin recovery password. Please check the password and try again." : "Incorrect admin recovery password. Please check the password and try again.",
    "Backend does not support password change, but the encryption of the account key was updated." : "Backend does not support password change, but the encryption of the account key was updated.",
    "Administrator documentation" : "Administrator documentation",
    "User documentation" : "User documentation",
    "Nextcloud help overview" : "Nextcloud help overview",
    "Invalid SMTP password." : "Invalid SMTP password.",
    "Email setting test" : "Email setting test",
    "Well done, %s!" : "Well done, %s!",
    "If you received this email, the email configuration seems to be correct." : "If you received this email, the email configuration seems to be correct.",
    "Email could not be sent. Check your mail server log" : "Email could not be sent. Check your mail server log",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "A problem occurred while sending the email. Please revise your settings. (Error: %s)",
    "You need to set your account email before being able to send test emails. Go to %s for that." : "You need to set your account email before being able to send test emails. Go to %s for that.",
    "Recently active" : "Recently active",
    "Disabled accounts" : "Disabled accounts",
    "Invalid account" : "Invalid account",
    "Invalid mail address" : "Invalid mail address",
    "Settings saved" : "Settings saved",
    "Unable to change full name" : "Unable to change full name",
    "Unable to change email address" : "Unable to change email address",
    "Unable to set invalid phone number" : "Unable to set invalid phone number",
    "Unable to set invalid website" : "Unable to set invalid website",
    "Some account data was invalid" : "Some account data was invalid",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):",
    "%1$s changed your password on %2$s." : "%1$s changed your password on %2$s.",
    "Your password on %s was changed." : "Your password on %s was changed.",
    "Your password on %s was reset by an administrator." : "Your password on %s was reset by an administrator.",
    "Your password on %s was reset." : "Your password on %s was reset.",
    "Password for %1$s changed on %2$s" : "Password for %1$s changed on %2$s",
    "Password changed for %s" : "Password changed for %s",
    "If you did not request this, please contact an administrator." : "If you did not request this, please contact an administrator.",
    "Your email address on %s was changed." : "Your email address on %s was changed.",
    "Your email address on %s was changed by an administrator." : "Your email address on %s was changed by an administrator.",
    "Email address for %1$s changed on %2$s" : "Email address for %1$s changed on %2$s",
    "Email address changed for %s" : "Email address changed for %s",
    "The new email address is %s" : "The new email address is %s",
    "Your %s account was created" : "Your %s account was created",
    "Welcome aboard" : "Welcome aboard",
    "Welcome aboard %s" : "Welcome aboard %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Welcome to your %s account, you can add, protect, and share your data.",
    "Your Login is: %s" : "Your Login is: %s",
    "Set your password" : "Set your password",
    "Go to %s" : "Go to %s",
    "Install Client" : "Install Client",
    "Logged in account must be a sub admin" : "Logged in account must be a sub admin",
    "Apps" : "Apps",
    "Personal" : "Personal",
    "Administration" : "Administration",
    "Users" : "Users",
    "Additional settings" : "Additional settings",
    "Assistant" : "Assistant",
    "Administration privileges" : "Administration privileges",
    "Groupware" : "Groupware",
    "Overview" : "Overview",
    "Basic settings" : "Basic settings",
    "Sharing" : "Sharing",
    "Availability" : "Availability",
    "Calendar" : "Calendar",
    "Personal info" : "Personal info",
    "Mobile & desktop" : "Mobile & desktop",
    "Artificial Intelligence" : "Artificial Intelligence",
    "Email server" : "Email server",
    "Mail Providers" : "Mail Providers",
    "Mail provider enables sending emails directly through the user's personal email account. At present, this functionality is limited to calendar invitations. It requires Nextcloud Mail 4.1 and an email account in Nextcloud Mail that matches the user's email address in Nextcloud." : "Mail provider enables sending emails directly through the user's personal email account. At present, this functionality is limited to calendar invitations. It requires Nextcloud Mail 4.1 and an email account in Nextcloud Mail that matches the user's email address in Nextcloud.",
    "Send emails using" : "Send emails using",
    "User's email account" : "User's email account",
    "System email account" : "System email account",
    "Security & setup checks" : "Security & setup checks",
    "Background jobs" : "Background jobs",
    "Unlimited" : "Unlimited",
    "Verifying" : "Verifying",
    "Allowed admin IP ranges" : "Allowed admin IP ranges",
    "Admin IP filtering isn't applied." : "Admin IP filtering isn't applied.",
    "Configuration key \"%1$s\" expects an array (%2$s found). Admin IP range validation will not be applied." : "Configuration key \"%1$s\" expects an array (%2$s found). Admin IP range validation will not be applied.",
    "Configuration key \"%1$s\" contains invalid IP range(s): \"%2$s\"" : "Configuration key \"%1$s\" contains invalid IP range(s): \"%2$s\"",
    "Admin IP filtering is correctly configured." : "Admin IP filtering is correctly configured.",
    "App directories owner" : "App directories owner",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:\n%s" : "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:\n%s",
    "App directories have the correct owner \"%s\"" : "App directories have the correct owner \"%s\"",
    "Brute-force Throttle" : "Brute-force Throttle",
    "Your remote address could not be determined." : "Your remote address could not be determined.",
    "Your remote address was identified as \"%s\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly." : "Your remote address was identified as \"%s\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly.",
    "Your remote address \"%s\" is not brute-force throttled." : "Your remote address \"%s\" is not brute-force throttled.",
    "Old administration imported certificates" : "Old administration imported certificates",
    "A background job is pending that checks for administration imported SSL certificates. Please check back later." : "A background job is pending that checks for administration imported SSL certificates. Please check back later.",
    "There are some administration imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "There are some administration imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below.",
    "Code integrity" : "Code integrity",
    "Integrity checker has been disabled. Integrity cannot be verified." : "Integrity checker has been disabled. Integrity cannot be verified.",
    "No altered files" : "No altered files",
    "Some files have not passed the integrity check. {link1} {link2}" : "Some files have not passed the integrity check. {link1} {link2}",
    "Cron errors" : "Cron errors",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:\n%s" : "It was not possible to execute the cron job via CLI. The following technical errors have appeared:\n%s",
    "The last cron job ran without errors." : "The last cron job ran without errors.",
    "Cron last run" : "Cron last ran",
    "Last background job execution ran %s. Something seems wrong. {link}." : "Last background job execution ran %s. Something seems wrong. {link}.",
    "Last background job execution ran %s." : "Last background job execution ran %s.",
    "Data directory protected" : "Data directory protected",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root.",
    "Could not check that the data directory is protected. Please check manually that your server does not allow access to the data directory." : "Could not check that the data directory is protected. Please check manually that your server does not allow access to the data directory.",
    "Database missing columns" : "Database missing columns",
    "Missing optional column \"%s\" in table \"%s\"." : "Missing optional column \"%s\" in table \"%s\".",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability.",
    "Database missing indices" : "Database missing indices",
    "Missing indices:" : "Missing indices:",
    "\"%s\" in table \"%s\"" : "\"%s\" in table \"%s\"",
    "Detected some missing optional indices. Occasionally new indices are added (by Nextcloud or installed applications) to improve database performance. Adding indices can sometimes take awhile and temporarily hurt performance so this is not done automatically during upgrades. Once the indices are added, queries to those tables should be faster. Use the command `occ db:add-missing-indices` to add them." : "Detected some missing optional indices. Occasionally new indices are added (by Nextcloud or installed applications) to improve database performance. Adding indices can sometimes take awhile and temporarily hurt performance so this is not done automatically during upgrades. Once the indices are added, queries to those tables should be faster. Use the command `occ db:add-missing-indices` to add them.",
    "Database missing primary keys" : "Database missing primary keys",
    "Missing primary key on table \"%s\"." : "Missing primary key on table \"%s\".",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running.",
    "Database pending bigint migrations" : "Database pending bigint migrations",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline." : "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline.",
    "Debug mode" : "Debug mode",
    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "This instance is running in debug mode. Only enable this for local development and not in production environments.",
    "Debug mode is disabled." : "Debug mode is disabled.",
    "Default phone region" : "Default phone region",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective ISO 3166-1 code of the region to your config file." : "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective ISO 3166-1 code of the region to your config file.",
    "Email test" : "Email test",
    "Mail delivery is disabled by instance config \"%s\"." : "Mail delivery is disabled by instance config \"%s\".",
    "Email test was successfully sent" : "Email test was successfully sent",
    "You have not set or verified your email server configuration, yet. Please head over to the \"Basic settings\" in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "You have not set or verified your email server configuration, yet. Please head over to the \"Basic settings\" in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings.",
    "Transactional File Locking" : "Transactional File Locking",
    "Transactional File Locking is disabled. This is not a a supported configuraton. It may lead to difficult to isolate problems including file corruption. Please remove the `'filelocking.enabled' => false` configuration entry from your `config.php` to avoid these problems." : "Transactional File Locking is disabled. This is not a a supported configuraton. It may lead to difficult to isolate problems including file corruption. Please remove the `'filelocking.enabled' => false` configuration entry from your `config.php` to avoid these problems.",
    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available." : "The database is used for transactional file locking. To enhance performance, please configure memcache, if available.",
    "Forwarded for headers" : "Forwarded for headers",
    "Your \"trusted_proxies\" setting is not correctly set, it should be an array." : "Your \"trusted_proxies\" setting is not correctly set, it should be an array.",
    "Your \"trusted_proxies\" setting is not correctly set, it should be an array of IP addresses - optionally with range in CIDR notation." : "Your \"trusted_proxies\" setting is not correctly set, it should be an array of IP addresses - optionally with range in CIDR notation.",
    "The reverse proxy header configuration is incorrect. This is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "The reverse proxy header configuration is incorrect. This is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud.",
    "Your IP address was resolved as %s" : "Your IP address was resolved as %s",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud.",
    "HTTPS access and URLs" : "HTTPS access and URLs",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!",
    "Accessing site insecurely via HTTP." : "Accessing site insecurely via HTTP.",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This likely means that your instance is behind a reverse proxy and the Nextcloud `overwrite*` config values are not set correctly." : "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This likely means that your instance is behind a reverse proxy and the Nextcloud `overwrite*` config values are not set correctly.",
    "Your instance is generating insecure URLs. If you access your instance over HTTPS, this likely means that your instance is behind a reverse proxy and the Nextcloud `overwrite*` config values are not set correctly." : "Your instance is generating insecure URLs. If you access your instance over HTTPS, this likely means that your instance is behind a reverse proxy and the Nextcloud `overwrite*` config values are not set correctly.",
    "You are accessing your instance over a secure connection, and your instance is generating secure URLs." : "You are accessing your instance over a secure connection, and your instance is generating secure URLs.",
    "Internet connectivity" : "Internet connectivity",
    "Internet connectivity is disabled in configuration file." : "Internet connectivity is disabled in configuration file.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features.",
    "JavaScript modules support" : "JavaScript modules support",
    "Unable to run check for JavaScript support. Please remedy or confirm manually if your webserver serves `.mjs` files using the JavaScript MIME type." : "Unable to run check for JavaScript support. Please remedy or confirm manually if your webserver serves `.mjs` files using the JavaScript MIME type.",
    "Your webserver does not serve `.mjs` files using the JavaScript MIME type. This will break some apps by preventing browsers from executing the JavaScript files. You should configure your webserver to serve `.mjs` files with either the `text/javascript` or `application/javascript` MIME type." : "Your webserver does not serve `.mjs` files using the JavaScript MIME type. This will break some apps by preventing browsers from executing the JavaScript files. You should configure your webserver to serve `.mjs` files with either the `text/javascript` or `application/javascript` MIME type.",
    "JavaScript source map support" : "JavaScript source map support",
    "Your webserver is not set up to serve `.js.map` files. Without these files, JavaScript Source Maps won't function properly, making it more challenging to troubleshoot and debug any issues that may arise." : "Your webserver is not set up to serve `.js.map` files. Without these files, JavaScript Source Maps won't function properly, making it more challenging to troubleshoot and debug any issues that may arise.",
    "Old server-side-encryption" : "Old server-side-encryption",
    "Disabled" : "Disabled",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "The old server-side-encryption format is enabled. We recommend disabling this.",
    "Logging level" : "Logging level",
    "The %1$s configuration option must be a valid integer value." : "The %1$s configuration option must be a valid integer value.",
    "The logging level is set to debug level. Use debug level only when you have a problem to diagnose, and then reset your log level to a less-verbose level as it outputs a lot of information, and can affect your server performance." : "The logging level is set to debug level. Use debug level only when you have a problem to diagnose, and then reset your log level to a less-verbose level as it outputs a lot of information, and can affect your server performance.",
    "Logging level configured correctly." : "Logging level configured correctly.",
    "Maintenance window start" : "Maintenance window start",
    "Server has no maintenance window start time configured. This means resource intensive daily background jobs will also be executed during your main usage time. We recommend to set it to a time of low usage, so users are less impacted by the load caused from these heavy tasks." : "Server has no maintenance window start time configured. This means resource intensive daily background jobs will also be executed during your main usage time. We recommend to set it to a time of low usage, so users are less impacted by the load caused from these heavy tasks.",
    "Maintenance window to execute heavy background jobs is between {start}:00 UTC and {end}:00 UTC" : "Maintenance window to execute heavy background jobs is between {start}:00 UTC and {end}:00 UTC",
    "Memcache" : "Memcache",
    "Memcached is configured as distributed cache, but the wrong PHP module (\"memcache\") is installed. Please install the PHP module \"memcached\"." : "Memcached is configured as distributed cache, but the wrong PHP module (\"memcache\") is installed. Please install the PHP module \"memcached\".",
    "Memcached is configured as distributed cache, but the PHP module \"memcached\" is not installed. Please install the PHP module \"memcached\"." : "Memcached is configured as distributed cache, but the PHP module \"memcached\" is not installed. Please install the PHP module \"memcached\".",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available." : "No memory cache has been configured. To enhance performance, please configure a memcache, if available.",
    "Failed to write and read a value from local cache." : "Failed to write and read a value from local cache.",
    "Failed to write and read a value from distributed cache." : "Failed to write and read a value from distributed cache.",
    "Configured" : "Configured",
    "Mimetype migrations available" : "Mimetype migrations available",
    "One or more mimetype migrations are available. Occasionally new mimetypes are added to better handle certain file types. Migrating the mimetypes take a long time on larger instances so this is not done automatically during upgrades. Use the command `occ maintenance:repair --include-expensive` to perform the migrations." : "One or more mimetype migrations are available. Occasionally new mimetypes are added to better handle certain file types. Migrating the mimetypes take a long time on larger instances so this is not done automatically during upgrades. Use the command `occ maintenance:repair --include-expensive` to perform the migrations.",
    "MySQL row format" : "MySQL row format",
    "You are not using MySQL" : "You are not using MySQL",
    "None of your tables use ROW_FORMAT=Compressed" : "None of your tables use ROW_FORMAT=Compressed",
    "Incorrect row format found in your database. ROW_FORMAT=Dynamic offers the best database performances for Nextcloud. Please update row format on the following list: %s." : "Incorrect row format found in your database. ROW_FORMAT=Dynamic offers the best database performances for Nextcloud. Please update row format on the following list: %s.",
    "MySQL Unicode support" : "MySQL Unicode support",
    "MySQL is used as database and does support 4-byte characters" : "MySQL is used as database and does support 4-byte characters",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL." : "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL.",
    "OCS provider resolving" : "OCS provider resolving",
    "Could not check if your web server properly resolves the OCM and OCS provider URLs." : "Could not check if your web server properly resolves the OCM and OCS provider URLs.",
    "Your web server is not properly set up to resolve %1$s.\nThis is most likely related to a web server configuration that was not updated to deliver this folder directly.\nPlease compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx.\nOn Nginx those are typically the lines starting with \"location ~\" that need an update." : "Your web server is not properly set up to resolve %1$s.\nThis is most likely related to a web server configuration that was not updated to deliver this folder directly.\nPlease compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx.\nOn Nginx those are typically the lines starting with \"location ~\" that need an update.",
    "Overwrite CLI URL" : "Overwrite CLI URL",
    "The \"overwrite.cli.url\" option in your config.php is correctly set to \"%s\"." : "The \"overwrite.cli.url\" option in your config.php is correctly set to \"%s\".",
    "The \"overwrite.cli.url\" option in your config.php is set to \"%s\" which is a correct URL. Suggested URL is \"%s\"." : "The \"overwrite.cli.url\" option in your config.php is set to \"%s\" which is a correct URL. Suggested URL is \"%s\".",
    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"%s\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"%s\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)",
    "PHP APCu configuration" : "PHP APCu configuration",
    "Your APCu cache has been running full, consider increasing the apc.shm_size php setting." : "Your APCu cache has been running full, consider increasing the apc.shm_size php setting.",
    "Your APCu cache is almost full at %s%%, consider increasing the apc.shm_size php setting." : "Your APCu cache is almost full at %s%%, consider increasing the apc.shm_size php setting.",
    "PHP default charset" : "PHP default charset",
    "PHP configuration option \"default_charset\" should be UTF-8" : "PHP configuration option \"default_charset\" should be UTF-8",
    "PHP set_time_limit" : "PHP set_time_limit",
    "The function is available." : "The function is available.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended.",
    "Freetype" : "Freetype",
    "Supported" : "Supported",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface.",
    "PHP getenv" : "PHP getenv",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response.",
    "PHP file size upload limit" : "PHP file size upload limit",
    "The PHP upload_max_filesize is too low. A size of at least %1$s is recommended. Current value: %2$s." : "The PHP upload_max_filesize is too low. A size of at least %1$s is recommended. Current value: %2$s.",
    "The PHP post_max_size is too low. A size of at least %1$s is recommended. Current value: %2$s." : "The PHP post_max_size is too low. A size of at least %1$s is recommended. Current value: %2$s.",
    "The PHP max_input_time is too low. A time of at least %1$s is recommended. Current value: %2$s." : "The PHP max_input_time is too low. A time of at least %1$s is recommended. Current value: %2$s.",
    "The PHP max_execution_time is too low. A time of at least %1$s is recommended. Current value: %2$s." : "The PHP max_execution_time is too low. A time of at least %1$s is recommended. Current value: %2$s.",
    "PHP memory limit" : "PHP memory limit",
    "The PHP memory limit is below the recommended value of %s. Some features or apps - including the Updater - may not function properly." : "The PHP memory limit is below the recommended value of %s. Some features or apps - including the Updater - may not function properly.",
    "PHP modules" : "PHP modules",
    "increases language translation performance and fixes sorting of non-ASCII characters" : "increases language translation performance and fixes sorting of non-ASCII characters",
    "for Argon2 for password hashing" : "for Argon2 for password hashing",
    "required for SFTP storage and recommended for WebAuthn performance" : "required for SFTP storage and recommended for WebAuthn performance",
    "for picture rotation in server and metadata extraction in the Photos app" : "for picture rotation in server and metadata extraction in the Photos app",
    "This instance is missing some required PHP modules. It is required to install them: %s." : "This instance is missing some required PHP modules. It is required to install them: %s.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them:\n%s" : "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them:\n%s",
    "PHP opcache" : "PHP opcache",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation.",
    "OPcache is disabled. For better performance, it is recommended to apply \"opcache.enable=1\" to your PHP configuration." : "OPcache is disabled. For better performance, it is recommended to apply \"opcache.enable=1\" to your PHP configuration.",
    "The shared memory based OPcache is disabled. For better performance, it is recommended to apply \"opcache.file_cache_only=0\" to your PHP configuration and use the file cache as second level cache only." : "The shared memory based OPcache is disabled. For better performance, it is recommended to apply \"opcache.file_cache_only=0\" to your PHP configuration and use the file cache as second level cache only.",
    "OPcache is not working as it should, opcache_get_status() returns false, please check configuration." : "OPcache is not working as it should, opcache_get_status() returns false, please check configuration.",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply \"opcache.max_accelerated_files\" to your PHP configuration with a value higher than \"%s\"." : "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply \"opcache.max_accelerated_files\" to your PHP configuration with a value higher than \"%s\".",
    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply \"opcache.memory_consumption\" to your PHP configuration with a value higher than \"%s\"." : "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply \"opcache.memory_consumption\" to your PHP configuration with a value higher than \"%s\".",
    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply \"opcache.interned_strings_buffer\" to your PHP configuration with a value higher than \"%s\"." : "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply \"opcache.interned_strings_buffer\" to your PHP configuration with a value higher than \"%s\".",
    "OPcache is configured to remove code comments. With OPcache enabled, \"opcache.save_comments=1\" must be set for Nextcloud to function." : "OPcache is configured to remove code comments. With OPcache enabled, \"opcache.save_comments=1\" must be set for Nextcloud to function.",
    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with \"opcache.restrict_api\" or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with \"opcache.restrict_api\" or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades.",
    "Checking from CLI, OPcache checks have been skipped." : "Checking from CLI, OPcache checks have been skipped.",
    "The PHP OPcache module is not properly configured. %s." : "The PHP OPcache module is not properly configured. %s.",
    "Correctly configured" : "Correctly configured",
    "PHP version" : "PHP version",
    "You are currently running PHP %1$s. PHP %2$s is deprecated since Nextcloud %3$s. Nextcloud %4$s may require at least PHP %5$s. Please upgrade to one of the officially supported PHP versions provided by the PHP Group as soon as possible." : "You are currently running PHP %1$s. PHP %2$s is deprecated since Nextcloud %3$s. Nextcloud %4$s may require at least PHP %5$s. Please upgrade to one of the officially supported PHP versions provided by the PHP Group as soon as possible.",
    "You are currently running PHP %s." : "You are currently running PHP %s.",
    "PHP \"output_buffering\" option" : "PHP \"output_buffering\" option",
    "PHP configuration option \"output_buffering\" must be disabled" : "PHP configuration option \"output_buffering\" must be disabled",
    "Push service" : "Push service",
    "Valid enterprise license" : "Valid enterprise license",
    "Free push service" : "Free push service",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {link}." : "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {link}.",
    "Random generator" : "Random generator",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons." : "No suitable source for randomness found by PHP which is highly discouraged for security reasons.",
    "Secure" : "Secure",
    "Configuration file access rights" : "Configuration file access rights",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update.",
    "Nextcloud configuration file is writable" : "Nextcloud configuration file is writable",
    "Scheduling objects table size" : "Scheduling objects table size",
    "You have more than %s rows in the scheduling objects table. Please run the expensive repair jobs via occ maintenance:repair --include-expensive." : "You have more than %s rows in the scheduling objects table. Please run the expensive repair jobs via occ maintenance:repair --include-expensive.",
    "Scheduling objects table size is within acceptable range." : "Scheduling objects table size is within acceptable range.",
    "HTTP headers" : "HTTP headers",
    "- The `%1$s` HTTP header is not set to `%2$s`. Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "- The `%1$s` HTTP header is not set to `%2$s`. Some features might not work correctly, as it is recommended to adjust this setting accordingly.",
    "- The `%1$s` HTTP header is not set to `%2$s`. This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "- The `%1$s` HTTP header is not set to `%2$s`. This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly.",
    "- The `%1$s` HTTP header is not set to `%2$s`, `%3$s`, `%4$s`, `%5$s` or `%6$s`. This can leak referer information. See the {w3c-recommendation}." : "- The `%1$s` HTTP header is not set to `%2$s`, `%3$s`, `%4$s`, `%5$s` or `%6$s`. This can leak referer information. See the {w3c-recommendation}.",
    "- The `Strict-Transport-Security` HTTP header is not set to at least `%d` seconds (current value: `%d`). For enhanced security, it is recommended to use a long HSTS policy." : "- The `Strict-Transport-Security` HTTP header is not set to at least `%d` seconds (current value: `%d`). For enhanced security, it is recommended to use a long HSTS policy.",
    "- The `Strict-Transport-Security` HTTP header is malformed: `%s`. For enhanced security, it is recommended to enable HSTS." : "- The `Strict-Transport-Security` HTTP header is malformed: `%s`. For enhanced security, it is recommended to enable HSTS.",
    "- The `Strict-Transport-Security` HTTP header is not set (should be at least `%d` seconds). For enhanced security, it is recommended to enable HSTS." : "- The `Strict-Transport-Security` HTTP header is not set (should be at least `%d` seconds). For enhanced security, it is recommended to enable HSTS.",
    "Some headers are not set correctly on your instance" : "Some headers are not set correctly on your instance",
    "Could not check that your web server serves security headers correctly. Please check manually." : "Could not check that your web server serves security headers correctly. Please check manually.",
    "Could not check that your web server serves security headers correctly, unable to query `%s`" : "Could not check that your web server serves security headers correctly, unable to query `%s`",
    "Your server is correctly configured to send security headers." : "Your server is correctly configured to send security headers.",
    "Database version" : "Database version",
    "MariaDB version 10.3 detected, this version is end-of-life and only supported as part of Ubuntu 20.04. MariaDB >=%1$s and <=%2$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "MariaDB version 10.3 detected, this version is end-of-life and only supported as part of Ubuntu 20.04. MariaDB >=%1$s and <=%2$s is suggested for best performance, stability and functionality with this version of Nextcloud.",
    "MariaDB version \"%1$s\" detected. MariaDB >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "MariaDB version \"%1$s\" detected. MariaDB >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud.",
    "MySQL version \"%1$s\" detected. MySQL >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "MySQL version \"%1$s\" detected. MySQL >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud.",
    "PostgreSQL version \"%1$s\" detected. PostgreSQL >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "PostgreSQL version \"%1$s\" detected. PostgreSQL >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend. This is particularly recommended when using the desktop client for file synchronisation. To migrate to another database use the command line tool: \"occ db:convert-type\"." : "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend. This is particularly recommended when using the desktop client for file synchronisation. To migrate to another database use the command line tool: \"occ db:convert-type\".",
    "Unknown database platform" : "Unknown database platform",
    "Architecture" : "Architecture",
    "64-bit" : "64-bit",
    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit!" : "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit!",
    "Task Processing pickup speed" : "Task Processing pickup speed",
    "_No scheduled tasks in the last %n hour._::_No scheduled tasks in the last %n hours._" : ["No scheduled tasks in the last %n hour.","No scheduled tasks in the last %n hours."],
    "_The task pickup speed has been ok in the last %n hour._::_The task pickup speed has been ok in the last %n hours._" : ["The task pickup speed has been ok in the last %n hour.","The task pickup speed has been ok in the last %n hours."],
    "_The task pickup speed has been slow in the last %n hour. Many tasks took longer than 4 minutes to be picked up. Consider setting up a worker to process tasks in the background._::_The task pickup speed has been slow in the last %n hours. Many tasks took longer than 4 minutes to be picked up. Consider setting up a worker to process tasks in the background._" : ["The task pickup speed has been slow in the last %n hour. Many tasks took longer than 4 minutes to be picked up. Consider setting up a worker to process tasks in the background.","The task pickup speed has been slow in the last %n hours. Many tasks took longer than 4 minutes to be picked up. Consider setting up a worker to process tasks in the background."],
    "Temporary space available" : "Temporary space available",
    "Error while checking the temporary PHP path - it was not properly set to a directory. Returned value: %s" : "Error while checking the temporary PHP path - it was not properly set to a directory. Returned value: %s",
    "The PHP function \"disk_free_space\" is disabled, which prevents the check for enough space in the temporary directories." : "The PHP function \"disk_free_space\" is disabled, preventing the system from checking for sufficient space in the temporary directories.",
    "Error while checking the available disk space of temporary PHP path or no free disk space returned. Temporary path: %s" : "Error while checking the available disk space of temporary PHP path or no free disk space returned. Temporary path: %s",
    "- %.1f GiB available in %s (PHP temporary directory)" : "- %.1f GiB available in %s (PHP temporary directory)",
    "- %.1f GiB available in %s (Nextcloud temporary directory)" : "- %.1f GiB available in %s (Nextcloud temporary directory)",
    "Temporary directory is correctly configured:\n%s" : "Temporary directory is correctly configured:\n%s",
    "This instance uses an S3 based object store as primary storage, and has enough space in the temporary directory.\n%s" : "This instance uses an S3 based object store as primary storage, and has enough space in the temporary directory.\n%s",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GiB of free space available in the temp directory of PHP. To improve this please change the temporary directory in the php.ini or make more space available in that path. \nChecking the available space in the temporary path resulted in %.1f GiB instead of the recommended 50 GiB. Path: %s" : "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GiB of free space available in the temp directory of PHP. To improve this please change the temporary directory in the php.ini or make more space available in that path. \nChecking the available space in the temporary path resulted in %.1f GiB instead of the recommended 50 GiB. Path: %s",
    "Database transaction isolation level" : "Database transaction isolation level",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel.",
    "Was not able to get transaction isolation level: %s" : "Was not able to get transaction isolation level: %s",
    ".well-known URLs" : ".well-known URLs",
    "`check_for_working_wellknown_setup` is set to false in your configuration, so this check was skipped." : "`check_for_working_wellknown_setup` is set to false in your configuration, so this check was skipped.",
    "Could not check that your web server serves `.well-known` correctly. Please check manually." : "Could not check that your web server serves `.well-known` correctly. Please check manually.",
    "Your web server is not properly set up to resolve `.well-known` URLs, failed on:\n`%s`" : "Your web server is not properly set up to resolve `.well-known` URLs, failed on:\n`%s`",
    "Your server is correctly configured to serve `.well-known` URLs." : "Your server is correctly configured to serve `.well-known` URLs.",
    "Font file loading" : "Font file loading",
    "Could not check for {extension} loading support. Please check manually if your webserver serves `.{extension}` files." : "Could not check for {extension} loading support. Please check manually if your webserver serves `.{extension}` files.",
    "Your web server is not properly set up to deliver .{extension} files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustment to also deliver .{extension} files. Compare your Nginx configuration to the recommended configuration in our documentation." : "Your web server is not properly set up to deliver .{extension} files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustment to also deliver .{extension} files. Compare your Nginx configuration to the recommended configuration in our documentation.",
    "Profile information" : "Profile information",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled",
    "Nextcloud settings" : "Nextcloud settings",
    "Unified task processing" : "Unified task processing",
    "AI tasks can be implemented by different apps. Here you can set which app should be used for which task." : "AI tasks can be implemented by different apps. Here you can set which app should be used for which task.",
    "Allow AI usage for guest users" : "Allow AI usage for guest users",
    "Provider for Task types" : "Provider for Task types",
    "Enable" : "Enable",
    "None of your currently installed apps provide Task processing functionality" : "None of your currently installed apps provide Task processing functionality",
    "Machine translation" : "Machine translation",
    "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment.",
    "Image generation" : "Image generation",
    "Image generation can be implemented by different apps. Here you can set which app should be used." : "Image generation can be implemented by different apps. Here you can set which app should be used.",
    "None of your currently installed apps provide image generation functionality" : "None of your currently installed apps provide image generation functionality",
    "Text processing" : "Text processing",
    "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task.",
    "Task:" : "Task:",
    "None of your currently installed apps provide text processing functionality using the Text Processing API." : "None of your currently installed apps provide text processing functionality using the Text Processing API.",
    "Here you can decide which group can access certain sections of the administration settings." : "Here you can decide which group can access certain sections of the administration settings.",
    "Unable to modify setting" : "Unable to modify setting",
    "None" : "None",
    "Changed disclaimer text" : "Changed disclaimer text",
    "Deleted disclaimer text" : "Deleted disclaimer text",
    "Could not set disclaimer text" : "Could not set disclaimer text",
    "Allow apps to use the Share API" : "Allow apps to use the Share API",
    "Allow resharing" : "Allow resharing",
    "Allow sharing with groups" : "Allow sharing with groups",
    "Restrict users to only share with users in their groups" : "Restrict users to only share with users in their groups",
    "Ignore the following groups when checking group membership" : "Ignore the following groups when checking group membership",
    "Allow users to preview files even if download is disabled" : "Allow users to preview files even if download is disabled",
    "Users will still be able to screenshot or record the screen. This does not provide any definitive protection." : "Users will still be able to screenshot or record the screen. This does not provide any definitive protection.",
    "Allow users to share via link and emails" : "Allow users to share via link and emails",
    "Allow public uploads" : "Allow public uploads",
    "Allow public shares to be added to other clouds by federation." : "Allow public shares to be added to other clouds by federation.",
    "This will add share permissions to all newly created link shares." : "This will add share permissions to all newly created link shares.",
    "Always ask for a password" : "Always ask for a password",
    "Enforce password protection" : "Enforce password protection",
    "Exclude groups from password requirements" : "Exclude groups from password requirements",
    "Exclude groups from creating link shares" : "Exclude groups from creating link shares",
    "Allow users to set custom share link tokens" : "Allow users to set custom share link tokens",
    "Shares with custom tokens will continue to be accessible after this setting has been disabled" : "Shares with custom tokens will continue to be accessible after this setting has been disabled",
    "Shares with guessable tokens may be accessed easily" : "Shares with guessable tokens may be accessed easily",
    "Limit sharing based on groups" : "Limit sharing based on groups",
    "Allow sharing for everyone (default)" : "Allow sharing for everyone (default)",
    "Exclude some groups from sharing" : "Exclude some groups from sharing",
    "Limit sharing to some groups" : "Limit sharing to some groups",
    "Groups allowed to share" : "Groups allowed to share",
    "Groups excluded from sharing" : "Groups excluded from sharing",
    "Not allowed groups will still be able to receive shares, but not to initiate them." : "Not allowed groups will still be able to receive shares, but not to initiate them.",
    "Set default expiration date for internal shares" : "Set default expiration date for internal shares",
    "Enforce expiration date" : "Enforce expiry date",
    "Default expiration time of new shares in days" : "Default expiration time of new shares in days",
    "Expire shares after x days" : "Expire shares after x days",
    "Set default expiration date for shares to other servers" : "Set default expiration date for shares to other servers",
    "Enforce expiration date for remote shares" : "Enforce expiration date for remote shares",
    "Default expiration time of remote shares in days" : "Default expiration time of remote shares in days",
    "Expire remote shares after x days" : "Expire remote shares after x days",
    "Set default expiration date for shares via link or mail" : "Set default expiration date for shares via link or mail",
    "Enforce expiration date for link or mail shares" : "Enforce expiration date for link or mail shares",
    "Default expiration time of shares in days" : "Default expiration time of shares in days",
    "Privacy settings for sharing" : "Privacy settings for sharing",
    "Allow account name autocompletion in share dialog and allow access to the system address book" : "Allow account name autocompletion in share dialog and allow access to the system address book",
    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user.",
    "Restrict account name autocompletion and system address book access to users within the same groups" : "Restrict account name autocompletion and system address book access to users within the same groups",
    "Restrict account name autocompletion to users based on phone number integration" : "Restrict account name autocompletion to users based on phone number integration",
    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Show disclaimer text on the public link upload page (only shown when the file list is hidden)",
    "Disclaimer text" : "Disclaimer text",
    "This text will be shown on the public link upload page when the file list is hidden." : "This text will be shown on the public link upload page when the file list is hidden.",
    "Default share permissions" : "Default share permissions",
    "Two-Factor Authentication" : "Two-Factor Authentication",
    "Two-factor authentication can be enforced for all accounts and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Two-factor authentication can be enforced for all accounts and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system.",
    "Enforce two-factor authentication" : "Enforce two-factor authentication",
    "Limit to groups" : "Limit to groups",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Enforcement of two-factor authentication can be set for certain groups only.",
    "Two-factor authentication is enforced for all members of the following groups." : "Two-factor authentication is enforced for all members of the following groups.",
    "Enforced groups" : "Enforced groups",
    "Two-factor authentication is not enforced for members of the following groups." : "Two-factor authentication is not enforced for members of the following groups.",
    "Excluded groups" : "Excluded groups",
    "When groups are selected/excluded, they use the following logic to determine if an account has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If an account is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "When groups are selected/excluded, they use the following logic to determine if an account has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If an account is both in a selected and excluded group, the selected takes precedence and 2FA is enforced.",
    "Save changes" : "Save changes",
    "Default" : "Default",
    "Registered Deploy daemons list" : "Registered Deploy daemons list",
    "No Deploy daemons configured" : "No Deploy daemons configured",
    "Register a custom one or setup from available templates" : "Register a custom one or setup from available templates",
    "Show details for {appName} app" : "Show details for {appName} app",
    "Update to {update}" : "Update to {update}",
    "Remove" : "Remove",
    "Featured" : "Featured",
    "This app is supported via your current Nextcloud subscription." : "This app is supported via your current Nextcloud subscription.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Featured apps are developed by and within the community. They offer central functionality and are ready for production use.",
    "Community rating: {score}/5" : "Community rating: {score}/5",
    "Disable all" : "Disable all",
    "Download and enable all" : "Download and enable all",
    "All apps are up-to-date." : "All apps are up-to-date.",
    "Icon" : "Icon",
    "Name" : "Surname",
    "Version" : "Version",
    "Level" : "Level",
    "Actions" : "Actions",
    "Results from other categories" : "Results from other categories",
    "No apps found for your version" : "No apps found for your version",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n app has an update available","%n apps have an update available"],
    "_Update_::_Update all_" : ["Update","Update all"],
    "Failed to load groups" : "Failed to load groups",
    "Failed to create group" : "Failed to create group",
    "Creating group…" : "Creating group…",
    "Create group" : "Create group",
    "Group name" : "Group name",
    "Please enter a valid group name" : "Please enter a valid group name",
    "Search groups…" : "Search groups…",
    "List of groups. This list is not fully populated for performance reasons. The groups will be loaded as you navigate or search through the list." : "List of groups. This list is not fully populated for performance reasons. The groups will be loaded as you navigate or search through the list.",
    "Loading groups…" : "Loading groups…",
    "Could not load app discover section" : "Could not load app discover section",
    "Could not render element" : "Could not render element",
    "Nothing to show" : "Nothing to show",
    "Could not load section content from app store." : "Could not load section content from app store.",
    "Loading" : "Loading",
    "Fetching the latest news…" : "Fetching the latest news…",
    "Carousel" : "Carousel",
    "Previous slide" : "Previous slide",
    "Next slide" : "Next slide",
    "Choose slide to display" : "Choose slide to display",
    "{index} of {total}" : "{index} of {total}",
    "Daemon" : "Daemon",
    "Deploy Daemon" : "Deploy Daemon",
    "Type" : "Type",
    "Display Name" : "Display Name",
    "GPUs support" : "GPUs support",
    "Compute device" : "Compute device",
    "Advanced deploy options" : "Advanced deploy options",
    "Edit ExApp deploy options before installation" : "Edit ExApp deploy options before installation",
    "Configured ExApp deploy options. Can be set only during installation" : "Configured ExApp deploy options. Can be set only during installation",
    "Learn more" : "Learn more",
    "Environment variables" : "Environment variables",
    "ExApp container environment variables" : "ExApp container environment variables",
    "No environment variables defined" : "No environment variables defined",
    "Mounts" : "Mounts",
    "Define host folder mounts to bind to the ExApp container" : "Define host folder mounts to bind to the ExApp container",
    "Must exist on the Deploy daemon host prior to installing the ExApp" : "Must exist on the Deploy daemon host prior to installing the ExApp",
    "Host path" : "Host path",
    "Container path" : "Container path",
    "Read-only" : "Read-only",
    "Remove mount" : "Remove mount",
    "New mount" : "New mount",
    "Enter path to host folder" : "Enter path to host folder",
    "Enter path to container folder" : "Enter path to container folder",
    "Toggle read-only mode" : "Toggle read-only mode",
    "Confirm adding new mount" : "Confirm adding new mount",
    "Confirm" : "Confirm",
    "Cancel adding mount" : "Cancel adding mount",
    "Cancel" : "Cancel",
    "Add mount" : "Add mount",
    "ExApp container mounts" : "ExApp container mounts",
    "No mounts defined" : "No mounts defined",
    "Description" : "Description",
    "View in store" : "View in store",
    "Visit website" : "Visit website",
    "Usage documentation" : "Usage documentation",
    "Admin documentation" : "Admin documentation",
    "Developer documentation" : "Developer documentation",
    "Details" : "Details",
    "All" : "All",
    "Limit app usage to groups" : "Limit app usage to groups",
    "No results" : "No results",
    "Update to {version}" : "Update to {version}",
    "Deploy options" : "Deploy options",
    "Default Deploy daemon is not accessible" : "Default Deploy daemon is not accessible",
    "Delete data on remove" : "Delete data on remove",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "This app has no minimum Nextcloud version assigned. This will cause an error in the future.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "This app has no maximum Nextcloud version assigned. This will cause an error in the future.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "This app cannot be installed because the following dependencies are not fulfilled:",
    "Latest updated" : "Latest updated",
    "Author" : "Author",
    "Categories" : "Categories",
    "Resources" : "Resources",
    "Documentation" : "Documentation",
    "Interact" : "Interact",
    "Report a bug" : "Report a bug",
    "Request feature" : "Request feature",
    "Ask questions or discuss" : "Ask questions or discuss",
    "Rate the app" : "Rate the app",
    "Rate" : "Rate",
    "Changelog" : "Changelog",
    "Google Chrome for Android" : "Google Chrome for Android",
    "{productName} iOS app" : "{productName} iOS app",
    "{productName} Android app" : "{productName} Android app",
    "{productName} Talk for iOS" : "{productName} Talk for iOS",
    "{productName} Talk for Android" : "{productName} Talk for Android",
    "Sync client" : "Sync client",
    "This session" : "This session",
    "{client} - {version} ({system})" : "{client} - {version} ({system})",
    "{client} - {version}" : "{client} - {version}",
    "Device name" : "Device name",
    "Cancel renaming" : "Cancel renaming",
    "Save new name" : "Save new name",
    "Marked for remote wipe" : "Marked for remote wipe",
    "Device settings" : "Device settings",
    "Allow filesystem access" : "Allow filesystem access",
    "Rename" : "Rename",
    "Revoke" : "Revoke",
    "Wipe device" : "Wipe device",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Revoking this token might prevent the wiping of your device if it has not started the wipe yet.",
    "Device" : "Device",
    "Last activity" : "Last activity",
    "Devices & sessions" : "Devices & sessions",
    "Web, desktop and mobile clients currently logged in to your account." : "Web, desktop and mobile clients currently logged in to your account.",
    "Error while creating device token" : "Error while creating device token",
    "App name" : "App name",
    "Create new app password" : "Create new app password",
    "App password copied!" : "App password copied!",
    "Copy app password" : "Copy app password",
    "Login name copied!" : "Login name copied!",
    "Copy login name" : "Copy login name",
    "Could not copy app password. Please copy it manually." : "Could not copy app password. Please copy it manually.",
    "Could not copy login name. Please copy it manually." : "Could not copy login name. Please copy it manually.",
    "New app password" : "New app password",
    "Use the credentials below to configure your app or device. For security reasons this password will only be shown once." : "Use the credentials below to configure your app or device. For security reasons this password will only be shown once.",
    "Login" : "Login",
    "Password" : "Password",
    "Show QR code for mobile apps" : "Show QR code for mobile apps",
    "Use system cron service to call the cron.php file every 5 minutes." : "Use system cron service to call the cron.php file every 5 minutes.",
    "The cron.php needs to be executed by the system account \"{user}\"." : "The cron.php needs to be executed by the system account \"{user}\".",
    "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details." : "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details.",
    "Unable to update background job mode" : "Unable to update background job mode",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information.",
    "Last job execution ran {time}. Something seems wrong." : "Last job execution ran {time}. Something seems wrong.",
    "Last job ran {relativeTime}." : "Last job ran {relativeTime}.",
    "Background job did not run yet!" : "Background job did not run yet!",
    "AJAX" : "AJAX",
    "Execute one task with each page loaded. Use case: Single account instance." : "Execute one task with each page loaded. Use case: Single account instance.",
    "Webcron" : "Webcron",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 accounts depending on the usage)." : "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 accounts depending on the usage).",
    "Cron (Recommended)" : "Cron (Recommended)",
    "Unable to update profile default setting" : "Unable to update profile default setting",
    "Profile" : "Profile",
    "Enable or disable profile by default for new accounts." : "Enable or disable profile by default for new accounts.",
    "Password confirmation is required" : "Password confirmation is required",
    "Failed to save setting" : "Failed to save setting",
    "{app}'s declarative setting field: {name}" : "{app}'s declarative setting field: {name}",
    "Unable to update server side encryption config" : "Unable to update server side encryption config",
    "Server-side encryption" : "Server-side encryption",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed.",
    "To encrypt all existing files run this OCC command:" : "To encrypt all existing files run this OCC command:",
    "Enable server-side encryption" : "Enable server-side encryption",
    "Disabling server side encryption is only possible using OCC, please refer to the documentation." : "Disabling server side encryption is only possible using OCC, please refer to the documentation.",
    "No encryption module loaded, please enable an encryption module in the app menu." : "No encryption module loaded, please enable an encryption module in the app menu.",
    "Select default encryption module:" : "Select default encryption module:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}",
    "Cancel encryption" : "Cancel encryption",
    "Enable encryption" : "Enable encryption",
    "Confirm enabling encryption" : "Confirm enabling encryption",
    "Please read carefully before activating server-side encryption:" : "Please read carefully before activating server-side encryption:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met.",
    "By default a master key for the whole instance will be generated. Please check if that level of access is compliant with your needs." : "By default a master key for the whole instance will be generated. Please check if that level of access is compliant with your needs.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Encryption alone does not guarantee complete security. Please read the documentation for information on how the encryption app works, and supported use cases.",
    "Be aware that encryption always increases the file size." : "Be aware that encryption always increases the file size.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data.",
    "Refer to the admin documentation on how to manually also encrypt existing files." : "Refer to the admin documentation on how to manually also encrypt existing files.",
    "This is the final warning: Do you really want to enable encryption?" : "This is the final warning: Do you really want to enable encryption?",
    "Failed to delete group \"{group}\"" : "Failed to delete group \"{group}\"",
    "Please confirm the group removal" : "Please confirm the group removal",
    "You are about to delete the group \"{group}\". The accounts will NOT be deleted." : "You are about to delete the group \"{group}\". The accounts will NOT be deleted.",
    "Submit" : "Submit",
    "Rename group" : "Rename group",
    "Delete group" : "Delete group",
    "Current password" : "Current password",
    "New password" : "New password",
    "Change password" : "Change password",
    "Choose your profile picture" : "Choose your profile picture",
    "Please select a valid png or jpg file" : "Please select a valid png or jpg file",
    "Error setting profile picture" : "Error setting profile picture",
    "Error cropping profile picture" : "Error cropping profile picture",
    "Error saving profile picture" : "Error saving profile picture",
    "Error removing profile picture" : "Error removing profile picture",
    "Your profile picture" : "Your profile picture",
    "Upload profile picture" : "Upload profile picture",
    "Choose profile picture from Files" : "Choose profile picture from Files",
    "Remove profile picture" : "Remove profile picture",
    "The file must be a PNG or JPG" : "The file must be a PNG or JPG",
    "Picture provided by original account" : "Picture provided by original account",
    "Set as profile picture" : "Set as profile picture",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Please note that it can take up to 24 hours for your profile picture to be updated everywhere.",
    "Your biography. Markdown is supported." : "Your biography. Markdown is supported.",
    "Unable to update date of birth" : "Unable to update date of birth",
    "Enter your date of birth" : "Enter your date of birth",
    "Bluesky handle" : "Bluesky handle",
    "You are using {s}{usage}{/s}" : "You are using {s}{usage}{/s}",
    "You are using {s}{usage}{/s} of {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})" : "You are using {s}{usage}{/s} of {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})",
    "You are a member of the following groups:" : "You are a member of the following groups:",
    "Your full name" : "Your full name",
    "Email options" : "Email options",
    "Options for additional email address {index}" : "Options for additional email address {index}",
    "Remove primary email" : "Remove primary email",
    "Delete email" : "Delete email",
    "This address is not confirmed" : "This address is not confirmed",
    "Unset as primary email" : "Unset as primary email",
    "Set as primary email" : "Set as primary email",
    "Additional email address {index}" : "Additional email address {index}",
    "Unable to delete primary email address" : "Unable to delete primary email address",
    "Unable to update primary email address" : "Unable to update primary email address",
    "Unable to add additional email address" : "Unable to add additional email address",
    "Unable to update additional email address" : "Unable to update additional email address",
    "Unable to delete additional email address" : "Unable to delete additional email address",
    "Primary email for password reset and notifications" : "Primary email for password reset and notifications",
    "No email address set" : "No email address set",
    "Your handle" : "Your handle",
    "Derived from your locale ({weekDayName})" : "Derived from your locale ({weekDayName})",
    "Unable to update first day of week" : "Unable to update first day of week",
    "Day to use as the first day of week" : "Day to use as the first day of week",
    "Your headline" : "Your headline",
    "Unable to update language" : "Unable to update language",
    "Languages" : "Languages",
    "Help translate" : "Help translate",
    "No language set" : "No language set",
    "Unable to update locale" : "Unable to update locale",
    "Locales" : "Locales",
    "Week starts on {firstDayOfWeek}" : "Week starts on {firstDayOfWeek}",
    "No locale set" : "No locale set",
    "Your city" : "Your city",
    "Your organisation" : "Your organisation",
    "Your phone number" : "Your phone number",
    "Edit your Profile visibility" : "Edit your Profile visibility",
    "Unable to update profile enabled state" : "Unable to update profile enabled state",
    "Enable profile" : "Enable profile",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected.",
    "Unable to update visibility of {displayId}" : "Unable to update visibility of {displayId}",
    "she/her" : "she/her",
    "he/him" : "he/him",
    "they/them" : "they/them",
    "Your pronouns. E.g. {pronounsExample}" : "Your pronouns. E.g. {pronounsExample}",
    "Your role" : "Your role",
    "Your X (formerly Twitter) handle" : "Your X (formerly Twitter) handle",
    "Your website" : "Your website",
    "Invalid value" : "Invalid value",
    "Unable to update {property}" : "Unable to update {property}",
    "No {property} set" : "No {property} set",
    "Change scope level of {property}, current scope is {scope}" : "Change scope level of {property}, current scope is {scope}",
    "Unable to update federation scope of the primary {property}" : "Unable to update federation scope of the primary {property}",
    "Unable to update federation scope of additional {property}" : "Unable to update federation scope of additional {property}",
    "Add additional email" : "Add additional email",
    "Add" : "Add",
    "Create" : "Create",
    "Change" : "Change",
    "Delete" : "Delete",
    "Reshare" : "Reshare",
    "Default language" : "Default language",
    "Common languages" : "Common languages",
    "Other languages" : "Other languages",
    "Password change is disabled because the master key is disabled" : "Password change is disabled because the master key is disabled",
    "No accounts" : "No accounts",
    "Loading accounts …" : "Loading accounts …",
    "List of accounts. This list is not fully rendered for performance reasons. The accounts will be rendered as you navigate through the list." : "List of accounts. This list is not fully rendered for performance reasons. The accounts will be rendered as you navigate through the list.",
    "Manager" : "Manager",
    "Set line manager" : "Set line manager",
    "Account name will be autogenerated" : "Account name will be autogenerated",
    "Account name (required)" : "Account name (required)",
    "Failed to search groups" : "Failed to search groups",
    "New account" : "New account",
    "Display name" : "Display name",
    "Either password or email is required" : "Either password or email is required",
    "Password (required)" : "Password (required)",
    "Email (required)" : "Email (required)",
    "Email" : "Email",
    "Member of the following groups (required)" : "Member of the following groups (required)",
    "Member of the following groups" : "Member of the following groups",
    "Set account groups" : "Set account groups",
    "Admin of the following groups" : "Admin of the following groups",
    "Set account as admin for …" : "Set account as admin for …",
    "Quota" : "Quota",
    "Set account quota" : "Set account quota",
    "Language" : "Language",
    "Set default language" : "Set default language",
    "Add new account" : "Add new account",
    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} account …","{userCount} accounts …"],
    "_{userCount} account_::_{userCount} accounts_" : ["{userCount} account","{userCount} accounts"],
    "Total rows summary" : "Total rows summary",
    "Scroll to load more rows" : "Scroll to load more rows",
    "Password or insufficient permissions message" : "Password or insufficient permissions message",
    "Avatar" : "Avatar",
    "Account name" : "Account name",
    "Group admin for" : "Group admin for",
    "Account backend" : "Account backend",
    "Storage location" : "Storage location",
    "First login" : "First login",
    "Last login" : "Last login",
    "Account actions" : "Account actions",
    "{size} used" : "{size} used",
    "Delete account" : "Delete account",
    "Disconnect all devices and delete local data" : "Disconnect all devices and delete local data",
    "Disable account" : "Disable account",
    "Enable account" : "Enable account",
    "Resend welcome email" : "Resend welcome email",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet.",
    "Remote wipe of devices" : "Remote wipe of devices",
    "Wipe {userid}'s devices" : "Wipe {userid}'s devices",
    "Wiped {userid}'s devices" : "Wiped {userid}'s devices",
    "Failed to load groups with details" : "Failed to load groups with details",
    "Failed to load sub admin groups with details" : "Failed to load sub admin groups with details",
    "Failed to update line manager" : "Failed to update line manager",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Fully delete {userid}'s account including all their personal files, app data, etc.",
    "Account deletion" : "Account deletion",
    "Delete {userid}'s account" : "Delete {userid}'s account",
    "Display name was successfully changed" : "Display name was successfully changed",
    "Password can't be empty" : "Password can't be empty",
    "Password was successfully changed" : "Password was successfully changed",
    "Email can't be empty" : "Email can't be empty",
    "Email was successfully changed" : "Email was successfully changed",
    "Welcome mail sent!" : "Welcome mail sent!",
    "Loading account …" : "Loading account …",
    "Change display name" : "Change display name",
    "Set new password" : "Set new password",
    "You do not have permissions to see the details of this account" : "You do not have permissions to see the details of this account",
    "Set new email address" : "Set new email address",
    "Add account to group" : "Add account to group",
    "Set account as admin for" : "Set account as admin for",
    "Select account quota" : "Select account quota",
    "Set the language" : "Set the language",
    "Toggle account actions menu" : "Toggle account actions menu",
    "Done" : "Done",
    "Edit" : "Edit",
    "Account management settings" : "Account management settings",
    "Visibility" : "Visibility",
    "Show language" : "Show language",
    "Show account backend" : "Show account backend",
    "Show storage path" : "Show storage path",
    "Show first login" : "Show first login",
    "Show last login" : "Show last login",
    "Sorting" : "Sorting",
    "The system config enforces sorting the groups by name. This also disables showing the member count." : "The system config enforces sorting the groups by name. This also disables showing the member count.",
    "Group list sorting" : "Group list sorting",
    "Sorting only applies to the currently loaded groups for performance reasons. Groups will be loaded as you navigate or search through the list." : "Sorting only applies to the currently loaded groups for performance reasons. Groups will be loaded as you navigate or search through the list.",
    "By member count" : "By member count",
    "By name" : "By name",
    "Send email" : "Send email",
    "Send welcome email to new accounts" : "Send welcome email to new accounts",
    "Defaults" : "Defaults",
    "Default quota" : "Default quota",
    "Select default quota" : "Select default quota",
    "Server error while trying to complete WebAuthn device registration" : "Server error while trying to complete WebAuthn device registration",
    "Passwordless authentication requires a secure connection." : "Passwordless authentication requires a secure connection.",
    "Add WebAuthn device" : "Add WebAuthn device",
    "Please authorize your WebAuthn device." : "Please authorise your WebAuthn device.",
    "Adding your device …" : "Adding your device …",
    "Unnamed device" : "Unnamed device",
    "Passwordless Authentication" : "Passwordless Authentication",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Set up your account for passwordless authentication following the FIDO2 standard.",
    "No devices configured." : "No devices configured.",
    "The following devices are configured for your account:" : "The following devices are configured for your account:",
    "Your browser does not support WebAuthn." : "Your browser does not support WebAuthn.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "As admin you can fine-tune the sharing behavior. Please see the documentation for more information.",
    "You need to enable the File sharing App." : "You need to enable the File sharing App.",
    "App Store" : "App Store",
    "Loading app list" : "Loading app list",
    "Loading categories" : "Loading categories",
    "Developer documentation ↗" : "Developer documentation ↗",
    "Version {version}, {license}-licensed" : "Version {version}, {license}-licensed",
    "Version {version}" : "Version {version}",
    "All accounts" : "All accounts",
    "Admins" : "Admins",
    "Account group: {group}" : "Account group: {group}",
    "Account management" : "Account management",
    "Sending…" : "Sending…",
    "Email sent" : "Email sent",
    "For performance reasons, when you enable encryption on a Nextcloud server only new and changed files are encrypted." : "For performance reasons, when you enable encryption on a Nextcloud server only new and changed files are encrypted.",
    "Location" : "Location",
    "Profile picture" : "Profile picture",
    "About" : "About",
    "Date of birth" : "Date of birth",
    "Full name" : "Full name",
    "Additional email" : "Additional email",
    "Fediverse (e.g. Mastodon)" : "Fediverse (e.g. Mastodon)",
    "Headline" : "Headline",
    "Organisation" : "Organisation",
    "Phone number" : "Phone number",
    "Pronouns" : "Pronouns",
    "Role" : "Role",
    "X (formerly Twitter)" : "X (formerly Twitter)",
    "Bluesky" : "Bluesky",
    "Website" : "Website",
    "Profile visibility" : "Profile visibility",
    "Locale" : "Locale",
    "First day of week" : "First day of week",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Not available as this property is required for core functionality including file sharing and calendar invitations",
    "Not available as federation has been disabled for your account, contact your system administration if you have any questions" : "Not available as federation has been disabled for your account, contact your system administration if you have any questions",
    "Not available as publishing account specific data to the lookup server is not allowed, contact your system administration if you have any questions" : "Not available as publishing account specific data to the lookup server is not allowed, contact your system administration if you have any questions",
    "Discover" : "Discover",
    "Your apps" : "Your apps",
    "Active apps" : "Active apps",
    "Disabled apps" : "Disabled apps",
    "Updates" : "Updates",
    "App bundles" : "App bundles",
    "Featured apps" : "Featured apps",
    "Supported apps" : "Supported apps",
    "Show to everyone" : "Show to everyone",
    "Show to logged in accounts only" : "Show to logged in accounts only",
    "Hide" : "Hide",
    "Manually installed apps cannot be updated" : "Manually installed apps cannot be updated",
    "{progress}% Deploying …" : "{progress}% Deploying …",
    "{progress}% Initializing …" : "{progress}% Initializing …",
    "Health checking" : "Health checking",
    "Deploy and Enable" : "Deploy and Enable",
    "Download and enable" : "Download and enable",
    "Disable" : "Disable",
    "Allow untested app" : "Allow untested app",
    "The app will be downloaded from the App Store" : "The app will be downloaded from the App Store",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected.",
    "Unknown" : "Unknown",
    "Never" : "Never",
    "Could not register device: Network error" : "Could not register device: Network error",
    "Could not register device: Probably already registered" : "Could not register device: Probably already registered",
    "Could not register device" : "Could not register device",
    "An error occurred during the request. Unable to proceed." : "An error occurred during the request. Unable to proceed.",
    "The app has been enabled but needs to be updated." : "The app has been enabled but needs to be updated.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Error: This app cannot be enabled because it makes the server unstable",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds.",
    "Do you really want to wipe your data from this device?" : "Do you really want to wipe your data from this device?",
    "Confirm wipe" : "Confirm wipe",
    "Could not delete the app token" : "Could not delete the app token",
    "Error while wiping the device with the token" : "Error while wiping the device with the token",
    "Error while updating device token name" : "Error while updating device token name",
    "Error while updating device token scope" : "Error while updating device token scope",
    "Could not set group sorting" : "Could not set group sorting",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "There were too many requests from your network. Retry later or contact your administrator if this is an error.",
    "Error" : "Error",
    "Account documentation" : "Account documentation",
    "Administration documentation" : "Administration documentation",
    "Forum" : "Forum",
    "Nextcloud help & privacy resources" : "Nextcloud help & privacy resources",
    "General documentation" : "General documentation",
    "Legal notice" : "Legal notice",
    "Privacy policy" : "Privacy policy",
    "None/STARTTLS" : "None/STARTTLS",
    "SSL" : "SSL",
    "Open documentation" : "Open documentation",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "It is important to set up this server to be able to send emails, like for password reset and notifications.",
    "Send mode" : "Send mode",
    "Encryption" : "Encryption",
    "Sendmail mode" : "Sendmail mode",
    "From address" : "From address",
    "Server address" : "Server address",
    "Port" : "Port",
    "Authentication" : "Authentication",
    "Authentication required" : "Authentication required",
    "Credentials" : "Credentials",
    "SMTP Login" : "SMTP Login",
    "SMTP Password" : "SMTP Password",
    "Save" : "Save",
    "Test and verify email settings" : "Test and verify email settings",
    "Security & setup warnings" : "Security & setup warnings",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information.",
    "All checks passed." : "All checks passed.",
    "There are some errors regarding your setup." : "There are some errors regarding your setup.",
    "There are some warnings regarding your setup." : "There are some warnings regarding your setup.",
    "Checking for system and security issues." : "Checking for system and security issues.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>.",
    "Reasons to use Nextcloud in your organization" : "Reasons to use Nextcloud in your organization",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Like our Facebook page",
    "Follow us on X" : "Follow us on X",
    "Follow us on Mastodon" : "Follow us on Mastodon",
    "Check out our blog" : "Check out our blog",
    "Subscribe to our newsletter" : "Subscribe to our newsletter",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "This community release of Nextcloud is unsupported and instant notifications are unavailable.",
    "Use a second factor besides your password to increase security for your account." : "Use a second factor besides your password to increase security for your account.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication.",
    "Logged in account must be a subadmin" : "Logged in account must be a subadmin",
    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule.",
    "File locking" : "File locking",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems." : "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems.",
    "The PHP memory limit is below the recommended value of %s." : "The PHP memory limit is below the recommended value of %s.",
    "for WebAuthn passwordless login" : "for WebAuthn passwordless login",
    "for WebAuthn passwordless login, and SFTP storage" : "for WebAuthn passwordless login, and SFTP storage",
    "- The `%1$s` HTTP header does not contain `%2$s`. This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "- The `%1$s` HTTP header does not contain `%2$s`. This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly.",
    "PostgreSQL version \"%s\" detected. PostgreSQL >=12 and <=16 is suggested for best performance, stability and functionality with this version of Nextcloud." : "PostgreSQL version \"%s\" detected. PostgreSQL >=12 and <=16 is suggested for best performance, stability and functionality with this version of Nextcloud.",
    "Set default expiration date for shares" : "Set default expiration date for shares",
    "Your biography" : "Your biography",
    "You are using <strong>{usage}</strong>" : "You are using <strong>{usage}</strong>",
    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
    "Failed to load subadmin groups with details" : "Failed to load subadmin groups with details"
},
"nplurals=2; plural=(n != 1);");
