OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Osobisty zasób aktywności dla %s",
    "Your feed URL is invalid" : "Adres URL zasobu jest nieprawidłowy",
    "Activity feed for %1$s" : "Kanał aktywności dla %1$s",
    "Activity feed" : "Zasób aktywności",
    "Your settings have been updated." : "Twoje ustawienia zostały zaktualizowane",
    "Settings have been updated." : "Ustawienia zostały zaktualizowane.",
    "remote user" : "użytkownik zdalny",
    "Recent activity" : "Ostatnia aktywność",
    "No activities" : "Brak aktywności",
    "More activities" : "Więcej aktywności",
    "Daily activity summary for %s" : "Podsumowanie dziennej aktywności dla %s",
    "_and %n more…_::_and %n more…_" : ["i jeszcze %n…","i jeszcze %n…","i jeszcze %n…","i jeszcze %n…"],
    "All activities" : "Wszystkie aktywności",
    "By others" : "Przez innych",
    "By you" : "Przez Ciebie",
    "Activity at %s" : "Aktywność w %s",
    "Hello %s" : "Witaj %s",
    "Hello %s," : "Witaj %s,",
    "There was some activity at %s" : "Zaistniała aktywność przy %s",
    "_and %n more _::_and %n more _" : ["i %n więcej","i %n więcej","i %n więcej","i %n więcej"],
    "Mail" : "E-mail",
    "Push" : "Push",
    "Activity" : "Aktywność",
    "Notifications" : "Powiadomienia",
    "This application enables people to view a log of activities about them, their files or other data." : "Aplikacja umożliwia ludziom przeglądanie aktywności działań na ich temat, plików lub innych danych.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Aplikacja ta pozwala ludziom zobaczyć aktywności związane z ich plikami i danymi w Nextcloud.\n\t\tKażda osoba może skonfigurować swoje indywidualne ustawienia aktywności w ustawieniach \t\tosobistych, aby wybrać, która aktywność ma być przekazywana na telefon komórkowy, wysyłana pocztą elektroniczną\n\t\tlub wysyłana każdego ranka jako codzienne podsumowanie.\n\t\tWięcej informacji można znaleźć w dokumentacji Aktywność.",
    "Send email" : "Wyślij e-mail",
    "Send push notification" : "Wyślij powiadomienie Push",
    "Activity notification configuration" : "Konfiguracja powiadomień o aktywności",
    "Today" : "Dzisiaj",
    "Yesterday" : "Wczoraj",
    "You need to set up your email address before you can receive notification emails." : "Aby otrzymywać wiadomości e-mail z powiadomieniem, musisz skonfigurować swój adres e-mail.",
    "Send activity emails" : "Wysyłaj e-maile o aktywności",
    "As soon as possible" : "Tak szybko, jak to możliwe",
    "Hourly" : "Co godzinę",
    "Daily" : "Codziennie",
    "Weekly" : "Co tydzień",
    "You commented" : "Skomentowałeś",
    "Message deleted by author" : "Wiadomość usunięta przez autora",
    "Open {filename}" : "Otwórz {filename}",
    "in {path}" : "w {path}",
    "Home" : "Strona główna",
    "Could not load activities" : "Nie można wczytać aktywności",
    "Loading activities" : "Wczytywanie aktywności",
    "This stream will show events like additions, changes & shares" : "W tym strumieniu będą wyświetlane wydarzenia, takie jak dodatki, zmiany i udostępnienia",
    "No activity yet" : "Brak aktywności",
    "Loading more activities" : "Wczytywanie dodatkowych aktywności",
    "No more activities." : "Brak innych aktywności",
    "Could not enable RSS link" : "Nie można aktywować odnośnika RSS",
    "RSS link copied to clipboard" : "Link RSS został skopiowany do schowka",
    "Could not copy the RSS link, please copy manually:" : "Nie można skopiować linku RSS, skopiuj go ręcznie:",
    "Activity settings" : "Ustawienia aktywności",
    "Enable RSS feed" : "Włącz kanał RSS",
    "RSS feed" : "Kanał RSS",
    "Copy RSS feed link" : "Kopiuj odnośnik do kanału RSS",
    "Personal notification settings" : "Osobiste ustawienia powiadomień",
    "Unable to load the activity list" : "Nie można załadować listy aktywności",
    "Choose for which activities you want to get an email or push notification." : "Wybierz, dla jakich aktywności chcesz otrzymywać powiadomienie e-mailem lub Push.",
    "Choose for which activities you want to get a push notification." : "Wybierz, dla jakich aktywności chcesz otrzymywać powiadomienie Push.",
    "Notification" : "Powiadomienie",
    "Enable notification emails" : "Włącz powiadomienie e-mailem",
    "Daily activity summary" : "Podsumowanie dziennej aktywności",
    "Send daily activity summary in the morning" : "Wysyłaj podsumowanie codziennej aktywności rano",
    "Default settings" : "Ustawienia domyślne",
    "Configure the default notification settings for new accounts." : "Skonfiguruj domyślne ustawienia powiadomień dla nowych kont.",
    "Unable to save the settings" : "Nie można zapisać ustawień",
    "No more events to load" : "Brak wydarzeń do załadowania"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
