OC.L10N.register(
    "app_api",
    {
    "Delete" : "Forigi",
    "Edit" : "Modifi",
    "Name" : "Nomo",
    "Host" : "Gastigo",
    "Display name" : "Vidiga nomo",
    "Network" : "Reto",
    "Confirm" : "Konfirmi",
    "Save" : "Konservi",
    "Register" : "Registriĝi",
    "Update to {version}" : "Ĝisdatigi al {version}",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Tiu aplikaĵo ne postulas minimuman Nextcloud-version. Tio estos eraro en la estonteco.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Tiu aplikaĵo ne postulas maksimuman Nextcloud-version. Tio estos eraro en la estonteco.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Tiu aplikaĵo ne instaliĝas, ĉar la jenaj dependecoj ne plenumiĝas:",
    "View in store" : "Vidi en la aplikaĵejo",
    "Visit website" : "Viziti retejon",
    "Report a bug" : "Raporti problemon",
    "User documentation" : "Dokumentaro por uzanto",
    "Admin documentation" : "Dokumentaro por administranto",
    "Developer documentation" : "Dokumentaro por programisto",
    "{license}-licensed" : "Permesilo: {license}",
    "This app is supported via your current Nextcloud subscription." : "Tiu aplikaĵo estas subtenita per via nuna Nextcloud-abono.",
    "Supported" : "Subtenite",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Elstaraj aplikaĵoj estas programataj de kaj ene de la komunumo. Ili alportas kernajn trajtojn kaj ili povas tuj uziĝi.",
    "Featured" : "Elstaraj",
    "Update to {update}" : "Ĝisdatigi al {update}",
    "Icon" : "Piktogramo",
    "Version" : "Versio",
    "Level" : "Nivelo",
    "Actions" : "Agoj",
    "Results from other categories" : "Rezultoj el aliaj kategorioj",
    "Type" : "Tipo",
    "Your apps" : "Viaj aplikaĵoj",
    "Documentation" : "Dokumentaro",
    "Details" : "Detaloj",
    "Changelog" : "Ŝanĝoprotokolo",
    "Active apps" : "Aktivaj aplikaĵoj",
    "Disabled apps" : "Malŝaltitaj aplikaĵoj",
    "Updates" : "Ĝisdatigoj",
    "Enable" : "Ŝalti",
    "Disable" : "Malŝalti",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Tiu aplikaĵo ne kongruas kun via Nextcloud-versio. Se vi daŭrigas, vi tamen povos instali ĝin, sed eble tiu aplikaĵo ne funkcios bone."
},
"nplurals=2; plural=(n != 1);");
