OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Filpåminnelser",
    "Reminder for {name}" : "Påminnelse för {name}",
    "View file" : "Visa fil",
    "View folder" : "Visa mapp",
    "Files reminder" : "Filpåminnelse",
    "The \"files_reminders\" app can work properly." : "\"files_reminders\" appen kan fungera korrekt.",
    "The \"files_reminders\" app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "Appen \"files_reminders\" behöver notification appen för att fungera korrekt. Du bör antingen aktivera aviseringar eller inaktivera files_reminder.",
    "Set file reminders" : "Ställ in filpåminnelser",
    "**📣 File reminders**\n\nSet file reminders.\n\nNote: to use the `File reminders` app, ensure that the `Notifications` app is installed and enabled. The `Notifications` app provides the necessary APIs for the `File reminders` app to work correctly." : "**📣 Filpåminnelser**\n\nStäll in påminnelser för filer.\n\nObs: För att använda appen `Filpåminnelser` måste du se till att appen `Aviseringar` är installerad och aktiverad. Appen `Aviseringar` tillhandahåller de nödvändiga API:erna för att appen `File reminders` ska fungera korrekt.",
    "Set reminder for \"{fileName}\"" : "Ställ in påminnelse för \"{fileName}\"",
    "Clear reminder" : "Rensa påminnelse",
    "Please choose a valid date & time" : "Välj ett giltigt datum och tid",
    "Reminder set for \"{fileName}\"" : "Påminnelse inställd för \"{fileName}\"",
    "Failed to set reminder" : "Kunde inte ställa in påminnelsen",
    "Reminder cleared for \"{fileName}\"" : "Påminnelse borttagen för \"{fileName}\"",
    "Failed to clear reminder" : "Kunde inte rensa påminnelsen",
    "We will remind you of this file" : "Vi kommer att påminna dig om denna fil",
    "Cancel" : "Avbryt",
    "Set reminder" : "Ställ in påminnelse",
    "Reminder set" : "Påminnelse inställd",
    "Later today" : "Senare idag",
    "Set reminder for later today" : "Ställ in påminnelse för senare idag",
    "Tomorrow" : "I morgon",
    "Set reminder for tomorrow" : "Ställ in påminnelse för imorgon",
    "This weekend" : "Denna helgen",
    "Set reminder for this weekend" : "Ställ in påminnelse för denna helg",
    "Next week" : "Nästa vecka",
    "Set reminder for next week" : "Ställ in påminnelse för nästa vecka",
    "This files_reminder can work properly." : "Den här filpåminnelsen kan fungera korrekt.",
    "The files_reminder app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "Appen files_reminder behöver notification appen för att fungera korrekt. Du bör antingen aktivera aviseringar eller inaktivera files_reminder.",
    "Set reminder at custom date & time" : "Ställ in påminnelse vid anpassat datum och tid",
    "Set custom reminder" : "Ställ in anpassad påminnelse"
},
"nplurals=2; plural=(n != 1);");
