OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Privacidade",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "No centro de privacidade pode verificar onde se encontram os seus dados. Pode ainda verificar quem tem acesso a eles, quer porque as partilhou com eles  quer porque são administradores. ",
    "Administrators" : "Administradores",
    "Add external admin" : "Adicionar administrador externo",
    "Cancel" : "Cancelar",
    "Add" : "Adicionar",
    "Name of external admin" : "Nome do administrador externo",
    "Your files are not protected by encryption." : "Os seus ficheiros não estão protegidos com encriptação. ",
    "Encryption" : "Cifragem",
    "Edit" : "Editar",
    "Privacy policy" : "Politica de privacidade",
    "Who has access to your data?" : "Quem tem acesso aos seus dados?",
    "Where is your data?" : "Onde estão os seus dados?",
    "Your data is located in:" : "Os seus dados estão localizados em:",
    "Change data location" : "Alterar a localização dos dados",
    "Region" : "Região",
    "Please select a region" : "Selecione uma região",
    "Control" : "Controle",
    "Knowledge" : "Conhecimento",
    "of how the data is stored" : "como os dados estão armazenados",
    "Freedom" : "Liberdade",
    "to choose a platform" : "para escolher a plataforma",
    "Learn more ↗" : "Aprenda mais ↗",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Emirados Árabes Unidos",
    "Afghanistan" : "Afeganistão",
    "Albania" : "Albânia",
    "Armenia" : "Arménia",
    "Angola" : "Angola",
    "Antarctica" : "Antárctica",
    "Argentina" : "Argentina",
    "American Samoa" : "Samoa Americana",
    "Austria" : "Áustria",
    "Australia" : "Austrália",
    "Aruba" : "Aruba",
    "Azerbaijan" : "Azerbaijão",
    "Bosnia and Herzegovina" : "Bosnia Herzegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Bélgica",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgária",
    "Burundi" : "Burundi",
    "Benin" : "Benim",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolívia",
    "Brazil" : "Brasil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Butão",
    "Botswana" : "Botswana",
    "Belarus" : "Bielorrússia",
    "Belize" : "Belize",
    "Canada" : "Canada",
    "Democratic Republic of the Congo" : "República Democrática do Congo",
    "Central African Republic" : "República Central Africana",
    "Congo" : "Congo",
    "Switzerland" : "Suiça",
    "Cote d'Ivoire" : "Costa do Marfim",
    "Cook Islands" : "Ilhas Cook",
    "Chile" : "Chile",
    "Cameroon" : "Camarões",
    "China" : "China",
    "Colombia" : "Colômbia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cabo Verde" : "Cabo Verde",
    "Cyprus" : "Chipre",
    "Germany" : "Alemanha",
    "Djibouti" : "Djibouti",
    "Denmark" : "Dinamarca",
    "Dominican Republic" : "República Dominicana",
    "Algeria" : "Argélia",
    "Ecuador" : "Equador",
    "Estonia" : "Estónia",
    "Egypt" : "Egipto",
    "Eritrea" : "Eritreia",
    "Spain" : "Espanha",
    "Ethiopia" : "Etiópia",
    "Finland" : "Finlândia",
    "Fiji" : "Ilhas Fiji",
    "Falkland Islands" : "Ilhas Falkland",
    "Micronesia" : "Micronésia",
    "Faroe Islands" : "Ilhas Faroe",
    "France" : "França",
    "Gabon" : "Gabão",
    "United Kingdom" : "Reino Unido",
    "Grenada" : "Granada",
    "Georgia" : "Geórgia",
    "French Guiana" : "Guiana Francesa",
    "Guernsey" : "Guernsey",
    "Ghana" : "Gana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Islândia",
    "Gambia" : "Gambia",
    "Guinea" : "Guiné",
    "Guadeloupe" : "Guadalupe",
    "Equatorial Guinea" : "Guiné Equatorial",
    "Greece" : "Grécia",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guiné-Bissau",
    "Guyana" : "Guiana",
    "Hong Kong" : "Hong Kong",
    "Honduras" : "Honduras",
    "Croatia" : "Croácia",
    "Haiti" : "Haiti",
    "Hungary" : "Hungria",
    "Indonesia" : "Indonésia",
    "Ireland" : "Irlanda",
    "Israel" : "Israel",
    "Isle of Man" : "Ilha de Man",
    "India" : "Índia",
    "Iraq" : "Iraque",
    "Iran" : "Irão",
    "Iceland" : "Islândia",
    "Italy" : "Italia",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordânia",
    "Japan" : "Japão",
    "Kenya" : "Quénia",
    "Kyrgyzstan" : "Quirquistão",
    "Cambodia" : "Cambodja",
    "North Korea" : "Coreia do Norte",
    "South Korea" : "Coreia do Sul",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Ilhas Caimão",
    "Kazakhstan" : "Casaquistão",
    "Laos" : "Laos",
    "Lebanon" : "Líbano",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Libéria",
    "Lesotho" : "Lesoto",
    "Lithuania" : "Lituania",
    "Luxembourg" : "Luxemburgo",
    "Latvia" : "Letónia",
    "Libya" : "Libia",
    "Morocco" : "Marrocos",
    "Monaco" : "Mónaco",
    "Moldova" : "Moldávia",
    "Montenegro" : "Montenegro",
    "Madagascar" : "Madagáscar",
    "Marshall Islands" : "Ilhas Marshall",
    "Macedonia" : "Macedónia",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolia",
    "Macao" : "Macau",
    "Mauritania" : "Mauritânia",
    "Montserrat" : "Monserrate",
    "Malta" : "Malta",
    "Mauritius" : "Ilhas Maurícias",
    "Maldives" : "Ilhas Maldivas",
    "Malawi" : "Malawi",
    "Mexico" : "México",
    "Malaysia" : "Malasia",
    "Mozambique" : "Moçambique",
    "Namibia" : "Namíbia",
    "New Caledonia" : "Nova Caledónia",
    "Niger" : "Níger",
    "Nigeria" : "Nigéria",
    "Nicaragua" : "Nicarágua",
    "Netherlands" : "Holanda",
    "Norway" : "Noruega",
    "Nepal" : "Nepal",
    "New Zealand" : "Nova Zelândia",
    "Oman" : "Oman",
    "Panama" : "Panamá",
    "Peru" : "Peru",
    "French Polynesia" : "Polinésia Francesa",
    "Papua New Guinea" : "Papua Nova Guiné",
    "Philippines" : "Filipinas",
    "Pakistan" : "Paquistão",
    "Poland" : "Polónia",
    "Puerto Rico" : "Porto Rico",
    "Palestine" : "Palestina",
    "Portugal" : "Portugal",
    "Paraguay" : "Paraguai",
    "Qatar" : "Quatar ",
    "Romania" : "Roménia",
    "Serbia" : "Servia",
    "Russia" : "Rússia",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Arábia Saudita",
    "Solomon Islands" : "Ilhas Salomão",
    "Seychelles" : "Ilhas Seychelles",
    "Sudan" : "Sudão",
    "Sweden" : "Suécia",
    "Singapore" : "Singapura",
    "Slovenia" : "Eslovénia",
    "Sierra Leone" : "Serra Leoa",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somália",
    "Suriname" : "Suriname",
    "Sao Tome and Principe" : "São Tomé e Príncipe",
    "El Salvador" : "El Salvador",
    "Syria" : "Síria",
    "Swaziland" : "Suazilândia",
    "Chad" : "Chade",
    "Togo" : "Togo",
    "Thailand" : "Tailândia",
    "Tajikistan" : "Tajaquistão",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Turcomenistão",
    "Tunisia" : "Tunísia",
    "Tonga" : "Tonga",
    "Turkey" : "Turquia",
    "Trinidad and Tobago" : "Trinidad e Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan" : "Taiwan",
    "Tanzania" : "Tanzânia",
    "Ukraine" : "Ucrânia",
    "Uganda" : "Uganda",
    "United States" : "Estados Unidos da América",
    "Uruguay" : "Uruguai",
    "Uzbekistan" : "Uzbequistão",
    "Venezuela" : "Venezuela",
    "Vietnam" : "Vietname",
    "Vanuatu" : "Vanuatu",
    "Samoa" : "Samoa",
    "Yemen" : "Iemen",
    "South Africa" : "África do Sul",
    "Zambia" : "Zâmbia",
    "Zimbabwe" : "Zimbábue "
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
