OC.L10N.register(
    "sharebymail",
    {
    "Shared with {email}" : "Partagé avec {email}",
    "Shared with {email} by {actor}" : "Partagé avec {email} par {actor}",
    "Unshared from {email}" : "Partage supprimé de {email}",
    "Unshared from {email} by {actor}" : "Partage supprimé de {email} par {actor}",
    "Password for mail share sent to {email}" : "Le mot de passe pour le partage par e-mail a été envoyé à {email}",
    "Password for mail share sent to you" : "Le mot de passe pour le partage par e-mail vous a été envoyé",
    "You shared {file} with {email} by mail" : "Vous avez partagé {file} avec {email} par e-mail",
    "{actor} shared {file} with {email} by mail" : "{actor} a partagé {file} avec {email} par e-mail",
    "You unshared {file} from {email} by mail" : "Vous avez supprimé le partage de {file} depuis {email} par e-mail",
    "{actor} unshared {file} from {email} by mail" : "{actor} a supprimé le partage de {file} depuis {email} par e-mail",
    "Password to access {file} was sent to {email}" : "Le mot de passe pour accèder à {file} a été envoyé à {email}",
    "Password to access {file} was sent to you" : "Le mot de passe pour accèder à {file} vous a été envoyé",
    "Share by mail" : "Partage par e-mail",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Impossible de partager %1$s car il est déjà partagé avec le compte %2$s",
    "We cannot send you the auto-generated password. Please set a valid email address in your personal settings and try again." : "Nous ne pouvons pas vous envoyer le mot de passe généré automatiquement. Merci de définir une adresse e-mail valide dans vos paramètres personnels et essayez à nouveau.",
    "Failed to send share by email. Got an invalid email address" : "Échec lors de l'envoi du partage par e-mail. L'adresse e-mail est invalide",
    "Failed to send share by email" : "Échec lors de l'envoi du partage par e-mail",
    "%1$s shared %2$s with you" : "%1$s a partagé %2$s avec vous",
    "Note:" : "Note :",
    "This share is valid until %s at midnight" : "Ce partage est valable jusqu'à minuit le %s",
    "Expiration:" : "Expiration:",
    "Open %s" : "Ouvrir %s",
    "%1$s via %2$s" : "%1$s via %2$s",
    "%1$s shared %2$s with you. You should have already received a separate mail with a link to access it." : "%1$s a partagé %2$s avec vous. Vous devriez déjà avoir reçu un e-mail séparé avec un lien pour y accéder.",
    "Password to access %1$s shared to you by %2$s" : "Mot de passe pour accéder à %1$s partagé avec vous par %2$s",
    "Password to access %s" : "Mot de passe pour accéder à %s",
    "It is protected with the following password:" : "Il est protégé avec le mot de passe suivant :",
    "This password will expire at %s" : "Le mot de passe expirera le %s",
    "%1$s shared %2$s with you and wants to add:" : "%1$s a partagé %2$s avec vous et souhaite ajouter :",
    "%1$s shared %2$s with you and wants to add" : "%1$s a partagé %2$s avec vous et souhaite ajouter",
    "%s added a note to a file shared with you" : "%s a ajouté une note à un fichier partagé avec vous",
    "You just shared %1$s with %2$s. The share was already sent to the recipient. Due to the security policies defined by the administrator of %3$s each share needs to be protected by password and it is not allowed to send the password directly to the recipient. Therefore you need to forward the password manually to the recipient." : "Vous venez de partager %1$s avec %2$s. Le partage a déjà été envoyé au destinataire. En raison des politiques de sécurité définies par l'administrateur de %3$s, chaque partage doit être protégé par un mot de passe et il n'est pas autorisé d'envoyer le mot de passe directement au destinataire. Vous devez donc transmettre le mot de passe manuellement au destinataire.",
    "Password to access %1$s shared by you with %2$s" : "Mot de passe pour accéder à %1$s partagé par vous avec %2$s",
    "This is the password:" : "Voici le mot de passe :",
    "You can choose a different password at any time in the share dialog." : "Vous pouvez choisir un mot de passe différent à n'importe quel moment dans la boîte de dialogue de partage.",
    "Could not find share" : "Impossible de trouver le partage",
    "Share provider which allows you to share files by mail" : "Fournisseur de partage qui vous permet de partager des fichiers par courrier électronique.",
    "Unable to update share by mail config" : "Impossible de mettre à jour la configuration du partage par e-mail",
    "Allows people to share a personalized link to a file or folder by putting in an email address." : "Autoriser les personnes à partager un lien personnalisé vers un fichier ou un dossier en renseignant une adresse e-mail.",
    "Send password by mail" : "Envoyer le mot de passe par e-mail",
    "Reply to initiator" : "Répondre à l'initiateur"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
