OC.L10N.register(
    "files_sharing",
    {
    "File shares" : "ファイル共有",
    "Downloaded via public link" : "公開リンクからダウンロードしました",
    "Downloaded by {email}" : "{email} がダウンロードしました",
    "{file} downloaded via public link" : "{file} が公開リンクからダウンロードされました",
    "{email} downloaded {file}" : "{email}が{file}をダウンロードしました",
    "Shared with group {group}" : "{group} グループと共有しました",
    "Removed share for group {group}" : "{group} グループの共有を解除しました",
    "{actor} shared with group {group}" : "{actor} が {group} グループに共有しました",
    "{actor} removed share for group {group}" : "{actor} が {group} グループへの共有を解除しました",
    "Share for group {group} expired" : "グループ{group}への共有が解除されました",
    "You shared {file} with group {group}" : "{file} を {group} グループに共有しました",
    "You removed group {group} from {file}" : "{file} を {group} グループから削除しました",
    "{actor} shared {file} with group {group}" : "{actor} が {file} を {group} グループに共有しました",
    "{actor} removed group {group} from {file}" : "{actor} が {group} グループから {file}  を削除しました",
    "Share for file {file} with group {group} expired" : "グループ{group}へのファイル:{file}の共有が解除されました",
    "Shared as public link" : "公開リンクとして共有",
    "Removed public link" : "公開リンクを削除",
    "Public link expired" : "公開リンクの有効期限が切れました",
    "{actor} shared as public link" : "{actor} が公開リンクとして共有しました",
    "{actor} removed public link" : "{actor} は公開リンクを削除しました",
    "Public link of {actor} expired" : "{actor} の公開リンクの期限が切れています",
    "You shared {file} as public link" : "{file} を公開リンクとして共有しました",
    "You removed public link for {file}" : "{file} の公開リンクを削除しました",
    "Public link expired for {file}" : "{file} の公開リンクの期限が切れています",
    "{actor} shared {file} as public link" : "{actor} が{file} を公開リンクとして共有しました",
    "{actor} removed public link for {file}" : "{actor} は{file} の公開リンクを削除しました",
    "Public link of {actor} for {file} expired" : "{actor} の {file} の公開リンクは期限が切れています",
    "{user} accepted the remote share" : "{user} は リモート共有を承認しました。",
    "{user} declined the remote share" : "{user} は リモート共有を拒否しました",
    "You received a new remote share {file} from {user}" : "{user} から {file} の新しいリモート共有が届いています",
    "{user} accepted the remote share of {file}" : "{user} は {file}  のリモート共有を承認しました",
    "{user} declined the remote share of {file}" : "{user} は {file}  のリモート共有を拒否しました",
    "{user} unshared {file} from you" : "{user} はあなたと {file} の共有を止めました。",
    "Shared with {user}" : "{user} と共有",
    "Removed share for {user}" : "{user} との共有を削除しました",
    "You removed yourself" : "自分自身を削除しました",
    "{actor} removed themselves" : "{actor} が自分自身を削除しました",
    "{actor} shared with {user}" : "{actor} が {user} と共有しました",
    "{actor} removed share for {user}" : "{actor} が {user} との共有を削除しました",
    "Shared by {actor}" : "{actor} から共有されました",
    "{actor} removed share" : "{actor} が共有を削除しました",
    "Share for {user} expired" : "ユーザー{user}への共有が解除されました",
    "Share expired" : "共有が解除されました",
    "You shared {file} with {user}" : "{user} と {file} を共有しました",
    "You removed {user} from {file}" : "{file} の {user} との共有を削除しました",
    "You removed yourself from {file}" : "{file}  から自分自身を削除しました",
    "{actor} removed themselves from {file}" : "{actor} が {file} から自分自身を削除しました",
    "{actor} shared {file} with {user}" : "{actor} が {file} を {user} に共有しました",
    "{actor} removed {user} from {file}" : "{actor} が {file} の {user} との共有を削除しました",
    "{actor} shared {file} with you" : "{actor} が {file} を共有しました",
    "{actor} removed you from the share named {file}" : "{actor}さんが{file}という名前の共有を削除しました",
    "Share for file {file} with {user} expired" : "ユーザー{user}へのファイル:{file}の共有が解除されました",
    "Share for file {file} expired" : "ファイル:{file}の共有が解除されました",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "メールまたは公開リンクにより共有されたファイルまたはフォルダーが<strong>ダウンロード</strong>されたとき",
    "Files have been <strong>uploaded</strong> to a folder shared by mail or by public link" : "メールまたはパブリックリンクで共有されているフォルダにファイルが<strong>アップロード</strong>されたとき",
    "A file or folder was shared from <strong>another server</strong>" : "ファイルまたはフォルダーが<strong>他のサーバー</strong>から共有されたとき",
    "Sharing" : "共有",
    "A file or folder has been <strong>shared</strong>" : "ファイルまたはフォルダーが<strong>共有</strong>されたとき",
    "Shared link" : "共有リンク",
    "Wrong share ID, share does not exist" : "共有IDが間違っています。共有がありません",
    "Could not delete share" : "共有を削除できませんでした",
    "Please specify a file or folder path" : "ファイルかフォルダーのパスを指定してください",
    "Wrong path, file/folder does not exist" : "パスが間違っています。ファイル/フォルダーがありません",
    "Could not create share" : "共有を作成できませんでした",
    "Please specify a valid account to share with" : "共有する有効なアカウントを指定してください",
    "Group sharing is disabled by the administrator" : "グループ共有が管理者によって無効にされています。",
    "Please specify a valid group" : "正しいグループを指定してください",
    "Public link sharing is disabled by the administrator" : "URL共有が管理者によって無効されています。",
    "Please specify a valid email address" : "有効なメールアドレスを入力してください",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Nextcloud Talkが有効になっていないため、Nextcloud Talkでパスワードを送信した %s を共有できませんでした",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "%1$s の共有に失敗しました。バックエンド側で %2$s タイプの共有が許可されていません。",
    "Please specify a valid federated account ID" : "有効なフェデレーションアカウントIDを指定してください",
    "Please specify a valid federated group ID" : "正しい連携グループIDを指定してください",
    "You cannot share to a Team if the app is not enabled" : "アプリが有効でない場合、チームに共有することはできません",
    "Please specify a valid team" : "有効なチームを指定してください",
    "Sharing %s failed because the back end does not support room shares" : "バックエンドがルーム共有をサポートしていないため、%s を共有できませんでした",
    "Sharing %s failed because the back end does not support ScienceMesh shares" : "バックエンドが ScienceMesh 共有をサポートしていないため %s の共有に失敗しました。",
    "Unknown share type" : "不明な共有タイプ",
    "Not a directory" : "ディレクトリではありません",
    "Could not lock node" : "ノードをロックできませんでした",
    "Public upload is only possible for publicly shared folders" : "公開共有されているフォルダーにしか公開アップロードはできません。",
    "Share must at least have READ or CREATE permissions" : "共有には少なくとも 読み込み または 作成の権限が必要です",
    "Share must have READ permission if UPDATE or DELETE permission is set" : "更新 または 削除権限が設定されている場合、共有者は 読み込み権限を持っている必要があります。",
    "Public upload disabled by the administrator" : "URL共有へのアップロードが管理者によって無効されています。",
    "Could not lock path" : "パスをロックできませんでした",
    "no sharing rights on this item" : "この項目には共有権限はありません",
    "You are not allowed to edit incoming shares" : "受信した共有を編集は許可されていません",
    "Wrong or no update parameter given" : "間違っているか、またはパラメータが更新されていません",
    "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled." : "Nextcloud Talkが有効になっていないため、ファイルまたはフォルダーを共有するための「NextcloudTalkによるパスワードの送信」ができませんでした。",
    "Custom share link tokens have been disabled by the administrator" : "カスタム共有リンクのトークンが管理者によって無効化されました。",
    "Tokens must contain at least 1 character and may only contain letters, numbers, or a hyphen" : "トークンは少なくとも1文字を含む必要があり、文字、数字、またはハイフンのみを含むことができます",
    "Invalid date. Format must be YYYY-MM-DD" : "日付が無効です。日付形式はYYYY-MM-DDである必要があります",
    "No sharing rights on this item" : "この項目には共有権限はありません",
    "Invalid share attributes provided: \"%s\"" : "無効な共有属性が指定されました \"%s\"",
    "You are not allowed to send mail notifications" : "メール通知を送信することは許可されていません",
    "No mail notification configured for this share type" : "この共有タイプにはメール通知が設定されていません",
    "Wrong password" : "パスワードが間違っています",
    "Error while sending mail notification" : "メール通知送信中にエラーが発生",
    "Failed to generate a unique token" : "一意なトークンの生成に失敗しました",
    "This share does not exist or is no longer available" : "このシェアは存在していないか、または利用できなくなりました",
    "shared by %s" : "%s が共有",
    "Download" : "ダウンロード",
    "Add to your %s" : "%sに追加",
    "Direct link" : "リンク",
    "Share API is disabled" : "共有APIが無効です。",
    "File sharing" : "ファイル共有",
    "Share will expire tomorrow" : "共有は明日期限切れになります",
    "Your share of {node} will expire tomorrow" : "{node}のシェアは明日期限切れになります",
    "You received {share} as a share by {user}" : "{user}からの共有として{share}を受け取りました",
    "You received {share} to group {group} as a share by {user}" : "{user}からのグループ{group}への共有として{share}を受け取りました",
    "Accept" : "承諾",
    "Decline" : "拒否",
    "Remember to upload the files to %s" : "%sにファイルをアップロードすることを忘れないでください。",
    "We would like to kindly remind you that you have not yet uploaded any files to the shared folder." : "まだ共有フォルダにファイルをアップロードしていないことをお知らせします。",
    "Open \"%s\"" : "\"%s\" を開く",
    "This application enables people to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable people can then share files and folders with other accounts and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other people outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation." : "このアプリケーションを使うと、Nextcloud 内でファイルを共有することができます。 有効にすると、管理者はファイルを共有できるグループを選択できます。 該当する人々は、Nextcloud 内の他のアカウントやグループとファイルやフォルダを共有できます。 さらに、管理者が共有リンク機能を有効にすると、外部リンクを使用してNextcloud 外の他の人々とファイルを共有することができます。 管理者は、パスワード、有効期限の日付を設定し、共有リンクを介したサーバ間の共有やモバイルデバイスからの共有を可能にすることもできます。\nこの機能をオフにすると、サーバ上のすべての共有受信者の共有ファイルとフォルダが削除され、 同期クライアントやモバイルアプリ上でも削除されます。詳細は Nextcloud ドキュメントをご覧ください。",
    "People" : "人",
    "Filter accounts" : "アカウントのフィルタリング",
    "The request will expire on {date} at midnight and will be password protected." : "リクエストの有効期限は{date}の午前0時で、パスワードで保護されています。",
    "The request will expire on {date} at midnight." : "リクエストの有効期限は{date}の午前0時です。",
    "The request will be password protected." : "リクエストはパスワードで保護されます。",
    "When should the request expire?" : "リクエストの有効期限はいつまでですか？",
    "Set a submission expiration date" : "送信の有効期限を設定する",
    "Expiration date" : "有効期限",
    "Select a date" : "日付を選択",
    "Your administrator has enforced a {count} days expiration policy." : "管理者が有効期限を{count}日に設定しています。",
    "What password should be used for the request?" : "リクエストにはどのようなパスワードを使用しますか？",
    "Set a password" : "パスワードを設定",
    "Password" : "パスワード",
    "Enter a valid password" : "有効なパスワードを入力",
    "Generate a new password" : "新しいパスワードを生成",
    "Your administrator has enforced a password protection." : "管理者はパスワードによる保護を行っています。",
    "Automatically copying failed, please copy the share link manually" : "自動コピーに失敗しました。手動で共有リンクをコピーしてください",
    "Link copied" : "リンクをコピーしました",
    "Email already added" : "メールはすでに追加されています",
    "Invalid email address" : "無効なメールアドレス",
    "_The following email address is not valid: {emails}_::_The following email addresses are not valid: {emails}_" : ["以下のメールアドレスは無効です： {emails}"],
    "_{count} email address already added_::_{count} email addresses already added_" : ["{count} メールアドレスはすでに追加されています"],
    "_{count} email address added_::_{count} email addresses added_" : ["{count} メールアドレスが追加されました"],
    "You can now share the link below to allow people to upload files to your directory." : "以下のリンクを共有することであなたのディレクトリにファイルをアップロードできるようになります。",
    "Share link" : "URLで共有",
    "Copy" : "コピー",
    "Send link via email" : "メールでリンクを送信",
    "Enter an email address or paste a list" : "メールアドレスを入力するか、リストを貼り付ける",
    "Remove email" : "メールを削除",
    "Select a destination" : "宛先を選択",
    "Select" : "選択",
    "What are you requesting?" : "何をリクエストしているのですか？",
    "Request subject" : "件名をリクエスト",
    "Birthday party photos, History assignment…" : "誕生日パーティーの写真、歴史の課題...",
    "Where should these files go?" : "これらのファイルはどこに保存すればいいでしょうか？",
    "Upload destination" : "アップロード先",
    "Revert to default" : "初期値に戻す",
    "The uploaded files are visible only to you unless you choose to share them." : "アップロードしたファイルは、あなたが共有することを選択しない限り、あなただけが見ることができます。",
    "Add a note" : "メモを追加する",
    "Note for recipient" : "受取人への注意",
    "Add a note to help people understand what you are requesting." : "あなたが何を要求しているのかを理解してもらうために、メモを追加してください。",
    "You can add links, date or any other information that will help the recipient understand what you are requesting." : "リンクや日付、その他の情報など受信者があなたの要求内容を理解するのに役立つ情報を追加することができます。",
    "Close" : "閉じる",
    "_Send email and close_::_Send {count} emails and close_" : ["{count}通のメールを送信して閉じる"],
    "Please select a folder, you cannot share the root directory." : "フォルダーを選択してください。ルートディレクトリを共有することはできません。",
    "File request created" : "ファイルリクエストが作成しました",
    "_File request created and email sent_::_File request created and {count} emails sent_" : ["ファイルリクエストの作成し{count}通のメールを送信しました"],
    "Error creating the share: {errorMessage}" : "共有の作成中にエラーが発生しました: {errorMessage}",
    "Error creating the share" : "共有の作成中にエラーが発生しました",
    "Error sending emails: {errorMessage}" : "メール送信エラー: {errorMessage}",
    "Error sending emails" : "メール送信エラー",
    "Create a file request" : "ファイルリクエストを作成",
    "Collect files from others even if they do not have an account." : "アカウントを持っていなくても、他の人からファイルを収集することができます。",
    "To ensure you can receive files, verify you have enough storage available." : "ファイルを確実に受信するには、十分なストレージがあることを確認してください。",
    "File request" : "ファイルリクエスト",
    "Previous step" : "前のステップ",
    "Cancel" : "キャンセル",
    "Cancel the file request creation" : "ファイルリクエスト作成をキャンセルする",
    "Close without sending emails" : "メールを送信せずに閉じる",
    "Continue" : "続ける",
    "Error while toggling options" : "オプションの切り替え中にエラーが発生しました",
    "Accept shares from other accounts and groups by default" : "他のアカウントやグループからの共有をデフォルトで受け入れる",
    "Choose a default folder for accepted shares" : "共有を受け入れるためのデフォルトフォルダーを選択",
    "Invalid path selected" : "無効なパスが選択されました",
    "Unknown error" : "不明なエラー",
    "Set default folder for accepted shares" : "共有を受け入れるためのデフォルトフォルダーを指定",
    "Reset" : "リセット",
    "Reset folder to system default" : "フォルダをシステムのデフォルトに戻す",
    "Share expiration: {date}" : "共有期限: {date}",
    "Share Expiration" : "共有期限",
    "group" : "グループ",
    "conversation" : "会話",
    "remote" : "リモート",
    "remote group" : "リモートグループ",
    "guest" : "ゲスト",
    "by {initiator}" : "{initiator}記載",
    "Shared with the group {user} by {owner}" : "{owner}によってグループ{user}と共有されました",
    "Shared with the conversation {user} by {owner}" : "{owner}が{user}との会話を共有しました",
    "Shared with {user} by {owner}" : "{owner}が{user}と共有",
    "Open Sharing Details" : "共有の詳細を開く",
    "Added by {initiator}" : "{initiator}によって追加されました",
    "Via “{folder}”" : "“{folder}” 経由",
    "Unshare" : "共有を解除",
    "Cannot copy, please copy the link manually" : "コピーできませんでした。手動でリンクをコピーしてください。",
    "Copy internal link" : "内部リンクをコピー",
    "Internal link" : "内部リンク",
    "{shareWith} by {initiator}" : "{initiator} により {shareWith}",
    "Shared via link by {initiator}" : "{initiator}がリンクで共有",
    "File request ({label})" : "ファイルリクエスト ({label})",
    "Mail share ({label})" : "メール共有 ({label})",
    "Share link ({label})" : "リンク共有 ({label})",
    "Mail share" : "メール共有",
    "Share link ({index})" : "リンク共有 ({index})",
    "Create public link" : "公開リンクを作成",
    "Actions for \"{title}\"" : "\"{title}\"のアクション",
    "Error, please enter proper password and/or expiration date" : "エラー、正しいパスワードおよび/または有効期限を入力してください",
    "Link share created" : "リンク共有が作成されました",
    "Error while creating the share" : "共有作成時にエラーが発生しました",
    "Please enter the following required information before creating the share" : "共有を作成する前に、次の必要な情報を入力してください",
    "Password protection (enforced)" : "パスワード保護（強制）",
    "Password protection" : "パスワード保護",
    "Enter a password" : "パスワードを入力",
    "Enable link expiration (enforced)" : "リンクの期限切れを有効にする（強制）",
    "Enable link expiration" : "リンクの期限切れを有効にする",
    "Enter expiration date (enforced)" : "有効期限を入力してください（強制）",
    "Enter expiration date" : "有効期限を入力してください",
    "Create share" : "共有を作成",
    "Customize link" : "共有のカスタマイズ",
    "Generate QR code" : "QRコードを生成",
    "Add another link" : "別のリンクを追加",
    "Create a new share link" : "新しい共有リンクを作成する",
    "Quick share options, the current selected is \"{selectedOption}\"" : "クイック共有オプション、現在の選択されているのは \"{selectedOption}\" です",
    "View only" : "閲覧のみ",
    "Can edit" : "編集可能",
    "Custom permissions" : "カスタム権限",
    "Resharing is not allowed" : "再共有は許可されていません",
    "Name or email …" : "名前またはメールアドレス…",
    "Name, email, or Federated Cloud ID …" : "名前、メールアドレス、またはクラウド連携ID…",
    "Searching …" : "検索しています…",
    "No elements found." : "要素が見つかりませんでした。",
    "Search everywhere" : "あらゆる場所を検索",
    "Guest" : "ゲスト",
    "Group" : "グループ",
    "Email" : "メール",
    "Team" : "チーム",
    "Talk conversation" : "会話",
    "Deck board" : "Deckボード",
    "ScienceMesh" : "ScienceMesh",
    "on {server}" : "{server} に",
    "Enter external recipients" : "外部の受信者を入力してください",
    "Search for internal recipients" : "内部受信者を検索",
    "Note from" : "注釈",
    "Note:" : "注意：",
    "File drop" : "ファイルを転送",
    "Upload files to {foldername}." : "{foldername}にファイルをアップロード",
    "By uploading files, you agree to the terms of service." : "ファイルをアップロードすることで、利用規約に同意したことになります。",
    "Successfully uploaded files" : "ファイルのアップロードに成功しました",
    "View terms of service" : "利用規約を見る",
    "Terms of service" : "サービス利用規約",
    "Share with email {email}" : "{email} とメールで共有",
    "Share with group" : "グループと共有する",
    "Share in conversation" : "会話で共有する",
    "Share with {user} on remote server {server}" : "リモートサーバー{server}上の{user}と共有する",
    "Share with remote group" : "リモートグループと共有する",
    "Share with guest" : "ゲストと共有する",
    "Update share" : "共有設定の更新",
    "Save share" : "共有を保存",
    "Read" : "読み込み",
    "Create" : "作成",
    "Edit" : "編集",
    "Share" : "共有",
    "Delete" : "削除",
    "Password field cannot be empty" : "パスワードフィールドは空にできません",
    "Replace current password" : "現在のパスワードを置き換える",
    "Failed to generate a new token" : "新しいトークンの生成に失敗しました",
    "Allow upload and editing" : "アップロードと編集を許可",
    "Allow editing" : "編集を許可",
    "Upload only" : "アップロードのみ",
    "Advanced settings" : "詳細設定",
    "Share label" : "共有ラベル",
    "Share link token" : "共有リンクのトークン",
    "Set the public share link token to something easy to remember or generate a new token. It is not recommended to use a guessable token for shares which contain sensitive information." : "公開共有リンクのトークンを覚えやすいものに設定するか、新しいトークンを生成してください。機密情報を含む共有には、推測可能なトークンを使用することはおすすめしません。",
    "Generating…" : "生成中…",
    "Generate new token" : "新しいトークンの生成",
    "Set password" : "パスワード設定",
    "Password expires {passwordExpirationTime}" : "パスワードの有効期限は、{passwordExpirationTime}",
    "Password expired" : "パスワード期限切れ",
    "Video verification" : "ビデオ通話によるパスワード通知",
    "Expiration date (enforced)" : "有効期限（強制）",
    "Set expiration date" : "有効期限を設定",
    "Hide download" : "ダウンロードを隠す",
    "Allow download and sync" : "ダウンロードと同期を許可",
    "Note to recipient" : "受取人への注意",
    "Enter a note for the share recipient" : "共有受信者へのメモを入力してください",
    "Show files in grid view" : "グリッドビューにファイルを表示",
    "Delete share" : "共有を解除",
    "Others with access" : "アクセス権を持つ他のユーザー",
    "No other accounts with access found" : "アクセス可能な他のアカウントは見つかりませんでした",
    "Toggle list of others with access to this directory" : "このフォルダーへのアクセス権を持つ他のユーザーリストを切り替えます",
    "Toggle list of others with access to this file" : "このファイルへのアクセス権を持つ他のユーザーのリストを切り替えます",
    "Unable to fetch inherited shares" : "継承された共有を取得できません",
    "Link shares" : "リンク共有",
    "Shares" : "共有",
    "Unable to load the shares list" : "共有リストを読み込めません",
    "Expires {relativetime}" : "有効期限 {relativetime}",
    "this share just expired." : "この共有は期限切れになりました。",
    "Shared with you by {owner}" : "{owner} と共有中",
    "Internal shares" : "内部共有",
    "Internal shares explanation" : "内部共有の説明",
    "External shares" : "外部共有",
    "External shares explanation" : "外部共有の説明",
    "Additional shares" : "追加の共有",
    "Additional shares explanation" : "追加の共有の説明",
    "Link to a file" : "ファイルへリンク",
    "_Accept share_::_Accept shares_" : ["共有を受け入れる"],
    "Open in Files" : "ファイルアプリで開く",
    "_Reject share_::_Reject shares_" : ["共有の受け入れを拒否する"],
    "_Restore share_::_Restore shares_" : ["共有を復元する"],
    "Shared" : "共有中",
    "Shared by {ownerDisplayName}" : "{ownerDisplayName} が共有済み",
    "Shared multiple times with different people" : "異なる人と複数回共有",
    "Shared with others" : "他ユーザーと共有中",
    "Create file request" : "ファイルリクエストを作成",
    "Upload files to {foldername}" : "{foldername}にファイルをアップロード",
    "Public file share" : "公開ファイル共有",
    "Publicly shared file." : "公開共有ファイル。",
    "No file" : "ファイルがありません",
    "The file shared with you will show up here" : "あなたと共有されたファイルはここに表示されます",
    "Public share" : "公開共有",
    "Publicly shared files." : "公開共有ファイル。",
    "No files" : "ファイルがありません",
    "Files and folders shared with you will show up here" : "あなたと共有されたファイルやフォルダーはここに表示されます",
    "Overview of shared files." : "共有済みファイルの概要",
    "No shares" : "共有なし",
    "Files and folders you shared or have been shared with you will show up here" : "共有済みまたは、共有されたファイルやフォルダはここに表示されます",
    "Shared with you" : "他ユーザーがあなたと共有中",
    "List of files that are shared with you." : "あなたと共有しているファイルの一覧。",
    "Nothing shared with you yet" : "あなたと共有しているファイルはありません。",
    "Files and folders others shared with you will show up here" : "他の人から共有されたファイルやフォルダは、ここに表示されます。",
    "List of files that you shared with others." : "他ユーザと共有したファイルの一覧。",
    "Nothing shared yet" : "まだ何も共有されていません",
    "Files and folders you shared will show up here" : "共有したファイルやフォルダは、ここに表示されます。",
    "Shared by link" : "URLリンクで共有中",
    "List of files that are shared by link." : "URL共有済みファイルの一覧。",
    "No shared links" : "共有リンクはありません",
    "Files and folders you shared by link will show up here" : "リンクで共有したファイルやフォルダは、ここに表示されます。",
    "File requests" : "ファイルリクエスト",
    "List of file requests." : "ファイル要求のリスト。",
    "No file requests" : "ファイル要求がありません",
    "File requests you have created will show up here" : "作成したファイルリクエストはここに表示されます",
    "Deleted shares" : "削除した共有",
    "List of shares you left." : "離脱した共有の一覧",
    "No deleted shares" : "削除（離脱）した共有はありません",
    "Shares you have left will show up here" : "登録を解除（離脱）した共有がここに表示されます",
    "Pending shares" : "保留中の共有",
    "List of unapproved shares." : "未承認の共有の一覧",
    "No pending shares" : "保留中の共有はありません",
    "Shares you have received but not approved will show up here" : "あなたが受け取ったが承認されていない共有は、ここに表示されます",
    "Error deleting the share: {errorMessage}" : "共有の削除中にエラーが発生しました: {errorMessage}",
    "Error deleting the share" : "共有の削除中にエラー",
    "Error updating the share: {errorMessage}" : "共有の更新中にエラーが発生しました: {errorMessage}",
    "Error updating the share" : "共有の更新中にエラー",
    "File \"{path}\" has been unshared" : "ファイルパス \"{path}\" が共有解除されました",
    "Folder \"{path}\" has been unshared" : "フォルダーパス \"{path}\" が共有解除されました",
    "Could not update share" : "共有を更新できませんでした",
    "Share saved" : "共有を保存しました",
    "Share expiry date saved" : "共有の有効期限が保存されました",
    "Share hide-download state saved" : "ダウンロードを隠す状態の共有が保存されました",
    "Share label saved" : "共有ラベルが保存されました",
    "Share note for recipient saved" : "共有の受取人への注意が保存されました",
    "Share password saved" : "共有パスワードが保存されました",
    "Share permissions saved" : "共有権限が保存されました",
    "To upload files to {folder}, you need to provide your name first." : "ファイルを{folder}にアップロードするには、最初に名前を入力する必要があります。",
    "Upload files to {folder}" : "{folder}にファイルをアップロード",
    "Please confirm your name to upload files to {folder}" : "{folder}にファイルをアップロードするには名前を確認してください",
    "{ownerDisplayName} shared a folder with you." : "{ownerDisplayName}はあなたとフォルダを共有しました。",
    "Names must not be empty." : "名前は空白にできません。",
    "Names must not start with a dot." : "ドットで始まる名前は使用できません。",
    "\"{char}\" is not allowed inside a name." : "\"{char}\"は名前の中で許可されていません。",
    "\"{segment}\" is a reserved name and not allowed." : "\"{segment}\"は予約名であり許可されていません。",
    "\"{extension}\" is not an allowed name." : "\"{extension}\"は使用できない名前です。",
    "Names must not end with \"{extension}\"." : "名前の末尾に\"{extension}\"は使用できません。",
    "Invalid name." : "無効な名前です。",
    "Shared by" : "共有者：",
    "Shared with" : "と共有",
    "Password created successfully" : "パスワードが正常に作成されました",
    "Error generating password from password policy" : "パスワード ポリシーからのパスワード生成エラー",
    "Shared with you and the group {group} by {owner}" : "あなたと {owner} のグループ {group} で共有中",
    "Shared with you and {circle} by {owner}" : "{owner} が{circle}で共有中",
    "Shared with you and the conversation {conversation} by {owner}" : "{owner}のスレッド{conversation}であなたと共有しました",
    "Shared with you in a conversation by {owner}" : "{owner}のスレッドであなたと共有しました",
    "Share not found" : "共有が見つかりません",
    "Back to %s" : "%s に戻る",
    "Add to your Nextcloud" : "あなたのNextcloudに追加",
    "Waiting…" : "待機中…",
    "error" : "エラー",
    "finished" : "完了",
    "This will stop your current uploads." : "現在のアップロードが停止されます",
    "Move or copy" : "移動またはコピー",
    "You can upload into this folder" : "このフォルダーにアップロードできます",
    "Show list view" : "リストビューで表示",
    "Show grid view" : "グリッドビューで表示",
    "No compatible server found at {remote}" : "互換性のあるサーバーが {remote} にはありません。",
    "Invalid server URL" : "サーバーのURLが無効",
    "Failed to add the public link to your Nextcloud" : "このNextcloudに公開リンクを追加できませんでした",
    "You are not allowed to edit link shares that you don't own" : "あなたが所有していない共有リンクを編集することは許可されていません",
    "Download all files" : "すべてのファイルをダウンロード",
    "Link copied to clipboard" : "クリップボードにリンクをコピーしました",
    "_1 email address already added_::_{count} email addresses already added_" : ["{count} メールアドレスはすでに追加されています"],
    "_1 email address added_::_{count} email addresses added_" : ["{count} メールアドレスが追加されました"],
    "Copy to clipboard" : "クリップボードにコピー",
    "Copy internal link to clipboard" : "内部リンクをクリップボードにコピー",
    "Only works for people with access to this folder" : "このフォルダにアクセスできる人にのみ機能します",
    "Only works for people with access to this file" : "このファイルへのアクセスできる人にのみ機能します",
    "Copy public link of \"{title}\" to clipboard" : "\"{title}\" の公開リンクをクリップボードにコピー",
    "Search globally" : "グローバルに検索",
    "Search for share recipients" : "共有の受信者を検索",
    "No recommendations. Start typing." : "推奨事項はありません。 入力を開始します。",
    "To upload files, you need to provide your name first." : "ファイルをアップロードするには、最初に名前を入力する必要があります。",
    "Enter your name" : "あなたの名前を入力",
    "Submit name" : "名前を送信",
    "Share with {userName}" : "{userName} と共有",
    "Show sharing options" : "共有オプションを表示",
    "Share note" : "共有ノート",
    "Upload files to %s" : "%s にファイルをアップロード",
    "%s shared a folder with you." : "%sはあなたとフォルダーを共有しました。",
    "Note" : "ノート",
    "Select or drop files" : "ファイルを選択するか、ドラッグ&ドロップしてください",
    "Uploading files" : "ファイルをアップロード中",
    "Uploaded files:" : "アップロード済ファイル:",
    "By uploading files, you agree to the %1$sterms of service%2$s." : "ファイルをアップロードすると、%1$s のサービス条件 %2$s に同意したことになります。",
    "Name" : "名前",
    "Use this method to share files with individuals or teams within your organization. If the recipient already has access to the share but cannot locate it, you can send them the internal share link for easy access." : "組織内の個人またはチームとファイルを共有するには、この方法を使用します。受信者がすでに共有にアクセスできるが、その場所を見つけられない場合は、簡単にアクセスできるように内部共有リンクを送信できます。",
    "Use this method to share files with individuals or organizations outside your organization. Files and folders can be shared via public share links and email addresses. You can also share to other Nextcloud accounts hosted on different instances using their federated cloud ID." : "組織外の個人や組織とファイルを共有するには、この方法を使用します。ファイルやフォルダは、パブリック共有リンクやメールアドレスで共有できます。また、連携クラウドIDを使用して、異なるインスタンスにホストされている他のNextcloudアカウントと共有することもできます。",
    "Shares that are not part of the internal or external shares. This can be shares from apps or other sources." : "内部または外部共有に含まれない共有。これはアプリや他のソースからの共有になります。",
    "Share with accounts, teams, federated cloud id" : "アカウント、チーム、連携クラウドIDで共有",
    "Share with accounts and teams" : "アカウントとチームで共有",
    "Federated cloud ID" : "クラウド共有ID",
    "Email, federated cloud id" : "電子メール、連携クラウドID",
    "Filename must not be empty." : "ファイル名は空白にできません。"
},
"nplurals=1; plural=0;");
