OC.L10N.register(
    "app_api",
    {
    "Daemon config not found" : "Daemon-Konfiguration nicht gefunden",
    "Error starting install of ExApp" : "Fehler beim Starten der Installation von ExApp",
    "ExApp failed to register, check the NC logs" : "ExApp konnte nicht registriert werden, NC-Protokolle überprüfen.",
    "ExApp not found, failed to get status" : "ExApp nicht gefunden, Status konnte nicht abgerufen werden",
    "This app is not installed from the AppStore. No extra information available. Only enable/disable and remove actions are allowed." : "Diese App ist nicht aus dem App-Store installiert. Keine weiteren Informationen verfügbar. Nur die Aktionen Aktivieren/Deaktivieren und Entfernen sind zulässig.",
    "Could not perform installation of ExApp" : "ExApp konnte nicht installiert werden",
    "Failed to enable ExApp" : "Aktivieren von ExApp fehlgeschlagen",
    "Failed to disable ExApp" : "Deaktivieren von ExApp fehlgeschlagen",
    "Could not update ExApp" : "ExApp konnte nicht aktualisiert werden",
    "Error starting update of ExApp" : "Fehler beim Starten eines Updates von ExApp",
    "Could not perform update of ExApp" : "Update von ExApp konnte nicht durchgeführt werden",
    "ExApp not found, failed to get logs" : "ExApp nicht gefunden, Protokolle konnten nicht abgerufen werden",
    "Failed to get container logs. Note: Downloading Docker container works only for containers with the json-file or journald logging driver. Error: %s" : "Containerprotokolle konnten nicht abgerufen werden. Hinweis: Das Herunterladen des Docker-Containers funktioniert nur für Container mit der JSON-Datei oder dem Journald-Protokollierungstreiber. Fehler: %s",
    "AppAPI authentication failed" : "AppAPI-Authentifizierung fehlgeschlagen",
    "AppAPI ExApp notifier" : "AppAPI ExApp Benachrichtigung",
    "AppAPI" : "AppAPI",
    "AI Integration Team" : "KI Integrations-Team",
    "ExApps Settings" : "ExApp-Einstellungen",
    "Nextcloud AppAPI" : "Nextcloud AppAPI",
    "### Boost your Nextcloud with AppAPI and its specially designed applications.\n\n\nThe AppAPI is a project within the Nextcloud ecosystem designed to streamline and enhance the process of\napplication development, deployment, and management.\n\nIt introduces a new methodology that allows developers to create\napplications using a variety of programming languages, not limited to PHP, which was traditionally used in Nextcloud development.\n\n\n### List of applications that require AppAPI:\n\n- [talk_bot_ai_example](https://github.com/cloud-py-api/talk_bot_ai_example)\n- [upscaler_example](https://github.com/cloud-py-api/upscaler_example)\n- [image_to_text_example](https://github.com/cloud-py-api/file_to_text_example)\n- [ai_image_generator_bot](https://github.com/cloud-py-api/ai_image_generator_bot)\n- [SummarAI](https://github.com/nextcloud/sumupbot)\n\n_If you wish to develop an application, we will gladly help and assist you._\n\n### Support\n\nWe appreciate any support for this project:\n\n- ⭐ Star our work on GitHub\n- ❗ Create an Issue or feature request\n- 💁 Resolve an Issue and create a Pull Request\n- 🧑‍💻 Develop your own application using AppAPI\n\nWe are genuinely excited about the future of the AppAPI project and its potential to transform\nthe way applications are developed and experienced within Nextcloud.\n\nAs we embark on this journey, we warmly invite you - developers, thinkers, creators, and visionaries -\nto join us in shaping a more versatile, stable, and secure app landscape.\n\n*Your insights, suggestions, and contributions are invaluable to us.*" : "### Erweiter deine Nextcloud mit AppAPI und den hierfür entwickelten Anwendungen.\n\n\nDie AppAPI ist ein Projekt innerhalb des Nextcloud-Ökosystems, das darauf abzielt, Prozesse der Anwendungsentwicklung, Bereitstellung und\nVerwaltung zu rationalisieren und zu verbessern.\n\nEs führt eine neue Methodik ein, die Entwicklern das Erstellen von Anwendungen nicht nur mit PHP,\ndas bislang in der Nextcloud-Entwicklung verwendet wurde, sondern mit einer Vielzahl von Programmiersprachen ermöglicht.\n\n\n### Liste der Anwendungen, die AppAPI erfordern:\n\n- [talk_bot_ai_example](https://github.com/cloud-py-api/talk_bot_ai_example)\n- [upscaler_example](https://github.com/cloud-py-api/upscaler_example)\n- [image_to_text_example](https://github.com/cloud-py-api/file_to_text_example)\n- [ai_image_generator_bot](https://github.com/cloud-py-api/ai_image_generator_bot)\n- [SummarAI](https://github.com/nextcloud/sumupbot)\n\n_Wenn du eine Anwendung entwickeln möchtest, helfen wir Ihnen gerne weiter._\n\n### Unterstützung\n\nWir freuen uns über jede Unterstützung für dieses Projekt:\n\n- ⭐ Markiere unsere Arbeit auf GitHub\n- ❗ Erstelle ein Issue oder einen Erweiterungsvorschlag\n- 💁 Löse ein Problem und erstelle einen Pull-Request\n- 🧑‍💻 Entwickle deine eigene Anwendung mit AppAPI\n\nWir sind sehr gespannt auf die Zukunft des AppAPI-Projekts und sein Transformationspotenzial\nbezüglich der Art und Weise, wie Anwendungen innerhalb von Nextcloud entwickelt und erlebt werden.\n\nWährend wir uns auf diese Reise begeben, laden wir dich – Entwickler, Denker, Schöpfer und Visionäre – herzlich ein –\ngemeinsam mit uns eine vielseitigere, stabilere und sicherere App-Landschaft zu gestalten.\n\n*Deine Erkenntnisse, Vorschläge und Beiträge sind für uns von unschätzbarem Wert.*",
    "The AppAPI Project is an exciting initiative that aims to revolutionize the way applications are developed for Nextcloud." : "Das AppAPI-Projekt ist eine aufregende Initiative, die darauf abzielt, die Art und Weise zu revolutionieren, wie Anwendungen für Nextcloud entwickelt werden.",
    "Deploy Daemons" : "Daemons bereitstellen",
    "Deploy Daemon (DaemonConfig) is an ExApps orchestration daemon." : "Deploy-Daemon (DaemonConfig) ist ein ExApps Orchestrierungs-Daemon.",
    "Deploy Daemons. Deploy Daemon (DaemonConfig) is an ExApps orchestration daemon." : "Deploy Daemons. Deploy-Daemon (DaemonConfig) ist ein ExApps Orchestrierungs-Daemon.",
    "Default Deploy Daemon is not accessible. Please verify its configuration" : "Standard-Deploy-Daemon ist nicht zugänglich. Bitte überprüfe seine Konfiguration.",
    "ExApp init timeout (minutes)" : "ExApp Initialisierungs-Timeout (Minuten)",
    "ExApp initialization process timeout after which AppAPI will mark it as failed" : "ExApp Initialisierungsprozess-Timeout, nach der AppAPI ihn als fehlgeschlagen markiert",
    "ExApp init timeout" : "ExApp Initialisierungs-Timeout",
    "ExApp container restart policy" : "ExApp Container Neustartrichtlinie",
    "Specify container restart policy, e.g. 'always' to ensure ExApp running after daemon server reboot" : "Gib die Neustartrichtlinie für den Container an, z. B. 'immer', um sicherzustellen, dass ExApp nach einem Neustart des Daemon-Servers ausgeführt wird",
    "This settings changes are reflected only for newly created containers" : "Diese Einstellungen werden nur für neu erstellte Container übernommen",
    "External Apps management" : "Externe Apps-Verwaltung",
    "Admin options saved" : "Administrationseinstellungen gespeichert",
    "Failed to save admin options" : "Fehler beim Speichern der-Administrationseinstellungen",
    "Are you sure you want delete Deploy Daemon" : "Möchtest du wirklich den Deploy Daemon löschen?",
    "All ExApps on this daemon will be removed" : "Alle ExApps auf diesem Daemon werden entfernt.",
    "All ExApps installed on this daemon will be removed" : "Alle ExApps auf diesem Daemon werden entfernt.",
    "Cancel" : "Abbrechen",
    "Delete" : "Löschen",
    "Default" : "Standard",
    "Set as default" : "Als Standard festlegen",
    "Test deploy" : "Bereitstellung testen",
    "Edit" : "Bearbeiten",
    "\"manual-install\" Deploy Daemon cannot be set as default" : "\"manual-install\" Bereitstellungsdaemon kann nicht als Standard festgelegt werden",
    "Failed to save admin options. Check the logs" : "Fehler beim Speichern der Administrationsoptionen. Prüfe die Protokolle.",
    "Password confirmation failed" : "Fehler bei der Passwortbestätigung",
    "Deploy daemon config details" : "Daemon-Konfigurationsdetails bereitstellen",
    "Deploy Daemon" : "Daemon bereitstellen",
    "Default daemon. ExApps will be installed on it" : "Standard-Daemon. ExApps werden hierauf installiert.",
    "Manual install daemon usually used for development. It cannot be set as default daemon." : "Manueller installierter Daemon, der normalerweise für die Entwicklung verwendet wird. Er kann nicht als Standard-Daemon festgelegt werden.",
    "ExApps installed" : "ExApps installiert",
    "Name" : "Name",
    "Protocol" : "Protokoll",
    "Host" : "Host",
    "Deploy config" : "Bereitstellungseinstellungen",
    "Docker network" : "Docker-Netzwerk",
    "Nextcloud URL" : "Nextcloud-URL",
    "HaProxy password" : "HaProxy-Passwort",
    "GPUs support" : "GPUs Unterstützung",
    "Compute device" : "Compute-Gerät",
    "Additional options" : "Zusatzoptionen",
    "Verify connection" : "Verbindung überprüfen",
    "Daemon connection successful" : "Verbindung zum Daemon erfolgreich",
    "Failed to connect to Daemon. Check the logs" : "Fehler beim Verbinden mit dem Daemon. Prüfe die Protokolle.",
    "Failed to check connection to Daemon. Check the logs" : "Fehler beim Prüfen der Verbindung zum Daemon. Prüfe die Protokolle.",
    "Registered Deploy daemons list" : "Liste von registrierten Bereitstellungsdaemons",
    "No Deploy daemons configured" : "Keine Bereitstellungsdämonen konfiguriert",
    "Register a custom one or setup from available templates" : "Registriere eine benutzerdefinierte Vorlage oder richte sie aus verfügbaren Vorlagen ein",
    "Register Daemon" : "Daemon registrieren",
    "AppAPI will try to install small skeleton ExApp to verify Daemon configured correctly and deployment steps are passing." : "AppAPI wird versuchen, ein kleines ExApp-Skelett zu installieren, um zu überprüfen, ob der Hintergrunddienst richtig konfiguriert ist und die Bereitstellungsschritte erfolgreich sind.",
    "The following Deploy test checks must be passed to succeed:" : "Die folgenden Tests müssen für eine erfolgreiche Bereitstellung bestanden werden:",
    "More info" : "Weitere Infos",
    "Download ExApp logs" : "ExApps-Protokolle herunterladen",
    "Remove test ExApp" : "Test-ExApp entfernen",
    "Start Deploy test" : "Bereitstellungstest starten",
    "Stop Deploy test" : "Bereitstellungstest anhalten",
    "ExApp is unregistered and container is removed on \"Stop deploy test\"" : "ExApp ist nicht registriert und der Container wird bei Auswahl von „Bereitstellungstest beenden“ entfernt.",
    "Register ExApp in Nextcloud" : "ExApp in Nextcloud registrieren",
    "Check if the ExApp is registered in Nextcloud before deployment" : "Überprüfe vor der Bereitstellung, ob die ExApp in Nextcloud registriert ist",
    "Image pull" : "Image abrufen",
    "Check if the image is successfully pulled" : "Überprüfe, ob das Image erfolgreich abgerufen wurde",
    "Container started" : "Container gestartet",
    "Check if the image successfully pulled and container is created and started" : "Überprüfe, ob das Image erfolgreich abgerufen und der Container erstellt und gestartet wurde",
    "Heartbeat" : "Herzschlag",
    "Check for the heartbeat is finished and healthy" : "Überprüfe, ob der Herzschlag vollendet und gesund ist",
    "Init step" : "Initialisierungsphase",
    "Wait for initialization step to finish" : "Warte bis die Initialisierungsphase abgeschlossen ist",
    "Enabled" : "Aktiviert",
    "Check if ExApp successfully handled the enabled event and registered all stuff properly" : "Überprüfen, ob ExApp das aktivierte Ereignis erfolgreich verarbeitet und alles ordnungsgemäß registriert hat",
    "Only if ExApp container is preset" : "Nur wenn ExApp-Container voreingestellt ist",
    "Deploy test passed successfully!" : "Bereitstellungstest erfolgreich bestanden!",
    "Deploy test failed at step \"{step}\"" : "Der Bereitstellungstest ist bei Schritt \"{step}\" fehlgeschlagen",
    "Edit Deploy Daemon" : "Bereitstellungs-Daemon bearbeiten",
    "Register Deploy Daemon" : "Bereitstellungsdaemon registrieren",
    "Daemon configuration template" : "Daemon-Konfigurationsvorlage",
    "Select daemon configuration template" : "Daemon-Konfigurationsvorlage auswählen",
    "Daemon registration form" : "Formular zur Registrierung des Daemons",
    "Unique Deploy Daemon Name" : "Einzigartiger Bereitstellungs-Daemonname",
    "Display name" : "Anzeigename",
    "Deployment method" : "Bereitstellungsmethode",
    "Select daemon deploy method" : "Daemon für Bereitstellungsmethode auswählen",
    "Daemon host" : "Daemon-Host",
    "Set daemon as default" : "Daemon als Standard auswählen",
    "Set as default daemon" : "Als Standard-Daemon festlegen",
    "Enable https" : "https aktivieren",
    "Show deploy config" : "Bereitstellungseinstellungen anzeigen",
    "Hide deploy config" : "Bereitstellungseinstellungen ausblenden",
    "Network" : "Netzwerk",
    "Docker network name" : "Docker-Netzwerkname",
    "AppAPI Docker Socket Proxy authentication password" : "AppAPI Docker Socket Proxy Authentifizierungs-Passwort",
    "Additional option" : "Zusatzoption",
    "Add additional option" : "Zusätzliche Option hinzufügen",
    "Option key (unique)" : "Optionsschlüssel (eindeutig)",
    "Option key (unique, e.g. my_key)" : "Optionsschlüssel (eindeutig, z. B. mein_Schlüssel)",
    "Option key is required" : "Optionsschlüssel ist erforderlich",
    "Option value" : "Optionswert",
    "Option value is required" : "Optionswert ist erforderlich",
    "Confirm" : "Bestätigen",
    "Save" : "Speichern",
    "Register" : "Registrieren",
    "Check connection" : "Verbindung prüfen",
    "Hostname to access ExApps" : "Hostname zum Zugriff auf ExApps",
    "Hostname or path to access Docker daemon (e.g. nextcloud-appapi-dsp:2375, /var/run/docker.sock)" : "Hostname oder Pfad zum Zugriff auf den Docker-Daemon (z.B. nextcloud-appapi-dsp:2375, /var/run/docker.sock)",
    "Daemon with this name already exists" : "Ein Daemon mit diesem Namen existiert bereits",
    "Password must be at least 12 characters long" : "Das Passwort muss mindestens 12 Zeichen lang sein",
    "With https enabled network is set to host" : "Bei aktiviertem https ist das Netzwerk auf Host eingestellt",
    "Changes would be applied only for newly installed ExApps. For existing ExApps, Docker containers should be recreated." : "Änderungen werden nur für neu installierte ExApps übernommen. Für vorhandene ExApps sollten die Docker-Container neu erstellt werden.",
    "URL should start with http:// or https://" : "Die URL muss mit http:// oder https:// beginnen",
    "For HTTPS daemon, Nextcloud URL should be HTTPS" : "Für den HTTPS-Daemon sollte die Nextcloud-URL HTTPS sein",
    "All available GPU devices on daemon host will be requested to be enabled in ExApp containers by Docker." : "Alle verfügbaren GPU-Geräte auf dem Daemon-Host werden von Docker aufgefordert, in ExApp-Containern aktiviert zu werden.",
    "DaemonConfig successfully registered" : "Daemonkonfiguration erfolgreich registriert",
    "Failed to register DaemonConfig. Check the logs" : "Fehler beim Registrieren der Daemonkonfiguration. Prüfe die Protokolle",
    "DaemonConfig successfully updated" : "DaemonConfig aktualisiert",
    "Failed to update DaemonConfig. Check the logs" : "DaemonConfig konnte nicht aktualisiert werden. Überprüfe die Protokolle.",
    "External Apps" : "Externe Apps",
    "Update to {version}" : "Aktualisieren auf {version}",
    "Remove" : "Entfernen",
    "Delete data on remove" : "Daten beim Entfernen löschen",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Für diese App wurde keine untere Versionsgrenze für Nextcloud gesetzt. Dies wird zukünftig als Fehler behandelt.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Für diese App wurde keine obere Versionsgrenze für Nextcloud gesetzt. Dies wird zukünftig als Fehler behandelt.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Diese App kann nicht installiert werden, weil die folgenden Abhängigkeiten nicht erfüllt sind:",
    "View in store" : "Im Store anzeigen",
    "Visit website" : "Webseite besuchen",
    "Report a bug" : "Einen technischen Fehler melden",
    "User documentation" : "Benutzer-Dokumentation",
    "Admin documentation" : "Administratoren-Dokumentation",
    "Developer documentation" : "Entwickler-Dokumentation",
    "This app is not registered in AppStore. No extra information available. Only enable/disable and remove actions are allowed." : "Diese App ist nicht im App-Store gelistet. Es sind keine weiteren Informationen verfügbar. Nur erlauben/deaktivieren und Aktionen entfernen ist zulässig.",
    "{license}-licensed" : "{license}-Lizenziert",
    "This app is supported via your current Nextcloud subscription." : "Diese App wird von deinem aktuellen Nextcloud-Abonnement unterstützt.",
    "Supported" : "Unterstützt",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Vorgestellte Apps werden von und innerhalb der Nextcloud-Community entwickelt. Sie stellen zentrale Funktionen bereit und sind für den produktiven Einsatz geeignet.",
    "Featured" : "Vorgestellt",
    "Update to {update}" : "Aktualisieren auf {update}",
    "All ExApps are up-to-date." : "Alle ExApps sind auf dem neuesten Stand.",
    "Default Deploy daemon is not accessible" : "Der Standard-Deploy-Daemon ist nicht zugänglich",
    "Icon" : "Symbol",
    "Version" : "Version",
    "Daemon" : "Daemon",
    "Level" : "Level",
    "Actions" : "Aktionen",
    "Results from other categories" : "Ergebnisse aus anderen Kategorien",
    "No apps found" : "Keine Apps gefunden",
    "_%n ExApp has an update available_::_%n apps have an update available_" : ["%n ExApp hat ein Update verfügbar.","Für %n Apps ist ein Update verfügbar"],
    "_Update_::_Update all_" : ["Aktualisieren","Alle aktualisieren"],
    "Type" : "Typ",
    "Display Name" : "Anzeigename",
    "Your apps" : "Deine Apps",
    "Documentation" : "Dokumentation",
    "Details" : "Details",
    "Changelog" : "Liste der Veränderungen",
    "by {author}\n{license}" : "von {author}\n{license}",
    "Active apps" : "Aktive Apps",
    "Disabled apps" : "Deaktivierte Apps",
    "Updates" : "Aktualisierungen",
    "Featured apps" : "Vorgestellte Apps",
    "Supported apps" : "Unterstützte Apps",
    "manual-install apps cannot be updated" : "manual-install Apps können nicht aktualisiert werden",
    "{progress}% Deploying" : "{progress}% bereitstellen",
    "{progress}% Initializing" : "{progress}% Initialisierung",
    "Healthchecking" : "Gesundheitscheck",
    "Deploy and Enable" : "Bereitstellen und Aktivieren",
    "Enable" : "Aktivieren",
    "Disable" : "Deaktivieren",
    "Allow untested app" : "Ungetestete App zulassen",
    "Default Deploy daemon is not accessible. Please verify configuration" : "Standard-Deploy-Daemon ist nicht zugänglich. Bitte überprüfe dessen Konfiguration",
    "The app will be downloaded from the App Store and deployed on default Deploy Daemon" : "Die App wird aus dem App-Store heruntergeladen und auf dem Standard-Deploy-Daemon bereitgestellt",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Diese App ist als nicht-kompatibel mit deiner Nextcloud-Version markiert. Wenn du fortfährst, so kannst du die App installieren. Bitte beachte, dass die App nicht wie erwartet funktionieren könnte.",
    "Your ExApps" : "Deine ExApps",
    "An error occurred during the request. Unable to proceed." : "Es ist ein Fehler bei der Anfrage aufgetreten. Es kann nicht fortgefahren werden.",
    "The app has been enabled but needs to be updated." : "Die App wurde aktiviert, muss jedoch aktualisiert werden.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Fehler: Diese App kann nicht aktiviert werden, da sie den Server instabil macht. "
},
"nplurals=2; plural=(n != 1);");
