OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "Όριο λήψης αρχείων",
    "File link share download limit" : "Όριο λήψης για κοινόχρηστους συνδέσμους αρχείων",
    "This app allows limiting the number of downloads for external link shares." : "Αυτή η εφαρμογή επιτρέπει τον περιορισμό του αριθμού λήψεων για εξωτερικούς κοινόχρηστους συνδέσμους.",
    "The minimum limit is 1" : "Το ελάχιστο όριο είναι 1",
    "Failed to set download limit" : "Αποτυχία ορισμού ορίου λήψης",
    "Failed to remove download limit" : "Αποτυχία κατάργησης ορίου λήψης",
    "Limit downloads" : "Όριο λήψεων",
    "Set download limit" : "Ορισμός ορίου λήψης",
    "Setting a new limit will reset the download count" : "Ο ορισμός ενός νέου ορίου θα επαναφέρει τον αριθμό λήψεων",
    "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["Επιτρέπεται 1 ακόμη λήψη","Επιτρέπονται {count} ακόμη λήψεις"],
    "Failed to set default download limit" : "Αποτυχία ορισμού προεπιλεγμένου ορίου λήψης",
    "Download limit" : "Όριο λήψης",
    "Configure the default download limit for external shares." : "Διαμορφώστε το προεπιλεγμένο όριο λήψης για εξωτερικούς κοινόχρηστους συνδέσμους.",
    "Set default download limit" : "Ορισμός προεπιλεγμένου ορίου λήψης",
    "You have reached the maximum amount of downloads allowed" : "Έχετε φτάσει τον μέγιστο αριθμό επιτρεπόμενων λήψεων",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "Αυτός ο κοινόχρηστος σύνδεσμος έχει περιορισμένο αριθμό λήψεων. Είστε σίγουροι ότι θέλετε να πραγματοποιήσετε μια νέα λήψη;"
},
"nplurals=2; plural=(n != 1);");
