.notifications-button .notifications-button__icon{height:20px}.notifications-button .notification__dot{fill:#ff4402}.notifications-button .notification__dot--warning{fill:var(--color-warning)}.notifications-button .notification__dot--white{fill:var(--color-primary-text)}.notifications-button.hasNotifications{animation-name:pulse;animation-duration:1.6s;animation-iteration-count:4}.notifications-button.hasNotifications svg{opacity:1}@keyframes pulse{0%{opacity:1}60%{opacity:.85}to{opacity:1}}.notification{padding-bottom:12px}.notification:not(:last-child){border-bottom:1px solid var(--color-border)}.notification .notification-heading{display:flex;align-items:center;min-height:26px}.notification .notification-heading .notification-time{color:var(--color-text-maxcontrast);margin:13px 0 13px auto}.notification .notification-heading .notification-dismiss-button{margin:6px}.notification .notification-subject,.notification .notification-message,.notification .notification-full-message,.notification .notification-actions{margin:0 12px 12px}.notification .notification-subject{display:flex;align-items:center}.notification .notification-subject>.image{align-self:flex-start}.notification .notification-subject>span.subject,.notification .notification-subject>a>span.subject,.notification .notification-subject>.rich-text--wrapper,.notification .notification-subject>a>.rich-text--wrapper{padding-left:10px;word-wrap:anywhere}.notification .notification-message,.notification .notification-full-message{padding-left:42px;color:var(--color-text-maxcontrast)}.notification .notification-message>.collapsed,.notification .notification-full-message>.collapsed{overflow:hidden;max-height:70px}.notification .notification-message>.notification-overflow,.notification .notification-full-message>.notification-overflow{box-shadow:0 0 20px 20px var(--color-main-background);position:relative}.notification strong{font-weight:700;opacity:1}.notification .notification-actions{overflow:hidden}.notification .notification-actions .button-vue{line-height:normal;margin:2px 8px}.notification .notification-actions:first-child{margin-left:auto}
