OC.L10N.register(
    "circles",
    {
    "{member} has been invited to join {circle} by {author}" : "{member} telah diundang untuk bergabung dengan {circle} oleh {author}",
    "Personal" : "Personal",
    "System" : "Sistem",
    "Visible" : "Tampak",
    "Open" : "Buka",
    "Password protected" : "Kata sandi dilindungi",
    "Hidden" : "Sembunyi",
    "Local" : "Lokal",
    "Root" : "Root",
    "Federated" : "Federated",
    "Email address" : "Alamat email",
    "Contact" : "Kontak",
    "Admin" : "Admin",
    "Owner" : "Owner",
    "Open »%s«" : "Buka »%s«",
    "Accept" : "Terima",
    "%s" : "%s",
    "Open %s" : "Buka %s",
    "Password to access content shared with you by %1$s" : "Kata sandi untuk mengakses konten yabg dibagikan dengan Anda oleh %1$s",
    "No files in here" : "Tidak ada berkas di sini",
    "No entries found in this folder" : "Tidak ada entri yang ditemukan dalam folder ini",
    "Name" : "Nama",
    "Size" : "Ukuran",
    "Modified" : "Dimodifikasi"
},
"nplurals=1; plural=0;");
