OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU ئۇچۇرى يوق",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: ئومۇمىي: {memTotalBytes} / ھازىرقى ئىشلىتىلىشى: {memUsageBytes}",
    "RAM info not available" : "RAM ئۇچۇرى يوق",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: ئومۇمىي: {swapTotalBytes} / ھازىرقى ئىشلىتىلىشى: {swapUsageBytes}",
    "SWAP info not available" : "SWAP ئۇچۇرى يوق",
    "Copied!" : "كۆچۈرۈلدى!",
    "Not supported!" : "قوللىمايدۇ!",
    "Press ⌘-C to copy." : "كۆچۈرۈش ئۈچۈن ⌘-C نى بېسىڭ.",
    "Press Ctrl-C to copy." : "كۆچۈرۈش ئۈچۈن Ctrl-C نى بېسىڭ.",
    "System" : "سىستېما",
    "Monitoring" : "نازارەت قىلىش",
    "Monitoring app with useful server information" : "پايدىلىق مۇلازىمېتىر ئۇچۇرلىرى بىلەن نازارەت قىلىش دېتالى",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "CPU يۈكى ، RAM ئىشلىتىش ، دىسكا ئىشلىتىش ، ئىشلەتكۈچى سانى قاتارلىق پايدىلىق مۇلازىمېتىر ئۇچۇرلىرى بىلەن تەمىنلەيدۇ.",
    "Operating System:" : "مەشغۇلات سىستېمىسى:",
    "CPU:" : "CPU:",
    "Memory:" : "ئەستە ساقلاش:",
    "Server time:" : "مۇلازىمېتىر ۋاقتى:",
    "Uptime:" : "Uptime:",
    "Temperature" : "تېمپېراتۇرا",
    "Load" : "Load",
    "Memory" : "ئەستە ساقلاش",
    "Disk" : "دىسكا",
    "Mount:" : "تاغ:",
    "Filesystem:" : "ھۆججەت سىستېمىسى:",
    "Size:" : "چوڭلۇقى:",
    "Available:" : "ئىشلەتكىلى بولىدۇ:",
    "Used:" : "ئىشلىتىلگەن:",
    "Files:" : "ھۆججەتلەر:",
    "Storages:" : "دۇكانلار:",
    "Free Space:" : "ھەقسىز بوشلۇق:",
    "Network" : "تور",
    "Hostname:" : "ساھىبجامال:",
    "Gateway:" : "دەرۋازا:",
    "Status:" : "ھالىتى:",
    "Speed:" : "سۈرئەت:",
    "Duplex:" : "Duplex:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "ئاكتىپ ئىشلەتكۈچىلەر",
    "Last hour" : "ئالدىنقى سائەت",
    "%s%% of all users" : "بارلىق ئىشلەتكۈچىلەرنىڭ% s %%",
    "Last 24 Hours" : "ئاخىرقى 24 سائەت",
    "Last 7 Days" : "ئاخىرقى 7 كۈن",
    "Last 30 Days" : "ئاخىرقى 30 كۈن",
    "Shares" : "Shares",
    "Users:" : "ئىشلەتكۈچىلەر:",
    "Groups:" : "گۇرۇپپىلار:",
    "Links:" : "ئۇلىنىشلار:",
    "Emails:" : "ئېلخەت:",
    "Federated sent:" : "فېدېراتسىيە ئەۋەتىلگەن:",
    "Federated received:" : "فېدېراتسىيە قوبۇل قىلدى:",
    "Talk conversations:" : "سۆھبەت پاراڭلىرى:",
    "PHP" : "PHP",
    "Version:" : "نەشرى:",
    "Memory limit:" : "ئەستە ساقلاش چېكى:",
    "Max execution time:" : "ئىجرا قىلىنىش ۋاقتى:",
    "Upload max size:" : "ئەڭ چوڭ چوڭلۇقى:",
    "OPcache Revalidate Frequency:" : "OPcache چاستوتىنى ئىناۋەتسىز قىلىدۇ:",
    "Extensions:" : "كېڭەيتىلمىسى:",
    "Unable to list extensions" : "كېڭەيتىلمىنى تىزىشقا ئامالسىز",
    "Show phpinfo" : "Phpinfo نى كۆرسەت",
    "Database" : "ساندان",
    "Type:" : "تىپى:",
    "External monitoring tool" : "تاشقى كۆزىتىش قورالى",
    "Use this end point to connect an external monitoring tool:" : "بۇ ئاخىرقى نۇقتىنى ئىشلىتىپ سىرتقى نازارەت قىلىش قورالىنى ئۇلاڭ:",
    "Copy" : "كۆچۈرۈڭ",
    "Output in JSON" : "JSON دىكى چىقىرىش",
    "Skip apps section (including apps section will send an external request to the app store)" : "ئەپ بۆلەكلىرىدىن ئاتلاش (ئەپ بۆلىكىنى ئۆز ئىچىگە ئالىدۇ) ئەپ دۇكىنىغا تاشقى تەلەپ ئەۋەتىدۇ)",
    "Skip server update" : "مۇلازىمېتىر يېڭىلاشتىن ئاتلاڭ",
    "To use an access token, please generate one then set it using the following command:" : "زىيارەت بەلگىسىنى ئىشلىتىش ئۈچۈن بىرنى ھاسىل قىلىڭ ، ئاندىن تۆۋەندىكى بۇيرۇقنى ئىشلىتىپ تەڭشەڭ:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "ئاندىن يۇقارقى URL نى سورىغاندا «NC-Token» ماۋزۇسى ئارقىلىق بەلگە يوللاڭ.",
    "Unknown Processor" : "نامەلۇم بىر تەرەپ قىلغۇچ"
},
"nplurals=2; plural=(n != 1);");
