OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Informação da CPU não disponível",
    "CPU Usage:" : "Uso de CPU:",
    "Load average: {percentage} % ({load}) last minute" : "Média de carga: {percentage} % ({load}) no último minuto",
    "{lastMinutePercentage} % ({lastMinute}) last Minute\n{last5MinutesPercentage} % ({last5Minutes}) last 5 Minutes\n{last15MinutesPercentage} % ({last15Minutes}) last 15 Minutes" : "{lastMinutePercentage} % ({lastMinute}) no último minuto\n{last5MinutesPercentage} % ({last5Minutes}) nos últimos 5 minutos\n{last15MinutesPercentage} % ({last15Minutes}) nos últimos 15 minutos",
    "RAM Usage:" : "Uso de RAM:",
    "SWAP Usage:" : "Uso de SWAP:",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Total: {memTotalBytes}/Uso atual: {memUsageBytes}",
    "RAM info not available" : "Informações de RAM não disponíveis",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Total: {swapTotalBytes}/Uso atual: {swapUsageBytes}",
    "SWAP info not available" : "Informações de SWAP não disponíveis",
    "Copied!" : "Copiado!",
    "Not supported!" : "Não suportado!",
    "Press ⌘-C to copy." : "Pressione ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Pressione Ctrl-C para copiar.",
    "System" : "Sistema",
    "Monitoring" : "Monitoramento",
    "Monitoring app with useful server information" : "Aplicativo de monitoramento com informações úteis do servidor",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Fornece informações úteis do servidor, como carga de CPU, uso de RAM, uso do disco, número de usuários, etc.",
    "Operating System:" : "Sistema Operacional:",
    "CPU:" : "CPU:",
    "threads" : "threads",
    "Memory:" : "Memoria:",
    "Server time:" : "Horário do servidor:",
    "Uptime:" : "Tempo de operação:",
    "Temperature" : "Temperatura",
    "Load" : "Carga",
    "Memory" : "Memória",
    "Disk" : "Disco",
    "Mount:" : "Montagem:",
    "Filesystem:" : "Sistema de arquivo:",
    "Size:" : "Tamanho:",
    "Available:" : "Disponível:",
    "Used:" : "Usado:",
    "Files:" : "Arquivos:",
    "Storages:" : "Armazenamentos:",
    "Free Space:" : "Espaço Livre:",
    "Network" : "Rede",
    "Hostname:" : "Nome do host:",
    "Gateway:" : "Gateway:",
    "Status:" : "Status:",
    "Speed:" : "Velocidade:",
    "Duplex:" : "Duplex:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Usuários ativos",
    "Last hour" : "Na última hora",
    "%s%% of all users" : "%s%% de todos os usuários",
    "Last 24 Hours" : "Nas Últimas 24 Horas",
    "Last 7 Days" : "Nos Últimos 7 Dias",
    "Last 30 Days" : "Nos Últimos 30 Dias",
    "Shares" : "Compartilhamentos",
    "Users:" : "Usuários:",
    "Groups:" : "Grupos:",
    "Links:" : "Links:",
    "Emails:" : "E-mails:",
    "Federated sent:" : "Envio federado:",
    "Federated received:" : "Recebimento federado:",
    "Talk conversations:" : "Conversas do Talk:",
    "PHP" : "PHP",
    "Version:" : "Versão:",
    "Memory limit:" : "Limite de memória:",
    "Max execution time:" : "Tempo máximo de execução:",
    "Upload max size:" : "Tamanho máximo para uploads:",
    "OPcache Revalidate Frequency:" : "Frequência de Revalidação do OPcache:",
    "Extensions:" : "Extensões:",
    "Unable to list extensions" : "Não foi possível listar as extensões",
    "Show phpinfo" : "Mostrar phpinfo",
    "FPM worker pool" : "Pool de trabalhadores FPM",
    "Pool name:" : "Nome do pool:",
    "Pool type:" : "Tipo do pool:",
    "Start time:" : "Hora de início:",
    "Accepted connections:" : "Conexões aceitas:",
    "Total processes:" : "Total de processos:",
    "Active processes:" : "Processos ativos:",
    "Idle processes:" : "Processes inativos:",
    "Listen queue:" : "Fila de escuta:",
    "Slow requests:" : "Solicitações lentas:",
    "Max listen queue:" : "Máximo da fila de escuta:",
    "Max active processes:" : "Máximo de processes ativos:",
    "Max children reached:" : "Máximo de processos filhos atingido:",
    "Database" : "Banco de Dados",
    "Type:" : "Tipo:",
    "External monitoring tool" : "Ferramenta de monitoramento externo",
    "Use this end point to connect an external monitoring tool:" : "Use este endpoint para conectar uma ferramenta de monitoramento externa:",
    "Copy" : "Copiar",
    "Output in JSON" : "Saída em JSON",
    "Skip apps section (including apps section will send an external request to the app store)" : "Ignorar a seção de aplicativos (incluir a seção de aplicativos enviará uma solicitação externa para a loja de aplicativos)",
    "Skip server update" : "Ignorar atualização do servidor",
    "To use an access token, please generate one then set it using the following command:" : "Para usar um token de acesso, gere um e defina-o usando o seguinte comando:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Em seguida, passe o token com o cabeçalho \"NC-Token\" ao consultar o URL acima.",
    "Unknown Processor" : "Processador Desconhecido"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
