OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "اول ویزاد را اجرا کنید",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "Add your profile information! For example your email is needed to receive notifications and reset your password.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "اطلاعات نمایهٔ خود را اضافه کنید! یک تصویر نمایه و نام کامل برای تشخیص آسان‌تر در تمام ویژگی‌ها تنظیم کنید.",
    "Add your profile information! Set a full name for easier recognition across all features." : "اطلاعات نمایهٔ خود را اضافه کنید! یک نام کامل برای تشخیص آسان‌تر در تمام ویژگی‌ها تنظیم کنید.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "اطلاعات نمایهٔ خود را اضافه کنید! برای تشخیص آسان‌تر در تمام ویژگی‌ها، یک تصویر نمایه تنظیم کنید.",
    "Schedule work & meetings, synced with all your devices." : "زمان‌بندی کار و جلسات، همگام‌سازی‌شده با تمام دستگاه‌های شما",
    "Keep your colleagues and friends in one place without leaking their private info." : "همکاران و دوستان خود را در یک مکان نگه دارید بدون اینکه اطلاعات خصوصی آنها را بشناسید.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "برنامه ایمیل ساده با پرونده ها ، مخاطبین و تقویم یکپارچه شده است.",
    "App recommendation: Tasks" : "توصیه برنامه: کارها",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "وظایف دستگاه های مختلف را با Nextcloud خود همگام سازی کرده و آنها را بصورت آنلاین ویرایش کنید.",
    "App recommendation: Deck" : "توصیه برنامه: عرشه",
    "Kanban style organization for personal planning and team projects." : "سازمان به سبک کانبان برای برنامه ریزی های شخصی و پروژه های تیمی.",
    "App recommendation: Forms" : "App recommendation: Forms",
    "Simple surveys and questionnaires, self-hosted" : "Simple surveys and questionnaires, self-hosted",
    "App recommendation: Recognize" : "App recommendation: Recognize",
    "Smart media tagging for Nextcloud" : "Smart media tagging for Nextcloud",
    "App recommendation: Group folders" : "توصیه برنامه: پوشه های گروه",
    "Admin-configured folders shared by everyone in a group." : "پوشه های پیکربندی اداری که توسط همه افراد در یک گروه به اشتراک گذاشته می شود.",
    "Connect your calendar" : "تقویم خود را وصل کنید",
    "Connect your contacts" : "مخاطبین خود را وصل کنید",
    "Access files via WebDAV" : "دسترسی فایل ها از طریق WebDAV",
    "Download macOS/iOS configuration profile" : "نمایه پیکربندی macOS / iOS را بارگیری کنید",
    "Desktop client" : "نرم افزار دسکتاپ",
    "Android app on Google Play Store" : "Android app on Google Play Store",
    "Android app on F-Droid" : "Android app on F-Droid",
    "iOS app" : "اپ iOS",
    "A welcome and introduction wizard for Nextcloud" : "خوش آمد گویی و معرفی ویزارد برای  Nextcloud",
    "This application enables a pop-up window when a user first logs into Nextcloud. This window welcomes new users to Nextcloud, and contains links to the standard desktop client, Android app, and the iOS app. The window also shows a link for accessing Nextcloud via WebDAV. At any time, the first run wizard can be opened again via link \"About\" on settings menu.\nThe First run wizard can be customized to meet specific design goals, or to change links and messages. Create an appropriate theme following the Theming documentation, and changes to the look and feel of this Wizard are simple. More information is available in the first run wizard documentation, as well as the theming documentation." : "این برنامه وقتی کاربر برای اولین بار وارد Nextcloud می شود ، پنجره بازشو را فعال می کند. این پنجره از کاربران جدید به Nextcloud استقبال می کند و شامل پیوندهایی به مشتری استاندارد رومیزی ، برنامه Android و برنامه iOS است. در پنجره همچنین پیوندی برای دسترسی به Nextcloud از طریق WebDAV نشان داده شده است. در هر زمان ، اولین جادوگر اجرا می تواند دوباره از طریق پیوند \"درباره\" در فهرست تنظیمات باز شود.\nجادوگر اجرای اول می تواند برای تحقق اهداف خاص طراحی یا تغییر لینک ها و پیام ها سفارشی شود. با دنبال کردن مستندات Theming ، یک تم مناسب ایجاد کنید و تغییراتی در ظاهر و احساس این جادوگر ساده است. اطلاعات بیشتر در مستندات جادوگر اول اجرا و همچنین اسناد مضامین موجود است.",
    "Close" : "بسته",
    "Need help? ↗" : "نیاز به راهنمایی دارید؟ ↗",
    "Calendar and contacts ↗" : "تقویم و مخاطبین",
    "Welcome to {cloudName}!" : "Welcome to {cloudName}!",
    "Privacy" : "محرمانگی",
    "Community" : "انجمن",
    "Share via email" : "Share via email",
    "Get the apps to sync your files" : "برنامه ها را دریافت کنید تا فایل هایتان را همگام سازید",
    "Server address" : "آدرس سرور",
    "Use this link to connect your apps and desktop client to this server:" : "برای اتصال برنامه ها و مشتری دسک تاپ خود به این سرور از این لینک استفاده کنید:",
    "What's new?" : "What's new?",
    "Read more" : "بیشتر بخوانید",
    "Share on social media" : "Share on social media",
    "App recommendation: Nextcloud Calendar" : "توصیه برنامه: تقویم نکست‌کلود",
    "App recommendation: Nextcloud Contacts" : "توصیه برنامه: مخاطبین Nextcloud",
    "App recommendation: Nextcloud Mail" : "توصیه برنامه: ایمیل Nextcloud"
},
"nplurals=2; plural=(n > 1);");
