OC.L10N.register(
    "files_versions",
    {
    "Versions" : "Wersje",
    "This application automatically maintains older versions of files that are changed." : "Aplikacja przechowuje starsze wersje plików poddanych modyfikacji.",
    "This application automatically maintains older versions of files that are changed. When enabled, a hidden versions folder is provisioned in every user's directory and is used to store old file versions. A user can revert to an older version through the web interface at any time, with the replaced file becoming a version. The app automatically manages the versions folder to ensure the account does not run out of Quota because of versions.\n\t\tIn addition to the expiry of versions, the versions app makes certain never to use more than 50% of the account's currently available free space. If stored versions exceed this limit, the app will delete the oldest versions first until it meets this limit. More information is available in the Versions documentation." : "Ta aplikacja automatycznie utrzymuje starsze wersje plików, które zostały zmienione. Po włączeniu, w katalogu każdego użytkownika udostępniany jest katalog wersji ukrytych, który służy do przechowywania starych wersji plików. Użytkownik może w dowolnym momencie powrócić do starszej wersji za pośrednictwem interfejsu internetowego, a zastąpiony plik staje się wersją. Aplikacja automatycznie zarządza katalogiem wersji, aby mieć pewność, że na koncie nie zabraknie miejsca z powodu wersji.\n\t\tOprócz wygaszania wersji aplikacja sprawdza, by nigdy nie zostało wykorzystane więcej niż 50% aktualnie dostępnego wolnego miejsca na koncie. Jeśli przechowywane wersje przekroczą ten limit, aplikacja najpierw usunie najstarsze wersje, aż do osiągnięcia tego limitu. Więcej informacji można znaleźć w dokumentacji aplikacji wersji.",
    "Current version" : "Obecna wersja",
    "Initial version" : "Początkowa wersja",
    "You" : "Ty",
    "Actions for version from {versionHumanExplicitDate}" : "Działania dla wersji z {versionHumanExplicitDate}",
    "Name this version" : "Nazwij tę wersję",
    "Edit version name" : "Edytuj nazwę wersji",
    "Compare to current version" : "Porównaj z aktualną wersją",
    "Restore version" : "Przywróć wersję",
    "Download version" : "Pobierz wersję",
    "Delete version" : "Usuń wersję",
    "Cancel" : "Anuluj",
    "Remove version name" : "Usuń nazwę wersji",
    "Save version name" : "Zapis nazwę wersji",
    "Version name" : "Nazwa wersji",
    "Named versions are persisted, and excluded from automatic cleanups when your storage quota is full." : "Nazwane wersje są utrwalane i wykluczane z automatycznego czyszczenia, gdy limit przechowywania zostanie przekroczony.",
    "Initial version restored" : "Przywrócono wersję początkową",
    "Version restored" : "Wersja przywrócona",
    "Could not restore version" : "Nie można przywrócić wersji",
    "Could not set version label" : "Nie można ustawić etykiety wersji",
    "Could not delete version" : "Nie można usunąć wersji",
    "File versions" : "Wersje plików"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
