OC.L10N.register(
    "suspicious_login",
    {
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "'n Nuwe aanmelding by u rekening is bespeur. Die IP-adres %s is as suspisieus geklassifiseer. As dit wel u was, ignoreer hierdie boodskap. Verander andersins u wagwoord.",
    "Suspicious Login" : "Verdagte aanmelding",
    "New login detected" : "Nuwe aanmelding is bespeur",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Bespeur en waarsku oor suspisieuse IP-adresse wat by Nextcloud aanmeld\n\t",
    "Suspicious login detection" : "Bespeuring van verdagte aanmeldings"
},
"nplurals=2; plural=(n != 1);");
