OC.L10N.register(
    "comments",
    {
    "Comments" : "Kommentare",
    "You commented" : "Sie haben kommentiert",
    "{author} commented" : "{author} kommentierte",
    "You commented on %1$s" : "Sie haben %1$s kommentiert",
    "You commented on {file}" : "Sie haben {file} kommentiert",
    "%1$s commented on %2$s" : "%1$s kommentierte %2$s",
    "{author} commented on {file}" : "{author} hat {file} kommentiert",
    "<strong>Comments</strong> for files" : "<strong>Kommentare</strong> für Dateien",
    "Files" : "Dateien",
    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "Sie wurden in einem Kommentar zu \"{file}\" von einem Konto erwähnt, das inzwischen gelöscht wurde.",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} hat Sie in einem Kommentar zu \"{file}\" erwähnt",
    "Files app plugin to add comments to files" : "Ein Plugin für die Dateien-App zum Kommentieren von Dateien",
    "Edit comment" : "Kommentar bearbeiten",
    "Delete comment" : "Kommentar löschen",
    "Cancel edit" : "Bearbeiten abbrechen",
    "New comment" : "Neuer Kommentar",
    "Write a comment …" : "Schreiben Sie einen Kommentar …",
    "Post comment" : "Kommentar veröffentlichen",
    "@ for mentions, : for emoji, / for smart picker" : "@ für Erwähnungen, : für Emoji, / für Smart Picker",
    "Could not reload comments" : "Kommentare konnten nicht erneut geladen werden",
    "Failed to mark comments as read" : "Kommentare konnten nicht als gelesen markiert werden",
    "Unable to load the comments list" : "Kommentarliste kann nicht geladen werden",
    "No comments yet, start the conversation!" : "Keine Kommentare bisher. Beginnen Sie die Diskussion!",
    "No more messages" : "Keine weiteren Nachrichten",
    "Retry" : "Wiederholen",
    "_1 new comment_::_{unread} new comments_" : ["1 neuer Kommentar","[unread] neue Kommentare"],
    "Comment" : "Kommentar",
    "An error occurred while trying to edit the comment" : "Es ist ein Fehler beim Bearbeiten des Kommentars aufgetreten",
    "Comment deleted" : "Kommentar gelöscht",
    "An error occurred while trying to delete the comment" : "Es ist ein Fehler beim Löschen des Kommentars aufgetreten",
    "An error occurred while trying to create the comment" : "Es ist ein Fehler beim Erstellen des Kommentars aufgetreten"
},
"nplurals=2; plural=(n != 1);");
