OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "ئىناۋەتسىز فېدېراتسىيە بۇلۇت كىملىكى",
    "Server to server sharing is not enabled on this server" : "بۇ مۇلازىمېتىردا مۇلازىمېتىردىن ئورتاقلىشىش مۇلازىمىتىرى قوزغىتىلمىغان",
    "Couldn't establish a federated share." : "فېدېراتسىيە ئۈلۈشىنى قۇرالمىدى.",
    "Couldn't establish a federated share, maybe the password was wrong." : "فېدېراتسىيە ھەمبەھىر قۇرالمىدى ، بەلكىم پارول خاتا بولۇشى مۇمكىن.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "فېدېراتسىيە ھەمبەھىر تەلىپى ئەۋەتىلدى ، تەكلىپ تاپشۇرۇۋالىسىز. ئۇقتۇرۇشلىرىڭىزنى تەكشۈرۈڭ.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "فېدېراتسىيە ئۈلۈشىنى قۇرالمىدى ، قارىماققا فېدېراتسىيە بىلەن مۇلازىمېتىر بەك كونا (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "بۇ مۇلازىمېتىردىن فېدېراتسىيە گۇرۇپپا پېيىنى ئەۋەتىشكە بولمايدۇ.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "%1 $ s نى ئورتاقلىشىش مەغلۇب بولدى ، چۈنكى بۇ تۈر%2 $ s ھېساباتى بىلەن ئورتاقلاشتى",
    "Not allowed to create a federated share to the same account" : "ئوخشاش ھېساباتقا فېدېراتسىيە ئورتاقلىشىش قۇرۇشقا بولمايدۇ",
    "Federated shares require read permissions" : "فېدېراتسىيە پاي چېكى ئوقۇش ئىجازىتىنى تەلەپ قىلىدۇ",
    "File is already shared with %s" : "ھۆججەت ئاللىقاچان% s بىلەن ئورتاقلاشتى",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "%1 $ s نى ئورتاقلىشىش مەغلۇب بولدى ،%2 $ s نى تاپالمىدى ، بەلكىم مۇلازىمېتىر ھازىرچە ئېرىشكىلى بولمايدۇ ياكى ئۆزى ئىمزا قويغان گۇۋاھنامىنى ئىشلىتىشى مۇمكىن.",
    "Could not find share" : "ئورتاقلىشالمىدى",
    "Federated sharing" : "فېدېراتسىيە ئورتاقلىشىش",
    "You received {share} as a remote share from {user}" : "{share} دىن يىراقتىن ئورتاقلىشىش سۈپىتىدە {user} نى تاپشۇرۇۋالدىڭىز",
    "Accept" : "قوبۇل قىلىڭ",
    "Decline" : "رەت قىلىش",
    "Federated Cloud Sharing" : "فېدېراتسىيە بۇلۇتتىن ئورتاقلىشىش",
    "Sharing" : "ھەمبەھىر",
    "Federated file sharing" : "فېدېراتسىيە ھۆججەت ئورتاقلىشىش",
    "Provide federated file sharing across servers" : "مۇلازىمېتىرلاردا فېدېراتسىيە ھۆججەت ئورتاقلىشىشنى تەمىنلەڭ",
    "Unable to update federated files sharing config" : "فېدېراتسىيە ھۆججەت ئورتاقلىشىش سەپلىمىسىنى يېڭىلاشقا ئامالسىز",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "كىشىلەرنىڭ مۇلازىمېتىر ئارىسىدا قانداق ھەمبەھىرلىنىدىغانلىقىنى تەڭشەڭ. بۇ ئەگەر ئورتاق بەھرىلىنىشنى ئىشلىتىۋاتقان بولسا ، بۇ مۇلازىمېتىردىكى كىشىلەر ئوتتۇرىسىدىكى ئورتاقلىشىشنى ئۆز ئىچىگە ئالىدۇ.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "بۇ مۇلازىمېتىردىكى كىشىلەرنىڭ باشقا مۇلازىمېتىرلارغا پاي ئەۋەتىشىگە يول قويۇڭ (بۇ تاللاش WebDAV نىڭ ئاممىۋى پاينى زىيارەت قىلىشىغا يول قويىدۇ)",
    "Allow people on this server to receive shares from other servers" : "بۇ مۇلازىمېتىردىكى كىشىلەرنىڭ باشقا مۇلازىمېتىرلاردىن پاي تاپشۇرۇۋېلىشىغا يول قويۇڭ",
    "Allow people on this server to send shares to groups on other servers" : "بۇ مۇلازىمېتىردىكى كىشىلەرنىڭ باشقا مۇلازىمېتىرلاردىكى گۇرۇپپىلارغا ئورتاقلىشىشىغا يول قويۇڭ",
    "Allow people on this server to receive group shares from other servers" : "بۇ مۇلازىمېتىردىكى كىشىلەرنىڭ باشقا مۇلازىمېتىرلاردىن گۇرۇپپا ئۈلۈشىنى قوبۇل قىلىشىغا يول قويۇڭ",
    "Search global and public address book for people" : "كىشىلەر ئۈچۈن دۇنياۋى ۋە ئاممىۋى ئادرېس دەپتىرىنى ئىزدەڭ",
    "Allow people to publish their data to a global and public address book" : "كىشىلەرنىڭ سانلىق مەلۇماتلىرىنى دۇنياۋى ۋە ئاممىۋى ئادرېس دەپتىرىگە ئېلان قىلىشىغا يول قويۇڭ",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "#Nextcloud فېدېراتسىيە بۇلۇت كىملىكىم ئارقىلىق مەن بىلەن ئورتاقلىشىڭ ، {url} see نى كۆرۈڭ",
    "Share with me through my #Nextcloud Federated Cloud ID" : "مېنىڭ # كېيىنكى بۇلۇت فېدېراتسىيە بۇلۇت كىملىكىم ئارقىلىق مەن بىلەن ئورتاقلىشىڭ",
    "Share with me via Nextcloud" : "Nextcloud ئارقىلىق مەن بىلەن ئورتاقلىشىڭ",
    "Copy" : "كۆچۈرۈڭ",
    "Clipboard not available. Please copy the cloud ID manually." : "چاپلاش تاختىسى يوق. بۇلۇت كىملىكىنى قولدا كۆچۈرۈڭ.",
    "Copied!" : "كۆچۈرۈلگەن!",
    "Federated Cloud" : "فېدېراتسىيە بۇلۇت",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Nextcloud مۇلازىمېتىرى ياكى باشقا ئوچۇق Cloud Mesh (OCM) ماس كېلىدىغان مۇلازىمېتىر ۋە مۇلازىمەتلەرنى ئىشلەتكەنلەر بىلەن ئورتاقلىشالايسىز! ئۇلارنىڭ فېدېراتسىيە بۇلۇت كىملىكىنى ئورتاقلىشىش دىئالوگىغا قويۇڭ. ئۇ person@cloud.example.com غا ئوخشايدۇ",
    "Your Federated Cloud ID" : "فېدېراتسىيە بۇلۇت كىملىكىڭىز",
    "Share it so your friends can share files with you:" : "ھەمبەھىرلەڭ ، دوستلىرىڭىز ھۆججەتلەرنى سىز بىلەن ئورتاقلىشالايدۇ:",
    "Facebook" : "Facebook",
    "X (formerly Twitter)" : "X (ئىلگىرىكى Twitter)",
    "formerly Twitter" : "ئىلگىرى Twitter",
    "Mastodon" : "Mastodon",
    "Add to your website" : "تور بېتىڭىزگە قوشۇڭ",
    "HTML Code:" : "HTML كودى:",
    "Cancel" : "ۋاز كەچ",
    "Add remote share" : "يىراقتىن ئورتاقلىشىش",
    "Remote share" : "يىراقتىن ئورتاقلىشىش",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "{remote} @ {owner} دىن يىراقتىن ئورتاقلىشىش {name} add نى قوشماقچىمۇ؟",
    "Remote share password" : "يىراقتىن ئورتاقلىشىش پارولى",
    "Incoming share could not be processed" : "كەلگەن ئۈلۈشنى بىر تەرەپ قىلغىلى بولمايدۇ",
    "Cloud ID copied to the clipboard" : "بۇلۇت كىملىكى چاپلاش تاختىسىغا كۆچۈرۈلدى",
    "Copy to clipboard" : "چاپلاش تاختىسىغا كۆچۈرۈڭ"
},
"nplurals=2; plural=(n != 1);");
