OC.L10N.register(
    "circles",
    {
    "Teams" : "團隊",
    "You created the team {circle}" : "您建立了團隊 {circle}",
    "{author} created the team {circle}" : "{author} 建立了團隊 {circle}",
    "You deleted {circle}" : "您刪除了 {circle}",
    "{author} deleted {circle}" : "{author} 刪除了 {circle}",
    "You made {member} join {circle}" : "您讓 {member} 加入了 {circle}",
    "{author} made {member} join {circle}" : "{author} 讓 {member} 加入了 {circle}",
    "You added team {member} as member to {circle}" : "您已將團隊 {member} 新增為 {circle} 的成員",
    "{author} added team {member} as member to {circle}" : "{author} 已將團隊 {member} 新增為 {circle} 的成員",
    "You made {member} leave {circle}" : "您讓 {member} 離開了 {circle}",
    "{author} made {member} leave {circle}" : "{author} 讓 {member} 離開了 {circle}",
    "You removed {member} from {circle}" : "您從 {circle} 移除了 {member}",
    "{author} removed {member} from {circle}" : "{author} 從 {circle} 移除了 {member}",
    "You joined {circle}" : "您已加入了 {circle}",
    "{member} joined {circle}" : "{member} 已加入 {circle}",
    "You accepted the invitation to join {circle}" : "您接受了加入 {circle} 的邀請",
    "{member} accepted the invitation to join {circle}" : "{member} 接受了加入 {circle} 的邀請",
    "You added {member} as member to {circle}" : "您已將 {member} 新增為 {circle} 的成員",
    "You have been added as member to {circle} by {author}" : "{author} 已將您新增為 {circle} 的成員",
    "{member} has been added as member to {circle} by {author}" : "{author} 已將 {member} 新增為 {circle} 的成員",
    "You added {external} to {circle}" : "您已將 {external} 新增到 {circle}",
    "{external} has been added to {circle} by {author}" : "{author} 已將 {external} 新增到 {circle}",
    "You accepted {member}'s request to join {circle}" : "您接受了 {member} 加入了 {circle} 的請求",
    "Your request to join {circle} has been accepted by {author}" : "{author} 接受了您加入了 {circle} 的請求",
    "{member}'s request to join {circle} has been accepted by {author}" : "{author} 接受了 {member} 加入了 {circle} 的請求",
    "You left {circle}" : "您離開了 {circle}",
    "{member} left {circle}" : "{member} 離開了 {circle}",
    "You declined the invitation to join {circle}" : "您拒絕了加入 {circle} 的邀請",
    "{member} declined an invitation to join {circle}" : "{member} 拒絕了加入 {circle} 的邀請",
    "You cancelled your request to join {circle}" : "您取消了您加入 {circle} 的請求",
    "{member} cancelled a request to join {circle}" : "{member} 取消了加入 {circle} 的請求",
    "You have been removed from {circle} by {author}" : "{author} 已將您從 {circle} 移除",
    "{member} has been removed from {circle} by {author}" : "{author} 已將 {member} 從 {circle} 移除",
    "You removed {external} from {circle}" : "您從 {circle} 移除了 {external}",
    "{external} has been removed from {circle} by {author}" : "{author} 從 {circle} 移除了 {external}",
    "You cancelled {member}'s invitation to join {circle}" : "您取消了 {member} 加入 {circle} 的邀請",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} 取消了您加入 {circle} 的邀請",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} 取消了 {member} 加入 {circle} 的邀請",
    "You dismissed {member}'s request to join {circle}" : "您拒絕了 {member} 加入了 {circle} 的請求",
    "Your request to join {circle} has been dismissed by {author}" : "{author} 拒絕了您加入了 {circle} 的請求",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} 拒絕了 {member} 加入了 {circle} 的請求",
    "You invited {member} to join {circle}" : "您邀請了 {member} 加入 {circle}",
    "You have been invited to join {circle} by {author}" : "{author} 已邀請您加入 {circle}",
    "{member} has been invited to join {circle} by {author}" : "{author} 已邀請 {member} 加入 {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "您變更了 {member} 在 {circle} 中的等級到 %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} 變更了 {member} 在 {circle} 中的等級到 %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} 變更了 {member} 在 {circle} 中的等級到 %1$s",
    "You sent a request to join {circle}" : "您傳送了加入 {circle} 的請求",
    "{member} sent a request to join {circle}" : "{member} 傳送了加入 {circle} 的請求",
    "You are the new owner of {circle}" : "您是 {circle} 的新擁有者",
    "{member} is the new owner of {circle}" : "{member} 是 {circle} 的新擁有者",
    "On events happening in a <strong>team</strong> of which you are a member" : "你所屬的<strong>團隊</strong>中發生的事件",
    "Any important event in a <strong>team</strong> you are moderating" : "您主持的<strong>團隊</strong>中任何重要事件",
    "On global events happening in any <strong>team</strong>" : "在任何<strong>團隊</strong>中發生的全域事件",
    "Single" : "單一",
    "Personal" : "個人",
    "System" : "系統",
    "Visible" : "可見",
    "Open" : "開放",
    "Invite" : "邀請",
    "Join request" : "加入請求",
    "Friends" : "朋友",
    "Password protected" : "受密碼保護",
    "No Owner" : "無擁有者",
    "Hidden" : "隱藏",
    "Backend" : "後端",
    "Local" : "本地",
    "Root" : "根",
    "Team invite" : "團隊邀請",
    "Federated" : "已聯盟",
    "Mount point" : "掛載點",
    "Nextcloud Account" : "Nextcloud 帳號",
    "Nextcloud Group" : "Nextcloud 群組",
    "Email address" : "電子郵件地址",
    "Contact" : "聯絡人",
    "Circle" : "小圈圈",
    "Nextcloud App" : "Nextcloud 應用程式",
    "Member" : "成員",
    "Moderator" : "主持人",
    "Admin" : "管理員",
    "Owner" : "擁有者",
    "%s shared »%s« with you." : "%s 與您分享了 %s。",
    "%s shared »%s« with \"%s\"." : "%s 分享了 %s 與「%s」。",
    "%s on %s" : "%s 在 %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s 與您分享了 %2$s。\n您應該已經收到一封包含了可以存取它的連結的單獨電子郵件。\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s 與您分享了 %2$s。您應該已經收到一封包含了可以存取它的連結的單獨電子郵件。",
    "Password to access »%1$s« shared to you by %2$s" : "存取 %2$s 分享給您 %1$s 的密碼",
    "Password to access »%s«" : "存取 %s 的密碼",
    "It is protected with the following password:" : "其受以下密碼保護：",
    "%1$s via %2$s" : "%1$s 由 %2$s",
    "Click the button below to open it." : "點擊下方按鈕以開啟。",
    "Open »%s«" : "開啟 »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s 與您分享了多個檔案。\n您應該已經收到一封包含了可以存取它們的連結的單獨電子郵件。\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s 與您分享了多個檔案。您應該已經收到一封包含了可以存取它們的連結的單獨電子郵件。",
    "Password to access files shared to you by %1$s" : "%1$s 與您分享的檔案密碼",
    "Password to access files" : "存取檔案的密碼",
    "%s shared multiple files with \"%s\"." : "%s 與「%s」分享了多個檔案。",
    "%s shared multiple files with you." : "%s 與您分享了多個檔案。",
    "Boot up" : "啟動",
    "Nextcloud Initialization" : "Nextcloud 初始化",
    "Circles App Initialization" : "初始化小圈圈應用程式",
    "Fresh installation status" : "全新安裝狀態",
    "Building Local Database" : "正在建構本地資料庫",
    "Testing Basic Circle Creation" : "正在測試基本小圈圈建立",
    "Adding local users and moderators" : "正在新增本地使用者與主持人",
    "Show all teams" : "顯示所有團隊",
    "Create a new team" : "建立新團隊",
    "Files" : "檔案",
    "This feature is not available for personal circles" : "此功能不適用於私人小圈圈",
    "The team is not federated" : "團隊未加入聯盟",
    "You cannot join this team" : "您無法加入此團隊",
    "This member is not a moderator" : "該成員並非主持人",
    "Insufficient privileges" : "權限不足",
    "This member does not exist" : "此成員不存在",
    "This member is the owner of the team" : "此成員是團隊的擁有者",
    "Level cannot be changed for this type of member" : "此類型的成員的等級無法變更",
    "You are already a member of this circle" : "您已經是這個小圈圈的成員",
    "You have been blocked from this circle" : "您已被這個小圈圈封鎖",
    "The account is already a member of this circle" : "帳號已是小圈圈的成員",
    "The account has already been invited into this circle" : "帳號已被邀請加入此小圈圈",
    "%s (Team owned by %s)" : "%s（由 %s 擁有的團隊）",
    "You are now a member of the Team \"%2$s\"" : "您現在是團隊「%2$s」的成員",
    "You have been invited by %1$s into the Team \"%2$s\"" : "您已被 %1$s 邀請至團隊「%2$s」",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s 傳送了成為團隊「%2$s」成員的請求",
    "Accept" : "接受",
    "Refuse" : "拒絕",
    "Leave the team" : "離開團隊",
    "%s" : "%s",
    "Personal team" : "個人團隊",
    "%s owned by %s" : "%s 被 %s 擁有",
    "You have no permission to create a new team" : "您無權建立新的團隊",
    "%s shared a file with \"%s\"." : "%s 與「%s」分享了一個檔案。",
    "%s shared a file with you." : "%s 與您分享了一個檔案。",
    "%1$s shared %2$s with %3$s" : "%1$s 與 %3$s 分享了 %2$s",
    "%1$s shared %2$s with \"%3$s\"" : "%1$s 與「%3$s」分享了 %2$s",
    "Open %s" : "開啟 %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s 與您分享了一些內容。\n您應該會收到一封包含存取連結的電子郵件。\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s 與您分享了一些內容。您應該會收到一封包含存取連結的電子郵件。",
    "Password to access content shared with you by %1$s" : "使用密碼存取由 %1$s 與您分享的內容",
    "Password to access content" : "用來存取內容的密碼",
    "This item is already shared with this team" : "此項目已與此團隊分享",
    "Bring cloud-users closer together." : "讓雲端使用者緊密連結。",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "團隊讓您的夥伴可以建立他們自己的夥伴／同事／朋友群組。\n然後，其他任何的應用程式都可以將那些夥伴群組用於分享目的。",
    "No files in here" : "沒有檔案在這裡。",
    "No entries found in this folder" : "在此資料夾中沒有任何項目",
    "Name" : "名稱",
    "Size" : "大小",
    "Modified" : "已修改",
    "Teams' files" : "團隊檔案",
    "Select team to filter by" : "選取要篩選的團隊",
    "No teams found" : "找不到團隊",
    "Please select teams to filter by" : "請選取要篩選的團隊",
    "No files found for the selected teams" : "找不到選定團隊的檔案",
    "Shared to Circles" : "分享到小圈圈"
},
"nplurals=1; plural=0;");
