OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Riêng tư",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Trung tâm riêng tư cho bạn thấy nơi mà dữ liệu của bạn được lưu trữ và ai có thể truy cập nó, kể cả là vì bạn chia sẻ với họ hay là vì họ là quản trị viên.",
    "Administrators" : "Các quản trị viên",
    "Add external admin" : "Thêm vào quản trị viên bên ngoài",
    "Cancel" : "Hủy",
    "Add" : "Thêm",
    "Name of external admin" : "Tên của quản trị viên bên ngoài",
    "This server is protected with full-disk-encryption." : "Máy chủ này được mã hóa với toàn-bộ-ổ-đĩa-mã-hóa.",
    "Your files are not protected by encryption." : "Các tệp của bạn KHÔNG được bảo vệ bởi sự mã hóa.",
    "Encryption" : "Mã hóa",
    "Edit" : "Chỉnh sửa",
    "This server is using full-disk-encryption." : "Máy chủ này đang sử dụng toàn-bộ-ổ-đĩa-mã-hóa.",
    "Privacy policy" : "Chính sách riêng tư",
    "Who has access to your data?" : "Ai có quyền truy cập dữ liệu của bạn?",
    "Where is your data?" : "Dữ liệu của bạn ở đâu?",
    "Change data location" : "Thay đổi địa điểm dữ liệu",
    "Region" : "Vùng/miền",
    "Please select a region" : "Chọn một khu vực",
    "User Data Manifesto 2.0" : "Quyền Dữ Liệu Người Dùng Manifesto 2.0",
    "Control" : "Kiểm soát",
    "over user data access" : "qua truy cập dữ liệu người dùng",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Dữ liệu được tải lên bởi một người dùng 1 cách rõ ràng và tự nguyện nên được kiểm soát hoàn toàn bởi chính người dùng đó. Những người dùng nên có được quyền quyết định đến ai có thể được cấp phép truy cập trực tiếp dữ liệu của họ và đối với các quyền hạn và giấy phép để có thể truy cập đó nên được cấp phép.",
    "Knowledge" : "Kiến thức",
    "of how the data is stored" : "dữ liệu được lưu trữ như thế nào",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Một khi đữ liệu được tải lên một nhà cung cấp dịch vụ cụ thể, người dùng phải nên dược thông báo rằng nhà cung cấp dịch vụ đó lưu trữ dữ liệu ở đâu, trong bao lâu, trong phạm vi quyền hạn nào nhà cung cấp dịch vụ đó hoạt động, và những điều luật nào được áp dụng. ",
    "Freedom" : "Sự tự do",
    "to choose a platform" : "để chọn một nền tảng",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Người dùng nên luôn có khả năng trích xuất dữ liệu của họ từ dịch vụ ở bất kì thời điểm nào mà không gặp phải bất cứ một cản trở nào từ phía cung cấp dịch vụ. Các tiêu chuẩn mở cho các định dạng và các cổng thông tin là cần thiết để đảm bảo điều này. ",
    "Learn more ↗" : "Để biết thêm↗",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Dữ liệu của bạn tượng trưng cho chính bạn và rất dễ dàng bị lợi dụng. Chúng tôi ở vWorkspace tin rằng bạn là người có quyền quyết định mọi thứ đối với dữ liệu của bạn. vWorkspace bảo vệ các quyền của bạn như là đã dược định rõ trong Quyền Dữ Liệu Người Dùng Manifesto!"
},
"nplurals=1; plural=0;");
