OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Assistente da primeira execução",
    "Add your profile information! For example your email is needed to receive notifications." : "Adicione as informações do seu perfil! Por exemplo, seu e-mail é necessário para receber notificações. ",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "Adicione as informações do seu perfil! Por exemplo, seu e-mail é necessário para receber notificações e redefinir sua senha. ",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Adicione informações ao seu perfil! Defina uma imagem de perfil e um nome completo para facilitar o reconhecimento em todas as características.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Adicione informações ao seu perfil! Defina um nome completo para facilitar o reconhecimento em todas as funções.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Adicione informações ao seu perfil! Defina uma imagem de perfil para facilitar o reconhecimento em todas as funcionalidades.",
    "App recommendation: Calendar" : "Recomendação de aplicativo: Calendário",
    "Schedule work & meetings, synced with all your devices." : "Agende trabalho e reuniões, sincronizadas com todos os seus dispositivos.",
    "App recommendation: Contacts" : "Recomendação de aplicativo: Contatos",
    "Keep your colleagues and friends in one place without leaking their private info." : "Mantenha seus colegas e amigos em um só lugar sem vazar informações pessoais.",
    "App recommendation: Mail" : "Recomendação de aplicativo: E-Mail",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Simples aplicativo de e-mail bem integrado com Arquivos, Contatos e Calendário.",
    "App recommendation: Tasks" : "Recomendação de aplicativo: Tarefas",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "Sincronize tarefas de vários dispositivos com o Nextcloud e edite-as on-line.",
    "App recommendation: Deck" : "Recomendação de aplicativo: Deck",
    "Kanban style organization for personal planning and team projects." : "Organização no estilo Kanban para planejamento pessoal e projetos de equipe.",
    "App recommendation: Forms" : "Recomendação de aplicativo: Formulários",
    "Simple surveys and questionnaires, self-hosted" : "Enquetes e questionários simples, auto-hospedados",
    "App recommendation: Recognize" : "Recomendação de aplicativo: Reconhecer",
    "Smart media tagging for Nextcloud" : "Etiquetagem de mídia inteligente para o Nextcloud",
    "App recommendation: Group folders" : "Recomendação de aplicativo: Pastas de grupo",
    "Admin-configured folders shared by everyone in a group." : "Pastas configuradas pelo administrador compartilhadas por todos em um grupo.",
    "App recommendation: Whiteboard" : "Recomendação de aplicativo: Quadro Branco",
    "Create and share whiteboards with others and collaborate in real-time." : "Crie e compartilhe quadros brancos com outras pessoas e colabore em tempo real.",
    "Connect your calendar" : "Conectar seu calendário",
    "Connect your contacts" : "Conectar seus contatos",
    "Access files via WebDAV" : "Acessar arquivos via WebDAV",
    "Download macOS/iOS configuration profile" : "Baixar perfil de configuração macOS/iOS",
    "Desktop client" : "Cliente Desktop",
    "Android app on Google Play Store" : "Aplicativo Android na Google Play Store",
    "Android app on F-Droid" : "Aplicativo Android no F-Droid",
    "iOS app" : "Apicativo iOS",
    "About & What's new" : "Sobre & Novidades",
    "A welcome and introduction wizard for Nextcloud" : "Um assistente de boas-vindas e introdução ao Nextcloud",
    "This application enables a pop-up window when a user first logs into Nextcloud. This window welcomes new users to Nextcloud, and contains links to the standard desktop client, Android app, and the iOS app. The window also shows a link for accessing Nextcloud via WebDAV. At any time, the first run wizard can be opened again via link \"About\" on settings menu.\nThe First run wizard can be customized to meet specific design goals, or to change links and messages. Create an appropriate theme following the Theming documentation, and changes to the look and feel of this Wizard are simple. More information is available in the first run wizard documentation, as well as the theming documentation." : "Este aplicativo ativa uma janela pop-up quando um usuário faz login pela primeira vez no Nextcloud. Essa janela dá boas-vindas aos novos usuários e contém links para os clientes padrões para desktop Android e iOS. A janela também mostra um link para acessar o Nextcloud via WebDAV. A qualquer momento, este assistente pode ser aberto novamente pelo link \"Sobre\" no menu de configurações.\nO assistente de primeira execução pode ser personalizado para atender a metas de design específicas ou para alterar links e mensagens. Crie um tema apropriado seguindo a documentação de Theming. Mais informações estão disponíveis na documentação deste assistente, bem como na documentação sobre temas.",
    "Download on Apple app store" : "Download da App Store do Apple",
    "Download on Google play store" : "Download da Play Store do Google",
    "Go to previous page" : "Ir para a página anterior",
    "Close" : "Fechar",
    "More about Nextcloud" : "Mais sobre o Nextcloud",
    "Explore more apps ↗" : "Explorar mais apps ↗",
    "Extend the functionality of Nextcloud with hundreds of community-developed apps." : "Estenda as funcionalidades do Nextcloud com centenas de aplicativos desenvolvidos pela comunidade",
    "Get involved! ↗" : "Envolva-se! ↗",
    "Be a part of the community that helps build, design, translate and promote Nextcloud!" : "Seja parte de uma comunidade que ajuda a construir, desenhar, traduzir e promover o Nextcloud!",
    "Need help? ↗" : "Precisa de ajuda? ↗",
    "Find out more about your Nextcloud setup with the admin, user or developer documentation." : "Descubra mais sobre seu Nextcloud com as documentações para administradores, usuários ou desenvolvedores.",
    "For large organisations ↗" : "Para grandes organizações ↗",
    "Get Nextcloud Enterprise for mission critical environments where advanced security and compliance are important." : "Adquira o Nextcloud Empresarial para ambientes críticos onde segurança e compliance são importantes.",
    "Seamless integration with your devices." : "Integração perfeita com seus dispositivos.",
    "Sync your files across your devices with the desktop and mobile apps, and connect your calendar and contacts." : "Sincronize seus arquivos em todos os seus dispositivos com os aplicativos de desktop e aplicativos móveis, e conecte seu calendário e contatos.",
    "Desktop app ↗" : "Aplicativo Desktop ↗",
    "Download For Windows, Mac OS and Linux." : "Download Para Windows, Mac OS e Linux.",
    "Calendar and contacts ↗" : "Calendário e Contatos ↗",
    "Connect your calendar and contacts with your devices." : "Conecte seu calendário e contatos com seus dispositivos.",
    "Introducing Nextcloud Hub {version}" : "Apresentando Nextcloud Hub {version}",
    "Welcome to {cloudName}!" : "Bem-vindo a {cloudName}!",
    "This Nextcloud is on version {version}" : "Este Nextcloud está na versão {version}",
    "A collaboration platform that puts you in control" : "Uma plataforma colaborativa que te coloca no controle",
    "Privacy" : "Privacidade",
    "Host your data and files where you decide." : "Hospede seus dados e arquivos onde você decidir.",
    "Productivity" : "Produtividade",
    "Collaborate and communicate across any platform." : "Colabore e comunique através de qualquer plataforma.",
    "Interoperability" : "Interoperabilidade",
    "Import and export anything you want with open standards." : "Importe e exporte tudo que quiser com protocolos abertos",
    "Community" : "Comunidade",
    "Enjoy constant improvements from a thriving open-source community." : "Aproveite os desenvolvimentos constantes de uma próspera comunidade de código aberto.",
    "Nextcloud Hub {version} release" : "Lançamento do Nextcloud Hub {version}",
    "Read more about it on the Nextcloud Hub {version} blog" : "Leia mais sobre isso no blog Nextcloud Hub {version}",
    "Find out more on the blog" : "Saiba mais no blog",
    "Read the Nextcloud Hub {version} blog" : "Leia o blog Nextcloud Hub {version}",
    "Share your opinion about Nextcloud Hub {version}" : "Compartilhe sua opinião sobre Nextcloud Hub {version}",
    "Share via email" : "Compartilhar via e-mail",
    "Share on {socialMedia}" : "Compartilhar em {socialMedia}",
    "New in Nextcloud Hub {version}" : "Novidades no Nextcloud Hub {version}",
    "Connect other apps to {productName}" : "Conecte outros aplicativos a {productName}",
    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to {productName}." : "Além dos aplicativos móveis e do cliente de desktop, você pode conectar qualquer outro software que suporte os protocolos WebDAV/CalDAV/CardDAV ao {productName}.",
    "Apps to connect to {productName}" : "Aplicativos para conectar a {productName}",
    "Set up sync clients using an {linkStart}app password{linkEnd}. That way you can make sure you are able to revoke access in case you lose that device." : "Configure clientes de sincronização usando uma {linkStart}senha de aplicativo{linkEnd}. Dessa forma, você pode ter certeza de que poderá revogar o acesso caso perca o dispositivo.",
    "Get the apps to sync your files" : "Obtenha aplicativos para sincronizar seus arquivos",
    "{productName} gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "{productName} lhe dá acesso aos seus arquivos onde quer que você esteja. Nossos clientes móveis e de desktop fáceis de usar estão disponíveis para todas as principais plataformas a custo zero.",
    "App for syncing" : "Aplicativo para sincronização",
    "URL copied" : "URL copiado",
    "Could not copy the URL, please copy manually" : "Não foi possível copiar o URL, copie manualmente",
    "Server address" : "Endereço do servidor",
    "Use this link to connect your apps and desktop client to this server:" : "Use este link para conectar seus aplicativos e clientes de desktop a este servidor:",
    "End-to-end encryption in calls and web" : "Criptografia de ponta-a-ponta em chamadas e na Web",
    "Performance improvements across all our products" : "Melhorias de desempenho em todos os nossos produtos",
    "Thousands of tweaks for improved UX and stability" : "Milhares de ajustes para melhorar a experiência do usuário e a estabilidade",
    "Your own new personal assistant" : "Seu novo assistente pessoal",
    "Seamless file conversions" : "Conversões de arquivos sem problemas",
    "Smarter team sharing with Team folders" : "Compartilhamento de equipe mais inteligente com as pastas de Equipe",
    "Schedule meetings directly in Talk" : "Agende reuniões diretamente no Talk",
    "Mail you love again: translations, summaries, and mentions" : "E-mail que você ama novamente: traduções, resumos e menções",
    "Get to know the new features of Hub {version}" : "Saiba mais sobre os novos recursos do Hub {version}",
    "Nextcloud Hub 10 is here – your modular & unified digital workspace! 💫" : "O Nextcloud Hub 10 está aqui – seu espaço de trabalho digital modular & unificado! 💫",
    "What's new?" : "O que há de novo?",
    "Nextcloud on all your devices" : "Nextcloud em todos os seus dispositivos",
    "Nextcloud Hub {version}" : "Nextcloud Hub {version}",
    "Read more" : "Leia mais",
    "Share on social media" : "Compartilhe nas redes sociais",
    "Get started!" : "Comece agora!",
    "App recommendation: Nextcloud Calendar" : "Recomendação de aplicativo: Calendário Nextcloud",
    "App recommendation: Nextcloud Contacts" : "Recomendação de aplicativo: Contatos Nextcloud",
    "App recommendation: Nextcloud Mail" : "Recomendação de aplicativo: E-mail Nextcloud",
    "Federated collaboration: file sharing, messaging, calls" : "Colaboração federada: compartilhamento de arquivos, mensagens, chamadas",
    "Nextcloud Whiteboard" : "Nextcloud Quadro Branco",
    "Workflow Engine" : "Motor de Fluxo de Trabalho",
    "Safer and swifter mail" : "E-mail mais seguro e rápido",
    "Public Collectives sharing, previews and QR-codes" : "Compartilhamento de Coletivos públicos, visualizações e códigos QR",
    "Office and PDF templates" : "Modelos de Office e PDF",
    "Chat mode for Nextcloud Assistant" : "Modo de bate-papo para o Nextcloud Assistente",
    "Get to know the new features of Hub 9" : "Conheça as novidades do Hub 9"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
