OC.L10N.register(
    "files_trashbin",
    {
    "restored" : "restaurado",
    "Deleted files" : "Arquivos excluídos",
    "Deleted files and folders in the trash bin (may expire during export if you are low on storage space)" : "Arquivos e pastas excluídos na lixeira (podem expirar durante a exportação se você estiver com pouco espaço de armazenamento)",
    "This application enables people to restore files that were deleted from the system." : "Este aplicativo permite que as pessoas restaurem arquivos que foram excluídos do sistema.",
    "This application enables people to restore files that were deleted from the system. It displays a list of deleted files in the web interface, and has options to restore those deleted files back to the people file directories or remove them permanently from the system. Restoring a file also restores related file versions, if the versions application is enabled. When a file is deleted from a share, it can be restored in the same manner, though it is no longer shared. By default, these files remain in the trash bin for 30 days.\nTo prevent an account from running out of disk space, the Deleted files app will not utilize more than 50% of the currently available free quota for deleted files. If the deleted files exceed this limit, the app deletes the oldest files until it gets below this limit. More information is available in the Deleted Files documentation." : "Este aplicativo permite que as pessoas restaurem arquivos que foram excluídos do sistema. Ele exibe uma lista de arquivos excluídos na interface da web e tem opções para restaurar esses arquivos excluídos de volta aos diretórios de arquivos de pessoas ou removê-los permanentemente do sistema. A restauração de um arquivo também restaura versões de arquivos relacionadas, se o aplicativo de versões estiver ativado. Quando um arquivo é excluído de um compartilhamento, ele pode ser restaurado da mesma maneira, embora não seja mais compartilhado. Por padrão, esses arquivos permanecem na lixeira por 30 dias. \nPara evitar que uma conta fique sem espaço em disco, o aplicativo Arquivos excluídos não utilizará mais de 50% da cota livre atualmente disponível para arquivos excluídos. Se os arquivos excluídos excederem esse limite, o aplicativo excluirá os arquivos mais antigos até ficarem abaixo desse limite. Mais informações estão disponíveis na documentação Arquivos Excluídos.",
    "Restore" : "Restaurar",
    "Not enough free space to restore the file/folder" : "Não há espaço livre suficiente para restaurar o arquivo/pasta",
    "Empty deleted files" : "Esvaziar arquivos excluídos",
    "Confirm permanent deletion" : "Confirme exclusão permanente",
    "Are you sure you want to permanently delete all files and folders in the trash? This cannot be undone." : "Tem certeza de que deseja excluir permanentemente todos os arquivos e pastas na lixeira? Isso não pode ser desfeito.",
    "Cancel" : "Cancelar",
    "Original location" : "Localização original",
    "Deleted by" : "Excluído por",
    "Deleted" : "Excluído",
    "few seconds ago" : "há alguns segundos",
    "A long time ago" : "Há muito tempo",
    "Unknown" : "Desconhecida",
    "All files" : "Todos os arquivos",
    "You" : "Você",
    "List of files that have been deleted." : "Lista de arquivos que foram excluídos.",
    "No deleted files" : "Nenhum arquivo excluído",
    "Files and folders you have deleted will show up here" : "Arquivos e pastas que você excluiu aparecerão aqui",
    "All files have been permanently deleted" : "Todos os arquivos foram excluídos permanentemente",
    "Failed to empty deleted files" : "Falha ao esvaziar arquivos excluídos",
    "Deletion cancelled" : "Operação de exclusão cancelada"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
