OC.L10N.register(
    "app_api",
    {
    "Cancel" : "Tühista",
    "Delete" : "Kustuta",
    "Edit" : "Redigeeri",
    "Name" : "Nimi",
    "Host" : "Host",
    "Enabled" : "Sisse lülitatud",
    "Display name" : "Kuvatav nimi",
    "Network" : "Võrk",
    "Confirm" : "Kinnita",
    "Save" : "Salvesta",
    "Register" : "Registreeru",
    "Update to {version}" : "Uuenda versioonile {version}",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Sellel rakendusel pole määratud minimaalset Nextcloudi versiooni. See põhjustab tulevikus veateateid.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Sellel rakendusel pole määratud maksimaalset Nextcloudi versiooni. See põhjustab tulevikus veateateid.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Seda rakendust ei saa paigaldada, sest järgmised sõltuvusel ei ole täidetud:",
    "Visit website" : "Külasta veebisaiti",
    "Report a bug" : "Teata veast",
    "User documentation" : "Kasutaja dokumentatsioon",
    "Admin documentation" : "Administraatori dokumentatsioon",
    "Developer documentation" : "Arendaja dokumentatsioon",
    "{license}-licensed" : "{license} litsents",
    "Featured" : "Esile tõstetud",
    "Icon" : "Ikoon",
    "Version" : "Versioon",
    "Level" : "Tase",
    "Actions" : "Tegevused",
    "Type" : "Tüüp",
    "Display Name" : "Kuvatav nimi",
    "Your apps" : "Sinu rakendused",
    "Documentation" : "Dokumentatsioon",
    "Details" : "Üksikasjad",
    "Changelog" : "Muudatuste logi",
    "Disabled apps" : "Keelatud rakendused",
    "Updates" : "Uuendused",
    "Disable" : "Lülita välja"
},
"nplurals=2; plural=(n != 1);");
