OC.L10N.register(
    "sharebymail",
    {
    "Shared with {email}" : "Bendrinama su {email}",
    "Shared with {email} by {actor}" : "{actor} pradėjo bendrinti su {email}",
    "Unshared from {email}" : "Nustota bendrinti su {email}",
    "Unshared from {email} by {actor}" : "{actor} nustojo bendrinti su {email}",
    "Password for mail share sent to {email}" : "Slaptažodis pasidalinimui per elektroninį paštą išsiųstas {email}",
    "Password for mail share sent to you" : "Jums išsiųstas slaptažodis pasidalinimui per elektroninį paštą",
    "You shared {file} with {email} by mail" : "El. paštu pradėjote bendrinti {file} su {email}",
    "{actor} shared {file} with {email} by mail" : "{actor} el. paštu pradėjo bendrinti {file} su {email}",
    "You unshared {file} from {email} by mail" : "Jūs nustojote el. paštu bendrinti {file} su {email}",
    "{actor} unshared {file} from {email} by mail" : "{actor} nebendrintas {file} iš {email} el. paštu",
    "Password to access {file} was sent to {email}" : "Slaptažodis, skirtas prieigai prie {file}, buvo išsiųstas į {email}",
    "Password to access {file} was sent to you" : "Jums buvo išsiųstas slaptažodis, skirtas prieigai prie {file}",
    "Share by mail" : "Bendrinimas el. paštu",
    "Failed to send share by email" : "Nepavyko pasidalinti el. paštu",
    "Note:" : "Pastaba:",
    "Open %s" : "Atverti %s",
    "%1$s via %2$s" : "%1$s per %2$s",
    "It is protected with the following password:" : "Apsaugota šiuo slaptažodžiu:",
    "This is the password:" : "Štai yra slaptažodis:",
    "You can choose a different password at any time in the share dialog." : "Dalinimosi dialoge bet kuriuo metu galite pasirinkti kitą slaptažodį.",
    "Could not find share" : "Nepavyko rasti viešinio",
    "Share provider which allows you to share files by mail" : "Bendrinimo teikėjas, kuris leidžia bendrinti failus el. paštu",
    "Send password by mail" : "Siųsti slaptažodį el. paštu",
    "Reply to initiator" : "Atsakyti iniciatoriui"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
