OC.L10N.register(
    "dav",
    {
    "Calendar" : "Takvim",
    "Tasks" : "Görevler",
    "Personal" : "Kişisel",
    "{actor} created calendar {calendar}" : "{actor}, {calendar} takvimini ekledi",
    "You created calendar {calendar}" : "{calendar} takvimini eklediniz",
    "{actor} deleted calendar {calendar}" : "{actor}, {calendar} takvimini sildi",
    "You deleted calendar {calendar}" : "{calendar} takvimini sildiniz",
    "{actor} updated calendar {calendar}" : "{actor}, {calendar} takvimini güncelledi",
    "You updated calendar {calendar}" : "{calendar} takvimini güncellediniz",
    "{actor} restored calendar {calendar}" : "{actor}, {calendar} takvimini geri yükledi",
    "You restored calendar {calendar}" : "{calendar} takvimini geri yüklediniz",
    "You shared calendar {calendar} as public link" : "{calendar} takvimini herkese açık bağlantı olarak paylaştınız",
    "You removed public link for calendar {calendar}" : "{calendar} takviminin herkese açık bağlantısını kaldırdınız",
    "{actor} shared calendar {calendar} with you" : "{actor}, {calendar} takvimini sizinle paylaştı",
    "You shared calendar {calendar} with {user}" : "{calendar} takvimini {user} kullanıcısı ile paylaştınız",
    "{actor} shared calendar {calendar} with {user}" : "{actor}, {calendar} takvimini {user} kullanıcısı ile paylaştı",
    "{actor} unshared calendar {calendar} from you" : "{actor}, {calendar} takviminin sizinle paylaşımını kaldırdı",
    "You unshared calendar {calendar} from {user}" : "{calendar} takviminin {user} kullanıcısı ile paylaşımını kaldırdınız",
    "{actor} unshared calendar {calendar} from {user}" : "{actor}, {calendar} takviminin {user} kullanıcısı ile paylaşımını kaldırdı",
    "{actor} unshared calendar {calendar} from themselves" : "{actor}, {calendar} takviminin kendisi ile paylaşımını kaldırdı",
    "You shared calendar {calendar} with group {group}" : "{calendar} takvimini {group} grubu ile paylaştınız",
    "{actor} shared calendar {calendar} with group {group}" : "{actor}, {calendar} takvimini {group} grubu ile paylaştı",
    "You unshared calendar {calendar} from group {group}" : "{calendar} takviminin {group} grubu ile paylaşımını kaldırdınız",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor}, {calendar} takviminin {group} grubu ile paylaşımını kaldırdı",
    "Untitled event" : "Adlandırılmamış etkinlik",
    "{actor} created event {event} in calendar {calendar}" : "{actor}, {calendar} takvimine {event} etkinliğini ekledi",
    "You created event {event} in calendar {calendar}" : "{calendar} takvimine {event} etkinliğini eklediniz",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor}, {calendar} takviminden {event} etkinliğini sildi",
    "You deleted event {event} from calendar {calendar}" : "{calendar} takviminden {event} etkinliğini sildiniz",
    "{actor} updated event {event} in calendar {calendar}" : "{actor}, {calendar} takvimindeki {event} etkinliğini güncelledi",
    "You updated event {event} in calendar {calendar}" : "{calendar} takvimindeki {event} etkinliğini güncellediniz",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor}, {event} etkinliğini {sourceCalendar} takviminden {targetCalendar} takvimine taşıdı",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{event} etkinliğini {sourceCalendar} takviminden {targetCalendar} takvimine taşıdınız",
    "{actor} restored event {event} of calendar {calendar}" : "{actor}, {calendar} takvimindeki {event} etkinliğini geri yükledi",
    "You restored event {event} of calendar {calendar}" : "{calendar} takvimindeki {event} etkinliğini geri yüklediniz",
    "Busy" : "Meşgul",
    "{actor} created to-do {todo} in list {calendar}" : "{actor}, {calendar} takvimi listesine {todo} yapılacak işini ekledi",
    "You created to-do {todo} in list {calendar}" : "{calendar} takvimi listesine {todo} yapılacak işini eklediniz",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor}, {calendar} takvimi listesinden {todo} yapılacak işini sildi",
    "You deleted to-do {todo} from list {calendar}" : "{calendar} takvimi listesinden {todo} yapılacak işini sildiniz",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor}, {calendar} takvimi listesindeki {todo} yapılacak işini güncelledi",
    "You updated to-do {todo} in list {calendar}" : "{calendar} takvimi listesindeki {todo} yapılacak işini güncellediniz",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor}, {calendar} takvimi listesindeki {todo} yapılacak işini tamamladı",
    "You solved to-do {todo} in list {calendar}" : "{calendar} takvimi listesindeki {todo} yapılacak işini tamamladınız",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor}, {calendar} takvimi listesindeki {todo} yapılacak işini yeniden başlattı",
    "You reopened to-do {todo} in list {calendar}" : "{calendar} takvimi listesindeki {todo} yapılacak işini yeniden başlattınız",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor}, {todo} yapılacak işini {sourceCalendar} listesinden {targetCalendar} listesine taşıdı",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{todo} yapılacak işini {sourceCalendar} listesinden {targetCalendar} listesine taşıdınız",
    "Calendar, contacts and tasks" : "Takvim, kişiler ve görevler",
    "A <strong>calendar</strong> was modified" : "Bir <strong>takvim</strong> düzenlendi",
    "A calendar <strong>event</strong> was modified" : "Bir takvim <strong>etkinliği</strong> düzenlendi",
    "A calendar <strong>to-do</strong> was modified" : "Bir takvim <strong>yapılacak işi</strong> düzenlendi",
    "Contact birthdays" : "Kişi doğum günleri",
    "Death of %s" : "%s ölümü",
    "Untitled calendar" : "Adlandırılmamış takvim",
    "Calendar:" : "Takvim:",
    "Date:" : "Tarih:",
    "Where:" : "Yer:",
    "Description:" : "Açıklama:",
    "_%n year_::_%n years_" : ["%n yıl","%n yıl"],
    "_%n month_::_%n months_" : ["%n ay","%n ay"],
    "_%n day_::_%n days_" : ["%n gün","%n gün"],
    "_%n hour_::_%n hours_" : ["%n saat","%n saat"],
    "_%n minute_::_%n minutes_" : ["%n dakika","%n dakika"],
    "%s (in %s)" : "%s (%s içinde)",
    "%s (%s ago)" : "%s (%s önce)",
    "Calendar: %s" : "Takvim: %s",
    "Date: %s" : "Tarih: %s",
    "Description: %s" : "Açıklama: %s",
    "Where: %s" : "Şurada: %s",
    "%1$s via %2$s" : "%1$s, %2$s aracılığıyla",
    "In the past on %1$s for the entire day" : "Tüm gün boyunca %1$s zamanında geçmişte",
    "_In a minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["Tüm gün boyunca %1$s zamanında bir dakika içinde","Tüm gün boyunca %1$s zamanında %n dakika içinde"],
    "_In a hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["Tüm gün boyunca %1$s zamanında bir saat içinde","Tüm gün boyunca %1$s zamanında %n saat içinde"],
    "_In a day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["Tüm gün boyunca %1$s zamanında bir gün içinde","Tüm gün boyunca %1$s zamanında %n gün içinde"],
    "_In a week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["Tüm gün boyunca %1$s zamanında bir hafta içinde","Tüm gün boyunca %1$s zamanında %n hafta içinde"],
    "_In a month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["Tüm gün boyunca %1$s zamanında bir ay içinde","Tüm gün boyunca %1$s zamanında %n ay içinde"],
    "_In a year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["Tüm gün boyunca %1$s zamanında bir yıl içinde","Tüm gün boyunca %1$s zamanında %n yıl içinde"],
    "In the past on %1$s between %2$s - %3$s" : "Geçmişte %1$s zamanında %2$s ile %3$s arasında",
    "_In a minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["Bir dakika içinde %1$s zamanında %2$s ile %3$s arasında","%n dakika içinde %1$s zamanında %2$s ile %3$s arasında"],
    "_In a hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["Bir saat içinde %1$s zamanında %2$s ile %3$s arasında","%n saat içinde %1$s zamanında %2$s ile %3$s arasında"],
    "_In a day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["Bir gün içinde %1$s zamanında %2$s ile %3$s arasında","%n gün içinde %1$s zamanında %2$s ile %3$s arasında"],
    "_In a week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["Bir hafta içinde %1$s zamanında %2$s ile %3$s arasında","%n hafta içinde %1$s zamanında %2$s ile %3$s arasında"],
    "_In a month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["Bir ay içinde %1$s zamanında %2$s ile %3$s arasında","%n ay içinde %1$s zamanında %2$s ile %3$s arasında"],
    "_In a year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["Bir yıl içinde %1$s zamanında %2$s ile %3$s arasında","%n yıl içinde %1$s zamanında %2$s ile %3$s arasında"],
    "Could not generate when statement" : "Zaman ifadesi oluşturulamadı",
    "Every Day for the entire day" : "Her gün tüm gün boyunca",
    "Every Day for the entire day until %1$s" : "%1$s zamanına kadar her gün tüm gün boyunca",
    "Every Day between %1$s - %2$s" : "Her gün %1$s ile %2$s arasında",
    "Every Day between %1$s - %2$s until %3$s" : "%3$s zamanına kadar %1$s ile %2$s arasında her gün",
    "Every %1$d Days for the entire day" : "Her %1$d günde tüm gün boyunca",
    "Every %1$d Days for the entire day until %2$s" : "%2$s zamanına kadar her %1$d günde tüm gün boyunca",
    "Every %1$d Days between %2$s - %3$s" : "Her %1$d günde %2$s ile %3$s arasında",
    "Every %1$d Days between %2$s - %3$s until %4$s" : "%4$s zamanına kadar her %1$d günde %2$s ile %3$s",
    "Could not generate event recurrence statement" : "Etkinlik yinelenme ifadesi oluşturulamadı",
    "Every Week on %1$s for the entire day" : "Her hafta %1$s zamanında tüm gün boyunca",
    "Every Week on %1$s for the entire day until %2$s" : "Her hafta %1$s zamanında tüm gün boyunca %2$s zamanına kadar",
    "Every Week on %1$s between %2$s - %3$s" : "Her hafta %1$s zamanında %2$s ile %3$s arasında",
    "Every Week on %1$s between %2$s - %3$s until %4$s" : "Her hafta %1$s zamanında %2$s ile %3$s arasında %4$s zamanına kadar",
    "Every %1$d Weeks on %2$s for the entire day" : "Her %1$d haftada bir %2$s zamanında tüm gün boyunca",
    "Every %1$d Weeks on %2$s for the entire day until %3$s" : "Her %1$d haftada bir %2$s zamanında tüm gün boyunca %3$s zamanına kadar",
    "Every %1$d Weeks on %2$s between %3$s - %4$s" : "Her %1$d haftada bir %2$s zamanında tüm gün boyunca %3$s ile %4$s arasında",
    "Every %1$d Weeks on %2$s between %3$s - %4$s until %5$s" : "Her %1$d haftada bir %2$s zamanında %3$s ile %4$s arasında %5$s zamanına kadar",
    "Every Month on the %1$s for the entire day" : "Her ay %1$s zamanında tüm gün boyunca",
    "Every Month on the %1$s for the entire day until %2$s" : "Her ay %1$s zamanında tüm gün boyunca %2$s zamanına kadar",
    "Every Month on the %1$s between %2$s - %3$s" : "Her ay %1$s zamanında %2$s ile %3$s arasında",
    "Every Month on the %1$s between %2$s - %3$s until %4$s" : "Her ay %1$s zamanında %2$s ile %3$s arasında %4$s zamanına kadar",
    "Every %1$d Months on the %2$s for the entire day" : "Her %1$d ayda bir %2$s zamanında tüm gün boyunca",
    "Every %1$d Months on the %2$s for the entire day until %3$s" : "Her %1$d ayda bir %2$s zamanında tüm gün boyunca %3$s zamanına kadar",
    "Every %1$d Months on the %2$s between %3$s - %4$s" : "Her %1$d ayda bir %2$s zamanında tüm gün boyunca %3$s ile %4$s arasında",
    "Every %1$d Months on the %2$s between %3$s - %4$s until %5$s" : "Her %1$d ayda bir %2$s zamanında %3$s ile %4$s arasında %5$s zamanına kadar",
    "Every Year in %1$s on the %2$s for the entire day" : "Her yıl %1$s içinde %2$s zamanında tüm gün boyunca",
    "Every Year in %1$s on the %2$s for the entire day until %3$s" : "Her yıl %1$s içinde %2$s zamanında tüm gün boyunca %3$s zamanına kadar",
    "Every Year in %1$s on the %2$s between %3$s - %4$s" : "Her yıl %1$s içinde %2$s zamanında tüm gün boyunca %3$s ile %4$s arasında",
    "Every Year in %1$s on the %2$s between %3$s - %4$s until %5$s" : "Her yıl %1$s içinde %2$s zamanında %3$s ile %4$s arasında %5$s zamanına kadar",
    "Every %1$d Years in %2$s on the %3$s for the entire day" : "Her %1$d yılda bir %2$s içinde %3$s zamanında tüm gün boyunca",
    "Every %1$d Years in %2$s on the %3$s for the entire day until %4$s" : "Her %1$d yılda bir %2$s içinde %3$s zamanında tüm gün boyunca %4$s zamanına kadar",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s" : "Her %1$d yılda bir %2$s içinde %3$s zamanında tüm gün boyunca %4$s ile %5$s arasında",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "Her %1$d yılda bir %2$s içinde %3$s zamanında %4$s ile %5$s arasında %6$s zamanına kadar",
    "On specific dates for the entire day until %1$s" : "Belirli tarihlerde tüm gün boyunca %1$s zamanına kadar",
    "On specific dates between %1$s - %2$s until %3$s" : "Belirli tarihlerde %1$s ile %2$s arasında %3$s zamanına kadar",
    "In the past on %1$s" : "%1$s zamanında geçmişte",
    "_In a minute on %1$s_::_In %n minutes on %1$s_" : ["%1$s zamanında bir dakika içinde","%1$s zamanında %n dakika içinde"],
    "_In a hour on %1$s_::_In %n hours on %1$s_" : ["%1$s zamanında bir saat içinde","%1$s zamanında %n saat içinde"],
    "_In a day on %1$s_::_In %n days on %1$s_" : ["%1$s zamanında bir gün içinde","%1$s zamanında %n gün içinde"],
    "_In a week on %1$s_::_In %n weeks on %1$s_" : ["%1$s zamanında bir hafta içinde","%1$s zamanında %n hafta içinde"],
    "_In a month on %1$s_::_In %n months on %1$s_" : ["%1$s zamanında bir ay içinde","%1$s zamanında %n ay içinde"],
    "_In a year on %1$s_::_In %n years on %1$s_" : ["%1$s zamanında bir yıl içinde","%1$s zamanında %n yıl içinde"],
    "In the past on %1$s then on %2$s" : "Geçmişte %1$s zamanında ardından %2$s zamanında",
    "_In a minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["Bir dakika içinde %1$s zamanında ardından %2$s zamanında","%n dakika içinde %1$s zamanında ardından %2$s zamanında"],
    "_In a hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["Bir saat içinde %1$s zamanında ardından %2$s zamanında","%n saat içinde %1$s zamanında ardından %2$s zamanında"],
    "_In a day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["Bir gün içinde %1$s zamanında ardından %2$s zamanında","%n gün içinde %1$s zamanında ardından %2$s zamanında"],
    "_In a week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["Bir hafta içinde %1$s zamanında ardından %2$s zamanında","%n hafta içinde %1$s zamanında ardından %2$s zamanında"],
    "_In a month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["Bir ay içinde %1$s zamanında ardından %2$s zamanında","%n ay içinde %1$s zamanında ardından %2$s zamanında"],
    "_In a year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["Bir yıl içinde %1$s zamanında ardından %2$s zamanında","%n yıl içinde %1$s zamanında ardından %2$s zamanında"],
    "In the past on %1$s then on %2$s and %3$s" : "Geçmişte %1$s zamanında ardından %2$s ve %3$s zamanında",
    "_In a minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["Bir dakika içinde %1$s zamanında ardından %2$s ve %3$s zamanında","%n dakika içinde %1$s zamanında ardından %2$s ve %3$s zamanında"],
    "_In a hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["Bir saat içinde %1$s zamanında ardından %2$s ve %3$s zamanında","%n saat içinde %1$s zamanında ardından %2$s ve %3$s zamanında"],
    "_In a day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["Bir gün içinde %1$s zamanında ardından %2$s ve %3$s zamanında","%n gün içinde %1$s zamanında ardından %2$s ve %3$s zamanında"],
    "_In a week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["Bir hafta içinde %1$s zamanında ardından %2$s ve %3$s zamanında","%n hafta içinde %1$s zamanında ardından %2$s ve %3$s zamanında"],
    "_In a month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["Bir ay içinde %1$s zamanında ardından %2$s ve %3$s zamanında","%n ay içinde %1$s zamanında ardından %2$s ve %3$s zamanında"],
    "_In a year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["Bir yıl içinde %1$s zamanında ardından %2$s ve %3$s zamanında","%n yıl içinde %1$s zamanında ardından %2$s ve %3$s zamanında"],
    "Could not generate next recurrence statement" : "Sonraki yinelenme ifadesi oluşturulamadı",
    "Cancelled: %1$s" : "İptal edildi: %1$s",
    "\"%1$s\" has been canceled" : "\"%1$s\" iptal edildi",
    "Re: %1$s" : "Ynt: %1$s",
    "%1$s has accepted your invitation" : "%1$s davetinizi kabul etti",
    "%1$s has tentatively accepted your invitation" : "%1$s davetinizi belirsiz olarak kabul etti",
    "%1$s has declined your invitation" : "%1$s davetinizi reddetti.",
    "%1$s has responded to your invitation" : "%1$s davetinizi yanıtladı",
    "Invitation updated: %1$s" : "Davet güncellendi: %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s, \"%2$s\" etkinliğini güncelledi",
    "Invitation: %1$s" : "Davet: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s, size \"%2$s\" için davet gönderdi",
    "Organizer:" : "Düzenleyen:",
    "Attendees:" : "Katılımcılar:",
    "Title:" : "Başlık:",
    "When:" : "Zaman:",
    "Location:" : "Konum:",
    "Link:" : "Bağlantı:",
    "Occurring:" : "Başlangıç:",
    "Accept" : "Kabul et",
    "Decline" : "Reddet",
    "More options …" : "Diğer seçenekler …",
    "More options at %s" : "%s üzerindeki diğer seçenekler",
    "Monday" : "Pazartesi",
    "Tuesday" : "Salı",
    "Wednesday" : "Çarşamba",
    "Thursday" : "Perşembe",
    "Friday" : "Cuma",
    "Saturday" : "Cumartesi",
    "Sunday" : "Pazar",
    "January" : "Ocak",
    "February" : "Şubat",
    "March" : "Mart",
    "April" : "Nisan",
    "May" : "Mayıs",
    "June" : "Haziran",
    "July" : "Temmuz",
    "August" : "Ağustos",
    "September" : "Eylül",
    "October" : "Ekim",
    "November" : "Kasım",
    "December" : "Aralık",
    "First" : "İlk",
    "Second" : "İkinci",
    "Third" : "Üçüncü",
    "Fourth" : "Dördüncü",
    "Fifth" : "Beşinci",
    "Last" : "Son",
    "Second Last" : "İkinci son",
    "Third Last" : "Üçüncü son",
    "Fourth Last" : "Dördüncü son",
    "Fifth Last" : "Beşinci son",
    "Contacts" : "Kişiler",
    "{actor} created address book {addressbook}" : "{actor}, {addressbook} adres defterini ekledi",
    "You created address book {addressbook}" : "{addressbook} adres defterini eklediniz",
    "{actor} deleted address book {addressbook}" : "{actor}, {addressbook} adres defterini sildi",
    "You deleted address book {addressbook}" : "{addressbook} adres defterini sildiniz",
    "{actor} updated address book {addressbook}" : "{actor}, {addressbook} adres defterini güncelledi",
    "You updated address book {addressbook}" : "{addressbook} adres defterini güncellediniz",
    "{actor} shared address book {addressbook} with you" : "{actor}, {addressbook} adres defterini sizinle paylaştı",
    "You shared address book {addressbook} with {user}" : "{addressbook} adres defterini {user} kullanıcısı ile paylaştınız",
    "{actor} shared address book {addressbook} with {user}" : "{actor}, {addressbook} adres defterini {user} kullanıcısı ile paylaştı",
    "{actor} unshared address book {addressbook} from you" : "{actor}, {addressbook} adres defterinin sizinle paylaşımını kaldırdı",
    "You unshared address book {addressbook} from {user}" : "{addressbook} adres defterinin {user} kullanıcısı ile paylaşımını kaldırdınız",
    "{actor} unshared address book {addressbook} from {user}" : "{actor}, {addressbook} adres defterinin {user} kullanıcısı ile paylaşımını kaldırdı",
    "{actor} unshared address book {addressbook} from themselves" : "{actor}, {addressbook} adres defterinin kendileri ile paylaşımını kaldırdı",
    "You shared address book {addressbook} with group {group}" : "{addressbook} adres defterini {group} grubu ile paylaştınız",
    "{actor} shared address book {addressbook} with group {group}" : "{actor}, {addressbook} adres defterini {group} grubu ile paylaştı",
    "You unshared address book {addressbook} from group {group}" : "{addressbook} adres defterinin {group} grubu ile paylaşımını kaldırdınız",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor}, {addressbook} adres defterinin {group} grubu ile paylaşımını kaldırdı",
    "{actor} created contact {card} in address book {addressbook}" : "{actor}, {addressbook} adres defterine {card} kişi kartını ekledi",
    "You created contact {card} in address book {addressbook}" : "{addressbook} adres defterine {card} kişi kartını eklediniz",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor}, {addressbook} adres defterinden {card} kişi kartını sildi",
    "You deleted contact {card} from address book {addressbook}" : "{addressbook} adres defterinden {card} kişi kartını sildiniz",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor}, {addressbook} adres defterindeki {card} kişi kartını güncelledi",
    "You updated contact {card} in address book {addressbook}" : "{addressbook} adres defterindeki {card} kişi kartını güncellediniz",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "Bir <strong>kişi</strong> ya da <strong>adres defteri</strong> değiştirildiğinde",
    "Accounts" : "Hesaplar",
    "System address book which holds all accounts" : "Tüm hesapların bulunduğu sistem adres defteri",
    "File is not updatable: %1$s" : "Dosya güncellenebilir değil: %1$s",
    "Failed to get storage for file" : "Dosyanın depolaması alınamadı",
    "Could not write to final file, canceled by hook" : "Sonuç dosyasına yazılamadı, bağlantı tarafından iptal edildi",
    "Could not write file contents" : "Dosya içerikleri yazılamadı",
    "_%n byte_::_%n bytes_" : ["%n bayt","%n bayt"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "Dosya hedef konuma kopyalanırken sorun çıktı (Kopyalanan: %1$s, Beklenen dosya boyutu: %2$s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "%1$s dosya boyutu bekleniyordu, ancak %2$s okundu (Nextcloud istemcisinden) ve yazıldı (Nextcloud depolamasına). Gönderici tarafında bir ağ sorunu veya sunucu tarafında depolamaya yazma sorunu olabilir.",
    "Could not rename part file to final file, canceled by hook" : "Parça dosyası sonuç dosyası olarak yeniden adlandırılamadı, bağlantı tarafından iptal edildi",
    "Could not rename part file to final file" : "Parça dosyası sonuç dosyası olarak yeniden adlandırılamadı",
    "Failed to check file size: %1$s" : "Dosya boyutu denetlenemedi: %1$s",
    "Could not open file: %1$s, file does seem to exist" : "Dosya açılamadı: %1$s, dosya var gibi görünüyor",
    "Could not open file: %1$s, file doesn't seem to exist" : "Dosya açılamadı: %1$s, dosya var gibi görünmüyor",
    "Encryption not ready: %1$s" : "Şifreleme hazır değil: %1$s",
    "Failed to open file: %1$s" : "Dosya açılamadı: %1$s",
    "Failed to unlink: %1$s" : "Bağlantı kaldırılamadı: %1$s",
    "Failed to write file contents: %1$s" : "Dosya içerikleri yazılamadı: %1$s",
    "File not found: %1$s" : "Dosya bulunamadı: %1$s",
    "Invalid target path" : "Hedef yol geçersiz",
    "System is in maintenance mode." : "Sistem bakım kipinde.",
    "Upgrade needed" : "Yükseltme gerekiyor",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "iOS/macOS üzerinde CalDAV ve CardDAV kullanabilmek için %s HTTPS kullanacak şekilde yapılandırılmalıdır.",
    "Configures a CalDAV account" : "Bir CalDAV hesabı yapılandırır",
    "Configures a CardDAV account" : "Bir CardDAV hesabı yapılandırır",
    "Events" : "Etkinlikler",
    "Untitled task" : "Adlandırılmamış görev",
    "Completed on %s" : "%s tarihinde tamamlandı",
    "Due on %s by %s" : "%s tarihine kadar %s tarafından",
    "Due on %s" : "%s tarihine kadar",
    "Welcome to Nextcloud Calendar!\n\nThis is a sample event - explore the flexibility of planning with Nextcloud Calendar by making any edits you want!\n\nWith Nextcloud Calendar, you can:\n- Create, edit, and manage events effortlessly.\n- Create multiple calendars and share them with teammates, friends, or family.\n- Check availability and display your busy times to others.\n- Seamlessly integrate with apps and devices via CalDAV.\n- Customize your experience: schedule recurring events, adjust notifications and other settings." : "Nextcloud Takvim uygulamasına hoş geldiniz!\n\nBu bir örnek etkinliktir. İstediğiniz düzenlemeleri yaparak Nextcloud Takvim ile planlamanın esnekliğini keşfedin!\n\nNextcloud Takvim ile şunları yapabilirsiniz:\n- Etkinlikleri kolayca oluşturabilir, düzenleyebilir ve yönetebilirsiniz.\n- Birden fazla takvim oluşturabilir ve bunları takım arkadaşlarınız, arkadaşlarınız veya ailenizle paylaşabilirsiniz.\n- Uygunluğunuzu kontrol edebilir ve yoğun zamanlarınızı başkalarına gösterebilirsiniz.\n- CalDAV aracılığıyla uygulamaları ve aygıtları sorunsuz bir şekilde bütünleştirebilirsiniz.\n- Deneyiminizi özelleştirebilirsiniz: Yinelenen etkinlikler planlayabilir, bildirimleri ve diğer ayarları ayarlayabilirsiniz.",
    "Example event - open me!" : "Örnek etkinlik. Beni aç!",
    "System Address Book" : "Sistem adres defteri",
    "The system address book contains contact information for all users in your instance." : "Sistem adres defterinde, kopyanızdaki tüm kullanıcıların iletişim bilgileri bulunur.",
    "Enable System Address Book" : "Sistem adres defteri kullanılsın",
    "DAV system address book" : "DAV sistem adres defteri",
    "No outstanding DAV system address book sync." : "Bekleyen bir DAV sistemi adres defteri eşitlemesi yok.",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "Kopyanızda 1000 üzerinde kullanıcı olduğundan ya da bir sorun çıktığından DAV sistemi adres defteri eşitlemesi henüz yapılmamış. Lütfen \"occ dav:sync-system-addressbook\" komutunu yürüterek el ile eşitleyin.",
    "WebDAV endpoint" : "WebDAV bağlantı noktası",
    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "Site sunucunuzun WebDAV  üzerinden dosya eşitlemesi için doğru şekilde ayarlanıp ayarlanmadığı denetlenemedi. Lütfen el ile denetleyin.",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Site sunucunuz dosya eşitlemesi için doğru şekilde ayarlanmamış. WebDAV arabirimi sorunlu görünüyor.",
    "Your web server is properly set up to allow file synchronization over WebDAV." : "Site sunucunuz WebDAV  üzerinden dosya eşitlemesi için doğru şekilde ayarlanmış.",
    "Migrated calendar (%1$s)" : "Aktarılmış takvim (%1$s)",
    "Calendars including events, details and attendees" : "Etkinlikler, bilgiler ve katılımcılar ile takvimler",
    "Contacts and groups" : "Kişiler ve gruplar",
    "WebDAV" : "WebDAV",
    "Absence saved" : "Bulunmama kaydedildi",
    "Failed to save your absence settings" : "Bulunmama ayarlarınız kaydedilemedi",
    "Absence cleared" : "Bulunmama temizlendi",
    "Failed to clear your absence settings" : "Bulunmama ayarlarınız temizlenemedi",
    "First day" : "İlk gün",
    "Last day (inclusive)" : "Son gün (dahil)",
    "Out of office replacement (optional)" : "Ofis dışındayken yerine bakacak kişi (isteğe bağlı)",
    "Name of the replacement" : "Yerine bakacak kişi adı",
    "No results." : "Herhangi bir sonuç bulunamadı.",
    "Start typing." : "Yazmaya başlayın.",
    "Short absence status" : "Kısa bulunmama durumu",
    "Long absence Message" : "Uzun bulunmama iletisi",
    "Save" : "Kaydet",
    "Disable absence" : "Bulunmamayı kapat",
    "Failed to load availability" : "Uygunluk yüklenemedi",
    "Saved availability" : "Uygunluk kaydedildi",
    "Failed to save availability" : "Uygunluk kaydedilemedi",
    "Time zone:" : "Saat dilimi:",
    "to" : "ile",
    "Delete slot" : "Aralığı sil",
    "No working hours set" : "Çalışma saatleri ayarlanmamış",
    "Add slot" : "Aralık ekle",
    "Weekdays" : "Hafta içi günleri",
    "Pick a start time for {dayName}" : "{dayName} için başlangıç zamanını seçin",
    "Pick a end time for {dayName}" : "{dayName} için bitiş zamanını seçin",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Tüm bildirimleri sessize almak için, uygunluk durumu dışında kullanıcı durumu otomatik olarak \"Rahatsız etmeyin\" olarak ayarlanır.",
    "Cancel" : "İptal",
    "Import" : "İçe aktar",
    "Error while saving settings" : "Ayarlar kaydedilirken sorun çıktı",
    "Contact reset successfully" : "Kişi sıfırlandı",
    "Error while resetting contact" : "Kişi sıfırlanırken sorun çıktı",
    "Contact imported successfully" : "Kişi içe aktarıldı",
    "Error while importing contact" : "Kişi içe aktarılırken sorun çıktı",
    "Import contact" : "Kişiyi içe aktar",
    "Reset to default" : "Varsayılanlara dön",
    "Import contacts" : "Kişileri içe aktar",
    "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "Yeni bir .vcf dosyasını içe aktarmak, var olan varsayılan kişiyi siler ve yenisiyle değiştirir. İlerlemek istiyor musunuz?",
    "Failed to save example event creation setting" : "Örnek etkinlik oluşturma ayarı kaydedilemedi",
    "Failed to upload the example event" : "Örnek etkinlik yüklenemedi",
    "Custom example event was saved successfully" : "Özel örnek etkinlik kaydedildi",
    "Failed to delete the custom example event" : "Özel örnek etkinlik silinemedi",
    "Custom example event was deleted successfully" : "Özel örnek etkinlik silindi",
    "Import calendar event" : "Takvim etkinliğini içe aktar",
    "Uploading a new event will overwrite the existing one." : "Yeni bir etkinlik yüklendiğinde eskisinin üzerine yazılır.",
    "Upload event" : "Etkinlik yükle",
    "Availability" : "Uygunluk",
    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Çalışma saatlerinizi ayarlarsanız, diğer kişiler bir toplantı ayarladıklarında ofis dışında olduğunuzu görürler.",
    "Absence" : "Bulunmama",
    "Configure your next absence period." : "Sonraki bulunmama aralığınızı yapılandırın.",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Ayrıca {calendarappstoreopen}Takvim Uygulamasını{linkclose} kurun ya da {calendardocopen}bilgisayarınızı ya da taşınabilir aygıtınızı eşitlemek üzere bağlayın  ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Lütfen {emailopen}e-posta sunucusunu{linkclose} doğru ayarladığınızdan emin olun.",
    "Calendar server" : "Takvim sunucusu",
    "Send invitations to attendees" : "Katılımcılara davet gönder",
    "Automatically generate a birthday calendar" : "Doğum günü takvimi otomatik oluşturulsun",
    "Birthday calendars will be generated by a background job." : "Açıldığında, arka plan görevi olarak doğum günü takvimi oluşturulur.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Açıldıktan hemen sonra değil bir süre sonra görüntülenir.",
    "Send notifications for events" : "Etkinlik bildirimleri gönderilsin",
    "Notifications are sent via background jobs, so these must occur often enough." : "Bildirimler arka plan işlemleri tarafından gönderilir. Bu nedenle sıklık değeri uygun şekilde ayarlanmalıdır.",
    "Send reminder notifications to calendar sharees as well" : "Takvim paylaşımlarına da hatırlatma bildirimleri gönderilsin",
    "Reminders are always sent to organizers and attendees." : "Açıldığında, anımsatıcılar düzenleyici ve katılımcılara her zaman gönderilir.",
    "Enable notifications for events via push" : "Anında etkinlik bildirimlerini aç",
    "Example content" : "Örnek içerik",
    "Example content serves to showcase the features of Nextcloud. Default content is shipped with Nextcloud, and can be replaced by custom content." : "Örnek içerik, Nextcloud özelliklerinin sunulmasını sağlar. Varsayılan içerik Nextcloud ile birlikte gelir ve özel içerikle değiştirilebilir.",
    "There was an error updating your attendance status." : "Katılım durumunuz güncellenirken bir sorun çıktı.",
    "Please contact the organizer directly." : "Lütfen düzenleyici ile doğrudan görüşün.",
    "Are you accepting the invitation?" : "Daveti kabul ediyor musunuz?",
    "Tentative" : "Kesin değil",
    "Your attendance was updated successfully." : "Katılımınız güncellendi."
},
"nplurals=2; plural=(n > 1);");
