<?php
/**
 * SPDX-FileCopyrightText: 2016 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */

\OCP\Util::addScript('settings', 'vue-settings-admin-security');
?>

<div id="two-factor-auth-settings"></div>

<div id="vue-admin-encryption"></div>
