<?php
// This file is auto-generated. Do not edit!
return array('Adlm'=>'Adlam','Afak'=>'Afaka','Ahom'=>'Ahom','Hluw'=>'Anatolian Hieroglyphs','Arab'=>array(''=>'Arabic','variant'=>array('Perso-Arabic')),'Armn'=>'Armenian','Avst'=>'Avestan','Bali'=>'Balinese','Bamu'=>'Bamum','Beng'=>'Bangla','Bass'=>'Bassa Vah','Batk'=>'Batak','Bhks'=>'Bhaiksuki','Blis'=>'Blissymbols','Phlv'=>'Book Pahlavi','Bopo'=>'Bopomofo','Brah'=>'Brahmi','Brai'=>'Braille','Bugi'=>'Buginese','Buhd'=>'Buhid','Cari'=>'Carian','Aghb'=>'Caucasian Albanian','Cakm'=>'Chakma','Cham'=>'Cham','Cher'=>'Cherokee','Chrs'=>'Chorasmian','Cirt'=>'Cirth','Zyyy'=>'Common','Copt'=>'Coptic','Cprt'=>'Cypriot','Cpmn'=>'Cypro-Minoan','Cyrl'=>'Cyrillic','Dsrt'=>'Deseret','Deva'=>'Devanagari','Diak'=>'Dives Akuru','Dogr'=>'Dogra','Dupl'=>'Duployan shorthand','Syrn'=>'Eastern Syriac','Egyd'=>'Egyptian demotic','Egyh'=>'Egyptian hieratic','Egyp'=>'Egyptian hieroglyphs','Elba'=>'Elbasan','Elym'=>'Elymaic','Zsye'=>'emoji','Syre'=>'Estrangelo Syriac','Ethi'=>'Ethiopic','Latf'=>'Fraktur Latin','Lisu'=>'Fraser','Latg'=>'Gaelic Latin','Geor'=>'Georgian','Geok'=>'Georgian Khutsuri','Glag'=>'Glagolitic','Goth'=>'Gothic','Gran'=>'Grantha','Grek'=>'Greek','Gujr'=>'Gujarati','Gong'=>'Gunjala Gondi','Guru'=>'Gurmukhi','Hani'=>'Han','Hanb'=>'Han with Bopomofo','Hang'=>'Hangul','Rohg'=>array(''=>'Hanifi','stand-alone'=>array('Hanifi Rohingya')),'Hano'=>'Hanunoo','Hatr'=>'Hatran','Hebr'=>'Hebrew','Hira'=>'Hiragana','Armi'=>'Imperial Aramaic','Inds'=>'Indus','Zinh'=>'Inherited','Phli'=>'Inscriptional Pahlavi','Prti'=>'Inscriptional Parthian','Jamo'=>'Jamo','Jpan'=>'Japanese','Hrkt'=>'Japanese syllabaries','Java'=>'Javanese','Jurc'=>'Jurchen','Kthi'=>'Kaithi','Knda'=>'Kannada','Kana'=>'Katakana','Kawi'=>'Kawi','Kali'=>'Kayah Li','Khar'=>'Kharoshthi','Kits'=>'Khitan small script','Khmr'=>'Khmer','Khoj'=>'Khojki','Sind'=>'Khudawadi','Kore'=>'Korean','Kpel'=>'Kpelle','Lana'=>'Lanna','Laoo'=>'Lao','Latn'=>'Latin','Lepc'=>'Lepcha','Limb'=>'Limbu','Lina'=>'Linear A','Linb'=>'Linear B','Loma'=>'Loma','Lyci'=>'Lycian','Lydi'=>'Lydian','Mahj'=>'Mahajani','Maka'=>'Makasar','Mlym'=>'Malayalam','Mand'=>'Mandaean','Mani'=>'Manichaean','Marc'=>'Marchen','Gonm'=>'Masaram Gondi','Zmth'=>'mathematical notation','Maya'=>'Mayan hieroglyphs','Medf'=>'Medefaidrin','Mtei'=>'Meitei Mayek','Mend'=>'Mende','Mero'=>'Meroitic','Merc'=>'Meroitic Cursive','Modi'=>'Modi','Mong'=>'Mongolian','Moon'=>'Moon','Mroo'=>'Mro','Mult'=>'Multani','Mymr'=>'Myanmar','Nkoo'=>'N’Ko','Nbat'=>'Nabataean','Nagm'=>'Nag Mundari','Nand'=>'Nandinagari','Aran'=>'Nastaliq','Nkgb'=>'Naxi Geba','Talu'=>'New Tai Lue','Newa'=>'Newa','Nshu'=>'Nüshu','Hmnp'=>'Nyiakeng Puachue Hmong','Orya'=>'Odia','Ogam'=>'Ogham','Olck'=>'Ol Chiki','Cyrs'=>'Old Church Slavonic Cyrillic','Hung'=>'Old Hungarian','Ital'=>'Old Italic','Narb'=>'Old North Arabian','Perm'=>'Old Permic','Xpeo'=>'Old Persian','Sogo'=>'Old Sogdian','Sarb'=>'Old South Arabian','Ougr'=>'Old Uyghur','Orkh'=>'Orkhon','Osge'=>'Osage','Osma'=>'Osmanya','Hmng'=>'Pahawh Hmong','Palm'=>'Palmyrene','Pauc'=>'Pau Cin Hau','Phag'=>'Phags-pa','Phnx'=>'Phoenician','Plrd'=>'Pollard Phonetic','Phlp'=>'Psalter Pahlavi','Rjng'=>'Rejang','Roro'=>'Rongorongo','Runr'=>'Runic','Samr'=>'Samaritan','Sara'=>'Sarati','Saur'=>'Saurashtra','Shrd'=>'Sharada','Shaw'=>'Shavian','Sidd'=>'Siddham','Sgnw'=>'SignWriting','Hans'=>array(''=>'Simplified','stand-alone'=>array('Simplified Han')),'Sinh'=>'Sinhala','Sogd'=>'Sogdian','Sora'=>'Sora Sompeng','Soyo'=>'Soyombo','Xsux'=>array(''=>'Sumero-Akkadian Cuneiform','short'=>array('S-A Cuneiform')),'Sund'=>'Sundanese','Sylo'=>'Syloti Nagri','Zsym'=>'symbols','Syrc'=>'Syriac','Tglg'=>'Tagalog','Tagb'=>'Tagbanwa','Tale'=>'Tai Le','Tavt'=>'Tai Viet','Takr'=>'Takri','Taml'=>'Tamil','Tnsa'=>'Tangsa','Tang'=>'Tangut','Telu'=>'Telugu','Teng'=>'Tengwar','Thaa'=>'Thaana','Thai'=>'Thai','Tibt'=>'Tibetan','Tfng'=>'Tifinagh','Tirh'=>'Tirhuta','Toto'=>'Toto','Hant'=>array(''=>'Traditional','stand-alone'=>array('Traditional Han')),'Ugar'=>'Ugaritic','Cans'=>array(''=>'Unified Canadian Aboriginal Syllabics','short'=>array('UCAS')),'Zzzz'=>'unknown script','Zxxx'=>'unwritten','Vaii'=>'Vai','Wara'=>'Varang Kshiti','Visp'=>'Visible Speech','Vith'=>'Vithkuqi','Wcho'=>'Wancho','Syrj'=>'Western Syriac','Wole'=>'Woleai','Yezi'=>'Yezidi','Yiii'=>'Yi','Zanb'=>'Zanabazar Square','Qaag'=>'Zawgyi');
