<?php
// This file is auto-generated. Do not edit!
return array('Ahom'=>'Ahom','Bhks'=>'Bhks','Chrs'=>'Chrs','Cpmn'=>'Cpmn','Diak'=>'Diak','Dogr'=>'Dogr','Elym'=>'Elym','Gong'=>'Gong','Gonm'=>'Gonm','Hatr'=>'Hatr','Hmnp'=>'Hmnp','Kawi'=>'Kawi','Kits'=>'Kits','Maka'=>'Maka','Marc'=>'Marc','Medf'=>'Medf','Mult'=>'Mult','Nagm'=>'Nagm','Nand'=>'Nand','Newa'=>'Newa','Osge'=>'Osge','Ougr'=>'Ougr','Qaag'=>'Qaag','Sogd'=>'Sogd','Sogo'=>'Sogo','Soyo'=>'Soyo','Tnsa'=>'Tnsa','Toto'=>'Toto','Vith'=>'Vith','Wcho'=>'Wcho','Yezi'=>'Yezi','Zanb'=>'Zanb','Grek'=>'กรีก','Glag'=>'กลาโกลิติก','Knda'=>'กันนาดา','Kthi'=>'กายติ','Nkgb'=>'กีบา-นาซี','Guru'=>'กูร์มูคี','Kore'=>'เกาหลี','Goth'=>'โกธิก','Khar'=>'ขโรษฐี','Khmr'=>'เขมร','Kali'=>'คยาห์','Gran'=>'คฤณห์','Khoj'=>'คอจคี','Copt'=>'คอปติก','Kana'=>'คะตะกะนะ','Hrkt'=>'คะตะกะนะหรือฮิระงะนะ','Geok'=>'คัตซูรีจอร์เจีย','Cari'=>'คาเรีย','Visp'=>'คำพูดที่มองเห็นได้','Gujr'=>'คุชราต','Sind'=>'คุดาวาดี','Zmth'=>'เครื่องหมายทางคณิตศาสตร์','Merc'=>'เคอร์ซีฟ-เมโรอิติก','Geor'=>'จอร์เจีย','Cakm'=>'จักม่า','Cham'=>'จาม','Jamo'=>'จาโม','Hanb'=>'จีนกลาง','Jurc'=>'จูร์เชน','Dupl'=>'ชวเลขดัปโลยัน','Java'=>'ชวา','Shrd'=>'ชาราดา','Cyrs'=>'เชอร์ชสลาโวนิกซีริลลิกโบราณ','Cher'=>'เชอโรกี','Shaw'=>'ซอเวียน','Samr'=>'ซามาเรีย','Sara'=>'ซาราติ','Sylo'=>'ซิโลตินากรี','Cyrl'=>'ซีริลลิก','Syrc'=>'ซีเรีย','Syrj'=>'ซีเรียตะวันตก','Syrn'=>'ซีเรียตะวันออก','Syre'=>'ซีเรียเอสทรานจีโล','Sund'=>'ซุนดา','Cirt'=>'เซิร์ท','Sgnw'=>'ไซน์ไรติ้ง','Cprt'=>'ไซเปรียท','Jpan'=>'ญี่ปุ่น','Egyd'=>'ดีโมติกอียิปต์','Dsrt'=>'เดเซเรท','Tagb'=>'ตักบันวา','Tang'=>'ตันกัท','Hant'=>array(''=>'ตัวเต็ม','stand-alone'=>array('ฮั่นตัวเต็ม')),'Hans'=>array(''=>'ตัวย่อ','stand-alone'=>array('ฮั่นตัวย่อ')),'Zzzz'=>'ตัวอักษรที่ไม่รู้จัก','Tglg'=>'ตากาล็อก','Telu'=>'เตลูกู','Taml'=>'ทมิฬ','Takr'=>'ทาครี','Thaa'=>'ทานา','Tibt'=>'ทิเบต','Tfng'=>'ทิฟินาก','Teng'=>'เทงกวาร์','Deva'=>'เทวนาครี','Tirh'=>'เทอฮุทา','Thai'=>'ไทย','Talu'=>'ไทลื้อใหม่','Tale'=>'ไทเล','Tavt'=>'ไทเวียต','Nbat'=>'นาบาทาเอียน','Aran'=>'นาสตาลิก','Nshu'=>'นุซุ','Blis'=>'บลิสซิมโบลส์','Bass'=>'บัสซา','Batk'=>'บาตัก','Bamu'=>'บามุม','Bali'=>'บาหลี','Bugi'=>'บูกิส','Buhd'=>'บูฮิด','Beng'=>'เบงกาลี','Brai'=>'เบรลล์','Pauc'=>'ป่อจิ้งฮอ','Bopo'=>'ปอพอมอฟอ','Phlp'=>'ปะห์ลาวีซอลเตอร์','Phlv'=>'ปะห์ลาวีบุ๊ก','Phli'=>'ปะห์ลาวีอินสคริปชันแนล','Hmng'=>'ปาเฮาห์ม้ง','Kpel'=>'เปลเล','Xpeo'=>'เปอร์เซียโบราณ','Perm'=>'เปอร์มิกโบราณ','Mymr'=>'พม่า','Brah'=>'พราหมี','Prti'=>'พาร์เทียอินสคริปชันแนล','Palm'=>'พาลไมรีน','Phag'=>'ฟากส์-ปา','Phnx'=>'ฟินิเชีย','Lisu'=>'เฟรเซอร์','Mroo'=>'มโร','Mahj'=>'มหาชนี','Mong'=>'มองโกเลีย','Mani'=>'มานิแชน','Maya'=>'มายาไฮโรกลิฟส์','Mlym'=>'มาลายาลัม','Moon'=>'มูน','Mtei'=>'เมเทมาเยก','Mend'=>'เมนเด','Mero'=>'เมโรติก','Mand'=>'แมนเดียน','Modi'=>'โมฑี','Zxxx'=>'ไม่มีภาษาเขียน','Yiii'=>'ยิ','Ugar'=>'ยูการิต','Roro'=>'รองโกรองโก','Runr'=>'รูนิก','Rjng'=>'เรจัง','Latn'=>'ละติน','Latg'=>'ลาติน - แกลิก','Latf'=>'ลาติน - ฟรังเตอร์','Lana'=>'ล้านนา','Laoo'=>'ลาว','Limb'=>'ลิมบู','Lydi'=>'ลีเดีย','Linb'=>'ลีเนียร์บี','Lina'=>'ลีเนียร์เอ','Lepc'=>'เลปชา','Loma'=>'โลมา','Lyci'=>'ไลเซีย','Wara'=>'วารังกสิติ','Vaii'=>'ไว','Zsym'=>'สัญลักษณ์','Plrd'=>'สัทศาสตร์พอลลาร์ด','Zyyy'=>'สามัญ','Sinh'=>'สิงหล','Sidd'=>'สิทธัม','Sora'=>'โสราสมเป็ง','Saur'=>'โสวรัสตระ','Avst'=>'อเวสตะ','Orkh'=>'ออร์คอน','Osma'=>'ออสมันยา','Afak'=>'อะฟาคา','Hluw'=>'อักขระอานาโตเลีย','Cans'=>'อักษรพยางค์ของชาวอะบอริจินในแคนาดา','Xsux'=>'อักษรรูปลิ่มสุเมเรีย-อัคคาเดีย','Adlm'=>'อัดลัม','Armn'=>'อาร์เมเนีย','Sarb'=>'อาระเบียใต้โบราณ','Narb'=>'อาระเบียเหนือโบราณ','Arab'=>array(''=>'อาหรับ','variant'=>array('เปอร์เซีย-อาหรับ')),'Ital'=>'อิตาลีโบราณ','Inds'=>'อินดัส','Zinh'=>'อินเฮอริต','Armi'=>'อิมพีเรียล อราเมอิก','Zsye'=>'อีโมจิ','Ethi'=>'เอธิโอปิก','Nkoo'=>'เอ็นโก','Elba'=>'เอลบ์ซาน','Aghb'=>'แอลเบเนีย คอเคเซีย','Ogam'=>'โอคัม','Orya'=>'โอริยา','Olck'=>'โอลชิกิ','Wole'=>'โอลีเอ','Rohg'=>'ฮะนีฟี','Hung'=>'ฮังการีโบราณ','Hani'=>'ฮั่น','Hang'=>'ฮันกึล','Hano'=>'ฮานูโนโอ','Hira'=>'ฮิระงะนะ','Hebr'=>'ฮีบรู','Egyh'=>'เฮียราติกอียิปต์','Egyp'=>'เฮียโรกลิฟส์อียิปต์');
