OC.L10N.register(
    "activity",
    {
    "Hello %s" : "Salam%s",
    "Activity" : "işjeňlik we hereket",
    "Notifications" : "Duýduryşlar",
    "Send email" : "E-poçta iber",
    "Today" : "Şu gün",
    "Yesterday" : "Düýn",
    "Home" : "Baş sahypa",
    "No activity yet" : "Entek işjeňlik ýok"
},
"nplurals=2; plural=(n != 1);");
