OC.L10N.register(
    "serverinfo",
    {
    "Copied!" : "S-a copiat!",
    "Not supported!" : "Nu este suportat!",
    "Press ⌘-C to copy." : "Apasă ⌘-C pentru copiere.",
    "Press Ctrl-C to copy." : "Apasă Ctrl-C pentru copiere.",
    "System" : "Sistem",
    "Monitoring" : "Monitorizare",
    "Size:" : "Mărime:",
    "Shares" : "Partajări",
    "Database" : "Baza de date",
    "Type:" : "Tip:",
    "Copy" : "Copiază"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
