OC.L10N.register(
    "notifications",
    {
    "User not found" : "Defnyddiwr heb ei ganfod",
    "Hello %s" : "Helo %s",
    "Hello %s," : "Helo %s,",
    "Notifications" : "Hysbysiadau",
    "in {path}" : "yn {path}",
    "Your settings have been updated." : "Mae eich gosodiadau wedi'u diweddaru.",
    "None" : "Dim",
    "You need to set up your email address before you can receive notification emails." : "Mae angen i chi osod eich cyfeiriad e-bost cyn y gallwch dderbyn negeseuon e-bost hysbysu.",
    "seconds ago" : "eiliad yn ôl"
},
"nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
