OC.L10N.register(
    "photos",
    {
    "Public link" : "Verejný odkaz",
    "Photos" : "Fotografie",
    "On This Day" : "V tento deň",
    "Your memories under your control" : "Vaše spomienky pod vašou kontrolou",
    "All media" : "Všetky médiá",
    "Videos" : "Videá",
    "Albums" : "Albumy",
    "Collaborative albums" : "Kolaboratívne albumy",
    "People" : "Ľudia",
    "Folders" : "Priečinky",
    "Favorites" : "Obľúbené",
    "On this day" : "V tento deň",
    "Shared with you" : "Zdieľané s vami",
    "Tags" : "Štítky",
    "Places" : "Miesta",
    "Map" : "Mapa",
    "Photos settings" : "Nastavenia fotiek",
    "Mark selection as favorite" : "Označiť vybrané ako obľúbené",
    "Add selection to favorites" : "Pridať vybrané ako obľúbené",
    "Remove selection from favorites" : "Odstrániť vybrané z obľúbených",
    "Name of the album" : "Názov albumu",
    "Location of the album" : "Umiestnenie albumu",
    "Back" : "Späť",
    "Add collaborators" : "Pridať spolupracovníkov",
    "Save" : "Uložiť",
    "Create album" : "Vytvoriť album",
    "Add to Album" : "Pridať do albumu",
    "Add selection to album {albumName}" : "Pridať vybrané do albumu {ablumName}",
    "Shared by" : "Zdieľané od",
    "Create a new album." : "Vytvoriť nový album.",
    "Create new album" : "Vytvoriť nový album",
    "New album" : "Nový album",
    "_%n item_::_%n photos and videos_" : ["%n fotka alebo video","%n fotky a videá","%n fotiek a videí","%n fotiek a videí"],
    "Failed to fetch collaborators list." : "Nepodarilo sa získať zoznam spolupracovníkov.",
    "Failed to update album." : "Nepodarilo sa aktualizovať album.",
    "Add people or groups who can edit your album" : "Pridať užívateľov alebo skupiny ktoré môžu upravovať váš album",
    "Search people or groups" : "Vyhľadať užívateľov alebo skupiny",
    "No recommendations. Start typing." : "Žiadne odporúčania. Môžete začať písať.",
    "Group" : "Skupina",
    "Remove {collaboratorLabel} from the collaborators list" : "Odobrať {collaboratorLabel} zo zoznamu spolupracovníkov",
    "Copy the public link" : "Kopírovať verejný odkaz",
    "Public link copied!" : "Verejný odkaz bol skopírovaný!",
    "Copy public link" : "Kopírovať verejný odkaz",
    "Delete the public link" : "Zmazať verejný odkaz",
    "Create public link share" : "Vytvoriť verejný odkaz so zdieľaním",
    "Share via public link" : "Zdieľať ako verejný odkaz",
    "This collection does not exist" : "Kolekcia neexistuje",
    "An error occurred" : "Vyskytla sa chyba",
    "No picture for this day" : "Žiadny obrázok pre tento deň",
    "Picture taken on this day will show up here." : "Tu sa zobrazí fotografia odfotená v tento deň.",
    "More photos from this day" : "Viac fotiek z tohto dňa",
    "_%n photos_::_%n photos_" : ["%n fotka","%n fotky","%n fotiek","%n fotiek"],
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n nepriradená fotografia","%n nepriradené fotografie","%n nepriradených fotografií","%n nepriradených fotografií"],
    "Favorite" : "Obľúbené",
    "Favorite image, open the full size \"{name}\" image" : "Obľúbený obrázok, otvoriť plnú veľkosť obrázka \"{name}\"",
    "Open the full size \"{name}\" image" : "Otvoriť fotografiu „{name}“ v pôvodnej veľkosti",
    "Select image {imageName}" : "Vybrať obrázok {imageName}",
    "Open the \"{name}\" folder" : "Otvoriť adresár \"{name}\"",
    "Go back" : "Ísť späť",
    "Dates" : "Dátumy",
    "Jump to specific date in list" : "Preskočiť na konkrétny dátum v zozname",
    "Jump to {date}" : "Preskočiť na {date}",
    "Add to {destination}" : "Pridať do {destination}",
    "The destination folder is owned by {owner}" : "Cieľový priečinok vlastní {owner}",
    "There are no photos or videos yet!" : "Zatiaľ tu nie sú žiadne fotky alebo videá!",
    "_{years} year ago_::_{years} years ago_" : ["pred {years} rokom","pred {years} rokmi","pred {years} rokmi","pred {years} rokmi"],
    "Enable squared photos view" : "Zapnúť štvorcové zobrazenie fotiek",
    "Delete source directory" : "Vymazať zdrojový adresár",
    "Pick folder" : "Vyberte adresár",
    "Select a source folder for your media" : "Vyberte zdrojový adresár pre vaše médiá.",
    "All folders" : "Všetky adresáre",
    "Add a Photos source for the timelines" : "Pridajte zdroj fotografií pre časové osi",
    "Add folder" : "Pridať priečinok",
    "Select the default upload location for your media" : "Vyberte predvolené umiestnenie pre vaše médiá",
    "Home" : "Domov",
    "Choose default Photos upload and Albums location" : "Vyberte predvolené umiestnenie pre nahrávané fotky a albumy",
    "Choose a different folder" : "Vyberte iný priečinok",
    "View" : "Prezerať",
    "Media folders" : "Adresáre médií",
    "Choose the folders from where photos and videos are shown." : "Vyberte priečinky, v ktorých sa budú zobrazovať fotografie a videá.",
    "Upload folder" : "Nahrať priečinok",
    "Choose the folder where photos and albums are uploaded to." : "Vyberte priečinok, do ktorého sa budú nahrávať fotografie a albumy.",
    "_%n photo_::_%n photos_" : ["%n fotka","%n fotky","%n fotiek","%n fotiek"],
    "Unselect all" : "Zrušiť výber",
    "Add photos to this album" : "Pridať fotky do tohto albumu",
    "Manage collaborators for this album" : "Spravovať spolupracovníkov pre tento album",
    "Open actions menu" : "Otvoriť ponuku akcií",
    "Edit album details" : "Upraviť podrobnosti o albume",
    "Download all files in album" : "Stiahnuť všetky súbory z albumu",
    "Delete album" : "Zmazať album",
    "Download selected files" : "Stiahnuť vybrané súbory",
    "Remove selection from album" : "Odstrániť vybrané z albumu",
    "This album does not have any photos or videos yet!" : "Tento album zatiaľ neobsahuje žiadne fotky alebo videá!",
    "Add photos to {albumName}" : "Pridať fotky do {albumName}",
    "Manage collaborators" : "Spravovať spolupracovníkov",
    "Save collaborators for this album." : "Uložiť spolupracovníkov pre tento album.",
    "Cover photo for album {albumName}" : "Titulná fotka pre album {albumName}",
    "There is no album yet!" : "Zatiaľ tu nie je žiadny album!",
    "This person could not be found" : "Túto osobu sa nepodarilo nájisť",
    "Rename person" : "Premenovať osobu",
    "Merge with different person" : "Zlúčiť s inou osobou",
    "Download selected photos" : "Stiahnuť vybrané fotky",
    "Remove from favorites" : "Odstrániť z obľúbených",
    "Remove person" : "Odstrániť osobu",
    "Name of this person" : "Meno tejto osoby",
    "Save." : "Uložiť.",
    "Merge person" : "Zlúčiť osobu",
    "Move to different person" : "Presunúť na inú osobu",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Presunúť fotografiu na inú osobu.","Presunúť fotografie na inú osobu","Presunúť fotografie na inú osobu","Presunúť fotografie na inú osobu"],
    "_Remove photo from person_::_Remove photos from person_" : ["Odstrániť fotku z osoby","Odstrániť fotky z osoby","Odstrániť fotky z osoby","Odstrániť fotky z osoby"],
    "This might take some time depending on the size of your photo library." : "Toto môže chvíľu trvať v závislosti od veľkosti vašej knižnice fotografií.",
    "Recognized people will show up here" : "Rozpoznané osoby sa zobrazia tu",
    "This folder does not exist" : "Tento priečinok neexistuje",
    "Loading folders …" : "Načítavanie priečinkov ...",
    "No photos in here" : "Nie sú tu žiadne fotografie",
    "Taken on {date} at {time}" : "Vytvorené dňa {date} o {time}",
    "This place does not have any photos or videos yet!" : "Tento miesto zatiaľ neobsahuje žiadne fotky alebo videá!",
    "Add photos to this place" : "Pridať fotky do tohto miesta",
    "Cover photo for place {placeName}" : "Titulná fotografia pre miesto {placeName}",
    "There is no place yet!" : "Zatiaľ tu nie je žiadne miesto!",
    "Cover photo for shared album {albumName}" : "Titulná fotka pre zdieľaný album {albumName}",
    "Back to tags overview" : "Späť k prehladu štítkov",
    "No photos with this tag yet" : "Zatiaľ nie sú žiadne fotky s týmto štítkom",
    "No tags yet" : "Zatiaľ žiadne štítky",
    "Photos with tags will show up here" : "Fotografie so štítkami sa zobrazia tu",
    "Popular tags" : "Populárne štítky",
    "All tags" : "Všetky štítky",
    "One of the source folders does not exist" : "Jeden zo zdrojových priečinkov neexistuje",
    "Add to album" : "Pridať do albumu",
    "Delete selection" : "Vymazať výber",
    "No photos or videos in here" : "Nie sú tu žiadne obrázky ani videá",
    "Unassigned faces" : "Nepriradené tváre",
    "Failed to fetch collection." : "Zlyhalo načítanie kolekcie.",
    "Failed to fetch collections list." : "Zlyhalo načítanie zoznamu kolekcií.",
    "Failed to fetch faces list." : "Nepodarilo sa načítať zoznam tvárí.",
    "Error fetching files" : "Chyba pri získavaní súborov",
    "All your media" : "Všetky vaše médiá",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "Zdieľané albumy",
    "Shared album {title}" : "Zdieľaný album {title}",
    "Public album {title}" : "Verejný album {title}",
    "Tagged photos" : "Fotografie so štítkom",
    "Tagged photo {title}" : "Fotografia so štítkom {title}",
    "{title}'s face" : "Tvár {title}",
    "{startDate} to {endDate}" : "{startDate} do {endDate}",
    "Details" : "Podrobnosti",
    "Failed to delete {fileBaseName}" : "Nepodarilo sa vymazať {fileBaseName}",
    "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "Nepodarilo sa premenovať {currentCollectionFileName} na {newCollectionFileName}",
    "Failed to delete {collectionFileName}" : "Nepodarilo sa vymazať {collectionFileName}",
    "Failed to rename {oldName} to {faceName}" : "Nepodarilo sa premenovať {oldName} na {faceName}",
    "Failed to delete {faceName}" : "Nepodarilo sa vymazať {faceName}",
    "Failed to delete {fileId}" : "Nepodarilo sa vymazať {fileId}",
    "Failed to delete {fileName}" : "Nepodarilo sa vymazať {fileName}",
    "Failed to set favorite state for {fileId}" : "Nepodarilo sa nastaviť obľúbený stav pre {fileId}",
    "Failed to set favorite state for {fileName}" : "Nepodarilo sa nastaviť obľúbený stav pre {fileName}",
    "Could not load photos folder" : "Nepodarilo sa načítať priečinok s fotkami",
    "Back to {folder}" : "Späť do {folder}",
    "Share this folder" : "Zdieľať tento priečinok",
    "One of the source folders does not exists" : "Jeden zo zdrojových priečinkov neexistuje",
    "Add" : "Pridať"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
