OC.L10N.register(
    "circles",
    {
    "Teams" : "Takımlar",
    "You created the team {circle}" : "{circle} takımını eklediniz",
    "{author} created the team {circle}" : "{author}, {circle} takımını ekledi",
    "You deleted {circle}" : "{circle} takımını sildiniz",
    "{author} deleted {circle}" : "{author}, {circle} takımını sildi",
    "You made {member} join {circle}" : "{member} üyesini {circle} takımına kattınız",
    "{author} made {member} join {circle}" : "{author}, {member} üyesini {circle} takımına kattı",
    "You added team {member} as member to {circle}" : "{member} üyesini {circle} takımına eklediniz",
    "{author} added team {member} as member to {circle}" : "{author}, {member} üyesini {circle} takımına ekledi",
    "You made {member} leave {circle}" : "{member} üyesini {circle} takımından çıkardınız",
    "{author} made {member} leave {circle}" : "{author}, {member} üyesini {circle} takımından çıkardı",
    "You removed {member} from {circle}" : "{member} üyesini {circle} takımından çıkardınız",
    "{author} removed {member} from {circle}" : "{author},  {member} üyesini {circle} takımından çıkardı",
    "You joined {circle}" : "{circle} takımına katıldınız",
    "{member} joined {circle}" : "{member}, {circle} takımına katıldı",
    "You accepted the invitation to join {circle}" : "{circle} takımına katılma davetini kabul ettiniz",
    "{member} accepted the invitation to join {circle}" : "{member}, {circle} takımına katılma davetini kabul etti",
    "You added {member} as member to {circle}" : "{member} üyesini {circle} takımına eklediniz",
    "You have been added as member to {circle} by {author}" : "{author} tarafından {circle} takımına eklendiniz",
    "{member} has been added as member to {circle} by {author}" : "{member}, {author} tarafından {circle} takımına eklendi",
    "You added {external} to {circle}" : "{external} kullanıcısını {circle} takımına eklediniz",
    "{external} has been added to {circle} by {author}" : "{external}, {author} tarafından {circle} takımına eklendi",
    "You accepted {member}'s request to join {circle}" : "{member} üyesinin {circle} takımına katılma isteğini kabul ettiniz",
    "Your request to join {circle} has been accepted by {author}" : "{circle} takımına katılma isteğiniz {author} tarafından kabul edildi",
    "{member}'s request to join {circle} has been accepted by {author}" : "{member} üyesinin {circle} takımına katılma isteği  {author} tarafından kabul edildi",
    "You left {circle}" : "{circle} takımından ayrıldınız",
    "{member} left {circle}" : "{member}, {circle} takımından ayrıldı",
    "You declined the invitation to join {circle}" : "{circle} takımına katılma davetini geri çevirdiniz",
    "{member} declined an invitation to join {circle}" : "{member}, {circle} takımına katılma davetini geri çevirdi",
    "You cancelled your request to join {circle}" : "{circle} takımına gönderdiğiniz katılma isteğini iptal ettiniz",
    "{member} cancelled a request to join {circle}" : "{member}, {circle} takımına gönderdiği katılma isteğini iptal etti",
    "You have been removed from {circle} by {author}" : "{author} tarafından {circle} takımından çıkarıldınız",
    "{member} has been removed from {circle} by {author}" : "{member}, {author} tarafından {circle} takımından çıkarıldı",
    "You removed {external} from {circle}" : "{external} kullanıcısını {circle} takımından çıkardınız",
    "{external} has been removed from {circle} by {author}" : "{external}, {author} tarafından {circle} takımından çıkarıldı",
    "You cancelled {member}'s invitation to join {circle}" : "{member} üyesine gönderilen {circle} takımına katılma davetini iptal ettiniz",
    "Your invitation to join {circle} has been cancelled by {author}" : "{circle} takımına katılmanız için yapılan davet {author} tarafından iptal edildi",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author}, {member} üyesine gönderilen {circle} takımına katılma davetini iptal etti",
    "You dismissed {member}'s request to join {circle}" : "{member} üyesinin {circle} takımına katılma isteğini reddettiniz",
    "Your request to join {circle} has been dismissed by {author}" : "{circle} takımına yaptığınız katılma isteği {author} tarafından reddedildi",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{member} üyesinin {circle} takımına katılma isteği  {author} tarafından reddedildi",
    "You invited {member} to join {circle}" : "{member} üyesini {circle} takımına katılmaya davet ettiniz",
    "You have been invited to join {circle} by {author}" : "{author} tarafından {circle} takımına katılmaya davet edildiniz",
    "{member} has been invited to join {circle} by {author}" : "{member}, {author} tarafından {circle} takımına katılmaya davet edildi",
    "You changed {member}'s level in {circle} to %1$s" : "{member} üyesinin {circle} takımındaki düzeyini %1$s olarak değiştirdiniz",
    "{author} changed your level in {circle} to %1$s" : "{author}, circle} takımındaki düzeyinizi %1$s olarak değiştirdi",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author}, {member} üyesinin {circle} takımındaki düzeyini %1$s olarak değiştirdi",
    "You sent a request to join {circle}" : "{circle} takımına katılma isteği gönderdiniz",
    "{member} sent a request to join {circle}" : "{member} üyesi {circle} takımına katılma isteği gönderdi",
    "You are the new owner of {circle}" : "Artık {circle} takımının sahibisiniz",
    "{member} is the new owner of {circle}" : "{member}, artık {circle} takımının sahibi",
    "On events happening in a <strong>team</strong> of which you are a member" : "Üyesi olduğunuz bir <strong>takımdaki</strong> olaylarda",
    "Any important event in a <strong>team</strong> you are moderating" : "Sorumlusu olduğunuz bir <strong>takımdaki</strong> önemli olaylarda",
    "On global events happening in any <strong>team</strong>" : "Herhangi bir <strong>takımdaki</strong> genel olaylarda",
    "Single" : "Tek",
    "Personal" : "Kişisel",
    "System" : "Sistem",
    "Visible" : "Görünür",
    "Open" : "Aç",
    "Invite" : "Davet et",
    "Join request" : "Katılma isteği",
    "Friends" : "Arkadaşlar",
    "Password protected" : "Parola korumalı",
    "No Owner" : "Sahibi yok",
    "Hidden" : "Gizli",
    "Backend" : "Yönetim bölümü",
    "Local" : "Yerel",
    "Root" : "Kök",
    "Team invite" : "Takım daveti",
    "Federated" : "Birleşik",
    "Mount point" : "Bağlama noktası",
    "Nextcloud Account" : "Nextcloud hesabı",
    "Nextcloud Group" : "Nextcloud grubu",
    "Email address" : "E-posta adresi",
    "Contact" : "Kişi",
    "Circle" : "Takım",
    "Nextcloud App" : "Nextcloud uygulaması",
    "Member" : "Üye",
    "Moderator" : "Sorumlu",
    "Admin" : "Yönetici",
    "Owner" : "Sahip",
    "%s shared »%s« with you." : "%s sizinle »%s« ögesini paylaştı.",
    "%s shared »%s« with \"%s\"." : "%s,  »%s« dosyasını \"%s\" ile paylaştı.",
    "%s on %s" : "%s %s zamanında",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s sizinle »%2$s« ögesini paylaştı.\nErişim bağlantısını içeren başka bir e-posta daha almış olmalısınız.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s sizinle »%2$s« ögesini paylaştı. Erişim bağlantısını içeren başka bir e-posta daha almış olmalısınız.",
    "Password to access »%1$s« shared to you by %2$s" : "»%1$s« için sizin tarafınızdan %2$s üzerinden paylaşılan erişim parolası",
    "Password to access »%s«" : "»%s« erişim parolası",
    "It is protected with the following password:" : "Şu parola ile korunuyor:",
    "%1$s via %2$s" : "%1$s, %2$s aracılığıyla",
    "Click the button below to open it." : "Açmak için aşağıdaki düğmeye tıklayın.",
    "Open »%s«" : "»%s« aç",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s sizinle birkaç dosya paylaştı.\nErişim bağlantısını içeren başka bir e-posta daha almış olmalısınız.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s sizinle birkaç dosya paylaştı. Erişim bağlantısını içeren başka bir e-posta daha almış olmalısınız.",
    "Password to access files shared to you by %1$s" : "Sizin tarafınızdan %1$s üzerinde paylaşılan dosyalara erişim parolası",
    "Password to access files" : "Dosyalara erişim parolası",
    "%s shared multiple files with \"%s\"." : "%s, \"%s\" ile birkaç dosya paylaştı.",
    "%s shared multiple files with you." : "%s sizinle birkaç dosya paylaştı.",
    "Boot up" : "Başlatma",
    "Nextcloud Initialization" : "Nextcloud başlatılıyor",
    "Circles App Initialization" : "Takımlar uygulaması başlatılıyor",
    "Fresh installation status" : "Yeni kurulum durumu",
    "Building Local Database" : "Yerel veri tabanı oluşturuluyor",
    "Testing Basic Circle Creation" : "Temel takım oluşturma sınanıyor",
    "Adding local users and moderators" : "Yerel kullanıcılar ve sorumlular ekleniyor",
    "Show all teams" : "Tüm takımları görüntüle",
    "Create a new team" : "Yeni takım ekle",
    "Files" : "Dosyalar",
    "This feature is not available for personal circles" : "Bu özellik kişisel takımlarda kullanılamaz",
    "The team is not federated" : "Takım birleşik değil",
    "You cannot join this team" : "Bu takıma katılamazsınız",
    "This member is not a moderator" : "Bu üye bir sorumlu değil",
    "Insufficient privileges" : "İzinler yetersiz",
    "This member does not exist" : "Bu üye bulunamadı",
    "This member is the owner of the team" : "Bu üye takımın sahibi",
    "Level cannot be changed for this type of member" : "Bu üye türünün düzeyi değiştirilemez",
    "You are already a member of this circle" : "Zaten bu takımın bir üyesisiniz",
    "You have been blocked from this circle" : "Bu takımda engellenmişsiniz",
    "The account is already a member of this circle" : "Hesap zaten bu takımın bir üyesi",
    "The account has already been invited into this circle" : "Hesap zaten bu takıma katılması için davet edilmiş",
    "%s (Team owned by %s)" : "%s (Takım sahibi %s)",
    "You are now a member of the Team \"%2$s\"" : "Artık \"%2$s\" takımının üyesisiniz",
    "You have been invited by %1$s into the Team \"%2$s\"" : "%1$s tarafından \"%2$s\" takımına davet edildiniz",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s, \"%2$s\" takımına üye olma isteğinde bulundu",
    "Accept" : "Kabul et",
    "Refuse" : "Reddet",
    "Leave the team" : "Takımdan ayrıl",
    "%s" : "%s",
    "Personal team" : "Kişisel takım",
    "%s owned by %s" : "%s sahibi %s",
    "You have no permission to create a new team" : "Yeni bir takım ekleme izniniz yok",
    "%s shared a file with \"%s\"." : "%s, \"%s\" ile bir dosya paylaştı.",
    "%s shared a file with you." : "%s sizinle bir dosya paylaştı.",
    "Open %s" : "%s ögesini aç",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s sizinle bir içerik paylaştı.\nErişim bağlantısını içeren başka bir e-posta daha almış olmalısınız.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s sizinle bir içerik paylaştı. Erişim bağlantısını içeren başka bir e-posta daha almış olmalısınız.",
    "Password to access content shared with you by %1$s" : "%1$s tarafından sizinle paylaşılan içeriğe erişme parolası",
    "Password to access content" : "İçeriğe erişme parolası",
    "This item is already shared with this team" : "Bu öge zaten bu takım ile paylaşılmış",
    "Bring cloud-users closer together." : "Bulut kullanıcılarını bir araya getirir.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Takımlar, kişilerin kendi kişi/iş arkadaşı/arkadaş gruplarını oluşturmasını sağlar.\nBu kişi grupları başka uygulamalar tarafından paylaşım amacıyla kullanılabilir.",
    "No files in here" : "Burada herhangi bir dosya yok",
    "No entries found in this folder" : "Bu klasörde herhangi bir kayıt yok",
    "Name" : "Ad",
    "Size" : "Boyut",
    "Modified" : "Değiştirilme",
    "Teams' files" : "Takımların dosyaları",
    "Select team to filter by" : "Süzülecek takımı seçin",
    "No teams found" : "Herhangi bir takım bulunamadı",
    "Please select teams to filter by" : "Lütfen süzülecek takımları seçin",
    "No files found for the selected teams" : "Seçilmiş takımlara uyan bir dosya bulunamadı",
    "Shared to Circles" : "Takımlarla paylaşıldı"
},
"nplurals=2; plural=(n > 1);");
