OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Mankas pasvorto de la restaŭroŝlosilo",
    "Please repeat the recovery key password" : "Bv. ripeti la pasvorton de restaŭroŝlosilo",
    "Repeated recovery key password does not match the provided recovery key password" : "La du pasvortoj pri la restaŭroŝlosilo ne kongruas",
    "Recovery key successfully enabled" : "Restaŭroŝlosilo sukcese ebligita",
    "Could not enable recovery key. Please check your recovery key password!" : "Restaŭroŝlosilo ne povis esti ŝaltita. Bv. kontroli vian pasvorton de restaŭroŝlosilo!",
    "Recovery key successfully disabled" : "Restaŭroŝlosilo sukcese malŝaltita",
    "Could not disable recovery key. Please check your recovery key password!" : "Restaŭroŝlosilo ne povis esti malŝaltita. Bv. kontroli vian pasvorton de restaŭroŝlosilo!",
    "Missing parameters" : "Mankas parametroj",
    "Please provide the old recovery password" : "Bv. doni la malnovan pasvorton de restaŭroŝlosilo",
    "Please provide a new recovery password" : "Bv. doni la novan pasvorton de restaŭroŝlosilo",
    "Please repeat the new recovery password" : "Bv. ripeti la novan pasvorton de restaŭroŝlosilo",
    "Password successfully changed." : "La pasvorto sukcese ŝanĝiĝis.",
    "Could not change the password. Maybe the old password was not correct." : "Ne eblis ŝanĝi la pasvorton. Eble la malnova pasvorto malĝustis.",
    "Recovery Key disabled" : "Restaŭroŝlosilo malŝaltita",
    "Recovery Key enabled" : "Restaŭroŝlosilo ŝaltita",
    "Could not enable the recovery key, please try again or contact your administrator" : "Restaŭroŝlosilo ne povis esti ŝaltita. Bv. re-provi aŭ kontakti vian administranton.",
    "Could not update the private key password." : "Ne eblis ĝisdatigi la pasvorton de restaŭroŝlosilo.",
    "The old password was not correct, please try again." : "La malnova pasvorto malĝustas. Provu denove.",
    "The current log-in password was not correct, please try again." : "La aktuala ensalutpasvorto ne ĝustas. Bv. provi denove.",
    "Private key password successfully updated." : "La pasvorto de la privata ŝlosilo sukcese ĝisdatiĝis.",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Nevalida privata ŝlosilo por la ĉifra aplikaĵo. Bv. ĝisdatigi la pasvorton de via privata ŝlosilo en viaj personaj agordoj por povi realiri al viaj ĉifritajn dosierojn.",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "Ĉifra aplikaĵo estas ŝaltita, sed viaj ŝlosiloj ne uziĝas. Bv. elsaluti kaj re-ensaluti.",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "Bv. ŝalti la ĉeservilan ĉifradon en la administraj agordoj por uzi la ĉifran modulon.",
    "Encryption app is enabled and ready" : "La ĉifra aplikaĵo estas ŝaltita kaj preta",
    "Bad Signature" : "Malbona subskribo",
    "Missing Signature" : "Mankanta subskribo",
    "one-time password for server-side-encryption" : "unuuza pasvorto por ĉeservila ĉifrado",
    "Default encryption module" : "Defaŭlta ĉifra modulo",
    "Default encryption module for server-side encryption" : "Defaŭlta ĉifra modulo por ĉeservila ĉifrado",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "Ĉifra aplikaĵo estas ŝaltita, sed viaj ŝlosiloj ne uziĝas. Bv. elsaluti kaj re-ensaluti.",
    "Encrypt the home storage" : "Ĉifri la ĉefkonservejon",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Ebligi tiun opcion ĉifras ĉiujn dosierojn de la ĉefkonservejo, alie nur dosieroj en ekstera konservejo ĉifriĝos.",
    "Enable recovery key" : "Ŝalti restaŭroŝlosilon",
    "Disable recovery key" : "Malŝalti restaŭroŝlosilon",
    "Recovery key password" : "Pasvorto de restaŭroŝlosilo",
    "Repeat recovery key password" : "Ripetu la pasvorton de restaŭroŝlosilo",
    "Change recovery key password:" : "Ŝanĝi la pasvorton de la restaŭroŝlosilo:",
    "Old recovery key password" : "Malnova pasvorto de restaŭroŝlosilo",
    "New recovery key password" : "Nova pasvorto de restaŭroŝlosilo",
    "Repeat new recovery key password" : "Ripetu la novan pasvorton de restaŭroŝlosilo",
    "Change Password" : "Ŝanĝi pasvorton",
    "Basic encryption module" : "Bazĉifrada modulo",
    "Your private key password no longer matches your log-in password." : "La pasvorto de via privata ŝlosilo ne plu kongruas kun via ensaluta pasvorto.",
    "Set your old private key password to your current log-in password:" : "Agordi la pasvorton de via antaŭa privata ŝlosilo al via nuna ensaluta pasvorto:",
    "Old log-in password" : "Malnova ensaluta pasvorto",
    "Current log-in password" : "Nuna ensaluta pasvorto",
    "Update Private Key Password" : "Ĝisdatigi la pasvorton de la malpublika ŝlosilo",
    "Enable password recovery:" : "Ŝalti restaŭron de pasvorto:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Ŝalti tiun opcion ebligas al vi rehavi aliron al viaj ĉifritaj dosierojn okaze de pasvorta perdo.",
    "Enabled" : "Ŝaltita",
    "Disabled" : "Malŝaltita"
},
"nplurals=2; plural=(n != 1);");
