OC.L10N.register(
    "logreader",
    {
    "Logging" : "Registro",
    "Log Reader" : "Lector de registro",
    "A log reader for Nextcloud" : "Un lector de registro para Nextcloud",
    "Log reader for Nextcloud" : "Lector de registro para Nextcloud",
    "Level" : "Nivel",
    "App" : "Aplicación",
    "Time" : "Hora",
    "Download logs" : "Descargar registros",
    "Relative" : "Relativo",
    "Message" : "Mensaje",
    "Show details" : "Mostrar detalles",
    "Info" : "Info",
    "Warning" : "Advertencia",
    "Error" : "Error"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
