OC.L10N.register(
    "comments",
    {
    "Comments" : "Σχόλια",
    "You commented" : "Σχολιάσατε",
    "{author} commented" : "Ο {author} σχολίασε",
    "You commented on %1$s" : "Σχολιάσατε στο %1$s",
    "You commented on {file}" : "Σχολιάσατε στο {file}",
    "%1$s commented on %2$s" : "%1$s σχολίασε στο %2$s",
    "{author} commented on {file}" : "Ο {author} σχολίασε στο {file}",
    "<strong>Comments</strong> for files" : "<strong>Σχόλια</strong> για αρχεία",
    "Files" : "Αρχεία",
    "{user} mentioned you in a comment on \"{file}\"" : "Ο/η {user} σας ανέφερε σε σχόλιο στο “{file}”",
    "Files app plugin to add comments to files" : "Επέκταση της εφαρμογής Αρχεία που επιτρέπει την προσθήκη σχολίων σε αρχεία",
    "Edit comment" : "Επεξεργασία σχολίου",
    "Delete comment" : "Διαγραφή σχολίου",
    "Cancel edit" : "Ακύρωση επεξεργασίας",
    "New comment" : "Νέο σχόλιο",
    "Post comment" : "Αναρτήστε σχόλιο",
    "Unable to load the comments list" : "Δεν είναι δυνατή η μεταφόρτωση της λίστας σχολίων.",
    "No comments yet, start the conversation!" : "Δεν υπάρχουν σχόλια, ξεκινήστε την συζήτηση!",
    "No more messages" : "Δεν υπάρχουν άλλα μηνύματα",
    "Retry" : "Δοκιμή ξανά",
    "_1 new comment_::_{unread} new comments_" : ["1 νέο σχόλιο","{unread} νέα σχόλια"],
    "Comment" : "Σχόλιο",
    "An error occurred while trying to edit the comment" : "Παρουσιάστηκε σφάλμα κατά την προσπάθεια επεξεργασίας του σχολίου",
    "Comment deleted" : "Το σχόλιο διαγράφηκε",
    "An error occurred while trying to delete the comment" : "Παρουσιάστηκε σφάλμα κατά την προσπάθεια διαγραφής του σχολίου",
    "An error occurred while trying to create the comment" : "Παρουσιάστηκε σφάλμα κατά την προσπάθεια δημιουργίας του σχολίου"
},
"nplurals=2; plural=(n != 1);");
