OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Канал на лични активности за %s",
    "Your feed URL is invalid" : "Вашиот URL канал не е исправен",
    "Activity feed for %1$s" : "Листа на активности за %1$s",
    "Activity feed" : "Канал на активности",
    "Your settings have been updated." : "Вашите параметри се ажурирани.",
    "Settings have been updated." : "Параметрите се ажурирани.",
    "remote user" : "оддалечен корисник",
    "Recent activity" : "Неодамнешни активности",
    "No activities" : "Нема активности",
    "More activities" : "Повеќе активности",
    "Daily activity summary for %s" : "Дневно резиме на активности за %s",
    "_and %n more…_::_and %n more…_" : ["и %n ","и %n други…"],
    "All activities" : "Сите активности",
    "By others" : "Од други",
    "By you" : "Од вас",
    "Activity at %s" : "Активност во %s",
    "Hello %s" : "Здраво %s",
    "Hello %s," : "Здраво %s,",
    "There was some activity at %s" : "Имаше активност во %s",
    "_and %n more _::_and %n more _" : ["и уште %n","и %n други"],
    "Mail" : "Електронска пошта",
    "Push" : "Пуш",
    "Activity" : "Активност",
    "Notifications" : "Известувања",
    "This application enables people to view a log of activities about them, their files or other data." : "Оваа апликација им овозможува на корисниците да ги прегледаат записите од промените, нивните датотеки или на други податоци.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation.",
    "Send email" : "Испрати е-пошта",
    "Send push notification" : "Испрати PUSH известување",
    "Activity notification configuration" : "Параметри за известување и активност",
    "Today" : "Денес",
    "Yesterday" : "Вчера",
    "You need to set up your email address before you can receive notification emails." : "Треба да ја внесете Вашата адреса на е-пошта за да можете да примате известувања по електронска пошта.",
    "Send activity emails" : "Испрати активности на е-пошта",
    "As soon as possible" : "Што побрзо",
    "Hourly" : "Часовно",
    "Daily" : "Дневно",
    "Weekly" : "Неделно",
    "You commented" : "Kоментиравте",
    "Message deleted by author" : "Пораката е избришана од авторот",
    "Open {filename}" : "Отвори {filename}",
    "in {path}" : "во {path}",
    "Home" : "Дома",
    "Could not load activities" : "Неможе да се вчитаат активностите",
    "Loading activities" : "Вчитување активности",
    "This stream will show events like additions, changes & shares" : "Овој стрим ќе прикажува настани како додатоци, промени и споделувања",
    "No activity yet" : "Сеуште нема активности",
    "Loading more activities" : "Вчитај повеќе активности",
    "No more activities." : "Нема повеќе активности",
    "Could not enable RSS link" : "Неможе да се овозможи RSS линк",
    "RSS link copied to clipboard" : "RSS линкот е копиран во клипборд",
    "Could not copy the RSS link, please copy manually:" : "Неможе да се копира RSS линкот. Ве молиме копирајте ја рачно:",
    "Activity settings" : "Праметри за активности",
    "Enable RSS feed" : "Овозможи RSS канал",
    "RSS feed" : "RSS канал",
    "Copy RSS feed link" : "Копирај RSS линк",
    "Personal notification settings" : "Персонални параметри за известување",
    "Unable to load the activity list" : "Неможе да се вчита листата на активности",
    "Choose for which activities you want to get an email or push notification." : "Изберете за кои активности сакате да добиете е-пошта или Пуш известување.",
    "Choose for which activities you want to get a push notification." : "Изберете за кои активности сакате да добиете Пуш известување.",
    "Notification" : "Известување",
    "Enable notification emails" : "Овозможи известување на E-пошта",
    "Daily activity summary" : "Дневно резиме на активности",
    "Send daily activity summary in the morning" : "Испрати дневно резиме на активности наутро",
    "Default settings" : "Стандардни поставки",
    "Configure the default notification settings for new accounts." : "Конфигурирај ги стандардните поставки за известување за нови корисници.",
    "Unable to save the settings" : "Неуспешно зачувување на параметрите",
    "No more events to load" : "Нема повеќе настани за вчитување"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
