OC.L10N.register(
    "recommendations",
    {
    "Recommended files" : "تەۋسىيە قىلىنغان ھۆججەتلەر",
    "Recommendations" : "تەۋسىيە",
    "Shows recommended files" : "تەۋسىيە قىلىنغان ھۆججەتلەرنى كۆرسىتىدۇ",
    "Shows recommended files for quick access of files and folders with recent activity" : "يېقىنقى پائالىيەتلەر بىلەن ھۆججەت ۋە ھۆججەت قىسقۇچلارنى تېز زىيارەت قىلىش ئۈچۈن تەۋسىيە قىلىنغان ھۆججەتلەرنى كۆرسىتىدۇ",
    "No recommendations yet" : "تېخى تەۋسىيە يوق",
    "Path name {path}" : "يول ئىسمى {path}",
    "Show recommendations" : "تەۋسىيە كۆرسەت",
    "Recently commented" : "يېقىندا باھا بەردى",
    "Recently edited" : "يېقىندا تەھرىرلەندى",
    "Recently shared" : "يېقىندا ھەمبەھىرلەندى"
},
"nplurals=2; plural=(n != 1);");
