OC.L10N.register(
    "provisioning_api",
    {
    "Logged in account must be an administrator or have authorization to edit this setting." : "Zalogowane konto musi być administratorem lub mieć uprawnienia do edycji tego ustawienia.",
    "Could not create non-existing user ID" : "Nie można utworzyć nieistniejącego identyfikatora użytkownika",
    "User already exists" : "Użytkownik już istnieje",
    "Group %1$s does not exist" : "Grupa %1$s nie istnieje",
    "Insufficient privileges for group %1$s" : "Niewystarczające uprawnienia do grupy %1$s",
    "No group specified (required for sub-admins)" : "Nie określono grupy (wymagane dla podadministratorów)",
    "Sub-admin group does not exist" : "Grupa podadministratorów nie istnieje",
    "Cannot create sub-admins for admin group" : "Nie można tworzyć podadministratorów dla grupy administratorów",
    "No permissions to promote sub-admins" : "Brak uprawnień do promowania podadministratorów",
    "Invalid password value" : "Nieprawidłowa wartość hasła",
    "An email address is required, to send a password link to the user." : "Wymagany jest adres e-mail, aby wysłać użytkownikowi link do ustawienia hasła.",
    "Required email address was not provided" : "Nie podano wymaganego adresu e-mail",
    "User creation failed" : "Nie udało się utworzyć użytkownika",
    "Invalid quota value: %1$s" : "Nieprawidłowa wartość limitu: %1$s",
    "Invalid quota value. %1$s is exceeding the maximum quota" : "Nieprawidłowy limit. %1$s przekracza maksymalny dopuszczalny limit",
    "Unlimited quota is forbidden on this instance" : "Nieograniczony limit jest zabroniony na tej instancji",
    "Setting the password is not supported by the users backend" : "Ustawianie hasła nie jest obsługiwane przez backend użytkowników",
    "Invalid language" : "Nieprawidłowy język",
    "Invalid locale" : "Nieprawidłowa lokalizacja",
    "Invalid first day of week" : "Nieprawidłowy pierwszy dzień tygodnia",
    "Cannot remove yourself from the admin group" : "Nie możesz usunąć siebie z grupy administratorów",
    "Cannot remove yourself from this group as you are a sub-admin" : "Nie możesz usunąć siebie z tej grupy, ponieważ jesteś jej podadministratorem",
    "Not viable to remove user from the last group you are sub-admin of" : "Nie można usunąć użytkownika z ostatniej grupy, której jest podadministratorem",
    "User does not exist" : "Użytkownik nie istnieje",
    "Group does not exist" : "Grupa nie istnieje",
    "User is not a sub-admin of this group" : "Użytkownik nie jest podadministratorem tej grupy",
    "Email address not available" : "Adres e-mail niedostępny",
    "Sending email failed" : "Wysyłanie e-maila nie powiodło się",
    "Email confirmation" : "Potwierdzenie e-mailem",
    "To enable the email address %s please click the button below." : "Aby włączyć adres e-mail %s, kliknij poniższy przycisk.",
    "Confirm" : "Potwierdź",
    "Email was already removed from account and cannot be confirmed anymore." : "E-mail został już usunięty z konta i nie można go już potwierdzić.",
    "Could not verify mail because the token is expired." : "Nie można zweryfikować poczty, ponieważ token wygasł.",
    "Could not verify mail because the token is invalid." : "Nie można zweryfikować poczty, ponieważ token jest nieprawidłowy.",
    "An unexpected error occurred. Please contact your admin." : "Wystąpił nieoczekiwany błąd. Skontaktuj się z administratorem.",
    "Email confirmation successful" : "Potwierdzenie e-maila powiodło się",
    "Provisioning API" : "API obsługi administracyjnej",
    "This application enables a set of APIs that external systems can use to manage accounts, groups and apps." : "Ta aplikacja umożliwia zestaw interfejsów API, które zewnętrzne systemy mogą wykorzystać do zarządzania kontami, grupami i aplikacjami.",
    "This application enables a set of APIs that external systems can use to create, edit, delete and query account\n\t\tattributes, query, set and remove groups, set quota and query total storage used in Nextcloud. Group admin accounts\n\t\tcan also query Nextcloud and perform the same functions as an admin for groups they manage. The API also enables\n\t\tan admin to query for active Nextcloud applications, application info, and to enable or disable an app remotely.\n\t\tOnce the app is enabled, HTTP requests can be used via a Basic Auth header to perform any of the functions\n\t\tlisted above. More information is available in the Provisioning API documentation, including example calls\n\t\tand server responses." : "Ta aplikacja udostępnia zestaw interfejsów API, które zewnętrzne systemy mogą wykorzystać do tworzenia, edytowania, usuwania i wyszukiwania kont użytkowników,\n\t\tatrybutów, zapytań, ustawiania i usuwania grup, limitów oraz zapytań o całkowite wykorzystanie przestrzeni w Nextcloud. Konta administratorów grup\n\t\tmogą również wykonywać zapytania do Nextcloud i działać jak administrator dla grup, którymi zarządzają. API umożliwia też administratorowi pobieranie aktywnych aplikacji, ich identyfikatorów, oraz włączanie lub wyłączanie aplikacji zdalnie.\n\t\tPo włączeniu aplikacji, zapytania HTTP mogą być wykonywane z nagłówkiem uwierzytelniającym Basic Auth, aby korzystać z funkcji\n\t\twymienionych powyżej. Więcej informacji znajduje się w dokumentacji API Provisioning, w tym przykładowe wywołania\n\t\ti odpowiedzi serwera."
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
