OC.L10N.register(
    "files_trashbin",
    {
    "restored" : "gjenopprettet",
    "Deleted files" : "Slettede filer",
    "Deleted files and folders in the trash bin (may expire during export if you are low on storage space)" : "Slettede filer og mapper i papirkurven (kan utløpe under eksport hvis du har lite lagringsplass)",
    "This application enables people to restore files that were deleted from the system." : "Denne applikasjonen lar personer gjenopprette filer som ble slettet fra systemet.",
    "This application enables people to restore files that were deleted from the system. It displays a list of deleted files in the web interface, and has options to restore those deleted files back to the people file directories or remove them permanently from the system. Restoring a file also restores related file versions, if the versions application is enabled. When a file is deleted from a share, it can be restored in the same manner, though it is no longer shared. By default, these files remain in the trash bin for 30 days.\nTo prevent an account from running out of disk space, the Deleted files app will not utilize more than 50% of the currently available free quota for deleted files. If the deleted files exceed this limit, the app deletes the oldest files until it gets below this limit. More information is available in the Deleted Files documentation." : "Denne applikasjonen lar personer gjenopprette filer som ble slettet fra systemet. Den viser en liste over slettede filer i webgrensesnittet, og har muligheter for å gjenopprette de slettede filene tilbake til personfilkatalogene eller fjerne dem permanent fra systemet. Gjenoppretting av en fil gjenoppretter også relaterte filversjoner, hvis versjonsprogrammet er aktivert. Når en fil slettes fra en delt ressurs, kan den gjenopprettes på samme måte, selv om den ikke lenger deles. Som standard forblir disse filene i papirkurven i 30 dager.\nFor å forhindre at en konto går tom for diskplass, vil ikke Slettede filer-appen bruke mer enn 50 % av den tilgjengelige gratiskvoten for slettede filer. Hvis de slettede filene overskrider denne grensen, sletter appen de eldste filene til den kommer under denne grensen. Du finner mer informasjon i dokumentasjonen for slettede filer.",
    "Restore" : "Gjenopprett",
    "Empty deleted files" : "Tøm papirkurven",
    "Confirm permanent deletion" : "Bekreft permanent sletting",
    "Are you sure you want to permanently delete all files and folders in the trash? This cannot be undone." : "Er du sikker på at du vil slette alle filer og mapper i papirkurven permanent? Denne handlingen kan ikke angres.",
    "Cancel" : "Avbryt",
    "Original location" : "Opprinnelig plassering",
    "Deleted by" : "Slettet av",
    "Deleted" : "Slettet",
    "A long time ago" : "Veldig lenge siden",
    "Unknown" : "Ukjent",
    "All files" : "Alle filer",
    "You" : "Du",
    "List of files that have been deleted." : "Liste over filer som har blitt slettet.",
    "No deleted files" : "Ingen slettede filer",
    "Files and folders you have deleted will show up here" : "Filer og mapper du har slettet vil dukke opp her",
    "Deletion cancelled" : "Sletting avbrutt"
},
"nplurals=2; plural=(n != 1);");
