OC.L10N.register(
    "comments",
    {
    "Comments" : "コメント",
    "You commented" : "コメント済",
    "{author} commented" : "{author} がコメントしました",
    "You commented on %1$s" : "%1$s についてコメントしました",
    "You commented on {file}" : "{file} にコメントしました",
    "%1$s commented on %2$s" : "%2$s について、%1$s がコメントしました",
    "{author} commented on {file}" : "{author} が{file} にコメントしました",
    "<strong>Comments</strong> for files" : "ファイルへの<strong>コメント</strong>があったとき",
    "Files" : "ファイル",
    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "あなたは \"{file}\" で、削除されたアカウントのコメントで言及されました",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} さんが \"{file}\" のコメント内であなたついて言及しました",
    "Files app plugin to add comments to files" : "ファイルにコメントを追加するためのファイルアプリプラグイン",
    "Edit comment" : "コメントを編集",
    "Delete comment" : "コメントを削除",
    "Cancel edit" : "編集をキャンセル",
    "New comment" : "新しいコメント",
    "Write a comment …" : "コメントを書く...",
    "Post comment" : "コメントを投稿",
    "@ for mentions, : for emoji, / for smart picker" : "メンションには@、絵文字には:、スマートピッカーには/",
    "Could not reload comments" : "コメントをリロードできませんでした",
    "Failed to mark comments as read" : "コメントを既読にすることができませんでした",
    "Unable to load the comments list" : "コメントリストを読み込めませんでした",
    "No comments yet, start the conversation!" : "まだコメントはありません、会話を開始してください！",
    "No more messages" : "これ以上のメッセージはありません",
    "Retry" : "再試行",
    "_1 new comment_::_{unread} new comments_" : ["の未読のコメント {unread}"],
    "Comment" : "コメント",
    "An error occurred while trying to edit the comment" : "コメント編集中にエラーが発生しました",
    "Comment deleted" : "コメントが削除されました",
    "An error occurred while trying to delete the comment" : "コメントの削除中にエラーが発生しました",
    "An error occurred while trying to create the comment" : "コメント中にエラーが発生しました"
},
"nplurals=1; plural=0;");
