OC.L10N.register(
    "logreader",
    {
    "App" : "แอป",
    "Time" : "เวลา",
    "Show details" : "แสดงข้อมูล",
    "Info" : "ข้อมูล",
    "Warning" : "คำเตือน",
    "Error" : "ข้อผิดพลาด"
},
"nplurals=1; plural=0;");
