OC.L10N.register(
    "files",
    {
    "Added to favorites" : "ياقتۇرىدىغانلارغا قوشۇلدى",
    "Removed from favorites" : "ياقتۇرىدىغانلاردىن ئۆچۈرۈلدى",
    "You added {file} to your favorites" : "ياقتۇرىدىغانلىرىڭىزغا {file} قوشتىڭىز",
    "You removed {file} from your favorites" : "ياقتۇرىدىغانلىرىڭىزدىن {file} نى ئۆچۈردىڭىز",
    "Favorites" : "يىغقۇچ",
    "File changes" : "ھۆججەت ئۆزگەرتىش",
    "Created by {user}" : "{user} قۇرغان",
    "Changed by {user}" : "{user} تەرىپىدىن ئۆزگەرتىلدى",
    "Deleted by {user}" : "{user} by تەرىپىدىن ئۆچۈرۈلدى",
    "Restored by {user}" : "{user} تەرىپىدىن ئەسلىگە كەلتۈرۈلدى",
    "Renamed by {user}" : "{user} تەرىپىدىن ئۆزگەرتىلدى",
    "Moved by {user}" : "{user} تەرىپىدىن يۆتكەلدى",
    "\"remote account\"" : "\"يىراقتىكى ھېسابات\"",
    "You created {file}" : "سىز {file} قۇردىڭىز",
    "You created an encrypted file in {file}" : "سىز {file} دە شىفىرلانغان ھۆججەت قۇردىڭىز",
    "{user} created {file}" : "{user} قۇرغان {file}",
    "{user} created an encrypted file in {file}" : "{user} {file} شىفىرلانغان ھۆججەت قۇردى",
    "{file} was created in a public folder" : "{file} public ئاممىۋى ھۆججەت قىسقۇچتا قۇرۇلدى",
    "You changed {file}" : "{file} ئۆزگەرتتىڭىز",
    "You changed an encrypted file in {file}" : "سىز شىفىرلانغان ھۆججەتنى {file} گە ئۆزگەرتتىڭىز",
    "{user} changed {file}" : "{user} ئۆزگەرتىلگەن {file}",
    "{user} changed an encrypted file in {file}" : "{user} شىفىرلانغان ھۆججەتنى {file} گە ئۆزگەرتتى",
    "You deleted {file}" : "{file} ئۆچۈردىڭىز",
    "You deleted an encrypted file in {file}" : "سىز {file} دىكى شىفىرلانغان ھۆججەتنى ئۆچۈردىڭىز",
    "{user} deleted {file}" : "{user} ئۆچۈرۈلگەن {file}",
    "{user} deleted an encrypted file in {file}" : "{user} شىفىرلانغان ھۆججەتنى {file} ئۆچۈردى",
    "You restored {file}" : "{file} ئەسلىگە كەلتۈردىڭىز",
    "{user} restored {file}" : "{user} ئەسلىگە كەلتۈرۈلگەن {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "سىز {oldfile} (يوشۇرۇن) نى {newfile} (يوشۇرۇن) غا ئۆزگەرتتىڭىز",
    "You renamed {oldfile} (hidden) to {newfile}" : "سىز {oldfile} (يوشۇرۇن) نى {newfile} غا ئۆزگەرتتىڭىز",
    "You renamed {oldfile} to {newfile} (hidden)" : "سىز {oldfile} غا {newfile} (يوشۇرۇن) دەپ ئىسىم قويدىڭىز",
    "You renamed {oldfile} to {newfile}" : "سىز {oldfile} غا {newfile} غا ئۆزگەرتتىڭىز",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} ئۆزگەرتىلگەن {oldfile} (يوشۇرۇن) {newfile} (يوشۇرۇن)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} ئۆزگەرتىلگەن {oldfile} (يوشۇرۇن) {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} ئۆزگەرتىلگەن {oldfile} دىن {newfile} (يوشۇرۇن)",
    "{user} renamed {oldfile} to {newfile}" : "{user} ئۆزگەرتىلگەن {oldfile} دىن {newfile}",
    "You moved {oldfile} to {newfile}" : "سىز {oldfile} نى {newfile} غا يۆتكىدىڭىز",
    "{user} moved {oldfile} to {newfile}" : "{user} {oldfile} نى {newfile} غا يۆتكىدى",
    "A file has been added to or removed from your <strong>favorites</strong>" : "ھۆججەتلىرىڭىز <strong> ياقتۇرىدىغان </ strong> غا قوشۇلدى ياكى ئۆچۈرۈلدى",
    "Files" : "ھۆججەتلەر",
    "A file or folder has been <strong>changed</strong>" : "ھۆججەت ياكى ھۆججەت قىسقۇچ <strong> ئۆزگەرتىلدى </ strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "ياقتۇرىدىغان ھۆججەت ياكى ھۆججەت قىسقۇچ <strong> ئۆزگەرتىلدى </ strong>",
    "Failed to authorize" : "ھوقۇق بېرىش مەغلۇب بولدى",
    "Invalid folder path" : "ھۆججەت قىسقۇچ يولى ئىناۋەتسىز",
    "Folder not found" : "ھۆججەت قىسقۇچ تېپىلمىدى",
    "Accept" : "قوبۇل قىلىڭ",
    "Reject" : "رەت قىلىش",
    "Incoming ownership transfer from {user}" : "{user} دىن كەلگەن ئىگىدارلىق ھوقۇقىنى يۆتكەش",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "{path} نى قوبۇل قىلامسىز؟\n\nئەسكەرتىش: قوبۇل قىلغاندىن كېيىن يۆتكىلىش جەريانى 1 سائەتكە يېتىشى مۇمكىن.",
    "Ownership transfer denied" : "ئىگىدارلىق ھوقۇقىنى يۆتكەش رەت قىلىندى",
    "Your ownership transfer of {path} was denied by {user}." : "{path} نىڭ ئىگىدارلىق ھوقۇقىڭىزنى {user} رەت قىلدى.",
    "Ownership transfer failed" : "ئىگىدارلىق ھوقۇقىنى يۆتكەش مەغلۇب بولدى",
    "Your ownership transfer of {path} to {user} failed." : "ئىگىدارلىق ھوقۇقىڭىز {path} دىن {user} غا يۆتكەلدى.",
    "The ownership transfer of {path} from {user} failed." : "{path} نىڭ {user} دىن ئىگىدارلىق ھوقۇقىنى يۆتكەش مەغلۇب بولدى.",
    "Ownership transfer done" : "ئىگىدارلىق ھوقۇقىنى يۆتكەش ئېلىپ بېرىلدى",
    "Your ownership transfer of {path} to {user} has completed." : "ئىگىدارلىق ھوقۇقىڭىزنى {path} دىن {user} غا يۆتكەش تاماملاندى.",
    "The ownership transfer of {path} from {user} has completed." : "{path} نىڭ {user} دىن ئىگىدارلىق ھوقۇقىنى يۆتكەش تاماملاندى.",
    "in %s" : "% s",
    "Transferred from %1$s on %2$s" : "%2 $ s دىكى%1 $ s دىن يۆتكەلدى",
    "Files compatibility" : "ھۆججەتلەرنىڭ ماسلىشىشچانلىقى",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "ھۆججەت نامىنى چەكلەشكە يول قويۇڭ ، ھۆججەتلەرنىڭ بارلىق خېرىدارلار بىلەن ماسقەدەملىنىشىگە كاپالەتلىك قىلىڭ. سۈكۈتتىكى ھالەتتە POSIX (ئىناۋەتلىك Linux ياكى macOS) دىكى بارلىق ھۆججەت ئىسمى رۇخسەت قىلىنىدۇ.",
    "Enforce Windows compatibility" : "Windows ماسلىشىشچانلىقىنى كۈچەيتىڭ",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "بۇ Windows سىستېمىسىدا كۈچكە ئىگە بولمىغان ھۆججەت نامىنى چەكلەيدۇ ، مەسىلەن زاپاس ئىسىم ياكى ئالاھىدە ھەرپلەرنى ئىشلىتىش دېگەندەك. ئەمما بۇ ئەھۋال سەزگۈرلۈكىنىڭ ماسلىشىشچانلىقىنى ئىجرا قىلمايدۇ.",
    "File Management" : "ھۆججەت باشقۇرۇش",
    "Home" : "ئۆي",
    "Target folder does not exist any more" : "نىشان ھۆججەت قىسقۇچ ئەمدى مەۋجۇت ئەمەس",
    "Reload current directory" : "نۆۋەتتىكى مۇندەرىجىنى قايتا يۈكلەڭ",
    "Go to the \"{dir}\" directory" : "\"{dir}\" مۇندەرىجىسىگە كىرىڭ",
    "Current directory path" : "نۆۋەتتىكى مۇندەرىجە يولى",
    "Your have used your space quota and cannot upload files anymore" : "بوشلۇق نورمىسىنى ئىشلىتىپ ، ھۆججەتلەرنى ئەمدى يۈكلىيەلمەيسىز",
    "Drag and drop files here to upload" : "ھۆججەتلەرنى بۇ يەرگە سۆرەپ تاشلاڭ",
    "Favorite" : "يىغقۇچ",
    "Back" : "قايتىش",
    "Toggle selection for file \"{displayName}\"" : "«{displayName}» ھۆججىتىنى تاللاڭ.",
    "Toggle selection for folder \"{displayName}\"" : "ھۆججەت قىسقۇچنى تاللاش \"{displayName}\"",
    "File is loading" : "ھۆججەت يۈكلىنىۋاتىدۇ",
    "Folder is loading" : "ھۆججەت قىسقۇچ يۈكلىنىۋاتىدۇ",
    "Filename" : "ھۆججەت ئىسمى",
    "Folder name" : "قىسقۇچ ئاتى",
    "This node is unavailable" : "بۇ تۈگۈننى ئىشلەتكىلى بولمايدۇ",
    "Another entry with the same name already exists." : "ئوخشاش ئىسىمدىكى يەنە بىر تۈر بار.",
    "Invalid filename." : "ئىناۋەتسىز ھۆججەت ئىسمى.",
    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" غا \"{newName}\" غا ئۆزگەرتىلدى",
    "Rename file" : "ھۆججەتنىڭ نامىنى ئۆزگەرتىش",
    "Folder" : "قىسقۇچ",
    "Pending" : "كۈتۈۋاتىدۇ",
    "Clear filter" : "سۈزگۈچنى تازىلاش",
    "Modified" : "ئۆزگەرتكەن",
    "Search everywhere" : "ھەممە يەردىن ئىزدەڭ",
    "Type" : "تىپ",
    "Active filters" : "ئاكتىپ سۈزگۈچ",
    "Remove filter" : "سۈزگۈچنى ئۆچۈرۈڭ",
    "Total rows summary" : "ئومۇمىي قۇر خۇلاسىسى",
    "Toggle selection for all files and folders" : "بارلىق ھۆججەت ۋە ھۆججەت قىسقۇچلارنى تاللاڭ",
    "Name" : "ئاتى",
    "Size" : "چوڭلۇقى",
    "Actions" : "مەشغۇلاتلار",
    "(selected)" : "(تاللانغان)",
    "List of files and folders." : "ھۆججەت ۋە ھۆججەت قىسقۇچلارنىڭ تىزىملىكى.",
    "Column headers with buttons are sortable." : "كۇنۇپكىلار بار ئىستون ماۋزۇلىرى تەرتىپلىك.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "بۇ تىزىملىك ئىقتىدار سەۋەبىدىن تولۇق كۆرسىتىلمىگەن. ھۆججەتلەر تىزىملىكتىن ئۆتكەندە كۆرسىتىلىدۇ.",
    "File not found" : "ھۆججەت تېپىلمىدى",
    "{usedQuotaByte} used" : "{usedQuotaByte} ئىشلىتىلگەن",
    "{used} of {quota} used" : "{used} {quota} ئىشلىتىلگەن",
    "{relative}% used" : "{relative}% ئىشلىتىلگەن",
    "Could not refresh storage stats" : "ساقلاش سانلىق مەلۇماتلىرىنى يېڭىلىيالمىدى",
    "Your storage is full, files can not be updated or synced anymore!" : "ساقلاش بوشلۇقىڭىز تولۇق ، ھۆججەتلەرنى يېڭىلاشقا ياكى ماسقەدەملەشكە بولمايدۇ!",
    "Storage information" : "ساقلاش ئۇچۇرى",
    "Storage quota" : "ساقلاش نورمىسى",
    "New folder" : "يېڭى قىسقۇچ",
    "Create new folder" : "يېڭى ھۆججەت قىسقۇچ قۇر",
    "This name is already in use." : "بۇ ئىسىم ئاللىقاچان ئىشلىتىلىۋاتىدۇ.",
    "Create" : "قۇر",
    "Fill template fields" : "قېلىپ بۆلەكلىرىنى تولدۇرۇڭ",
    "Submit" : "يوللاڭ",
    "Choose a file or folder to transfer" : "يۆتكەش ئۈچۈن ھۆججەت ياكى ھۆججەت قىسقۇچنى تاللاڭ",
    "Transfer" : "يۆتكەش",
    "Transfer {path} to {userid}" : "{path} نى {userid} غا يۆتكەڭ",
    "Invalid path selected" : "ئىناۋەتسىز يول تاللانغان",
    "Unknown error" : "يوچۇن خاتالىق",
    "Ownership transfer request sent" : "ئىگىدارلىق ھوقۇقىنى يۆتكەش ئىلتىماسى ئەۋەتىلدى",
    "Cannot transfer ownership of a file or folder you do not own" : "سىز ئىگە بولمىغان ھۆججەت ياكى ھۆججەت قىسقۇچنىڭ ئىگىدارلىق ھوقۇقىنى يۆتكىگىلى بولمايدۇ",
    "Transfer ownership of a file or folder" : "ھۆججەت ياكى ھۆججەت قىسقۇچنىڭ ئىگىدارلىق ھوقۇقىنى يۆتكەڭ",
    "Choose file or folder to transfer" : "يۆتكەش ئۈچۈن ھۆججەت ياكى ھۆججەت قىسقۇچنى تاللاڭ",
    "Change" : "ئۆزگەرتىش",
    "New owner" : "يېڭى خوجايىن",
    "Select file or folder to link to" : "ئۇلىنىدىغان ھۆججەت ياكى ھۆججەت قىسقۇچنى تاللاڭ",
    "Choose {file}" : "{file} نى تاللاڭ",
    "Share" : "ھەمبەھىرلەش",
    "Shared by link" : "ئۇلىنىش ئارقىلىق ئورتاقلاشتى",
    "Shared" : "ئورتاقلاشتى",
    "Switch to list view" : "تىزىملىك كۆرۈنۈشىگە ئالماشتۇرۇڭ",
    "Switch to grid view" : "كاتەكچە كۆرۈنۈشكە ئالماشتۇرۇڭ",
    "Upload was cancelled by user" : "ئىشلەتكۈچى يوللاش ئەمەلدىن قالدۇرۇلدى",
    "Not enough free space" : "يېتەرلىك بوشلۇق يوق",
    "Operation is blocked by access control" : "زىيارەتنى كونترول قىلىش ئارقىلىق مەشغۇلات توسۇلۇپ قالىدۇ",
    "Error during upload: {message}" : "يوللاشتىكى خاتالىق: {message}",
    "Error during upload, status code {status}" : "يوللاش جەريانىدا خاتالىق ، ھالەت كودى {status}",
    "Unknown error during upload" : "يوللاش جەريانىدا نامەلۇم خاتالىق",
    "Loading current folder" : "نۆۋەتتىكى ھۆججەت قىسقۇچنى يۈكلەۋاتىدۇ",
    "Retry" : "قايتا سىناڭ",
    "No files in here" : "بۇ يەردە ھۆججەت يوق",
    "Upload some content or sync with your devices!" : "بەزى مەزمۇنلارنى يۈكلەڭ ياكى ئۈسكۈنىڭىز بىلەن ماسقەدەملەڭ!",
    "Go back" : "قايتىڭ",
    "Views" : "كۆرۈنۈشلەر",
    "Files settings" : "ھۆججەت تەڭشىكى",
    "Your files" : "ھۆججەتلىرىڭىز",
    "Open in files" : "ھۆججەتلەرنى ئېچىڭ",
    "File cannot be accessed" : "ھۆججەتنى زىيارەت قىلغىلى بولمايدۇ",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "ھۆججەت تېپىلمىدى ياكى ئۇنى كۆرۈش ھوقۇقىڭىز يوق. ئەۋەتكۈچىدىن ئورتاقلىشىشنى سوراڭ.",
    "Clipboard is not available" : "چاپلاش تاختىسى يوق",
    "General" : "General",
    "All files" : "بارلىق ھۆججەتلەر",
    "Personal files" : "شەخسىي ھۆججەتلەر",
    "Sort favorites first" : "ياقتۇرىدىغانلارنى رەتلەڭ",
    "Sort folders before files" : "ھۆججەتلەرنى ھۆججەتتىن بۇرۇن تەرتىپلەڭ",
    "Appearance" : "كۆرۈنۈش",
    "Show hidden files" : "يوشۇرۇن ھۆججەتلەرنى كۆرسەت",
    "Crop image previews" : "رەسىمنى ئالدىن كۆرۈش",
    "Additional settings" : "قوشۇمچە تەڭشەكلەر",
    "WebDAV" : "WebDAV",
    "WebDAV URL" : "WebDAV URL",
    "Copy" : "كۆچۈرۈڭ",
    "Keyboard shortcuts" : "كۇنۇپكا تاختىسى تېزلەتمىسى",
    "File actions" : "ھۆججەت ھەرىكىتى",
    "Rename" : "ئات ئۆزگەرت",
    "Delete" : "ئۆچۈر",
    "Manage tags" : "خەتكۈچلەرنى باشقۇرۇش",
    "Selection" : "تاللاش",
    "Deselect all" : "ھەممىنى تاللاڭ",
    "Navigation" : "يول باشلاش",
    "View" : "كۆرۈش",
    "You" : "سەن",
    "Shared multiple times with different people" : "ئوخشىمىغان كىشىلەر بىلەن كۆپ قېتىم ئورتاقلاشتى",
    "Error while loading the file data" : "ھۆججەت سانلىق مەلۇماتلىرىنى يۈكلەۋاتقاندا خاتالىق",
    "Owner" : "ئىگىسى",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Tags" : "بەلگەلەر",
    "Blank" : "ئوچۇق",
    "Unable to create new file from template" : "قېلىپتىن يېڭى ھۆججەت قۇرالمىدى",
    "Pick a template for {name}" : "{name} for نىڭ قېلىپىنى تاللاڭ",
    "Create a new file with the selected template" : "تاللانغان قېلىپ بىلەن يېڭى ھۆججەت قۇر",
    "Creating file" : "ھۆججەت قۇرۇش",
    "Leave this share" : "بۇ ئۈلۈشنى قالدۇرۇڭ",
    "Leave these shares" : "بۇ پايلارنى قالدۇرۇڭ",
    "Disconnect storage" : "ساقلاشنى ئۈزۈڭ",
    "Disconnect storages" : "دۇكانلارنى ئۈزۈڭ",
    "Delete permanently" : "مەڭگۈلۈك ئۆچۈر",
    "Delete and unshare" : "ئۆچۈرۈش ۋە ئورتاقلىشىش",
    "Delete file" : "ھۆججەتنى ئۆچۈرۈڭ",
    "Delete files" : "ھۆججەتلەرنى ئۆچۈرۈڭ",
    "Delete folder" : "ھۆججەت قىسقۇچنى ئۆچۈرۈڭ",
    "Delete folders" : "ھۆججەت قىسقۇچلارنى ئۆچۈرۈڭ",
    "Confirm deletion" : "ئۆچۈرۈشنى جەزملەشتۈرۈڭ",
    "Cancel" : "ۋاز كەچ",
    "Download" : "چۈشۈر",
    "Moving \"{source}\" to \"{destination}\" …" : "\"{source}\" نى \"{destination}\" غا يۆتكەش…",
    "Copying \"{source}\" to \"{destination}\" …" : "\"{source}\" نى \"{destination}\" غا كۆچۈرۈش…",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "ھۆججەت ياكى ھۆججەت قىسقۇچنى ئۆزىڭىزگە ياكى تارماق قىسقۇچقا يۆتكىيەلمەيسىز",
    "(copy)" : "(كۆپەيتىلگەن نۇسخىسى)",
    "(copy %n)" : "(% n)",
    "A file or folder with that name already exists in this folder" : "بۇ ھۆججەت قىسقۇچتا بۇ ئىسىم بار ھۆججەت ياكى ھۆججەت قىسقۇچ بار",
    "The files are locked" : "ھۆججەتلەر قۇلۇپلاندى",
    "The file does not exist anymore" : "بۇ ھۆججەت ئەمدى مەۋجۇت ئەمەس",
    "Choose destination" : "مەنزىلنى تاللاڭ",
    "Copy to {target}" : "{target} غا كۆچۈرۈڭ",
    "Move to {target}" : "{target} يۆتكەڭ",
    "Move" : "Move",
    "Move or copy operation failed" : "يۆتكەش ياكى كۆچۈرۈش مەشغۇلاتى مەغلۇپ بولدى",
    "Move or copy" : "يۆتكەش ياكى كۆچۈرۈش",
    "Open folder {displayName}" : "ھۆججەت قىسقۇچ {displayName}",
    "Open in Files" : "ھۆججەتلەرنى ئېچىڭ",
    "Open locally" : "يەرلىكتە ئېچىڭ",
    "Failed to redirect to client" : "خېرىدارغا قايتا نىشانلاش مەغلۇپ بولدى",
    "Open file locally" : "ھۆججەتنى يەرلىكتە ئېچىڭ",
    "Details" : "تەپسىلاتى",
    "View in folder" : "قىسقۇچتا كۆرۈش",
    "Today" : "بۈگۈن",
    "Last 7 days" : "ئاخىرقى 7 كۈن",
    "Last 30 days" : "ئاخىرقى 30 كۈن",
    "This year ({year})" : "بۇ يىل ({year})",
    "Last year ({year})" : "ئۆتكەن يىلى ({year})",
    "Documents" : "ھۆججەتلەر",
    "Spreadsheets" : "ئېلېكترونلۇق جەدۋەل",
    "Presentations" : "Presentations",
    "PDFs" : "PDF",
    "Folders" : "ھۆججەت قىسقۇچ",
    "Audio" : "Audio",
    "Images" : "سۈرەتلەر",
    "Videos" : "سىنلار",
    "Created new folder \"{name}\"" : "يېڭى ھۆججەت قىسقۇچ \"{name}\" قۇرۇلدى",
    "Unable to initialize the templates directory" : "قېلىپ مۇندەرىجىسىنى قوزغىتالمىدى",
    "Create templates folder" : "قېلىپ ھۆججەت قىسقۇچى قۇرۇش",
    "Templates" : "قېلىپلار",
    "New template folder" : "يېڭى قېلىپ ھۆججەت قىسقۇچى",
    "In folder" : "ھۆججەت قىسقۇچتا",
    "Search in folder: {folder}" : "ھۆججەت قىسقۇچتىن ئىزدەش: {folder} قىسقۇچ}",
    "One of the dropped files could not be processed" : "تاشلانغان ھۆججەتلەرنىڭ بىرىنى بىر تەرەپ قىلالمىدى",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "توركۆرگۈڭىز Filesystem API نى قوللىمايدۇ. مۇندەرىجە يۈكلەنمەيدۇ",
    "No files to upload" : "يۈكلەيدىغان ھۆججەت يوق",
    "Unable to create the directory {directory}" : "مۇندەرىجە {directory} قۇرالمىدى",
    "Some files could not be uploaded" : "بەزى ھۆججەتلەرنى يۈكلەشكە بولمىدى",
    "Files uploaded successfully" : "ھۆججەتلەر مۇۋەپپەقىيەتلىك يۈكلەندى",
    "No files to process" : "بىر تەرەپ قىلىدىغان ھۆججەت يوق",
    "Some files could not be copied" : "بەزى ھۆججەتلەرنى كۆچۈرگىلى بولمىدى",
    "Some files could not be moved" : "بەزى ھۆججەتلەرنى يۆتكىگىلى بولمىدى",
    "Files copied successfully" : "ھۆججەتلەر مۇۋەپپەقىيەتلىك كۆچۈرۈلدى",
    "Files moved successfully" : "ھۆججەتلەر مۇۋەپپەقىيەتلىك يۆتكەلدى",
    "Conflicts resolution skipped" : "زىددىيەتنىڭ ھەل قىلىنىشى ئاتلاپ كەتتى",
    "Upload cancelled" : "يۈكلەش ئەمەلدىن قالدۇرۇلدى",
    "Could not rename \"{oldName}\", it does not exist any more" : "\"{oldName}\" نىڭ نامىنى ئۆزگەرتەلمىدى ، ئۇ ئەمدى مەۋجۇت ئەمەس",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{dir}\" ھۆججەت قىسقۇچىدا \"{newName}\" ئىسمى ئاللىبۇرۇن ئىشلىتىلگەن. باشقا ئىسىمنى تاللاڭ.",
    "Could not rename \"{oldName}\"" : "\"{oldName}\" نىڭ نامىنى ئۆزگەرتەلمىدى",
    "This operation is forbidden" : "بۇ مەشغۇلات مەنئى قىلىنىدۇ",
    "Storage is temporarily not available" : "ساقلاش ۋاقتىنى ۋاقىتلىق ئىشلەتكىلى بولمايدۇ",
    "Unexpected error: {error}" : "ئويلىمىغان خاتالىق: {error}",
    "Filename must not be empty." : "ھۆججەت ئىسمى بوش بولماسلىقى كېرەك.",
    "\"{char}\" is not allowed inside a filename." : "ھۆججەت نامىدا \"{char}\" رۇخسەت قىلىنمايدۇ.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" زاپاس ئىسىم بولۇپ ، ھۆججەت نامىغا رۇخسەت قىلىنمايدۇ.",
    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" رۇخسەت قىلىنغان ھۆججەت تىپى ئەمەس.",
    "Filenames must not end with \"{extension}\"." : "ھۆججەت ئىسمى «{extension}» بىلەن ئاخىرلاشماسلىقى كېرەك.",
    "List of favorite files and folders." : "ياقتۇرىدىغان ھۆججەت ۋە ھۆججەت قىسقۇچلارنىڭ تىزىملىكى.",
    "No favorites yet" : "ياقتۇرىدىغانلار تېخى يوق",
    "Files and folders you mark as favorite will show up here" : "سىز ياقتۇرىدىغان ھۆججەت ۋە ھۆججەت قىسقۇچلار بۇ يەردە كۆرۈنىدۇ",
    "List of your files and folders." : "ھۆججەت ۋە ھۆججەت قىسقۇچلىرىڭىزنىڭ تىزىملىكى.",
    "List of your files and folders that are not shared." : "ئورتاقلاشمىغان ھۆججەت ۋە ھۆججەت قىسقۇچلىرىڭىزنىڭ تىزىملىكى.",
    "No personal files found" : "شەخسىي ھۆججەت تېپىلمىدى",
    "Files that are not shared will show up here." : "ئورتاقلاشمىغان ھۆججەتلەر بۇ يەردە كۆرۈنىدۇ.",
    "Recent" : "يېقىنقى",
    "List of recently modified files and folders." : "يېقىندا ئۆزگەرتىلگەن ھۆججەت ۋە ھۆججەت قىسقۇچلارنىڭ تىزىملىكى.",
    "No recently modified files" : "يېقىندا ئۆزگەرتىلگەن ھۆججەت يوق",
    "Files and folders you recently modified will show up here." : "سىز يېقىندا ئۆزگەرتكەن ھۆججەت ۋە ھۆججەت قىسقۇچلار بۇ يەردە كۆرۈنىدۇ.",
    "Search" : "ئىزدەش",
    "No entries found in this folder" : "بۇ ھۆججەت قىسقۇچتا ھېچقانداق مەزمۇن تېپىلمىدى",
    "Select all" : "ھەممىنى تاللاڭ",
    "Upload too large" : "يۈكلەندىغىنى بەك چوڭ",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "سىز يۈكلىمەكچى بولغان ھۆججەتلەر بۇ مۇلازىمېتىردا ھۆججەت يوللاشنىڭ ئەڭ چوڭ چوڭلۇقىدىن ئېشىپ كەتتى.",
    "File could not be found" : "ھۆججەت تېپىلمىدى",
    "Show list view" : "تىزىملىك كۆرۈنۈشىنى كۆرسىتىش",
    "Show grid view" : "كاتەكچە كۆرۈنۈشنى كۆرسىتىش",
    "Close" : "ياپ",
    "Could not create folder \"{dir}\"" : "\"{dir}\" ھۆججەت قىسقۇچى قۇرالمىدى",
    "This will stop your current uploads." : "بۇ سىزنىڭ نۆۋەتتىكى يۈكلىنىشىڭىزنى توختىتىدۇ.",
    "Upload cancelled." : "يۈكلەشتىن ۋاز كەچتى.",
    "Processing files …" : "ھۆججەتلەرنى بىر تەرەپ قىلىش…",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "مۇندەرىجە ياكى 0 بايىت بولغانلىقى ئۈچۈن {filename} نامىنى يۈكلىيەلمىدى",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "يېتەرلىك بوشلۇق يوق ، سىز {size1} نى يۈكلەۋاتىسىز ، ئەمما پەقەت {size2} قالدى",
    "Target folder \"{dir}\" does not exist any more" : "نىشان ھۆججەت قىسقۇچ \"{dir}\" ئەمدى مەۋجۇت ئەمەس",
    "An unknown error has occurred" : "نامەلۇم خاتالىق كۆرۈلدى",
    "File could not be uploaded" : "ھۆججەت يۈكلەشكە بولمىدى",
    "Uploading …" : "يۈكلەش…",
    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber} / {total})",
    "Uploading … ({currentNumber}/{total})" : "يۈكلەش… ({currentNumber} / {total})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "ئۇ نەرسىنى يۈكلەشنى قوللىمايدۇ",
    "Error when assembling chunks, status code {status}" : "پارچىلارنى قۇرغاندا خاتالىق ، ھالەت كودى {status}",
    "Choose target folder" : "نىشان ھۆججەت قىسقۇچىنى تاللاڭ",
    "Set reminder" : "ئەسكەرتىش بەلگىلەڭ",
    "Edit locally" : "يەرلىكتە تەھرىرلەڭ",
    "Open" : "ئېچىڭ",
    "Could not load info for file \"{file}\"" : "\"{file}\" ھۆججىتىگە ئۇچۇر يۈكلىيەلمىدى",
    "Please select tag(s) to add to the selection" : "تاللاشقا قوشۇش ئۈچۈن بەلگە (لەرنى) تاللاڭ",
    "Apply tag(s) to selection" : "تاللاشقا بەلگە (لەر) نى ئىشلىتىڭ",
    "Select directory \"{dirName}\"" : "مۇندەرىجە \"{dirName}\" نى تاللاڭ",
    "Select file \"{fileName}\"" : "ھۆججەت \"{fileName}\" نى تاللاڭ",
    "Unable to determine date" : "چېسلانى بەلگىلىيەلمىدى",
    "This directory is unavailable, please check the logs or contact the administrator" : "بۇ مۇندەرىجىنى ئىشلەتكىلى بولمايدۇ ، خاتىرىلەرنى تەكشۈرۈپ بېقىڭ ياكى باشقۇرغۇچى بىلەن ئالاقىلىشىڭ",
    "Could not move \"{file}\", target exists" : "\"{file}\" نى يۆتكىگىلى بولمىدى ، نىشان مەۋجۇت",
    "Could not move \"{file}\"" : "\"{file}\" نى يۆتكىگىلى بولمىدى",
    "copy" : "كۆپەيتىلگەن",
    "Could not copy \"{file}\", target exists" : "\"{file}\" نى كۆچۈرەلمىدى ، نىشان مەۋجۇت",
    "Could not copy \"{file}\"" : "\"{file}\" نى كۆچۈرەلمىدى",
    "Copied {origin} inside {destination}" : "كۆچۈرۈلگەن {origin} ئىچىدىكى {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} ئىچىدىكى {destination} ۋە {nbfiles} باشقا ھۆججەتلەر كۆچۈرۈلگەن",
    "{newName} already exists" : "{newName} مەۋجۇت",
    "Could not create file \"{file}\"" : "\"{file}\" ھۆججىتىنى قۇرالمىدى",
    "Could not create file \"{file}\" because it already exists" : "«{file}» ھۆججىتىنى قۇرالمىدى ، چۈنكى ئۇ مەۋجۇت",
    "Could not create folder \"{dir}\" because it already exists" : "«{dir}» ھۆججەت قىسقۇچى قۇرالمىدى ، چۈنكى ئۇ مەۋجۇت",
    "Could not fetch file details \"{file}\"" : "ھۆججەت تەپسىلاتلىرىنى \"{file}\" غا ئېرىشەلمىدى",
    "Error deleting file \"{fileName}\"." : "\"{fileName}\" ھۆججىتىنى ئۆچۈرۈشتە خاتالىق.",
    "No search results in other folders for {tag}{filter}{endtag}" : "باشقا ھۆججەت قىسقۇچلاردا {tag} {filter} {endtag} دىن ئىزدەش نەتىجىسى يوق",
    "Enter more than two characters to search in other folders" : "باشقا ھۆججەت قىسقۇچلاردىن ئىزدەش ئۈچۈن ئىككىدىن ئارتۇق ھەرپ كىرگۈزۈڭ",
    "{dirs} and {files}" : "{dirs} ۋە {files}",
    "You do not have permission to upload or create files here" : "بۇ يەرگە ھۆججەت يوللاش ياكى قۇرۇش ھوقۇقىڭىز يوق",
    "New" : "يېڭى",
    "New file/folder menu" : "يېڭى ھۆججەت / ھۆججەت قىسقۇچ تىزىملىكى",
    "Select file range" : "ھۆججەت دائىرىسىنى تاللاڭ",
    "{used}%" : "{used}%",
    "{used} used" : "{used} ئىشلىتىلگەن",
    "\"{name}\" is an invalid file name." : "\"{name}\" ئىناۋەتسىز ھۆججەت ئىسمى.",
    "File name cannot be empty." : "ھۆججەت ئىسمى قۇرۇق بولمايدۇ.",
    "\"/\" is not allowed inside a file name." : "ھۆججەت نامىدا \"/\" رۇخسەت قىلىنمايدۇ.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" رۇخسەت قىلىنغان ھۆججەت شەكلى ئەمەس",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "{owner} نىڭ ساقلاش بوشلۇقى تولۇق ، ھۆججەتلەرنى يېڭىلاشقا ياكى ماسقەدەملەشكە بولمايدۇ!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "گۇرۇپپا قىسقۇچ \"{mountPoint}\" تولۇق ، ھۆججەتلەرنى يېڭىلاشقا ياكى ماسقەدەملەشكە بولمايدۇ!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "سىرتقى ساقلاش \"{mountPoint}\" تولۇق ، ھۆججەتلەرنى يېڭىلاشقا ياكى ماسقەدەملەشكە بولمايدۇ!",
    "Your storage is full, files cannot be updated or synced anymore!" : "ساقلاش بوشلۇقىڭىز تولۇق ، ھۆججەتلەرنى يېڭىلاشقا ياكى ماسقەدەملەشكە بولمايدۇ!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "{owner} نىڭ ساقلاش بوشلۇقى تولۇق ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "گۇرۇپپا قىسقۇچ \"{mountPoint}\" ئاساسەن دېگۈدەك تولۇق ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "سىرتقى ساقلاش \"{mountPoint}\" ئاساسەن دېگۈدەك تولۇق ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "ساقلاش بوشلۇقىڭىز ئاساسەن دېگۈدەك تولۇق ({usedSpacePercent}%).",
    "Direct link was copied (only works for people who have access to this file/folder)" : "بىۋاسىتە ئۇلىنىش كۆچۈرۈلدى (پەقەت بۇ ھۆججەت / ھۆججەت قىسقۇچنى زىيارەت قىلىدىغان كىشىلەر ئۈچۈن ئىشلەيدۇ)",
    "Path" : "Path",
    "Favored" : "ياخشى كۆرىدۇ",
    "Favor" : "ياق",
    "Copy direct link (only works for people who have access to this file/folder)" : "بىۋاسىتە ئۇلىنىشنى كۆچۈرۈڭ (پەقەت بۇ ھۆججەت / ھۆججەت قىسقۇچنى زىيارەت قىلالايدىغان كىشىلەر ئۈچۈن ئىشلەيدۇ)",
    "Upload file" : "Upload file",
    "Not favored" : "ياقتۇرمايدۇ",
    "An error occurred while trying to update the tags" : "خەتكۈچلەرنى يېڭىلىماقچى بولغاندا خاتالىق كۆرۈلدى",
    "Upload (max. %s)" : "يۈكلەش (max.% S)",
    "\"{displayName}\" action executed successfully" : "\"{displayName}\" ھەرىكىتى مۇۋەپپەقىيەتلىك ئىجرا قىلىندى",
    "\"{displayName}\" action failed" : "\"{displayName}\" ھەرىكىتى مەغلۇپ بولدى",
    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" تۈركۈمدىكى ھەرىكەت مۇۋەپپەقىيەتلىك ئىجرا قىلىندى",
    "Submitting fields…" : "يول يوللاش…",
    "Filter filenames…" : "ھۆججەت نامىنى سۈزۈڭ…",
    "WebDAV URL copied to clipboard" : "WebDAV URL چاپلاش تاختىسىغا كۆچۈرۈلدى",
    "Enable the grid view" : "كاتەكچە كۆرۈنۈشىنى قوزغىتىڭ",
    "Enable folder tree" : "ھۆججەت قىسقۇچنى قوزغىتىڭ",
    "Copy to clipboard" : "چاپلاش تاختىسىغا كۆچۈرۈڭ",
    "Use this address to access your Files via WebDAV" : "بۇ ئادرېسنى ئىشلىتىپ WebDAV ئارقىلىق ھۆججەتلىرىڭىزنى زىيارەت قىلىڭ",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "ئەگەر سىز 2FA نى قوزغىتىپ قويغان بولسىڭىز ، بۇ يەرنى چېكىپ چوقۇم يېڭى ئەپ پارولى قۇرالايسىز ۋە ئىشلىتىڭ.",
    "Deletion cancelled" : "ئۆچۈرۈش ئەمەلدىن قالدۇرۇلدى",
    "Move cancelled" : "يۆتكەش ئەمەلدىن قالدۇرۇلدى",
    "Cancelled move or copy of \"{filename}\"." : "«{filename} ئىسمى}» نىڭ يۆتكىلىشى ياكى كۆپەيتىلگەن نۇسخىسى.",
    "Cancelled move or copy operation" : "يۆتكەش ياكى كۆچۈرۈش مەشغۇلاتى ئەمەلدىن قالدۇرۇلدى",
    "Open details" : "تەپسىلاتلارنى ئېچىڭ",
    "Photos and images" : "رەسىم ۋە رەسىم",
    "New folder creation cancelled" : "يېڭى ھۆججەت قىسقۇچ قۇرۇش ئەمەلدىن قالدۇرۇلدى",
    "{fileCount} files and {folderCount} folders" : "{fileCount} ھۆججەتلىرى ۋە {folderCount} ھۆججەت قىسقۇچلىرى",
    "All folders" : "بارلىق ھۆججەت قىسقۇچلار",
    "Personal Files" : "شەخسىي ھۆججەتلەر",
    "Text file" : "تېكىست ھۆججەت",
    "New text file.txt" : "يېڭى تېكىست ھۆججىتى. Txt"
},
"nplurals=2; plural=(n != 1);");
