OC.L10N.register(
    "nextcloud_announcements",
    {
    "Nextcloud announcements" : "Nextcloudi teadaanded",
    "Nextcloud announcement" : "Nextcloudi teadaanne",
    "Read more" : "Loe rohkem",
    "Disable announcements" : "Lülita teadaanded välja",
    "(These announcements are only shown to administrators)" : "(Neid teadaandeid näidatakse ainult administraatoritele)",
    "Nextcloud announcements brings the latest news of Nextcloud into your notifications" : "Nextcloudi teadaanded toovad viimaseid uudiseid Nextcloudi kohta sinu teavitustesse"
},
"nplurals=2; plural=(n != 1);");
