OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Pridané do obľúbených",
    "Removed from favorites" : "Odstránené z obľúbených",
    "You added {file} to your favorites" : "Pridali ste {file} do vašich obľúbených",
    "You removed {file} from your favorites" : "Odstránili ste {file} z vašich obľúbených",
    "Favorites" : "Obľúbené",
    "File changes" : "Zmeny v súboroch",
    "Created by {user}" : "Vytvorené užívateľom {user}",
    "Changed by {user}" : "Zmenené užívateľom {user}",
    "Deleted by {user}" : "Zmazané užívateľom {user}",
    "Restored by {user}" : "Obnovené užívateľom {user}",
    "Renamed by {user}" : "Premenované užívateľom {user}",
    "Moved by {user}" : "Presunuté užívateľom {user}",
    "\"remote account\"" : "\"vzdialený účet\"",
    "You created {file}" : "Vytvorili ste súbor {file}",
    "You created an encrypted file in {file}" : "Vytvorili ste zašifrovaný súbor  {file}",
    "{user} created {file}" : "{user} vytvoril súbor {file}",
    "{user} created an encrypted file in {file}" : "{user} vytvoril šifrovaný súbor {file}",
    "{file} was created in a public folder" : "{file} bol vytvorený vo verejnom priečinku",
    "You changed {file}" : "Zmenili ste {file}",
    "You changed an encrypted file in {file}" : "Zmenili ste šifrovaný súbor {file}",
    "{user} changed {file}" : "{user} zmenil {file}",
    "{user} changed an encrypted file in {file}" : "{user} zmenil šifrovaný súbor {file}",
    "You deleted {file}" : "Odstránili ste {file}",
    "You deleted an encrypted file in {file}" : "Odstránili ste šifrovaný súbor {file}",
    "{user} deleted {file}" : "{user} zmazal {file}",
    "{user} deleted an encrypted file in {file}" : "{user} zmazal šifrovaný súbor {file}",
    "You restored {file}" : "Obnovili ste {file}",
    "{user} restored {file}" : "{user} obnovil {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Premenovali ste {oldfile} (skryté) na {newfile} (skryté)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Premenovali ste {oldfile} (skryté) na {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Premenovali ste {oldfile} na {newfile} (skryté)",
    "You renamed {oldfile} to {newfile}" : "Premenovali ste {oldfile} na {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} premenoval {oldfile} (skryté) na {newfile} (skryté)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} premenoval {oldfile} (skryté) na {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} premenoval {oldfile} na {newfile} (skryté)",
    "{user} renamed {oldfile} to {newfile}" : "{user} premenoval {oldfile} na {newfile}",
    "You moved {oldfile} to {newfile}" : "Presunuli ste {oldfile} do {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} presunul {oldfile} do {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Súbor bol pridaný alebo odstránený z vašich <strong>obľúbených</strong>",
    "Files" : "Súbory",
    "A file or folder has been <strong>changed</strong>" : "Súbor alebo priečinok bol <strong>zmenený</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Obľúbený súbor alebo priečinok bol <strong>zmenený</strong>",
    "Failed to authorize" : "Autorizácia zlyhala",
    "Invalid folder path" : "Neplatná cesta k priečinku",
    "Folder not found" : "Priečinok nebol nájdený",
    "The file cannot be found" : "Súbor sa nepodarilo nájisť",
    "The destination path does not exist: %1$s" : "Cieľová cesta neexistuje: %1$s",
    "You do not have permission to create a file at the specified location" : "Nemáte oprávnenie vytvoriť súbor v zadanom umiestnení",
    "The file could not be converted." : "Súbor nemohol byť skonvertovaný.",
    "Could not get relative path to converted file" : "Nepodarilo sa získať relatícnu cestu ku skonvertovanému súboru",
    "Favorite files" : "Obľúbené súbory",
    "No favorites" : "Žiadne obľúbené",
    "More favorites" : "Viac obľúbených",
    "Accept" : "Prijať",
    "Reject" : "Odmietnuť",
    "Incoming ownership transfer from {user}" : "Prichádzajúci prevod vlastníctva od {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Chcete prijať {path}?\n\nPozn.: Proces pre prijatie môže trvať až hodinu.",
    "Ownership transfer denied" : "Prevod vlastníctva bol odmietnutý",
    "Your ownership transfer of {path} was denied by {user}." : "{user} odmietol prevod vlastníctva {path}.",
    "Ownership transfer failed" : "Prevod vlastníctva zlyhal",
    "Your ownership transfer of {path} to {user} failed." : "Prevod vlastníctva {path} od vás na {user} zlyhal.",
    "The ownership transfer of {path} from {user} failed." : "Prevod vlastníctva {path} od {user} zlyhal.",
    "Ownership transfer done" : "Prevod vlastníctva dokončený",
    "Your ownership transfer of {path} to {user} has completed." : "Prevod vami vlastnenej položky {path} na {user} bol dokončený.",
    "The ownership transfer of {path} from {user} has completed." : "Prevod vlastníctva položky {path} od {user} bol dokončený.",
    "in %s" : "v %s",
    "Transferred from %1$s on %2$s" : "Prevedené z %1$s na %2$s",
    "Files compatibility" : "Kompatibilita súborov",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Povoliť obmedzenie názvov súborov, aby sa zabezpečila synchronizácia súborov so všetkými klientmi. V predvolenom nastavení sú povolené všetky názvy súborov platné pre POSIX (napr. Linux alebo macOS).",
    "Enforce Windows compatibility" : "Vynútiť kompatibilitu s Windows",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Tým sa zablokujú názvy súborov, ktoré nie sú platné v systémoch Windows, ako napríklad používanie vyhradených názvov alebo špeciálnych znakov. To však nevynúti kompatibilitu rozlišovania malých a veľkých písmen.",
    "File Management" : "Správa súborov",
    "Home" : "Domov",
    "Target folder does not exist any more" : "Cieľový priečinok už neexistuje",
    "Reload current directory" : "Znova načítať súčasný adresár",
    "Go to the \"{dir}\" directory" : "Ísť do \"{dir}\" adresára",
    "Current directory path" : "Aktuálna cesta k adresáru",
    "Your have used your space quota and cannot upload files anymore" : "Dosiahli ste limit vášho priestoru a už viac nemôžete nahrávať súbory",
    "You do not have permission to upload or create files here." : "Nemáte oprávnenie sem nahrávať alebo vytvárať súbory.",
    "Drag and drop files here to upload" : "Pre nahratie presuňte do tohto priestoru súbory ťahaním",
    "Favorite" : "Obľúbené",
    "Back" : "Späť",
    "Toggle selection for file \"{displayName}\"" : "Prepnúť výber pre súbor \"{displayName}\"",
    "Toggle selection for folder \"{displayName}\"" : "Prepnúť výber pre adresár \"{displayName}\"",
    "File is loading" : "Súbor sa nahráva",
    "Folder is loading" : "Adresár sa nahráva",
    "Filename" : "Názov súboru",
    "Folder name" : "Názov priečinka",
    "This node is unavailable" : "Uzol nie je k dispozícií",
    "Another entry with the same name already exists." : "Iná položka s rovnakým menom už existuje.",
    "Invalid filename." : "Chybný názov súboru.",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Premenované z \"{oldName}\" na \"{newName}\"",
    "Rename file" : "Premenovať súbor",
    "Folder" : "Priečinok",
    "Pending" : "Čaká",
    "Unknown date" : "Neznámy dátum",
    "Clear filter" : "Vyčistiť filter",
    "Modified" : "Upravené",
    "Search everywhere" : "Hľadať všade",
    "Type" : "Typ",
    "Active filters" : "Aktívne filtre",
    "Remove filter" : "Odstrániť filter",
    "Total rows summary" : "Súčet všetkých riadkov",
    "Toggle selection for all files and folders" : "Prepnúť výber pre všetky súbory a adresáre",
    "Name" : "Názov",
    "Size" : "Veľkosť",
    "Actions" : "Akcie",
    "(selected)" : "(vybrané)",
    "List of files and folders." : "Zoznam súborov a priečinkov.",
    "You have used your space quota and cannot upload files anymore." : "Už ste využili kapacitu úložného priestoru a nie je možné nahrávať ďalšie súbory.",
    "Column headers with buttons are sortable." : "Stĺpce hlavičiek s tlačidlami sú triediteľné.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Tento zoznam nie je úplne vykreslený z dôvodov výkonu. Súbory budú vykreslené, keď budete prechádzať zoznamom.",
    "File not found" : "Súbor nenájdený",
    "_{count} selected_::_{count} selected_" : ["{count} vybraný","{count} vybrané","{count} vybraných","{count} vybraných"],
    "{usedQuotaByte} used" : "{usedQuotaByte} použitých",
    "{used} of {quota} used" : "použitých {used} z {quota}",
    "{relative}% used" : "{relative}% použitých",
    "Could not refresh storage stats" : "Nebolo možné obnoviť úložiskové štatistiky",
    "Your storage is full, files can not be updated or synced anymore!" : "Vaše úložisko je plné. Súbory nemožno aktualizovať ani synchronizovať!",
    "Storage information" : "Informácie o úložisku",
    "Storage quota" : "Kvóta pre úložisko",
    "New folder" : "Nový priečinok",
    "Create new folder" : "Vytvoriť nový priečinok",
    "This name is already in use." : "Toto meno je už používané.",
    "Create" : "Vytvoriť",
    "Fill template fields" : "Vyplňte položky šablóny",
    "Submitting fields …" : "Položky sa odosielajú ...",
    "Submit" : "Odoslať",
    "Choose a file or folder to transfer" : "Vyberte súbor alebo priečinok na prevod",
    "Transfer" : "Prevod",
    "Transfer {path} to {userid}" : "Previesť {path} na {userid}",
    "Invalid path selected" : "Bola vybraná neplatná cesta",
    "Unknown error" : "Neznáma chyba",
    "Ownership transfer request sent" : "Žiadosť o prevod vlastníctva bola odoslaná",
    "Cannot transfer ownership of a file or folder you do not own" : "Nie je možné preniesť vlastníctvo súboru alebo priečinka, ktorý nevlastníte",
    "Transfer ownership of a file or folder" : "Prevod vlastníctva súboru alebo priečinka",
    "Choose file or folder to transfer" : "Vyberte súbor alebo priečinok na prevod",
    "Change" : "Zmeniť",
    "New owner" : "Nový vlastník",
    "Keep {old}" : "Ponechať {old}",
    "Keep without extension" : "Ponechať bez prípony",
    "Use {new}" : "Použiť {new}",
    "Remove extension" : "Odstrániť príponu",
    "Change file extension" : "Zmeniť príponu súboru",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Zmena prípony súboru z „{old}“ na „{new}“ môže spôsobiť, že súbor bude nečitateľný.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "Odstránenie prípony súboru „{old}“ môže spôsobiť, že súbor bude nečitateľný.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "Pridanie prípony súboru „{new}“ môže spôsobiť, že súbor bude nečitateľný.",
    "Do not show this dialog again." : "Toto dialógové okno už nezobrazovať.",
    "Select file or folder to link to" : "Vyberte súbor alebo priečinok na ktorý odkazovať",
    "Choose {file}" : "Vyberte {file}",
    "Share" : "Zdieľať",
    "Shared by link" : "Sprístupnené odkazom",
    "Shared" : "Sprístupnené",
    "Switch to list view" : "Prepnúť na zobrazenie v zozname",
    "Switch to grid view" : "Prepnúť na zobrazenie v mriežke",
    "The file could not be found" : "Súbor nebol nájdený",
    "Upload was cancelled by user" : "Nahrávanie bolo zrušené užívateľom",
    "Not enough free space" : "Nedostatok voľného miesta",
    "Operation is blocked by access control" : "Činnosť je blokovaná kontrolou prístupu",
    "Error during upload: {message}" : "Chyba počas nahrávania: {message}",
    "Error during upload, status code {status}" : "Chyba počas nahrávania, chybový kód {status}",
    "Unknown error during upload" : "Neznáma chyba počas nahrávania",
    "Loading current folder" : "Načítavanie súčasného priečinka",
    "Retry" : "Zopakovať",
    "No files in here" : "Nie sú tu žiadne súbory",
    "Upload some content or sync with your devices!" : "Nahrajte nejaký obsah alebo synchronizujte dáta so svojimi zariadeniami!",
    "Go back" : "Ísť späť",
    "Views" : "Zobrazenia",
    "Files settings" : "Nastavenia súborov",
    "Your files" : "Vaše súbory",
    "Open in files" : "Otvoriť v súboroch",
    "File cannot be accessed" : "Súbor nie je možné sprístupniť",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Súbor sa nenašiel alebo nemáte oprávnenie na jeho zobrazenie. Požiadajte odosielateľa, aby ho sprístupnil.",
    "Clipboard is not available" : "Schránka nie je prístupná",
    "General" : "Všeobecné",
    "All files" : "Všetky súbory",
    "Personal files" : "Osobné súbory",
    "Sort favorites first" : "Zoradiť od najobľúbenejších",
    "Sort folders before files" : "Zoradiť adresáre pred súbormi",
    "Appearance" : "Vzhľad",
    "Show hidden files" : "Zobraziť skryté súbory",
    "Crop image previews" : "Orezať náhľady obrázkov",
    "Additional settings" : "Ďalšie nastavenia",
    "WebDAV" : "WebDAV",
    "WebDAV URL" : "WebDAV URL",
    "Copy" : "Kopírovať",
    "Warnings" : "Upozornenia",
    "Keyboard shortcuts" : "Klávesové skratky",
    "File actions" : "Akcie súboru",
    "Rename" : "Premenovať",
    "Delete" : "Zmazať",
    "Manage tags" : "Spravovať štítky",
    "Selection" : "Výber",
    "Select all files" : "Vybrať všetky súbory",
    "Deselect all" : "Odznačiť všetko",
    "Navigation" : "Navigácia",
    "View" : "Zobraziť",
    "Toggle grid view" : "Prepnúť zobrazenie mriežky",
    "Show those shortcuts" : "Zobraziť klávesové skratky",
    "You" : "Vy",
    "Shared multiple times with different people" : "Zdieľané viackrát rôznymi ľuďmi",
    "Unable to change the favorite state of the file" : "Nie je možné zmeniť stav „obľúbené“ súboru",
    "Error while loading the file data" : "Chyba pri načítaní údajov súboru",
    "Owner" : "Vlastník",
    "Remove from favorites" : "Odstrániť z obľúbených",
    "Add to favorites" : "Pridať do obľúbených",
    "Tags" : "Štítky",
    "Blank" : "Prázdne",
    "Unable to create new file from template" : "Nemôžem vytvoriť nový súbor zo šablóny",
    "Pick a template for {name}" : "Vyberte šablónu pre {name}",
    "Create a new file with the selected template" : "Vytvoriť nový súbor pomocou vybranej šablóny",
    "Creating file" : "Vytvára sa súbor",
    "Save as {displayName}" : "Uložiť ako {displayName}",
    "Save as …" : "Uložiť ako ...",
    "Converting files …" : "Konverzia súborov ...",
    "Failed to convert files: {message}" : "Nepodarilo sa skonvertovať súbory: {message}",
    "All files failed to be converted" : "Nepodarilo sa skonvertovať žiadne súbory",
    "One file could not be converted: {message}" : "Jeden súbor sa nepodarilo skonvertovať: {message}",
    "_One file could not be converted_::_%n files could not be converted_" : ["Jeden súbor sa nepodarilo skonvertovať","%n súbory sa nepodarilo skonvertovať","%n súborov sa nepodarilo skonvertovať","%n súborov sa nepodarilo skonvertovať"],
    "_One file successfully converted_::_%n files successfully converted_" : ["Jeden súbor bol úspešne skonvertovaný","%n súbory boli úspešne skonvertované","%n súborov bolo úspešne skonvertovaných","%n súborov bolo úspešne skonvertovaných"],
    "Files successfully converted" : "Súbory boli úspešne skonvertované",
    "Failed to convert files" : "Konverzia súborov zlyhala",
    "Converting file …" : "Konverzia súborov ...",
    "File successfully converted" : "Súbor bol úspešne skonvertovaný",
    "Failed to convert file: {message}" : "Nepodarilo sa skonvertovať súbor: {message}",
    "Failed to convert file" : "Konverzia súboru zlyhala",
    "Leave this share" : "Opustiť toto zdieľanie.",
    "Leave these shares" : "Opustiť tieto zdieľania.",
    "Disconnect storage" : "Odpojiť úložisko",
    "Disconnect storages" : "Odpojiť úložiská",
    "Delete permanently" : "Zmazať  natrvalo",
    "Delete and unshare" : "Vymazať a zrušiť zdieľanie",
    "Delete file" : "Zmazať súbor",
    "Delete files" : "Zmazať súbory",
    "Delete folder" : "Zmazať priečinok",
    "Delete folders" : "Zmazať priečinky",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Chystáte sa permanentne vymazať {count} položku","Chystáte sa permanentne vymazať {count} položky","Chystáte sa permanentne vymazať {count} položiek","Chystáte sa permanentne vymazať {count} položiek"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Chystáte sa vymazať {count} položku","Chystáte sa vymazať {count} položky","Chystáte sa vymazať {count} položiek","Chystáte sa vymazať {count} položiek"],
    "Confirm deletion" : "Potvrdiť vymazanie",
    "Cancel" : "Zrušiť",
    "Download" : "Stiahnuť",
    "Moving \"{source}\" to \"{destination}\" …" : "Presúvanie \"{source}\" do \"{destination}\" …",
    "Copying \"{source}\" to \"{destination}\" …" : "Kopírovanie \"{source}\" do \"{destination}\" …",
    "Destination is not a folder" : "Cieľ nie je priečinok",
    "This file/folder is already in that directory" : "Tento súbor/priečinok sa už v danom adresári nachádza",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Nemôžete presunúť súbor/priečinok do seba alebo do jeho podpriečinka.",
    "(copy)" : "(kopírovať)",
    "(copy %n)" : "(kopírovať %n)",
    "A file or folder with that name already exists in this folder" : "Súbor alebo priečinok s týmto názvom už existuje v tomto priečinku",
    "The files are locked" : "Súbory sú uzamknuté.",
    "The file does not exist anymore" : "Súbor už neexistuje",
    "Choose destination" : "Vyberte cieľ",
    "Copy to {target}" : "Kopírovať do {target}",
    "Move to {target}" : "Presunúť do {target}",
    "Move" : "Presunúť",
    "Move or copy operation failed" : "Operácia presunu alebo kopírovania zlyhala",
    "Move or copy" : "Presunúť alebo kopírovať",
    "Open folder {displayName}" : "Otvoriť priečinok {displayName}",
    "Open in Files" : "Otvoriť v súboroch",
    "Open locally" : "Otvoriť lokálne",
    "Failed to redirect to client" : "Nepodarilo sa presmerovať na klienta",
    "Open file locally" : "Otvoriť súbor lokálne",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Súbor by sa mal teraz otvoriť v zariadení. Ak sa tak nestane, skontrolujte, či máte nainštalovanú aplikáciu pre počítače.",
    "Retry and close" : "Skúsiť znova a zatvoriť",
    "Open online" : "Otvoriť online",
    "Details" : "Podrobnosti",
    "View in folder" : "Zobraziť v priečinku",
    "Today" : "Dnes",
    "Last 7 days" : "Posledných 7 dní",
    "Last 30 days" : "Posledných 30 dní",
    "This year ({year})" : "Tento rok ({year})",
    "Last year ({year})" : "Minulý rok ({year})",
    "Documents" : "Dokumenty",
    "Spreadsheets" : "Tabuľky",
    "Presentations" : "Prezentácie",
    "PDFs" : "PDFká",
    "Folders" : "Priečinky",
    "Audio" : "Zvuk",
    "Images" : "Obrázky",
    "Videos" : "Videá",
    "Created new folder \"{name}\"" : "Vytvorený nový priečinok \"{name}\"",
    "Unable to initialize the templates directory" : "Nemôžem inicializovať priečinok so šablónami",
    "Create templates folder" : "Vytvoriť adresár pre šablóny",
    "Templates" : "Šablóny",
    "New template folder" : "Nový adresár šablóny",
    "In folder" : "V adresári",
    "Search in folder: {folder}" : "Hľadať v adresári: {folder}",
    "One of the dropped files could not be processed" : "Jeden z vložených súborov nemohol byť spracovaný.",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Váš prehliadač nepodporuje Filesystem API. Adresáre nebudú nahrané",
    "No files to upload" : "Žiadne súbory pre nahratie",
    "Unable to create the directory {directory}" : "Nie je možné vytvoriť adresár {directory}",
    "Some files could not be uploaded" : "Niektoré súbory nebolo možné nahrať.",
    "Files uploaded successfully" : "Súbory boli úspešne nahrané.",
    "No files to process" : "Žiadne súbory pre spracovanie",
    "Some files could not be copied" : "Niektoré súbory nebolo možné skopírovať",
    "Some files could not be moved" : "Niektoré súbory nebolo možné presunúť",
    "Files copied successfully" : "Súbory boli úspešne skopírované",
    "Files moved successfully" : "Súbory boli úspešne presunuté",
    "Conflicts resolution skipped" : "Riešenie konfliktov bolo preskočené",
    "Upload cancelled" : "Odosielanie bolo zrušené",
    "Could not rename \"{oldName}\", it does not exist any more" : "Nebolo možné premenovať  \"{oldName}\". Položka už neexistuje.",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Názov \"{newName}\" sa už používa v priečinku \"{dir}\". Vyberte prosím iný názov.",
    "Could not rename \"{oldName}\"" : "Nebolo možné premenovať \"{oldName}\"",
    "This operation is forbidden" : "Táto operácia je zakázaná",
    "Storage is temporarily not available" : "Úložisko je dočasne nedostupné",
    "Unexpected error: {error}" : "Neočakávaná chyba: {error}",
    "_%n file_::_%n files_" : ["%n súbor","%n súbory","%n súborov","%n súborov"],
    "_%n folder_::_%n folders_" : ["%n priečinok","%n priečinky","%n priečinkov","%n priečinkov"],
    "Filename must not be empty." : "Názov súboru nesmie byť prázdny.",
    "\"{char}\" is not allowed inside a filename." : "Znak \"{char}\" nie je povolený v názve súboru.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" je rezervované slovo a nie je možné ho použiť v názvoch súborov.",
    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" nie je povolená prípona súboru.",
    "Filenames must not end with \"{extension}\"." : "Názvy súborov nesmú končiť s \"{extension}\"",
    "List of favorite files and folders." : "Zoznam obľúbených súborov a priečinkov.",
    "No favorites yet" : "Zatiaľ žiadne obľúbené",
    "Files and folders you mark as favorite will show up here" : "Súbory a priečinky označené ako obľúbené budú zobrazené tu",
    "List of your files and folders." : "Zoznam vašich súborov a priečinkov.",
    "List of your files and folders that are not shared." : "Zoznam vašich súborov a priečinkov, ktoré nie sú zdieľané.",
    "No personal files found" : "Žiadne osobné súbory nenájdené",
    "Files that are not shared will show up here." : "Súbory, ktoré nie sú zdieľané, sa tu nezobrazia.",
    "Recent" : "Nedávne",
    "List of recently modified files and folders." : "Zoznam nedávno upravených súborov a priečinkov.",
    "No recently modified files" : "Žiadne nedávno upravené súbory",
    "Files and folders you recently modified will show up here." : "Súbory a priečinky, ktoré ste nedávno upravili sa zobrazia tu",
    "Search" : "Hľadať",
    "No entries found in this folder" : "V tomto priečinku nebolo nič nájdené",
    "Select all" : "Vybrať všetko",
    "Upload too large" : "Nahrávanie je príliš veľké",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Súbory, ktoré sa snažíte nahrať, presahujú maximálnu veľkosť pre nahratie súborov na tento server.",
    "File could not be found" : "Súbor nie je možné nájsť",
    "Show list view" : "Zobraziť ako zoznam",
    "Show grid view" : "Zobraziť v mriežke",
    "Close" : "Zavrieť",
    "Could not create folder \"{dir}\"" : "Nemožno vytvoriť priečinok \"{dir}\"",
    "This will stop your current uploads." : "Toto zastaví práve prebiehajúce nahrávania.",
    "Upload cancelled." : "Odosielanie je zrušené.",
    "Processing files …" : "Spracovávam súbory ...",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nemožno nahrať súbor {filename}, pretože je to priečinok, alebo má 0 bitov",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nie je dostatok voľného miesta, chcete nahrať {size1} ale k dispozíciji je len {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Cieľový priečinok \"{dir}\" už neexistuje",
    "An unknown error has occurred" : "Vyskytla sa neznáma chyba",
    "File could not be uploaded" : "Súbor nemôže byť nahraný",
    "Uploading …" : "Nahrávanie...",
    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
    "Uploading … ({currentNumber}/{total})" : "Nahrávanie... ({currentNumber}/{total})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} z {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Nahrávanie tejto položky nie je podporované",
    "Error when assembling chunks, status code {status}" : "Chyba pri zostavovaní kusov, kód chyby {status}",
    "Choose target folder" : "Vyberte cieľový priečinok",
    "Set reminder" : "Nastaviť pripomienku",
    "Edit locally" : "Editovať lokálne",
    "Open" : "Otvoriť",
    "Could not load info for file \"{file}\"" : "Nebolo možné načítať informácie súboru \"{file}\"",
    "Please select tag(s) to add to the selection" : "Prosím vyberte štítok (štítky) pre pridanie do výberu",
    "Apply tag(s) to selection" : "Aplikovať štítok(štítky) do výberu",
    "Select directory \"{dirName}\"" : "Vybrať priečinok \"{dirName}\"",
    "Select file \"{fileName}\"" : "Vybrať súbor \"{fileName}\"",
    "Unable to determine date" : "Nemožno určiť dátum",
    "This directory is unavailable, please check the logs or contact the administrator" : "Priečinok je nedostupný, skontrolujte prosím logy, alebo kontaktujte správcu",
    "Could not move \"{file}\", target exists" : "Nie je možné presunúť \"{file}\", cieľ už existuje",
    "Could not move \"{file}\"" : "Nie je možné presunúť \"{file}\"",
    "copy" : "kópia",
    "Could not copy \"{file}\", target exists" : "Nie je možné kopírovať \"{file}\", cieľ už existuje",
    "Could not copy \"{file}\"" : "Nie je možné skopírovať \"{file}\"",
    "Copied {origin} inside {destination}" : "Skopírované {origin} do {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Skopírované {origin} a {nbfiles} ostatných súborov do {destination}",
    "{newName} already exists" : "{newName} už existuje",
    "Could not create file \"{file}\"" : "Nie je možné vytvoriť súbor \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Nie je možné vytvoriť súbor \"{file}\" lebo už existuje",
    "Could not create folder \"{dir}\" because it already exists" : "Nie je možné vytvoriť priečinok \"{dir}\" lebo už existuje",
    "Could not fetch file details \"{file}\"" : "Podrobnosti o súbore „{file}“ sa nepodarilo načítať",
    "Error deleting file \"{fileName}\"." : "Chyba pri mazaní súboru \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Žiadne výsledky vyhľadávania v ostatných priečinkoch pre {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Ak chcete hľadať v iných priečinkoch, zadajte viac ako dva znaky",
    "{dirs} and {files}" : "{dirs} a {files}",
    "_including %n hidden_::_including %n hidden_" : ["vrátane %n skytého","vrátane %n skrytých","vrátane %n skrytých","vrátane %n skrytých"],
    "You do not have permission to upload or create files here" : "Nemáte oprávnenie sem nahrávať alebo vytvárať súbory",
    "_Uploading %n file_::_Uploading %n files_" : ["Nahráva sa %n súbor","Nahrávajú sa %n súbory","Nahráva sa %n súborov","Nahráva sa %n súborov"],
    "New" : "Nový",
    "New file/folder menu" : "Ponuka nového súboru/priečinka",
    "Select file range" : "Vybrať rozsah súborov",
    "{used}%" : "{used}%",
    "{used} used" : "{used} použitých",
    "\"{name}\" is an invalid file name." : "\"{name}\" je neplatné meno súboru.",
    "File name cannot be empty." : "Meno súboru nemôže byť prázdne",
    "\"/\" is not allowed inside a file name." : "Znak \"/\" nie je povolený v názve súboru.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" nie je povolený typ súboru",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Úložisko používateľa {owner} je plné, súbory sa viac nedajú aktualizovať ani synchronizovať!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Priečinok skupiny \"{mountPoint}\" je plné, súbory nemožno aktualizovať ani synchronizovať!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Externé úložisko \"{mountPoint}\" je plné, súbory nemožno aktualizovať ani synchronizovať!",
    "Your storage is full, files cannot be updated or synced anymore!" : "Vaše úložisko je plné, súbory nemožno aktualizovať ani synchronizovať!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Úloisko používateľa {owner} je takmer plné ({usedSpacePercent}%)",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Priečinok skupiny \"{mountPoint}\" je takmer plné ({usedSpacePercent}%)",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Externé úložisko \"{mountPoint}\" je takmer plné ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)." : "Vaše úložisko je takmer plné ({usedSpacePercent}%)",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["odpovedá \"{filter}\"","odpovedá \"{filter}\"","odpovedá \"{filter}\"","odpovedajú \"{filter}\""],
    "Direct link was copied (only works for people who have access to this file/folder)" : "Priamy odkaz bol skopirovaný (funguje iba pre užívateľov, ktorí majú prístup k danému súboru/adresáru)",
    "Path" : "Cesta",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajty","%n bajtov","%n bajtov"],
    "Favored" : "Zaradiť medzi obľúbené",
    "Favor" : "Zaradené medzi obľúbené",
    "Copy direct link (only works for people who have access to this file/folder)" : "Kopírovať priamy odkaz (funguje iba pre užívateľov, ktorí majú prístup k tomuto súboru/priečinku)",
    "Upload file" : "Nahrať súbor",
    "Not favored" : "Nie je v obľúbených",
    "An error occurred while trying to update the tags" : "Pri pokuse o aktualizáciu štítkov došlo k chybe",
    "Upload (max. %s)" : "Nahrať (max. %s)",
    "\"{displayName}\" action executed successfully" : "\"{displayName}\" akcia vykonaná úspešne",
    "\"{displayName}\" action failed" : "\"{displayName}\" akcia zlýhala",
    "\"{displayName}\" failed on some elements" : "\"{displayName}\" zlyhalo na niektorých prvkoch.",
    "\"{displayName}\" batch action executed successfully" : "Hromadná operácia \"{displayName}\" bola úspešne vykonaná",
    "Submitting fields…" : "Položky sa odosielajú ...",
    "Filter filenames…" : "Filtrovať názvy súborov...",
    "WebDAV URL copied to clipboard" : "WebDAV URL skopirovaná do schránky",
    "Enable the grid view" : "Povoliť zobrazenie v mriežke",
    "Enable folder tree" : "Povoliť adresárový strom",
    "Copy to clipboard" : "Skopírovať do schránky",
    "Use this address to access your Files via WebDAV" : "Táto adresa sa používa na prístup k vašim súborom prostredníctvom WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Ak ste povolili 2FA, musíte kliknutím sem vytvoriť a použiť nové heslo pre aplikáciu.",
    "Deletion cancelled" : "Zmazanie zrušené",
    "Move cancelled" : "Presun zrušený",
    "Cancelled move or copy of \"{filename}\"." : "Zrušené kopírovanie alebo presun \"{filename}\".",
    "Cancelled move or copy operation" : "Zrušená operácia kopírovania alebo presunu",
    "Open details" : "Otvoriť detaily",
    "Photos and images" : "Fotky a obrázky",
    "New folder creation cancelled" : "Vytvorenie adresára bolo zrušené",
    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} priečinok","{folderCount} priečinky","{folderCount} priečinkov","{folderCount} priečinkov"],
    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} súbor","{fileCount} súbory","{fileCount} súborov","{fileCount} súborov"],
    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 súbor a {folderCount} priečinok","1 súbor a {folderCount} priečinky","1 súbor a {folderCount} priečinky","1 súbor a {folderCount} priečinky"],
    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} súbor a 1 priečinok","{fileCount} súborov a 1 priečinok","{fileCount} súborov a 1 priečinok","{fileCount} súborov a 1 priečinok"],
    "{fileCount} files and {folderCount} folders" : "{fileCount} súborov a {folderCount} priečinkov",
    "All folders" : "Všetky adresáre",
    "Personal Files" : "Osobné Súbory",
    "Text file" : "Textový súbor",
    "New text file.txt" : "Nový text file.txt",
    "Filter file names …" : "Filtrovať názvy súborov ...",
    "Prevent warning dialogs from open or reenable them." : "Zabrániť otváraniu varovných dialógov alebo ich znova povoliť.",
    "Show a warning dialog when changing a file extension." : "Pri zmene prípony súboru zobraziť dialógové okno s upozornením.",
    "Speed up your Files experience with these quick shortcuts." : "Zrýchlite používanie Súborov využitím klávesových skratiek.",
    "Open the actions menu for a file" : "Otvoriť menu akcií pre súbor",
    "Rename a file" : "Premenovať súbor",
    "Delete a file" : "Zmazať súbor",
    "Favorite or remove a file from favorites" : "Pridať alebo odobrať súbor z obľúbených",
    "Manage tags for a file" : "Spravovať štítky súborov",
    "Deselect all files" : "Zrušiť výber všetkých súborov",
    "Select or deselect a file" : "Vybrať alebo zrušiť výber súboru",
    "Select a range of files" : "Vybrať viacero súborov",
    "Navigate to the parent folder" : "Navigovať do nadradeného adresára",
    "Navigate to the file above" : "Navigovať na predošlý súbor",
    "Navigate to the file below" : "Navigovať na ďalší súbor",
    "Navigate to the file on the left (in grid mode)" : "Navigovať na súbor vľavo (v režime zobrazenia v mriežke)",
    "Navigate to the file on the right (in grid mode)" : "Navigovať na súbor vpravo (v režime zobrazenia v mriežke)",
    "Toggle the grid view" : "Prepnúť na zobrazenie v mriežke",
    "Open the sidebar for a file" : "Otvoriť bočný panel pre súbor"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
