OC.L10N.register(
    "logreader",
    {
    "Logging" : "Dnevnik beleženja",
    "Errors in the log" : "Napake v dnevniških zapisih",
    "No errors in the logs since %s" : "V dnevniških zapisih ni napak od %s",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["V dnevniških zapisih je zabeležena %n napaka (%s je datum prve)","V dnevniških zapisih sta zabeleženi %n napaki (%s je datum prve)","V dnevniških zapisih je zabeležene %n napake (%s je datum prve)","V dnevniških zapisih je zabeleženih %n napak (%s je datum prve)"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["V dnevniških zapisih je zabeleženo %n opozorilo (%s je datum prvega)","V dnevniških zapisih sta zabeleženi %n opozorili (%s je datum prvega)","V dnevniških zapisih so zabeležena %n opozorila (%s je datum prvega)","V dnevniških zapisih je zabeleženih %n opozoril (%s je datum prvega)"],
    "Log Reader" : "Bralnik dnevnikov",
    "A log reader for Nextcloud" : "Bralnik dnevnikov za Nextcloud",
    "Log reader for Nextcloud" : "Bralnik dnevnikov za Nextcloud",
    "Log reader" : "Bralnik dnevnikov",
    "Open log reader settings" : "Odpri nastavitve bralnika dnevnikov",
    "Log reader settings" : "Nastavitve bralnika dnevnikov",
    "Show server log" : "Pokaži dnevnik strežnika",
    "Live view is disabled" : "Pogled v živo je onemogočen",
    "No log file" : "Ni datoteke nevniškega zapisa",
    "Level" : "Raven",
    "App" : "Program",
    "Time" : "Čas",
    "Copy raw entry" : "Kopiraj neoblikovan vpis",
    "Copy formatted entry" : "Kopiraj oblikovan vpis",
    "Search log entries" : "Preišči dnevniške vnose",
    "Line {line}" : "Vrstica {line}",
    "Live view" : "Pogled v živo",
    "Ctrl" : "CTRL",
    "Download logs" : "Prejem dnevnikov",
    "Raw data" : "Surovi podatki",
    "Local time" : "Krajevni čas",
    "UTC time" : "Čas v sistemu UTC",
    "Relative" : "Relativno",
    "Filter logging levels" : "Filtriraj ravni beleženja",
    "Application" : "Program",
    "Message" : "Sporočilo",
    "Collapse row" : "Zloži vrstico",
    "Expand row" : "Razširi vrstico",
    "Show details" : "Pokaži podrobnosti",
    "Debug" : "Razhroščevanje",
    "Info" : "Podrobnosti",
    "Warning" : "Opozorilo",
    "Error" : "Napaka",
    "Fatal" : "Usodna napaka",
    "Could not load log entries" : "Ni mogoče naložiti vnosov dnevnika",
    "Clipboard" : "Odložišče",
    "Could not parse clipboard content" : "Ni mogoče razčleniti vsebine datoteke",
    "Could not fetch new log entries (server unavailable)" : "Ni mogoče pridobiti novih vnosov (strežnik ni na voljo)",
    "Could not fetch new entries" : "Ni mogoče pridobiti novih vnosov",
    "Could not copy to clipboard, please copy manually:" : "Kopiranje v odložišče ni mogoče, poskusite kopirati ročno:",
    "\tfrom {address} by {user} at {time}\n" : "\tz naslova {address}, uporabnik {user} ob {time}\n"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
