<?php
// This file was auto-generated from sdk-root/src/data/ssm-quicksetup/2018-05-10/paginators-1.json
return [ 'pagination' => [ 'ListConfigurationManagers' => [ 'input_token' => 'StartingToken', 'output_token' => 'NextToken', 'limit_key' => 'MaxItems', 'result_key' => 'ConfigurationManagersList', ], ],];
