OC.L10N.register(
    "profile",
    {
    "Profile" : "Profiel",
    "This application provides the profile" : "Deze applicatie biedt het profiel",
    "Provides a customisable user profile interface." : "Biedt een aanpasbare gebruikersprofielinterface.",
    "You have not added any info yet" : "Je hebt nog geen info toegevoegd",
    "{user} has not added any info yet" : "{user} heeft nog geen info toegevoegd",
    "Error opening the user status modal, try hard refreshing the page" : "Fout bij het openen van het gebruiker status model, probeer een harde refresh van de pagina",
    "Edit Profile" : "Wijzig Profiel",
    "The headline and about sections will show up here" : "De koplijn- en oversectie zal hier verschijnen",
    "Profile not found" : "Profiel niet gevonden",
    "The profile does not exist." : "Het profiel bestaat niet.",
    "Back to %s" : "Terug naar %s"
},
"nplurals=2; plural=(n != 1);");
