OC.L10N.register(
    "app_api",
    {
    "Daemon config not found" : "Nie znaleziono konfiguracji demona",
    "AppAPI authentication failed" : "Uwierzytelnienie AppAPI nie powiodło się",
    "AppAPI ExApp notifier" : "Powiadomienie AppAPI ExApp",
    "AppAPI" : "AppAPI",
    "Nextcloud AppAPI" : "AppAPI Nextcloud",
    "The AppAPI Project is an exciting initiative that aims to revolutionize the way applications are developed for Nextcloud." : "Projekt AppAPI to ekscytująca inicjatywa, której celem jest zrewolucjonizowanie sposobu tworzenia aplikacji dla Nextcloud.",
    "ExApp initialization process timeout after which AppAPI will mark it as failed" : "Upłynął limit czasu procesu inicjalizacji ExApp, po którym AppAPI oznaczy go jako zakończony niepowodzeniem",
    "This settings changes are reflected only for newly created containers" : "Zmiany tych ustawień zostaną odzwierciedlone tylko w przypadku nowo utworzonych kontenerów",
    "Admin options saved" : "Opcje administracyjne zostały zapisane",
    "Failed to save admin options" : "Nie udało się zapisać opcji administratora",
    "Cancel" : "Anuluj",
    "Delete" : "Usuń",
    "Default" : "Domyślny",
    "Set as default" : "Ustaw jako domyślny",
    "Edit" : "Edycja",
    "Failed to save admin options. Check the logs" : "Nie udało się zapisać opcji administratora. Sprawdź dzienniki",
    "Password confirmation failed" : "Potwierdzenie hasła nie powiodło się",
    "Name" : "Nazwa",
    "Protocol" : "Protokół",
    "Host" : "Host",
    "Docker network" : "Sieć Dockera",
    "Nextcloud URL" : "Adres URL Nextcloud",
    "GPUs support" : "Obsługa procesorów graficznych",
    "Compute device" : "Urządzenie obliczeniowe",
    "Additional options" : "Dodatkowe opcje",
    "Verify connection" : "Sprawdź połączenie",
    "AppAPI will try to install small skeleton ExApp to verify Daemon configured correctly and deployment steps are passing." : "AppAPI spróbuje zainstalować mały szkielet ExApp, aby sprawdzić, czy demon jest poprawnie skonfigurowany i czy etapy wdrażania zostały wykonane.",
    "More info" : "Więcej informacji",
    "Enabled" : "Włączone",
    "Display name" : "Wyświetlana nazwa",
    "Deployment method" : "Metoda wdrażania",
    "Select daemon deploy method" : "Wybierz metodę wdrażania demona",
    "Network" : "Sieć",
    "Docker network name" : "Nazwa sieci Dockera",
    "AppAPI Docker Socket Proxy authentication password" : "Hasło uwierzytelniające AppAPI Docker Socket Proxy",
    "Additional option" : "Opcja dodatkowa",
    "Add additional option" : "Dodaj dodatkową opcję",
    "Option key is required" : "Wymagany jest klucz opcji",
    "Option value" : "Wartość opcji",
    "Option value is required" : "Wymagana jest wartość opcji",
    "Confirm" : "Potwierdź",
    "Save" : "Zapisz",
    "Register" : "Zarejestruj się",
    "Check connection" : "Sprawdź połączenie",
    "Hostname to access ExApps" : "Nazwa hosta umożliwiająca dostęp do ExApps",
    "Hostname or path to access Docker daemon (e.g. nextcloud-appapi-dsp:2375, /var/run/docker.sock)" : "Nazwa hosta lub ścieżka dostępu do demona Docker (np. nextcloud-appapi-dsp:2375, /var/run/docker.sock)",
    "Daemon with this name already exists" : "Demon o tej nazwie już istnieje",
    "Password must be at least 12 characters long" : "Hasło musi mieć co najmniej 12 znaków",
    "With https enabled network is set to host" : "Przy włączonym https sieć jest ustawiona na host",
    "External Apps" : "Aplikacje zewnętrzne",
    "Update to {version}" : "Zaktualizuj do {version}",
    "Remove" : "Usuń",
    "Delete data on remove" : "Usuń dane przy usuwaniu",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ta aplikacja nie ma przypisanej minimalnej wersji Nextcloud. W przyszłości będzie to błąd.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ta aplikacja nie ma przypisanej maksymalnej wersji Nextcloud. W przyszłości będzie to błąd.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ta aplikacja nie może być zainstalowana, ponieważ nie są spełnione następujące zależności:",
    "View in store" : "Zobacz w sklepie",
    "Visit website" : "Odwiedź stronę",
    "Report a bug" : "Zgłoś błąd",
    "User documentation" : "Dokumentacja użytkownika",
    "Admin documentation" : "Dokumentacja administratora",
    "Developer documentation" : "Dokumentacja dewelopera",
    "This app is not registered in AppStore. No extra information available. Only enable/disable and remove actions are allowed." : "Ta aplikacja nie jest zarejestrowana w AppStore. Brak dodatkowych informacji. Dozwolone są tylko akcje włączania/wyłączania i usuwania.",
    "{license}-licensed" : "na licencji {license}",
    "This app is supported via your current Nextcloud subscription." : "Ta aplikacja jest obsługiwana za pośrednictwem bieżącej subskrypcji Nextcloud.",
    "Supported" : "Wspierany",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Polecane aplikacje są tworzone przez społeczność. Oferują główną funkcjonalność i są gotowe do użycia w produkcji.",
    "Featured" : "Polecane",
    "Update to {update}" : "Zaktualizuj do {update}",
    "All ExApps are up-to-date." : "Wszystkie ExApps są aktualne.",
    "Default Deploy daemon is not accessible" : "Domyślny demon wdrażania jest niedostępny",
    "Icon" : "Ikona",
    "Version" : "Wersja",
    "Daemon" : "Demon",
    "Level" : "Poziom",
    "Actions" : "Akcje",
    "Results from other categories" : "Wyniki z innych kategorii",
    "No apps found" : "Nie znaleziono aplikacji",
    "_Update_::_Update all_" : ["Zaktualizuj","Zaktualizuj","Zaktualizuj","Zaktualizuj wszystko"],
    "Type" : "Rodzaj",
    "Display Name" : "Wyświetlana nazwa",
    "Your apps" : "Twoje aplikacje",
    "Documentation" : "Dokumentacja",
    "Details" : "Szczegóły",
    "Changelog" : "Dziennik zmian",
    "by {author}\n{license}" : "wykonane przez {author}\n{license}",
    "Active apps" : "Aktywne aplikacje",
    "Disabled apps" : "Wyłączone aplikacje",
    "Updates" : "Aktualizacje",
    "Featured apps" : "Polecane aplikacje",
    "Supported apps" : "Obsługiwane aplikacje",
    "manual-install apps cannot be updated" : "aplikacji instalowanych ręcznie nie można aktualizować",
    "Healthchecking" : "Sprawdzanie stanu zdrowia",
    "Deploy and Enable" : "Wdróż i włącz",
    "Enable" : "Włącz",
    "Disable" : "Wyłącz",
    "Allow untested app" : "Zezwól na nietestowane aplikacje",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ta aplikacja jest niezgodna z wersją Nextcloud. Przy dalszej kontynuacji, możesz pozwolić na zainstalowanie tej aplikacji. Pamiętaj, że aplikacja może nie działać zgodnie z oczekiwaniami.",
    "Your ExApps" : "Twoje ExApps",
    "An error occurred during the request. Unable to proceed." : "Wystąpił błąd podczas żądania. Nie można kontynuować.",
    "The app has been enabled but needs to be updated." : "Aplikacja została włączona, ale wymaga aktualizacji.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Błąd: Ta aplikacja nie zostanie włączona ze względu na możliwość niestabilnej pracy serwera"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
