OC.L10N.register(
    "related_resources",
    {
    "Calendar" : "Ημερολόγιο",
    "Deck" : "Deck",
    "Files" : "Αρχεία",
    "Talk conversation" : "Συνομιλία στο Talk",
    "Talk" : "Ομιλία"
},
"nplurals=2; plural=(n != 1);");
