<?php

declare(strict_types=1);


/**
 * SPDX-FileCopyrightText: 2022 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */


namespace OCA\RelatedResources\Tools\Exceptions;

use Exception;

/**
 * Class ItemNotFoundException
 *
 * @package OCA\RelatedResources\Tools\Exceptions
 */
class ItemNotFoundException extends Exception {
}
