OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Rilevada una positzione de identificatzione",
    "New login detected" : "Rilevada identificatzione noa",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6"
},
"nplurals=2; plural=(n != 1);");
