OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Introduktions guide",
    "Add your profile information! For example your email is needed to receive notifications." : "Tilføj dine profiloplysninger! For eksempel er din e-mail nødvendig for at modtage meddelelser.",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "Tilføj dine profiloplysninger! For eksempel er din e-mail nødvendig for at modtage meddelelser og nulstille din adgangskode.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Tilføj dine profil informationer! Tilføj et profil billede og fuldt navn for nemmere genkendelse på tværs af alle funktioner.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Tilføj dine profil informationer! Tilføj et fuldt navn for nemmere genkendelse på tværs af alle funktioner.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Tilføj dine profil informationer! Tilføj et profil billede for nemmere genkendelse på tværs af alle funktioner.",
    "App recommendation: Calendar" : "App anbefaling: Kalender",
    "Schedule work & meetings, synced with all your devices." : "Skemalagt arbejde og møder, synkroniseret med alle dine enheder.",
    "App recommendation: Contacts" : "App anbefaling: Kontakter",
    "Keep your colleagues and friends in one place without leaking their private info." : "Saml dine kollegaer og venner på et sted ude at lække deres private informationer.",
    "App recommendation: Mail" : "App anbefaling: Mail",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Simpel email-app som er integreret med Filer, Kontakter og Kalender.",
    "App recommendation: Tasks" : "Appanbefaling: Opgaver",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "Synkroniser opgaver fra forskellige enheder med din Nextcloud og rediger dem online.",
    "App recommendation: Deck" : "Appanbefaling: Opslag",
    "Kanban style organization for personal planning and team projects." : "Kanban-stilorganisation til personlig planlægning og teamprojekter.",
    "App recommendation: Forms" : "Appanbefaling: Formularer",
    "Simple surveys and questionnaires, self-hosted" : "Simple undersøgelser og spørgeskemaer, du selv styrer",
    "App recommendation: Recognize" : "Appanbefaling: Genkend",
    "Smart media tagging for Nextcloud" : "Intelligent medie tracking til Nextcloud ",
    "App recommendation: Group folders" : "Appanbefaling: Gruppemapper",
    "Admin-configured folders shared by everyone in a group." : "Administrator-konfigurerede mapper, der deles af alle i en gruppe.",
    "App recommendation: Whiteboard" : "App anbefaling: Whiteboard",
    "Create and share whiteboards with others and collaborate in real-time." : "Opret og del whiteboards med andre og samarbejd i realtid.",
    "Connect your calendar" : "Tilslut din kalender",
    "Connect your contacts" : "Tilslut dine kontaktpersoner",
    "Access files via WebDAV" : "Adgang til filer via WebDAV",
    "Download macOS/iOS configuration profile" : "Download macOS/iOS-konfigurationsprofil",
    "Desktop client" : "Skrivebordsklient",
    "Android app on Google Play Store" : "Android app i Google Play",
    "Android app on F-Droid" : "Android app på F-Droid",
    "iOS app" : "iOS-app",
    "About & What's new" : "Om & Hvad der er nyt",
    "A welcome and introduction wizard for Nextcloud" : "En velkomst- og introduktionsguide til Nextcloud",
    "This application enables a pop-up window when a user first logs into Nextcloud. This window welcomes new users to Nextcloud, and contains links to the standard desktop client, Android app, and the iOS app. The window also shows a link for accessing Nextcloud via WebDAV. At any time, the first run wizard can be opened again via link \"About\" on settings menu.\nThe First run wizard can be customized to meet specific design goals, or to change links and messages. Create an appropriate theme following the Theming documentation, and changes to the look and feel of this Wizard are simple. More information is available in the first run wizard documentation, as well as the theming documentation." : "Denne applikation aktiverer et pop op-vindue, når en bruger første gang logger på Nextcloud. Dette vindue byder nye brugere velkommen til Nextcloud og indeholder links til standard desktop-klienten, Android-appen og iOS-appen. Vinduet viser også et link til at få adgang til Nextcloud via WebDAV. Den første kørselsguide kan til enhver tid åbnes igen via linket \"Om\" i indstillingsmenuen.\nGuiden Første kørsel kan brugerdefineres til at opfylde specifikke designmål eller til at ændre links og beskeder. Opret et passende tema efter temadokumentationen, og ændringer i udseendet og fornemmelsen af denne guide er enkle. Mere information er tilgængelig i guidedokumentationen for første kørsel samt temadokumentationen.",
    "Download on Apple app store" : "Download i Apple app store",
    "Download on Google play store" : "Download i Google Play",
    "Go to previous page" : "Gå til forrige side",
    "Close" : "Luk",
    "More about Nextcloud" : "Mere omkring Nextcloud",
    "Explore more apps ↗" : "Find flere apps ↗",
    "Extend the functionality of Nextcloud with hundreds of community-developed apps." : "Udvid funktionaliteten af Nextcloud med hundredevis af apps udviklet af fællesskabet.",
    "Get involved! ↗" : "Bidrag! ↗",
    "Be a part of the community that helps build, design, translate and promote Nextcloud!" : "Du kan også blive en del af fællesskabet, der udvikler, designer, oversætter og promoverer Nextcloud!",
    "Need help? ↗" : "Brug for hjælp? ↗",
    "Find out more about your Nextcloud setup with the admin, user or developer documentation." : "Brug dokumentationen til at blive klogere på din Nextcloud installation, uanset om du er administrator, bruger eller udvikler.",
    "For large organisations ↗" : "Til større organisationer ↗",
    "Get Nextcloud Enterprise for mission critical environments where advanced security and compliance are important." : "Brug Nextcloud Enterprise ved kritiske miljøer hvor avanceret sikkerhed og krav til retningslinjer er vigtig.",
    "Seamless integration with your devices." : "Nem integration på dine enheder.",
    "Sync your files across your devices with the desktop and mobile apps, and connect your calendar and contacts." : "Synkroniser filer, kalender og kontaktpersoner imellem dine enheder, med computer og mobil apps.",
    "Desktop app ↗" : "App til computer ↗",
    "Download For Windows, Mac OS and Linux." : "Tilgængelig til Windows, Mac OS og Linux.",
    "Calendar and contacts ↗" : "Kalender og kontaktpersoner ↗",
    "Connect your calendar and contacts with your devices." : "Forbind din kalender og kontaktpersoner med dine enheder.",
    "Introducing Nextcloud Hub {version}" : "Introduktion af Nextcloud Hub {version}",
    "Welcome to {cloudName}!" : "Velkommen til {cloudName}!",
    "This Nextcloud is on version {version}" : "Denne Nextcloud er på version {version}",
    "A collaboration platform that puts you in control" : "En synkroniseringsplatform der giver dig kontrollen.",
    "Privacy" : "Privatliv",
    "Host your data and files where you decide." : "Host dine data og filer, hvor du bestemmer.",
    "Productivity" : "Få ting gjort",
    "Collaborate and communicate across any platform." : "Synkroniser og kommuniker på enhver platform.",
    "Interoperability" : "Gennemgående fleksibilitet",
    "Import and export anything you want with open standards." : "Importér og eksportér alt ved brug af åbne standarder",
    "Community" : "Onlinefællesskab",
    "Enjoy constant improvements from a thriving open-source community." : "Nyd konstante forbedringer fra et ivrigt open-source fællesskab.",
    "Nextcloud Hub {version} release" : "Nextcloud Hub {version} udgivelse",
    "Read more about it on the Nextcloud Hub {version} blog" : "Læs mere om det på Nextcloud Hub {version} bloggen",
    "Find out more on the blog" : "Find ud af mere på bloggen",
    "Read the Nextcloud Hub {version} blog" : "Læs Nextcloud Hub {version} bloggen",
    "Share your opinion about Nextcloud Hub {version}" : "Del din mening om Nextcloud Hub {version}",
    "Share via email" : "Del via e-mail",
    "Share on {socialMedia}" : "Del på {socialMedia}",
    "New in Nextcloud Hub {version}" : "Ny i Nextcloud Hub {version}",
    "Connect other apps to {productName}" : "Tilslut andre apps til {productName}",
    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to {productName}." : "Udover mobil apps og desktop klient kan du tilslutte enhver anden software, der understøtter WebDAV / CalDAV / CardDAV protokoller til {productName}.",
    "Apps to connect to {productName}" : "Apps der skal oprettes forbindelse til {productName}",
    "Set up sync clients using an {linkStart}app password{linkEnd}. That way you can make sure you are able to revoke access in case you lose that device." : "Indstil synkronisering af klienter ved hjælp af en {linkStart} app adgangskode {linkEnd}. På den måde kan du sørge for, at du er i stand til at tilbagekalde adgang, hvis du mister enheden.",
    "Get the apps to sync your files" : "Hent applikationerne for at synkronisere dine filer",
    "{productName} gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "{productName} giver dig adgang til dine filer, uanset hvor du er. Vores brugervenlige desktop- og mobilklienter er tilgængelige for alle større platforme uden omkostninger.",
    "App for syncing" : "App til synkronisering",
    "URL copied" : "URL kopieret",
    "Could not copy the URL, please copy manually" : "Kunne ikke kopiere URLen. Kopier venligst manuelt",
    "Server address" : "Serveradresse",
    "Use this link to connect your apps and desktop client to this server:" : "Brug dette link til at forbinde dine apps og desktop-klient til denne server:",
    "End-to-end encryption in calls and web" : "End-to-end kryptering i opkald og web",
    "Performance improvements across all our products" : "Ydeevneforbedringer på tværs af alle vores produkter",
    "Thousands of tweaks for improved UX and stability" : "Tusindvis af tweaks for forbedret UX og stabilitet",
    "Your own new personal assistant" : "Din egen nye personlige assistent",
    "Seamless file conversions" : "Gnidningsfrie filkonverteringer",
    "Smarter team sharing with Team folders" : "Smartere teamdeling med teammapper",
    "Schedule meetings directly in Talk" : "Planlæg møder direkte i Snak",
    "Mail you love again: translations, summaries, and mentions" : "Mail, du elsker igen: oversættelser, resuméer og omtaler",
    "Get to know the new features of Hub {version}" : "Lær de nye funktioner i Hub {version} at kende",
    "Nextcloud Hub 10 is here – your modular & unified digital workspace! 💫" : "Nextcloud Hub 10 er her – dit modulære og forenede digitale arbejdsområde! 💫",
    "What's new?" : "Hvad er nyt?",
    "Nextcloud on all your devices" : "Nextcloud på alle dine enheder",
    "Nextcloud Hub {version}" : "Nextcloud Hub {version}",
    "Read more" : "Læs mere",
    "Share on social media" : "Del på sociale medier",
    "Get started!" : "Kom i gang!",
    "App recommendation: Nextcloud Calendar" : "Appanbefaling: Nextcloud-kalender",
    "App recommendation: Nextcloud Contacts" : "Appanbefaling: Nextcloud-kontakter",
    "App recommendation: Nextcloud Mail" : "Appanbefaling: Nextcloud Mail",
    "Federated collaboration: file sharing, messaging, calls" : "Sammenkoblings samarbejde: fildeling, beskeder, opkald",
    "Nextcloud Whiteboard" : "Nextcloud Whiteboard",
    "Workflow Engine" : "Arbejdsflowmotor",
    "Safer and swifter mail" : "Sikker og hurtigere mail",
    "Public Collectives sharing, previews and QR-codes" : "Offentlige kollektiver delinger, forhåndsvisninger og QR-koder",
    "Office and PDF templates" : "Office og PDF skabeloner",
    "Chat mode for Nextcloud Assistant" : "Chattilstand til Nextcloud assistent",
    "Get to know the new features of Hub 9" : "Lær nye funktioner i Hub 9 at kende"
},
"nplurals=2; plural=(n != 1);");
