OC.L10N.register(
    "files_trashbin",
    {
    "restored" : "повратени",
    "Deleted files" : "Избришани датотеки",
    "Deleted files and folders in the trash bin (may expire during export if you are low on storage space)" : "Избришани датотеки и папки во корпата за отпадоци (може да истечат за време на извозот ако немате доволно простор за складирање)",
    "This application enables people to restore files that were deleted from the system." : "Оваа апликација им овозможува на корисниците да ги вратат датотеките што се избришани од системот.",
    "This application enables people to restore files that were deleted from the system. It displays a list of deleted files in the web interface, and has options to restore those deleted files back to the people file directories or remove them permanently from the system. Restoring a file also restores related file versions, if the versions application is enabled. When a file is deleted from a share, it can be restored in the same manner, though it is no longer shared. By default, these files remain in the trash bin for 30 days.\nTo prevent an account from running out of disk space, the Deleted files app will not utilize more than 50% of the currently available free quota for deleted files. If the deleted files exceed this limit, the app deletes the oldest files until it gets below this limit. More information is available in the Deleted Files documentation." : "Оваа апликација им овозможува на корисниците да ги вратат датотеките што се избришани од системот. Прикажува листа на избришани датотеки во веб-интерфејсот и има можност да ги вратите тие избришани датотеки назад до директориумот од каде се избришани или да ги отстраните трајно од системот. Враќањето на датотека ги враќа и нејзините верзии, доколку е овозможена апликацијата за верзии. Кога избришаната датотеката била споделена, таа може да се врати на ист начин, но истата повеќе не е споделена. Стандардно, овие датотеки остануваат во корпата за отпадоци 30 дена.\nСо цел да се спречи да не се искористи просторот за складирање на корисникот, апликацијата Избришани датотеки нема да користи повеќе од 50% од тековно достапната квота за избришани датотеки. Ако избришаните датотеки ја надминат оваа граница, апликацијата ги брише најстарите датотеки сè додека не се дојде под ова ограничување. Повеќе информации се достапни во документацијата за избришани датотеки.",
    "Restore" : "Врати",
    "Empty deleted files" : "Испразни ја корпата",
    "Confirm permanent deletion" : "Потврди бришење за стално",
    "Are you sure you want to permanently delete all files and folders in the trash? This cannot be undone." : "Дали сте сигурни дека сакате перманентно да ги избришете сите датотеки и папки од корпата за отпадоци? Оваа акција неможе да се врати назад.",
    "Cancel" : "Откажи",
    "Original location" : "Оргинална локација",
    "Deleted by" : "Избришано од",
    "Deleted" : "Избришана",
    "A long time ago" : "Многу одамна",
    "Unknown" : "Непознат",
    "All files" : "Сите датотеки",
    "You" : "Вас",
    "List of files that have been deleted." : "Листа на датотеки што ги имате избришано.",
    "No deleted files" : "Нема избришани датотеки",
    "Files and folders you have deleted will show up here" : "Датотеките и папките кои ги имате избришано ќе се појават тука",
    "Deletion cancelled" : "Бришењето е откажано"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
