OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "最后一次报告发送于: {on}",
    "An error occurred while sending your report." : "发送报告时发生了错误。",
    "App list <em>(for each app: name, version, enabled status)</em>" : "应用列表 <em>（对于每个应用：名称、版本、启用状态）</em>",
    "Database environment <em>(type, version, database size)</em>" : "数据库环境<em>（类型，版本，数据库大小）</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "加密信息<em>（是否已启用？哪个是默认的模块）</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "共享量<em>（每个类型和权限设置）</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP 环境<em>（版本，内存限制，最大执行时间，最大文件尺寸）</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "服务器实例详情 <em>（版本、memcache 用量、锁定/预览/头像的状态）</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "统计 <em>(文件数, 用户, 各存储类型, 评论及标签)</em>",
    "Usage survey" : "使用情况调查",
    "Help improve Nextcloud" : "帮助改进 Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "您想通过给我们提供一些关于您的安装及使用情况的匿名数据来帮忙改进 Nextcloud 吗？您可以随时在管理员菜单的设置中关闭它。",
    "Send usage" : "发送使用情况",
    "Not now" : "以后再说",
    "Never" : "永不",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "向 Nextcloud 发送匿名数据帮助改进 Nextcloud。",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "您可以通过发送一些关于您当前安装及使用的数据来帮助我们改进 Nextcloud。",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. To delete the stored usage data, upload an empty report by unchecking all of the boxes then sending a new report." : "我们认真对待你的隐私。默认情况下，发送数据是禁用的，如果你选择打开它，它将首先被匿名化，你可以选择共享哪些内容。收到报告后，上一份报告将被删除。要删除已保存的使用数据，请通过取消选中所有框然后发送新报告来上传空报告。",
    "Send new report now" : "立即发送新报告",
    "Send usage survey monthly" : "按月发送使用情况",
    "Data to send" : "发送数据",
    "Last report sent on: %s" : "最后一次上报发送于: %s",
    "Last report" : "最后上报"
},
"nplurals=1; plural=0;");
